@@ -14,7 +14,25 @@ Classification tools for grids.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Supervised_Image_Classification(GRIDS=None, TRAINING=None, TRAIN_SAMPLES=None, CLASSES=None, QUALITY=None, CLASSES_LUT=None, NORMALISE=None, GRID_SYSTEM=None, TRAIN_WITH=None, TRAINING_CLASS=None, TRAIN_BUFFER=None, FILE_LOAD=None, FILE_SAVE=None, METHOD=None, THRESHOLD_DIST=None, THRESHOLD_ANGLE=None, THRESHOLD_PROB=None, RELATIVE_PROB=None, Verbose=2):
+def Supervised_Image_Classification(
+    GRIDS=None,
+    TRAINING=None,
+    TRAIN_SAMPLES=None,
+    CLASSES=None,
+    QUALITY=None,
+    CLASSES_LUT=None,
+    NORMALISE=None,
+    GRID_SYSTEM=None,
+    TRAIN_WITH=None,
+    TRAINING_CLASS=None,
+    TRAIN_BUFFER=None,
+    FILE_LOAD=None,
+    FILE_SAVE=None,
+    METHOD=None,
+    THRESHOLD_DIST=None,
+    THRESHOLD_ANGLE=None,
+    THRESHOLD_PROB=None,
+    RELATIVE_PROB=None, Verbose=2):
     '''
     Supervised Image Classification
     ----------
@@ -69,7 +87,25 @@ def Supervised_Image_Classification(GRIDS=None, TRAINING=None, TRAIN_SAMPLES=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_classification_0(GRIDS=None, TRAINING=None, TRAIN_SAMPLES=None, CLASSES=None, QUALITY=None, CLASSES_LUT=None, NORMALISE=None, GRID_SYSTEM=None, TRAIN_WITH=None, TRAINING_CLASS=None, TRAIN_BUFFER=None, FILE_LOAD=None, FILE_SAVE=None, METHOD=None, THRESHOLD_DIST=None, THRESHOLD_ANGLE=None, THRESHOLD_PROB=None, RELATIVE_PROB=None, Verbose=2):
+def run_tool_imagery_classification_0(
+    GRIDS=None,
+    TRAINING=None,
+    TRAIN_SAMPLES=None,
+    CLASSES=None,
+    QUALITY=None,
+    CLASSES_LUT=None,
+    NORMALISE=None,
+    GRID_SYSTEM=None,
+    TRAIN_WITH=None,
+    TRAINING_CLASS=None,
+    TRAIN_BUFFER=None,
+    FILE_LOAD=None,
+    FILE_SAVE=None,
+    METHOD=None,
+    THRESHOLD_DIST=None,
+    THRESHOLD_ANGLE=None,
+    THRESHOLD_PROB=None,
+    RELATIVE_PROB=None, Verbose=2):
     '''
     Supervised Image Classification
     ----------
@@ -124,7 +160,16 @@ def run_tool_imagery_classification_0(GRIDS=None, TRAINING=None, TRAIN_SAMPLES=N
         return Tool.Execute(Verbose)
     return False
 
-def KMeans_Clustering_for_Grids(GRIDS=None, CLUSTER=None, STATISTICS=None, METHOD=None, NCLUSTER=None, MAXITER=None, NORMALISE=None, INITIALIZE=None, OLDVERSION=None, Verbose=2):
+def KMeans_Clustering_for_Grids(
+    GRIDS=None,
+    CLUSTER=None,
+    STATISTICS=None,
+    METHOD=None,
+    NCLUSTER=None,
+    MAXITER=None,
+    NORMALISE=None,
+    INITIALIZE=None,
+    OLDVERSION=None, Verbose=2):
     '''
     K-Means Clustering for Grids
     ----------
@@ -161,7 +206,16 @@ def KMeans_Clustering_for_Grids(GRIDS=None, CLUSTER=None, STATISTICS=None, METHO
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_classification_1(GRIDS=None, CLUSTER=None, STATISTICS=None, METHOD=None, NCLUSTER=None, MAXITER=None, NORMALISE=None, INITIALIZE=None, OLDVERSION=None, Verbose=2):
+def run_tool_imagery_classification_1(
+    GRIDS=None,
+    CLUSTER=None,
+    STATISTICS=None,
+    METHOD=None,
+    NCLUSTER=None,
+    MAXITER=None,
+    NORMALISE=None,
+    INITIALIZE=None,
+    OLDVERSION=None, Verbose=2):
     '''
     K-Means Clustering for Grids
     ----------
@@ -198,7 +252,24 @@ def run_tool_imagery_classification_1(GRIDS=None, CLUSTER=None, STATISTICS=None,
         return Tool.Execute(Verbose)
     return False
 
-def Confusion_Matrix_Two_Grids(ONE=None, TWO=None, ONE_LUT=None, TWO_LUT=None, COMBINED=None, CONFUSION=None, CLASSES=None, SUMMARY=None, ONE_LUT_MIN=None, ONE_LUT_MAX=None, ONE_LUT_NAM=None, TWO_LUT_MIN=None, TWO_LUT_MAX=None, TWO_LUT_NAM=None, NOCHANGE=None, NODATA=None, OUTPUT=None, Verbose=2):
+def Confusion_Matrix_Two_Grids(
+    ONE=None,
+    TWO=None,
+    ONE_LUT=None,
+    TWO_LUT=None,
+    COMBINED=None,
+    CONFUSION=None,
+    CLASSES=None,
+    SUMMARY=None,
+    ONE_LUT_MIN=None,
+    ONE_LUT_MAX=None,
+    ONE_LUT_NAM=None,
+    TWO_LUT_MIN=None,
+    TWO_LUT_MAX=None,
+    TWO_LUT_NAM=None,
+    NOCHANGE=None,
+    NODATA=None,
+    OUTPUT=None, Verbose=2):
     '''
     Confusion Matrix (Two Grids)
     ----------
@@ -256,7 +327,24 @@ def Confusion_Matrix_Two_Grids(ONE=None, TWO=None, ONE_LUT=None, TWO_LUT=None, C
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_classification_2(ONE=None, TWO=None, ONE_LUT=None, TWO_LUT=None, COMBINED=None, CONFUSION=None, CLASSES=None, SUMMARY=None, ONE_LUT_MIN=None, ONE_LUT_MAX=None, ONE_LUT_NAM=None, TWO_LUT_MIN=None, TWO_LUT_MAX=None, TWO_LUT_NAM=None, NOCHANGE=None, NODATA=None, OUTPUT=None, Verbose=2):
+def run_tool_imagery_classification_2(
+    ONE=None,
+    TWO=None,
+    ONE_LUT=None,
+    TWO_LUT=None,
+    COMBINED=None,
+    CONFUSION=None,
+    CLASSES=None,
+    SUMMARY=None,
+    ONE_LUT_MIN=None,
+    ONE_LUT_MAX=None,
+    ONE_LUT_NAM=None,
+    TWO_LUT_MIN=None,
+    TWO_LUT_MAX=None,
+    TWO_LUT_NAM=None,
+    NOCHANGE=None,
+    NODATA=None,
+    OUTPUT=None, Verbose=2):
     '''
     Confusion Matrix (Two Grids)
     ----------
@@ -314,7 +402,15 @@ def run_tool_imagery_classification_2(ONE=None, TWO=None, ONE_LUT=None, TWO_LUT=
         return Tool.Execute(Verbose)
     return False
 
-def Decision_Tree(ROOT_GRID=None, CLASSES=None, ROOT_GRID_GRIDSYSTEM=None, ROOT_THRESHOLD=None, ROOT_A_NAME=None, ROOT_A_NODE=None, ROOT_B_NAME=None, ROOT_B_NODE=None, Verbose=2):
+def Decision_Tree(
+    ROOT_GRID=None,
+    CLASSES=None,
+    ROOT_GRID_GRIDSYSTEM=None,
+    ROOT_THRESHOLD=None,
+    ROOT_A_NAME=None,
+    ROOT_A_NODE=None,
+    ROOT_B_NAME=None,
+    ROOT_B_NODE=None, Verbose=2):
     '''
     Decision Tree
     ----------
@@ -349,7 +445,15 @@ def Decision_Tree(ROOT_GRID=None, CLASSES=None, ROOT_GRID_GRIDSYSTEM=None, ROOT_
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_classification_3(ROOT_GRID=None, CLASSES=None, ROOT_GRID_GRIDSYSTEM=None, ROOT_THRESHOLD=None, ROOT_A_NAME=None, ROOT_A_NODE=None, ROOT_B_NAME=None, ROOT_B_NODE=None, Verbose=2):
+def run_tool_imagery_classification_3(
+    ROOT_GRID=None,
+    CLASSES=None,
+    ROOT_GRID_GRIDSYSTEM=None,
+    ROOT_THRESHOLD=None,
+    ROOT_A_NAME=None,
+    ROOT_A_NODE=None,
+    ROOT_B_NAME=None,
+    ROOT_B_NODE=None, Verbose=2):
     '''
     Decision Tree
     ----------
@@ -384,7 +488,19 @@ def run_tool_imagery_classification_3(ROOT_GRID=None, CLASSES=None, ROOT_GRID_GR
         return Tool.Execute(Verbose)
     return False
 
-def Confusion_Matrix_Polygons__Grid(GRID=None, POLYGONS=None, GRID_LUT=None, CONFUSION=None, CLASSES=None, SUMMARY=None, GRID_VALUES=None, GRID_LUT_MIN=None, GRID_LUT_MAX=None, GRID_LUT_NAM=None, FIELD=None, NO_CLASS=None, Verbose=2):
+def Confusion_Matrix_Polygons__Grid(
+    GRID=None,
+    POLYGONS=None,
+    GRID_LUT=None,
+    CONFUSION=None,
+    CLASSES=None,
+    SUMMARY=None,
+    GRID_VALUES=None,
+    GRID_LUT_MIN=None,
+    GRID_LUT_MAX=None,
+    GRID_LUT_NAM=None,
+    FIELD=None,
+    NO_CLASS=None, Verbose=2):
     '''
     Confusion Matrix (Polygons / Grid)
     ----------
@@ -427,7 +543,19 @@ def Confusion_Matrix_Polygons__Grid(GRID=None, POLYGONS=None, GRID_LUT=None, CON
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_classification_6(GRID=None, POLYGONS=None, GRID_LUT=None, CONFUSION=None, CLASSES=None, SUMMARY=None, GRID_VALUES=None, GRID_LUT_MIN=None, GRID_LUT_MAX=None, GRID_LUT_NAM=None, FIELD=None, NO_CLASS=None, Verbose=2):
+def run_tool_imagery_classification_6(
+    GRID=None,
+    POLYGONS=None,
+    GRID_LUT=None,
+    CONFUSION=None,
+    CLASSES=None,
+    SUMMARY=None,
+    GRID_VALUES=None,
+    GRID_LUT_MIN=None,
+    GRID_LUT_MAX=None,
+    GRID_LUT_NAM=None,
+    FIELD=None,
+    NO_CLASS=None, Verbose=2):
     '''
     Confusion Matrix (Polygons / Grid)
     ----------
@@ -470,7 +598,19 @@ def run_tool_imagery_classification_6(GRID=None, POLYGONS=None, GRID_LUT=None, C
         return Tool.Execute(Verbose)
     return False
 
-def Local_Climate_Zone_Classification(FEATURES=None, LCZC=None, LCZC_FILTERED=None, GRID_SYSTEM=None, GRIDDEFILE=None, FILE_TRAINING=None, CLASSIFIER=None, CLASS_DEF_SRC=None, CLASS_DEF_FILE=None, LCZC_FILE=None, FILE_FILTERED_LCZC=None, FILTER_RADIUS=None, Verbose=2):
+def Local_Climate_Zone_Classification(
+    FEATURES=None,
+    LCZC=None,
+    LCZC_FILTERED=None,
+    GRID_SYSTEM=None,
+    GRIDDEFILE=None,
+    FILE_TRAINING=None,
+    CLASSIFIER=None,
+    CLASS_DEF_SRC=None,
+    CLASS_DEF_FILE=None,
+    LCZC_FILE=None,
+    FILE_FILTERED_LCZC=None,
+    FILTER_RADIUS=None, Verbose=2):
     '''
     Local Climate Zone Classification
     ----------
@@ -519,7 +659,19 @@ def Local_Climate_Zone_Classification(FEATURES=None, LCZC=None, LCZC_FILTERED=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_classification_lczc(FEATURES=None, LCZC=None, LCZC_FILTERED=None, GRID_SYSTEM=None, GRIDDEFILE=None, FILE_TRAINING=None, CLASSIFIER=None, CLASS_DEF_SRC=None, CLASS_DEF_FILE=None, LCZC_FILE=None, FILE_FILTERED_LCZC=None, FILTER_RADIUS=None, Verbose=2):
+def run_tool_imagery_classification_lczc(
+    FEATURES=None,
+    LCZC=None,
+    LCZC_FILTERED=None,
+    GRID_SYSTEM=None,
+    GRIDDEFILE=None,
+    FILE_TRAINING=None,
+    CLASSIFIER=None,
+    CLASS_DEF_SRC=None,
+    CLASS_DEF_FILE=None,
+    LCZC_FILE=None,
+    FILE_FILTERED_LCZC=None,
+    FILTER_RADIUS=None, Verbose=2):
     '''
     Local Climate Zone Classification
     ----------
@@ -568,7 +720,30 @@ def run_tool_imagery_classification_lczc(FEATURES=None, LCZC=None, LCZC_FILTERED
         return Tool.Execute(Verbose)
     return False
 
-def Supervised_Majority_Choice_Image_Classification(FEATURES=None, TRAIN_AREAS=None, TRAIN_SAMPLES=None, CLASSES=None, MAJORITY_COUNT=None, NUNIQUES=None, NORMALIZE=None, MODEL_TRAIN=None, TRAIN_CLASS=None, TRAIN_BUFFER=None, GRID_SYSTEM=None, UNAMBIGUOUS=None, CLASSIFY_BOX=None, CLASSIFY_MINDIST=None, CLASSIFY_MAHALONOBIS=None, CLASSIFY_MAXLIKE=None, CLASSIFY_SAM=None, CLASSIFY_BAYES=None, CLASSIFY_DT=None, CLASSIFY_RF=None, CLASSIFY_SVM=None, CLASSIFY_KNN=None, CLASSIFY_ANN=None, Verbose=2):
+def Supervised_Majority_Choice_Image_Classification(
+    FEATURES=None,
+    TRAIN_AREAS=None,
+    TRAIN_SAMPLES=None,
+    CLASSES=None,
+    MAJORITY_COUNT=None,
+    NUNIQUES=None,
+    NORMALIZE=None,
+    MODEL_TRAIN=None,
+    TRAIN_CLASS=None,
+    TRAIN_BUFFER=None,
+    GRID_SYSTEM=None,
+    UNAMBIGUOUS=None,
+    CLASSIFY_BOX=None,
+    CLASSIFY_MINDIST=None,
+    CLASSIFY_MAHALONOBIS=None,
+    CLASSIFY_MAXLIKE=None,
+    CLASSIFY_SAM=None,
+    CLASSIFY_BAYES=None,
+    CLASSIFY_DT=None,
+    CLASSIFY_RF=None,
+    CLASSIFY_SVM=None,
+    CLASSIFY_KNN=None,
+    CLASSIFY_ANN=None, Verbose=2):
     '''
     Supervised Majority Choice Image Classification
     ----------
@@ -636,7 +811,30 @@ def Supervised_Majority_Choice_Image_Classification(FEATURES=None, TRAIN_AREAS=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_classification_classify_majority(FEATURES=None, TRAIN_AREAS=None, TRAIN_SAMPLES=None, CLASSES=None, MAJORITY_COUNT=None, NUNIQUES=None, NORMALIZE=None, MODEL_TRAIN=None, TRAIN_CLASS=None, TRAIN_BUFFER=None, GRID_SYSTEM=None, UNAMBIGUOUS=None, CLASSIFY_BOX=None, CLASSIFY_MINDIST=None, CLASSIFY_MAHALONOBIS=None, CLASSIFY_MAXLIKE=None, CLASSIFY_SAM=None, CLASSIFY_BAYES=None, CLASSIFY_DT=None, CLASSIFY_RF=None, CLASSIFY_SVM=None, CLASSIFY_KNN=None, CLASSIFY_ANN=None, Verbose=2):
+def run_tool_imagery_classification_classify_majority(
+    FEATURES=None,
+    TRAIN_AREAS=None,
+    TRAIN_SAMPLES=None,
+    CLASSES=None,
+    MAJORITY_COUNT=None,
+    NUNIQUES=None,
+    NORMALIZE=None,
+    MODEL_TRAIN=None,
+    TRAIN_CLASS=None,
+    TRAIN_BUFFER=None,
+    GRID_SYSTEM=None,
+    UNAMBIGUOUS=None,
+    CLASSIFY_BOX=None,
+    CLASSIFY_MINDIST=None,
+    CLASSIFY_MAHALONOBIS=None,
+    CLASSIFY_MAXLIKE=None,
+    CLASSIFY_SAM=None,
+    CLASSIFY_BAYES=None,
+    CLASSIFY_DT=None,
+    CLASSIFY_RF=None,
+    CLASSIFY_SVM=None,
+    CLASSIFY_KNN=None,
+    CLASSIFY_ANN=None, Verbose=2):
     '''
     Supervised Majority Choice Image Classification
     ----------
