@@ -616,3 +616,93 @@ def run_tool_io_grid_image_4(
         return Tool.Execute(Verbose)
     return False
 
+def Extract_Image_GPS_Tags(
+    SHAPES=None,
+    CRS_STRING=None,
+    SOURCE=None,
+    FILES=None,
+    DIRECTORY=None,
+    RECURSIVE=None, Verbose=2):
+    '''
+    Extract Image GPS Tags
+    ----------
+    [io_grid_image.5]\n
+    This tool extracts EXIF GPS tags from image files and creates corresponding point features using the Exiv2 library. One can either select individual files or let the tool recursively search entire directories for supported image formats. The output features can be assigned a target coordinate system, and the tool will reproject the GPS coordinates accordingly. The default projection is Web Mercator.The original GPS values are also preserved for reference.\n
+    The following GPS information is currently extracted:\n
+    (-) Latitude\n
+    (-) Longitude\n
+    (-) Altitude\n
+    (-) Direction\n
+    (-) Compass method (Magnetic or True North)\n
+    (-) Dilution of Precision (DOP)\n
+    This tool can also add the point features to a new or the currently active map and display the corresponding images next to each point. To modify the display settings, go to 'Settings > Display > Image Field'.\n
+    Arguments
+    ----------
+    - SHAPES [`output shapes`] : Shape. Shape
+    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
+    - SOURCE [`choice`] : Select From. Available Choices: [0] Files [1] Directory Default: 0
+    - FILES [`file path`] : Set Image Files
+    - DIRECTORY [`file path`] : Set Image Directory
+    - RECURSIVE [`boolean`] : Recursive. Default: 0
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('io_grid_image', '5', 'Extract Image GPS Tags')
+    if Tool.is_Okay():
+        Tool.Set_Output('SHAPES', SHAPES)
+        Tool.Set_Option('CRS_STRING', CRS_STRING)
+        Tool.Set_Option('SOURCE', SOURCE)
+        Tool.Set_Option('FILES', FILES)
+        Tool.Set_Option('DIRECTORY', DIRECTORY)
+        Tool.Set_Option('RECURSIVE', RECURSIVE)
+        return Tool.Execute(Verbose)
+    return False
+
+def run_tool_io_grid_image_5(
+    SHAPES=None,
+    CRS_STRING=None,
+    SOURCE=None,
+    FILES=None,
+    DIRECTORY=None,
+    RECURSIVE=None, Verbose=2):
+    '''
+    Extract Image GPS Tags
+    ----------
+    [io_grid_image.5]\n
+    This tool extracts EXIF GPS tags from image files and creates corresponding point features using the Exiv2 library. One can either select individual files or let the tool recursively search entire directories for supported image formats. The output features can be assigned a target coordinate system, and the tool will reproject the GPS coordinates accordingly. The default projection is Web Mercator.The original GPS values are also preserved for reference.\n
+    The following GPS information is currently extracted:\n
+    (-) Latitude\n
+    (-) Longitude\n
+    (-) Altitude\n
+    (-) Direction\n
+    (-) Compass method (Magnetic or True North)\n
+    (-) Dilution of Precision (DOP)\n
+    This tool can also add the point features to a new or the currently active map and display the corresponding images next to each point. To modify the display settings, go to 'Settings > Display > Image Field'.\n
+    Arguments
+    ----------
+    - SHAPES [`output shapes`] : Shape. Shape
+    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
+    - SOURCE [`choice`] : Select From. Available Choices: [0] Files [1] Directory Default: 0
+    - FILES [`file path`] : Set Image Files
+    - DIRECTORY [`file path`] : Set Image Directory
+    - RECURSIVE [`boolean`] : Recursive. Default: 0
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('io_grid_image', '5', 'Extract Image GPS Tags')
+    if Tool.is_Okay():
+        Tool.Set_Output('SHAPES', SHAPES)
+        Tool.Set_Option('CRS_STRING', CRS_STRING)
+        Tool.Set_Option('SOURCE', SOURCE)
+        Tool.Set_Option('FILES', FILES)
+        Tool.Set_Option('DIRECTORY', DIRECTORY)
+        Tool.Set_Option('RECURSIVE', RECURSIVE)
+        return Tool.Execute(Verbose)
+    return False
+
