@@ -14,7 +14,13 @@ Tools for the import and export of tables.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Export_Text_Table(TABLE=None, HEADLINE=None, STRQUOTA=None, SEPARATOR=None, SEP_OTHER=None, FILENAME=None, Verbose=2):
+def Export_Text_Table(
+    TABLE=None,
+    HEADLINE=None,
+    STRQUOTA=None,
+    SEPARATOR=None,
+    SEP_OTHER=None,
+    FILENAME=None, Verbose=2):
     '''
     Export Text Table
     ----------
@@ -45,7 +51,13 @@ def Export_Text_Table(TABLE=None, HEADLINE=None, STRQUOTA=None, SEPARATOR=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_table_0(TABLE=None, HEADLINE=None, STRQUOTA=None, SEPARATOR=None, SEP_OTHER=None, FILENAME=None, Verbose=2):
+def run_tool_io_table_0(
+    TABLE=None,
+    HEADLINE=None,
+    STRQUOTA=None,
+    SEPARATOR=None,
+    SEP_OTHER=None,
+    FILENAME=None, Verbose=2):
     '''
     Export Text Table
     ----------
@@ -76,7 +88,13 @@ def run_tool_io_table_0(TABLE=None, HEADLINE=None, STRQUOTA=None, SEPARATOR=None
         return Tool.Execute(Verbose)
     return False
 
-def Import_Text_Table(TABLE=None, HEADLINE=None, SEPARATOR=None, ENCODING=None, SEP_OTHER=None, FILENAME=None, Verbose=2):
+def Import_Text_Table(
+    TABLE=None,
+    HEADLINE=None,
+    SEPARATOR=None,
+    ENCODING=None,
+    SEP_OTHER=None,
+    FILENAME=None, Verbose=2):
     '''
     Import Text Table
     ----------
@@ -107,7 +125,13 @@ def Import_Text_Table(TABLE=None, HEADLINE=None, SEPARATOR=None, ENCODING=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_table_1(TABLE=None, HEADLINE=None, SEPARATOR=None, ENCODING=None, SEP_OTHER=None, FILENAME=None, Verbose=2):
+def run_tool_io_table_1(
+    TABLE=None,
+    HEADLINE=None,
+    SEPARATOR=None,
+    ENCODING=None,
+    SEP_OTHER=None,
+    FILENAME=None, Verbose=2):
     '''
     Import Text Table
     ----------
@@ -138,7 +162,13 @@ def run_tool_io_table_1(TABLE=None, HEADLINE=None, SEPARATOR=None, ENCODING=None
         return Tool.Execute(Verbose)
     return False
 
-def Import_Text_Table_with_Numbers_only(TABLES=None, SKIP=None, HEADLINE=None, SEPARATOR=None, SEP_OTHER=None, FILENAME=None, Verbose=2):
+def Import_Text_Table_with_Numbers_only(
+    TABLES=None,
+    SKIP=None,
+    HEADLINE=None,
+    SEPARATOR=None,
+    SEP_OTHER=None,
+    FILENAME=None, Verbose=2):
     '''
     Import Text Table with Numbers only
     ----------
@@ -169,7 +199,13 @@ def Import_Text_Table_with_Numbers_only(TABLES=None, SKIP=None, HEADLINE=None, S
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_table_2(TABLES=None, SKIP=None, HEADLINE=None, SEPARATOR=None, SEP_OTHER=None, FILENAME=None, Verbose=2):
+def run_tool_io_table_2(
+    TABLES=None,
+    SKIP=None,
+    HEADLINE=None,
+    SEPARATOR=None,
+    SEP_OTHER=None,
+    FILENAME=None, Verbose=2):
     '''
     Import Text Table with Numbers only
     ----------
@@ -200,7 +236,12 @@ def run_tool_io_table_2(TABLES=None, SKIP=None, HEADLINE=None, SEPARATOR=None, S
         return Tool.Execute(Verbose)
     return False
 
-def Import_Text_Tables(TABLES=None, FILES=None, HEADLINE=None, SEPARATOR=None, SEP_OTHER=None, Verbose=2):
+def Import_Text_Tables(
+    TABLES=None,
+    FILES=None,
+    HEADLINE=None,
+    SEPARATOR=None,
+    SEP_OTHER=None, Verbose=2):
     '''
     Import Text Tables
     ----------
@@ -229,7 +270,12 @@ def Import_Text_Tables(TABLES=None, FILES=None, HEADLINE=None, SEPARATOR=None, S
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_table_import_text_tables(TABLES=None, FILES=None, HEADLINE=None, SEPARATOR=None, SEP_OTHER=None, Verbose=2):
+def run_tool_io_table_import_text_tables(
+    TABLES=None,
+    FILES=None,
+    HEADLINE=None,
+    SEPARATOR=None,
+    SEP_OTHER=None, Verbose=2):
     '''
     Import Text Tables
     ----------
