@@ -55,7 +55,7 @@ def Rectify_Grid(
     - YFIELD [`table field`] : y Position
     - METHOD [`choice`] : Method. Available Choices: [0] Automatic [1] Triangulation [2] Spline [3] Affine [4] 1st Order Polynomial [5] 2nd Order Polynomial [6] 3rd Order Polynomial [7] Polynomial, Order Default: 0
     - ORDER [`integer number`] : Polynomial Order. Minimum: 1 Default: 3
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - BYTEWISE [`boolean`] : Bytewise Interpolation. Default: 0
     - DATA_TYPE [`data type`] : Data Type. Available Choices: [0] unsigned 1 byte integer [1] signed 1 byte integer [2] unsigned 2 byte integer [3] signed 2 byte integer [4] unsigned 4 byte integer [5] signed 4 byte integer [6] unsigned 8 byte integer [7] signed 8 byte integer [8] 4 byte floating point number [9] 8 byte floating point number [10] Preserve Default: 10
     - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
@@ -146,7 +146,7 @@ def run_tool_pj_georeference_1(
     - YFIELD [`table field`] : y Position
     - METHOD [`choice`] : Method. Available Choices: [0] Automatic [1] Triangulation [2] Spline [3] Affine [4] 1st Order Polynomial [5] 2nd Order Polynomial [6] 3rd Order Polynomial [7] Polynomial, Order Default: 0
     - ORDER [`integer number`] : Polynomial Order. Minimum: 1 Default: 3
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - BYTEWISE [`boolean`] : Bytewise Interpolation. Default: 0
     - DATA_TYPE [`data type`] : Data Type. Available Choices: [0] unsigned 1 byte integer [1] signed 1 byte integer [2] unsigned 2 byte integer [3] signed 2 byte integer [4] unsigned 4 byte integer [5] signed 4 byte integer [6] unsigned 8 byte integer [7] signed 8 byte integer [8] 4 byte floating point number [9] 8 byte floating point number [10] Preserve Default: 10
     - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
@@ -339,7 +339,7 @@ def Direct_Georeferencing_of_Airborne_Photographs(
     - KAPPA_OFF [`floating point number`] : Offset. Default: 90.000000 origin adjustment angle [degree] for kappa (Z axis, heading)
     - ORIENTATION [`choice`] : Orientation. Available Choices: [0] BLUH [1] PATB Default: 0
     - ROW_ORDER [`choice`] : Row Order. Available Choices: [0] top down [1] bottom up Default: 0
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - DATA_TYPE [`data type`] : Data Type. Available Choices: [0] unsigned 1 byte integer [1] signed 1 byte integer [2] unsigned 2 byte integer [3] signed 2 byte integer [4] unsigned 4 byte integer [5] signed 4 byte integer [6] unsigned 8 byte integer [7] signed 8 byte integer [8] 4 byte floating point number [9] 8 byte floating point number [10] same as original Default: 10
     - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
     - TARGET_USER_SIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -451,7 +451,7 @@ def run_tool_pj_georeference_4(
     - KAPPA_OFF [`floating point number`] : Offset. Default: 90.000000 origin adjustment angle [degree] for kappa (Z axis, heading)
     - ORIENTATION [`choice`] : Orientation. Available Choices: [0] BLUH [1] PATB Default: 0
     - ROW_ORDER [`choice`] : Row Order. Available Choices: [0] top down [1] bottom up Default: 0
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - DATA_TYPE [`data type`] : Data Type. Available Choices: [0] unsigned 1 byte integer [1] signed 1 byte integer [2] unsigned 2 byte integer [3] signed 2 byte integer [4] unsigned 4 byte integer [5] signed 4 byte integer [6] unsigned 8 byte integer [7] signed 8 byte integer [8] 4 byte floating point number [9] 8 byte floating point number [10] same as original Default: 10
     - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
     - TARGET_USER_SIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -758,7 +758,7 @@ def Georeference_with_Coordinate_Grids(
     - GRIDS [`input grid list`] : Grids
     - TARGET_TEMPLATE [`optional input grid`] : Target System. use this grid's system for output grids
     - OUTPUT [`output grid list`] : Grids
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - BYTEWISE [`boolean`] : Bytewise Interpolation. Default: 0
     - KEEP_TYPE [`boolean`] : Preserve Data Type. Default: 0
     - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
@@ -834,7 +834,7 @@ def run_tool_pj_georeference_7(
     - GRIDS [`input grid list`] : Grids
     - TARGET_TEMPLATE [`optional input grid`] : Target System. use this grid's system for output grids
     - OUTPUT [`output grid list`] : Grids
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - BYTEWISE [`boolean`] : Bytewise Interpolation. Default: 0
     - KEEP_TYPE [`boolean`] : Preserve Data Type. Default: 0
     - TARGET_DEFINITION [`choice`] : Target Grid System. Available Choices: [0] user defined [1] grid or grid system Default: 0
@@ -919,7 +919,7 @@ def Rectify_Grid_List(
     - YFIELD [`table field`] : y Position
     - METHOD [`choice`] : Method. Available Choices: [0] Automatic [1] Triangulation [2] Spline [3] Affine [4] 1st Order Polynomial [5] 2nd Order Polynomial [6] 3rd Order Polynomial [7] Polynomial, Order Default: 0
     - ORDER [`integer number`] : Polynomial Order. Minimum: 1 Default: 3
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - BYTEWISE [`boolean`] : Bytewise Interpolation. Default: 0
     - DATA_TYPE [`data type`] : Data Type. Available Choices: [0] unsigned 1 byte integer [1] signed 1 byte integer [2] unsigned 2 byte integer [3] signed 2 byte integer [4] unsigned 4 byte integer [5] signed 4 byte integer [6] unsigned 8 byte integer [7] signed 8 byte integer [8] 4 byte floating point number [9] 8 byte floating point number [10] Preserve Default: 10
     - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
@@ -1010,7 +1010,7 @@ def run_tool_pj_georeference_10(
     - YFIELD [`table field`] : y Position
     - METHOD [`choice`] : Method. Available Choices: [0] Automatic [1] Triangulation [2] Spline [3] Affine [4] 1st Order Polynomial [5] 2nd Order Polynomial [6] 3rd Order Polynomial [7] Polynomial, Order Default: 0
     - ORDER [`integer number`] : Polynomial Order. Minimum: 1 Default: 3
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
     - BYTEWISE [`boolean`] : Bytewise Interpolation. Default: 0
     - DATA_TYPE [`data type`] : Data Type. Available Choices: [0] unsigned 1 byte integer [1] signed 1 byte integer [2] unsigned 2 byte integer [3] signed 2 byte integer [4] unsigned 4 byte integer [5] signed 4 byte integer [6] unsigned 8 byte integer [7] signed 8 byte integer [8] 4 byte floating point number [9] 8 byte floating point number [10] Preserve Default: 10
     - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
