@@ -14,7 +14,11 @@ Tools related to gridded and vector data (conversions, combinations, etc.).
 
 from PySAGA.helper import Tool_Wrapper
 
-def Add_Grid_Values_to_Points(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None, Verbose=2):
+def Add_Grid_Values_to_Points(
+    SHAPES=None,
+    GRIDS=None,
+    RESULT=None,
+    RESAMPLING=None, Verbose=2):
     '''
     Add Grid Values to Points
     ----------
@@ -25,7 +29,7 @@ def Add_Grid_Values_to_Points(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=N
     - SHAPES [`input shapes`] : Points
     - GRIDS [`input grid list`] : Grids
     - RESULT [`output shapes`] : Result
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -41,7 +45,11 @@ def Add_Grid_Values_to_Points(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_0(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None, Verbose=2):
+def run_tool_shapes_grid_0(
+    SHAPES=None,
+    GRIDS=None,
+    RESULT=None,
+    RESAMPLING=None, Verbose=2):
     '''
     Add Grid Values to Points
     ----------
@@ -52,7 +60,7 @@ def run_tool_shapes_grid_0(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None
     - SHAPES [`input shapes`] : Points
     - GRIDS [`input grid list`] : Grids
     - RESULT [`output shapes`] : Result
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -68,7 +76,11 @@ def run_tool_shapes_grid_0(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None
         return Tool.Execute(Verbose)
     return False
 
-def Add_Grid_Values_to_Shapes(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None, Verbose=2):
+def Add_Grid_Values_to_Shapes(
+    SHAPES=None,
+    GRIDS=None,
+    RESULT=None,
+    RESAMPLING=None, Verbose=2):
     '''
     Add Grid Values to Shapes
     ----------
@@ -79,7 +91,7 @@ def Add_Grid_Values_to_Shapes(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=N
     - SHAPES [`input shapes`] : Shapes
     - GRIDS [`input grid list`] : Grids
     - RESULT [`output shapes`] : Result
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -95,7 +107,11 @@ def Add_Grid_Values_to_Shapes(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_1(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None, Verbose=2):
+def run_tool_shapes_grid_1(
+    SHAPES=None,
+    GRIDS=None,
+    RESULT=None,
+    RESAMPLING=None, Verbose=2):
     '''
     Add Grid Values to Shapes
     ----------
@@ -106,7 +122,7 @@ def run_tool_shapes_grid_1(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None
     - SHAPES [`input shapes`] : Shapes
     - GRIDS [`input grid list`] : Grids
     - RESULT [`output shapes`] : Result
-    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear Interpolation [2] Bicubic Spline Interpolation [3] B-Spline Interpolation Default: 3
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -122,7 +138,23 @@ def run_tool_shapes_grid_1(SHAPES=None, GRIDS=None, RESULT=None, RESAMPLING=None
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Statistics_for_Polygons(GRIDS=None, POLYGONS=None, RESULT=None, NAMING=None, METHOD=None, PARALLELIZED=None, COUNT=None, MIN=None, MAX=None, RANGE=None, SUM=None, MEAN=None, VAR=None, STDDEV=None, GINI=None, QUANTILES=None, Verbose=2):
+def Grid_Statistics_for_Polygons(
+    GRIDS=None,
+    POLYGONS=None,
+    RESULT=None,
+    NAMING=None,
+    METHOD=None,
+    PARALLELIZED=None,
+    COUNT=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    GINI=None,
+    QUANTILES=None, Verbose=2):
     '''
     Grid Statistics for Polygons
     ----------
@@ -173,7 +205,23 @@ def Grid_Statistics_for_Polygons(GRIDS=None, POLYGONS=None, RESULT=None, NAMING=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_2(GRIDS=None, POLYGONS=None, RESULT=None, NAMING=None, METHOD=None, PARALLELIZED=None, COUNT=None, MIN=None, MAX=None, RANGE=None, SUM=None, MEAN=None, VAR=None, STDDEV=None, GINI=None, QUANTILES=None, Verbose=2):
+def run_tool_shapes_grid_2(
+    GRIDS=None,
+    POLYGONS=None,
+    RESULT=None,
+    NAMING=None,
+    METHOD=None,
+    PARALLELIZED=None,
+    COUNT=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    GINI=None,
+    QUANTILES=None, Verbose=2):
     '''
     Grid Statistics for Polygons
     ----------
@@ -224,7 +272,14 @@ def run_tool_shapes_grid_2(GRIDS=None, POLYGONS=None, RESULT=None, NAMING=None,
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Cells_to_PointsPolygons(GRIDS=None, POLYGONS=None, POINTS=None, CELLS=None, ATTRIBUTE=None, NODATA=None, TYPE=None, Verbose=2):
+def Grid_Cells_to_PointsPolygons(
+    GRIDS=None,
+    POLYGONS=None,
+    POINTS=None,
+    CELLS=None,
+    ATTRIBUTE=None,
+    NODATA=None,
+    TYPE=None, Verbose=2):
     '''
     Grid Cells to Points/Polygons
     ----------
@@ -257,7 +312,14 @@ def Grid_Cells_to_PointsPolygons(GRIDS=None, POLYGONS=None, POINTS=None, CELLS=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_3(GRIDS=None, POLYGONS=None, POINTS=None, CELLS=None, ATTRIBUTE=None, NODATA=None, TYPE=None, Verbose=2):
+def run_tool_shapes_grid_3(
+    GRIDS=None,
+    POLYGONS=None,
+    POINTS=None,
+    CELLS=None,
+    ATTRIBUTE=None,
+    NODATA=None,
+    TYPE=None, Verbose=2):
     '''
     Grid Cells to Points/Polygons
     ----------
@@ -290,7 +352,10 @@ def run_tool_shapes_grid_3(GRIDS=None, POLYGONS=None, POINTS=None, CELLS=None, A
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Values_to_Points_randomly(GRID=None, POINTS=None, FREQ=None, Verbose=2):
+def Grid_Values_to_Points_randomly(
+    GRID=None,
+    POINTS=None,
+    FREQ=None, Verbose=2):
     '''
     Grid Values to Points (randomly)
     ----------
@@ -315,7 +380,10 @@ def Grid_Values_to_Points_randomly(GRID=None, POINTS=None, FREQ=None, Verbose=2)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_4(GRID=None, POINTS=None, FREQ=None, Verbose=2):
+def run_tool_shapes_grid_4(
+    GRID=None,
+    POINTS=None,
+    FREQ=None, Verbose=2):
     '''
     Grid Values to Points (randomly)
     ----------
@@ -340,7 +408,25 @@ def run_tool_shapes_grid_4(GRID=None, POINTS=None, FREQ=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Contour_Lines_from_Grid(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYSTEM=None, VERTEX=None, LINE_OMP=None, LINE_PARTS=None, POLY_OMP=None, POLY_PARTS=None, PRECISION=None, SCALE=None, BOUNDARY=None, MINLENGTH=None, INTERVALS=None, ZMIN=None, ZMAX=None, ZSTEP=None, ZLIST=None, Verbose=2):
+def Contour_Lines_from_Grid(
+    GRID=None,
+    CONTOUR=None,
+    POLYGONS=None,
+    GRID_GRIDSYSTEM=None,
+    VERTEX=None,
+    LINE_OMP=None,
+    LINE_PARTS=None,
+    POLY_OMP=None,
+    POLY_PARTS=None,
+    PRECISION=None,
+    SCALE=None,
+    BOUNDARY=None,
+    MINLENGTH=None,
+    INTERVALS=None,
+    ZMIN=None,
+    ZMAX=None,
+    ZSTEP=None,
+    ZLIST=None, Verbose=2):
     '''
     Contour Lines from Grid
     ----------
@@ -395,7 +481,25 @@ def Contour_Lines_from_Grid(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYS
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_5(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYSTEM=None, VERTEX=None, LINE_OMP=None, LINE_PARTS=None, POLY_OMP=None, POLY_PARTS=None, PRECISION=None, SCALE=None, BOUNDARY=None, MINLENGTH=None, INTERVALS=None, ZMIN=None, ZMAX=None, ZSTEP=None, ZLIST=None, Verbose=2):
+def run_tool_shapes_grid_5(
+    GRID=None,
+    CONTOUR=None,
+    POLYGONS=None,
+    GRID_GRIDSYSTEM=None,
+    VERTEX=None,
+    LINE_OMP=None,
+    LINE_PARTS=None,
+    POLY_OMP=None,
+    POLY_PARTS=None,
+    PRECISION=None,
+    SCALE=None,
+    BOUNDARY=None,
+    MINLENGTH=None,
+    INTERVALS=None,
+    ZMIN=None,
+    ZMAX=None,
+    ZSTEP=None,
+    ZLIST=None, Verbose=2):
     '''
     Contour Lines from Grid
     ----------
@@ -450,7 +554,13 @@ def run_tool_shapes_grid_5(GRID=None, CONTOUR=None, POLYGONS=None, GRID_GRIDSYST
         return Tool.Execute(Verbose)
     return False
 
-def Vectorizing_Grid_Classes(GRID=None, POLYGONS=None, CLASS_ALL=None, CLASS_ID=None, SPLIT=None, ALLVERTICES=None, Verbose=2):
+def Vectorizing_Grid_Classes(
+    GRID=None,
+    POLYGONS=None,
+    CLASS_ALL=None,
+    CLASS_ID=None,
+    SPLIT=None,
+    ALLVERTICES=None, Verbose=2):
     '''
     Vectorizing Grid Classes
     ----------
@@ -481,7 +591,13 @@ def Vectorizing_Grid_Classes(GRID=None, POLYGONS=None, CLASS_ALL=None, CLASS_ID=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_6(GRID=None, POLYGONS=None, CLASS_ALL=None, CLASS_ID=None, SPLIT=None, ALLVERTICES=None, Verbose=2):
+def run_tool_shapes_grid_6(
+    GRID=None,
+    POLYGONS=None,
+    CLASS_ALL=None,
+    CLASS_ID=None,
+    SPLIT=None,
+    ALLVERTICES=None, Verbose=2):
     '''
     Vectorizing Grid Classes
     ----------
@@ -512,7 +628,11 @@ def run_tool_shapes_grid_6(GRID=None, POLYGONS=None, CLASS_ALL=None, CLASS_ID=No
         return Tool.Execute(Verbose)
     return False
 
-def Clip_Grid_with_Polygon(INPUT=None, POLYGONS=None, OUTPUT=None, EXTENT=None, Verbose=2):
+def Clip_Grid_with_Polygon(
+    INPUT=None,
+    POLYGONS=None,
+    OUTPUT=None,
+    EXTENT=None, Verbose=2):
     '''
     Clip Grid with Polygon
     ----------
@@ -539,7 +659,11 @@ def Clip_Grid_with_Polygon(INPUT=None, POLYGONS=None, OUTPUT=None, EXTENT=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_7(INPUT=None, POLYGONS=None, OUTPUT=None, EXTENT=None, Verbose=2):
+def run_tool_shapes_grid_7(
+    INPUT=None,
+    POLYGONS=None,
+    OUTPUT=None,
+    EXTENT=None, Verbose=2):
     '''
     Clip Grid with Polygon
     ----------
@@ -566,7 +690,22 @@ def run_tool_shapes_grid_7(INPUT=None, POLYGONS=None, OUTPUT=None, EXTENT=None,
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Statistics_for_Points(GRIDS=None, POINTS=None, RESULT=None, KERNEL_TYPE=None, KERNEL_SIZE=None, NAMING=None, COUNT=None, MIN=None, MAX=None, RANGE=None, SUM=None, MEAN=None, VAR=None, STDDEV=None, QUANTILE=None, Verbose=2):
+def Grid_Statistics_for_Points(
+    GRIDS=None,
+    POINTS=None,
+    RESULT=None,
+    KERNEL_TYPE=None,
+    KERNEL_SIZE=None,
+    NAMING=None,
+    COUNT=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    QUANTILE=None, Verbose=2):
     '''
     Grid Statistics for Points
     ----------
@@ -615,7 +754,22 @@ def Grid_Statistics_for_Points(GRIDS=None, POINTS=None, RESULT=None, KERNEL_TYPE
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_8(GRIDS=None, POINTS=None, RESULT=None, KERNEL_TYPE=None, KERNEL_SIZE=None, NAMING=None, COUNT=None, MIN=None, MAX=None, RANGE=None, SUM=None, MEAN=None, VAR=None, STDDEV=None, QUANTILE=None, Verbose=2):
+def run_tool_shapes_grid_8(
+    GRIDS=None,
+    POINTS=None,
+    RESULT=None,
+    KERNEL_TYPE=None,
+    KERNEL_SIZE=None,
+    NAMING=None,
+    COUNT=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    QUANTILE=None, Verbose=2):
     '''
     Grid Statistics for Points
     ----------
@@ -664,7 +818,13 @@ def run_tool_shapes_grid_8(GRIDS=None, POINTS=None, RESULT=None, KERNEL_TYPE=Non
         return Tool.Execute(Verbose)
     return False
 
-def Local_Minima_and_Maxima(GRID=None, MINIMA=None, MAXIMA=None, IDENTITY=None, ABSOLUTE=None, BOUNDARY=None, Verbose=2):
+def Local_Minima_and_Maxima(
+    GRID=None,
+    MINIMA=None,
+    MAXIMA=None,
+    IDENTITY=None,
+    ABSOLUTE=None,
+    BOUNDARY=None, Verbose=2):
     '''
     Local Minima and Maxima
     ----------
@@ -695,7 +855,13 @@ def Local_Minima_and_Maxima(GRID=None, MINIMA=None, MAXIMA=None, IDENTITY=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_9(GRID=None, MINIMA=None, MAXIMA=None, IDENTITY=None, ABSOLUTE=None, BOUNDARY=None, Verbose=2):
+def run_tool_shapes_grid_9(
+    GRID=None,
+    MINIMA=None,
+    MAXIMA=None,
+    IDENTITY=None,
+    ABSOLUTE=None,
+    BOUNDARY=None, Verbose=2):
     '''
     Local Minima and Maxima
     ----------
@@ -726,7 +892,11 @@ def run_tool_shapes_grid_9(GRID=None, MINIMA=None, MAXIMA=None, IDENTITY=None, A
         return Tool.Execute(Verbose)
     return False
 
-def Grid_System_Extent(EXTENT=None, GRID_SYSTEM=None, BORDER=None, Verbose=2):
+def Grid_System_Extent(
+    GRID=None,
+    EXTENT=None,
+    GRID_SYSTEM=None,
+    BORDER=None, Verbose=2):
     '''
     Grid System Extent
     ----------
@@ -734,9 +904,10 @@ def Grid_System_Extent(EXTENT=None, GRID_SYSTEM=None, BORDER=None, Verbose=2):
     Creates a polygon (rectangle) from a grid system's extent.\n
     Arguments
     ----------
+    - GRID [`optional input grid`] : Grid. Select a grid for extent's CRS definition.
     - EXTENT [`output shapes`] : Extent
     - GRID_SYSTEM [`grid system`] : Grid System
-    - BORDER [`choice`] : Border. Available Choices: [0] grid cells [1] grid nodes Default: 0
+    - BORDER [`choice`] : Border. Available Choices: [0] cells [1] nodes Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -745,13 +916,18 @@ def Grid_System_Extent(EXTENT=None, GRID_SYSTEM=None, BORDER=None, Verbose=2):
     '''
     Tool = Tool_Wrapper('shapes_grid', '10', 'Grid System Extent')
     if Tool.is_Okay():
+        Tool.Set_Input ('GRID', GRID)
         Tool.Set_Output('EXTENT', EXTENT)
         Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
         Tool.Set_Option('BORDER', BORDER)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_10(EXTENT=None, GRID_SYSTEM=None, BORDER=None, Verbose=2):
+def run_tool_shapes_grid_10(
+    GRID=None,
+    EXTENT=None,
+    GRID_SYSTEM=None,
+    BORDER=None, Verbose=2):
     '''
     Grid System Extent
     ----------
@@ -759,9 +935,10 @@ def run_tool_shapes_grid_10(EXTENT=None, GRID_SYSTEM=None, BORDER=None, Verbose=
     Creates a polygon (rectangle) from a grid system's extent.\n
     Arguments
     ----------
+    - GRID [`optional input grid`] : Grid. Select a grid for extent's CRS definition.
     - EXTENT [`output shapes`] : Extent
     - GRID_SYSTEM [`grid system`] : Grid System
-    - BORDER [`choice`] : Border. Available Choices: [0] grid cells [1] grid nodes Default: 0
+    - BORDER [`choice`] : Border. Available Choices: [0] cells [1] nodes Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -770,13 +947,19 @@ def run_tool_shapes_grid_10(EXTENT=None, GRID_SYSTEM=None, BORDER=None, Verbose=
     '''
     Tool = Tool_Wrapper('shapes_grid', '10', 'Grid System Extent')
     if Tool.is_Okay():
+        Tool.Set_Input ('GRID', GRID)
         Tool.Set_Output('EXTENT', EXTENT)
         Tool.Set_Option('GRID_SYSTEM', GRID_SYSTEM)
         Tool.Set_Option('BORDER', BORDER)
         return Tool.Execute(Verbose)
     return False
 
-def Clip_Grid_with_Rectangle(INPUT=None, SHAPES=None, OUTPUT=None, INPUT_GRIDSYSTEM=None, BORDER=None, Verbose=2):
+def Clip_Grid_with_Rectangle(
+    INPUT=None,
+    SHAPES=None,
+    OUTPUT=None,
+    INPUT_GRIDSYSTEM=None,
+    BORDER=None, Verbose=2):
     '''
     Clip Grid with Rectangle
     ----------
@@ -806,7 +989,12 @@ def Clip_Grid_with_Rectangle(INPUT=None, SHAPES=None, OUTPUT=None, INPUT_GRIDSYS
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_11(INPUT=None, SHAPES=None, OUTPUT=None, INPUT_GRIDSYSTEM=None, BORDER=None, Verbose=2):
+def run_tool_shapes_grid_11(
+    INPUT=None,
+    SHAPES=None,
+    OUTPUT=None,
+    INPUT_GRIDSYSTEM=None,
+    BORDER=None, Verbose=2):
     '''
     Clip Grid with Rectangle
     ----------
@@ -836,7 +1024,13 @@ def run_tool_shapes_grid_11(INPUT=None, SHAPES=None, OUTPUT=None, INPUT_GRIDSYST
         return Tool.Execute(Verbose)
     return False
 
-def Gradient_Vectors_from_Surface(SURFACE=None, VECTORS=None, STEP=None, SIZE=None, AGGR=None, STYLE=None, Verbose=2):
+def Gradient_Vectors_from_Surface(
+    SURFACE=None,
+    VECTORS=None,
+    STEP=None,
+    SIZE=None,
+    AGGR=None,
+    STYLE=None, Verbose=2):
     '''
     Gradient Vectors from Surface
     ----------
@@ -867,7 +1061,13 @@ def Gradient_Vectors_from_Surface(SURFACE=None, VECTORS=None, STEP=None, SIZE=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_15(SURFACE=None, VECTORS=None, STEP=None, SIZE=None, AGGR=None, STYLE=None, Verbose=2):
+def run_tool_shapes_grid_15(
+    SURFACE=None,
+    VECTORS=None,
+    STEP=None,
+    SIZE=None,
+    AGGR=None,
+    STYLE=None, Verbose=2):
     '''
     Gradient Vectors from Surface
     ----------
@@ -898,7 +1098,14 @@ def run_tool_shapes_grid_15(SURFACE=None, VECTORS=None, STEP=None, SIZE=None, AG
         return Tool.Execute(Verbose)
     return False
 
-def Gradient_Vectors_from_Direction_and_Length(DIR=None, LEN=None, VECTORS=None, STEP=None, SIZE=None, AGGR=None, STYLE=None, Verbose=2):
+def Gradient_Vectors_from_Direction_and_Length(
+    DIR=None,
+    LEN=None,
+    VECTORS=None,
+    STEP=None,
+    SIZE=None,
+    AGGR=None,
+    STYLE=None, Verbose=2):
     '''
     Gradient Vectors from Direction and Length
     ----------
@@ -931,7 +1138,14 @@ def Gradient_Vectors_from_Direction_and_Length(DIR=None, LEN=None, VECTORS=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_16(DIR=None, LEN=None, VECTORS=None, STEP=None, SIZE=None, AGGR=None, STYLE=None, Verbose=2):
+def run_tool_shapes_grid_16(
+    DIR=None,
+    LEN=None,
+    VECTORS=None,
+    STEP=None,
+    SIZE=None,
+    AGGR=None,
+    STYLE=None, Verbose=2):
     '''
     Gradient Vectors from Direction and Length
     ----------
@@ -964,7 +1178,14 @@ def run_tool_shapes_grid_16(DIR=None, LEN=None, VECTORS=None, STEP=None, SIZE=No
         return Tool.Execute(Verbose)
     return False
 
-def Gradient_Vectors_from_Directional_Components(X=None, Y=None, VECTORS=None, STEP=None, SIZE=None, AGGR=None, STYLE=None, Verbose=2):
+def Gradient_Vectors_from_Directional_Components(
+    X=None,
+    Y=None,
+    VECTORS=None,
+    STEP=None,
+    SIZE=None,
+    AGGR=None,
+    STYLE=None, Verbose=2):
     '''
     Gradient Vectors from Directional Components
     ----------
@@ -997,7 +1218,14 @@ def Gradient_Vectors_from_Directional_Components(X=None, Y=None, VECTORS=None, S
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_17(X=None, Y=None, VECTORS=None, STEP=None, SIZE=None, AGGR=None, STYLE=None, Verbose=2):
+def run_tool_shapes_grid_17(
+    X=None,
+    Y=None,
+    VECTORS=None,
+    STEP=None,
+    SIZE=None,
+    AGGR=None,
+    STYLE=None, Verbose=2):
     '''
     Gradient Vectors from Directional Components
     ----------
@@ -1030,7 +1258,18 @@ def run_tool_shapes_grid_17(X=None, Y=None, VECTORS=None, STEP=None, SIZE=None,
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Classes_Area_for_Polygons(POLYGONS=None, GRID=None, GRID_LUT=None, RESULT=None, PROCESS=None, METHOD=None, OUTPUT=None, GRID_VALUES=None, GRID_LUT_MIN=None, GRID_LUT_MAX=None, GRID_LUT_NAM=None, Verbose=2):
+def Grid_Classes_Area_for_Polygons(
+    POLYGONS=None,
+    GRID=None,
+    GRID_LUT=None,
+    RESULT=None,
+    PROCESS=None,
+    METHOD=None,
+    OUTPUT=None,
+    GRID_VALUES=None,
+    GRID_LUT_MIN=None,
+    GRID_LUT_MAX=None,
+    GRID_LUT_NAM=None, Verbose=2):
     '''
     Grid Classes Area for Polygons
     ----------
@@ -1039,12 +1278,12 @@ def Grid_Classes_Area_for_Polygons(POLYGONS=None, GRID=None, GRID_LUT=None, RESU
     Arguments
     ----------
     - POLYGONS [`input shapes`] : Polygons
-    - GRID [`input grid`] : Grid
+    - GRID [`input grid`] : Classes
     - GRID_LUT [`optional input table`] : Look-up Table
     - RESULT [`output shapes`] : Result
     - PROCESS [`choice`] : Processing Order. Available Choices: [0] cell by cell [1] polygon by polygon Default: 1 If only a small part of the grid area is covered by polygons, polygon by polygon processing might give an enormous performance boost.
     - METHOD [`choice`] : Cell Area Intersection. Available Choices: [0] cell center [1] cell area Default: 0
-    - OUTPUT [`choice`] : Output Measurment. Available Choices: [0] total area [1] percentage Default: 0
+    - OUTPUT [`choice`] : Output Measurement. Available Choices: [0] total area [1] percentage Default: 0
     - GRID_VALUES [`choice`] : Class Definition. Available Choices: [0] values are class identifiers [1] use look-up table Default: 0
     - GRID_LUT_MIN [`table field`] : Value
     - GRID_LUT_MAX [`table field`] : Value (Maximum)
@@ -1071,7 +1310,18 @@ def Grid_Classes_Area_for_Polygons(POLYGONS=None, GRID=None, GRID_LUT=None, RESU
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_18(POLYGONS=None, GRID=None, GRID_LUT=None, RESULT=None, PROCESS=None, METHOD=None, OUTPUT=None, GRID_VALUES=None, GRID_LUT_MIN=None, GRID_LUT_MAX=None, GRID_LUT_NAM=None, Verbose=2):
+def run_tool_shapes_grid_18(
+    POLYGONS=None,
+    GRID=None,
+    GRID_LUT=None,
+    RESULT=None,
+    PROCESS=None,
+    METHOD=None,
+    OUTPUT=None,
+    GRID_VALUES=None,
+    GRID_LUT_MIN=None,
+    GRID_LUT_MAX=None,
+    GRID_LUT_NAM=None, Verbose=2):
     '''
     Grid Classes Area for Polygons
     ----------
@@ -1080,12 +1330,12 @@ def run_tool_shapes_grid_18(POLYGONS=None, GRID=None, GRID_LUT=None, RESULT=None
     Arguments
     ----------
     - POLYGONS [`input shapes`] : Polygons
-    - GRID [`input grid`] : Grid
+    - GRID [`input grid`] : Classes
     - GRID_LUT [`optional input table`] : Look-up Table
     - RESULT [`output shapes`] : Result
     - PROCESS [`choice`] : Processing Order. Available Choices: [0] cell by cell [1] polygon by polygon Default: 1 If only a small part of the grid area is covered by polygons, polygon by polygon processing might give an enormous performance boost.
     - METHOD [`choice`] : Cell Area Intersection. Available Choices: [0] cell center [1] cell area Default: 0
-    - OUTPUT [`choice`] : Output Measurment. Available Choices: [0] total area [1] percentage Default: 0
+    - OUTPUT [`choice`] : Output Measurement. Available Choices: [0] total area [1] percentage Default: 0
     - GRID_VALUES [`choice`] : Class Definition. Available Choices: [0] values are class identifiers [1] use look-up table Default: 0
     - GRID_LUT_MIN [`table field`] : Value
     - GRID_LUT_MAX [`table field`] : Value (Maximum)
@@ -1112,7 +1362,12 @@ def run_tool_shapes_grid_18(POLYGONS=None, GRID=None, GRID_LUT=None, RESULT=None
         return Tool.Execute(Verbose)
     return False
 
-def Boundary_Cells_to_Polygons(GRID=None, POLYGONS=None, BOUNDARY_CELLS=None, BOUNDARY_VALUE=None, ALLVERTICES=None, Verbose=2):
+def Boundary_Cells_to_Polygons(
+    GRID=None,
+    POLYGONS=None,
+    BOUNDARY_CELLS=None,
+    BOUNDARY_VALUE=None,
+    ALLVERTICES=None, Verbose=2):
     '''
     Boundary Cells to Polygons
     ----------
@@ -1141,7 +1396,12 @@ def Boundary_Cells_to_Polygons(GRID=None, POLYGONS=None, BOUNDARY_CELLS=None, BO
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_19(GRID=None, POLYGONS=None, BOUNDARY_CELLS=None, BOUNDARY_VALUE=None, ALLVERTICES=None, Verbose=2):
+def run_tool_shapes_grid_19(
+    GRID=None,
+    POLYGONS=None,
+    BOUNDARY_CELLS=None,
+    BOUNDARY_VALUE=None,
+    ALLVERTICES=None, Verbose=2):
     '''
     Boundary Cells to Polygons
     ----------
@@ -1170,7 +1430,22 @@ def run_tool_shapes_grid_19(GRID=None, POLYGONS=None, BOUNDARY_CELLS=None, BOUND
         return Tool.Execute(Verbose)
     return False
 
-def Line_Direction(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Line_Direction(
+    INPUT=None,
+    TARGET_TEMPLATE=None,
+    GRID=None,
+    ORDER_FIELD=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Line Direction
     ----------
@@ -1190,6 +1465,7 @@ def Line_Direction(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_FIELD=None
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -1212,12 +1488,28 @@ def Line_Direction(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_FIELD=None
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_20(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_shapes_grid_20(
+    INPUT=None,
+    TARGET_TEMPLATE=None,
+    GRID=None,
+    ORDER_FIELD=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Line Direction
     ----------
@@ -1237,6 +1529,7 @@ def run_tool_shapes_grid_20(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_F
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -1259,12 +1552,86 @@ def run_tool_shapes_grid_20(INPUT=None, TARGET_TEMPLATE=None, GRID=None, ORDER_F
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Values_and_Polygon_Attributes_to_Points(GRID=None, POLYGONS=None, POINTS=None, GRID_GRIDSYSTEM=None, ATTRIBUTE=None, Verbose=2):
+def Collect_Grid_Values_for_Points(
+    GRIDS=None,
+    LOCATIONS=None,
+    VALUES=None,
+    LOCATION=None,
+    RESAMPLING=None, Verbose=2):
+    '''
+    Collect Grid Values for Points
+    ----------
+    [shapes_grid.21]\n
+    Collect values from selected grids for given point locations. If input grid list provides a single grid collection object, its Z-attribute will be included in the resulting table.\n
+    Arguments
+    ----------
+    - GRIDS [`input grid list`] : Grids
+    - LOCATIONS [`input shapes`] : Locations
+    - VALUES [`output table`] : Values
+    - LOCATION [`table field`] : Identifier. If not provided location entries will simply be enumerated.
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('shapes_grid', '21', 'Collect Grid Values for Points')
+    if Tool.is_Okay():
+        Tool.Set_Input ('GRIDS', GRIDS)
+        Tool.Set_Input ('LOCATIONS', LOCATIONS)
+        Tool.Set_Output('VALUES', VALUES)
+        Tool.Set_Option('LOCATION', LOCATION)
+        Tool.Set_Option('RESAMPLING', RESAMPLING)
+        return Tool.Execute(Verbose)
+    return False
+
+def run_tool_shapes_grid_21(
+    GRIDS=None,
+    LOCATIONS=None,
+    VALUES=None,
+    LOCATION=None,
+    RESAMPLING=None, Verbose=2):
+    '''
+    Collect Grid Values for Points
+    ----------
+    [shapes_grid.21]\n
+    Collect values from selected grids for given point locations. If input grid list provides a single grid collection object, its Z-attribute will be included in the resulting table.\n
+    Arguments
+    ----------
+    - GRIDS [`input grid list`] : Grids
+    - LOCATIONS [`input shapes`] : Locations
+    - VALUES [`output table`] : Values
+    - LOCATION [`table field`] : Identifier. If not provided location entries will simply be enumerated.
+    - RESAMPLING [`choice`] : Resampling. Available Choices: [0] Nearest Neighbour [1] Bilinear [2] Cubic 1 [3] Cubic 2 Default: 3
+
+    - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
+    Returns
+    ----------
+    `boolean` : `True` on success, `False` on failure.
+    '''
+    Tool = Tool_Wrapper('shapes_grid', '21', 'Collect Grid Values for Points')
+    if Tool.is_Okay():
+        Tool.Set_Input ('GRIDS', GRIDS)
+        Tool.Set_Input ('LOCATIONS', LOCATIONS)
+        Tool.Set_Output('VALUES', VALUES)
+        Tool.Set_Option('LOCATION', LOCATION)
+        Tool.Set_Option('RESAMPLING', RESAMPLING)
+        return Tool.Execute(Verbose)
+    return False
+
+def Grid_Values_and_Polygon_Attributes_to_Points(
+    GRID=None,
+    POLYGONS=None,
+    POINTS=None,
+    GRID_GRIDSYSTEM=None,
+    ATTRIBUTE=None, Verbose=2):
     '''
     Grid Values and Polygon Attributes to Points
     ----------
@@ -1293,7 +1660,12 @@ def Grid_Values_and_Polygon_Attributes_to_Points(GRID=None, POLYGONS=None, POINT
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_grid_grid_and_polygon_to_points(GRID=None, POLYGONS=None, POINTS=None, GRID_GRIDSYSTEM=None, ATTRIBUTE=None, Verbose=2):
+def run_tool_shapes_grid_grid_and_polygon_to_points(
+    GRID=None,
+    POLYGONS=None,
+    POINTS=None,
+    GRID_GRIDSYSTEM=None,
+    ATTRIBUTE=None, Verbose=2):
     '''
     Grid Values and Polygon Attributes to Points
     ----------
