@@ -1599,7 +1599,7 @@ def Polygon_Generalization(
     Polygon Generalization
     ----------
     [shapes_polygons.23]\n
-    A simple generalization tool for polygons. The tool joins polygons with an area size smaller than the specified threshold to a neighbouring polygon. Either the neighbouring polygon with the largest area or the one with which the largest edge length is shared wins.\n
+    A simple generalization tool for polygons. The tool joins polygons with an area size smaller than the specified threshold to a neighbouring polygon. Either the neighbouring polygon with the largest area or the one with the longest shared edge wins.\n
     Arguments
     ----------
     - POLYGONS [`input shapes`] : Shapes. The input polygons.
@@ -1636,7 +1636,7 @@ def run_tool_shapes_polygons_23(
     Polygon Generalization
     ----------
     [shapes_polygons.23]\n
-    A simple generalization tool for polygons. The tool joins polygons with an area size smaller than the specified threshold to a neighbouring polygon. Either the neighbouring polygon with the largest area or the one with which the largest edge length is shared wins.\n
+    A simple generalization tool for polygons. The tool joins polygons with an area size smaller than the specified threshold to a neighbouring polygon. Either the neighbouring polygon with the largest area or the one with the longest shared edge wins.\n
     Arguments
     ----------
     - POLYGONS [`input shapes`] : Shapes. The input polygons.
