@@ -14,7 +14,56 @@ Modelling erosion processes.
 
 from PySAGA.helper import Tool_Wrapper
 
-def MMFSAGA_Soil_Erosion_Model(DTM=None, S=None, PI=None, CC=None, PH=None, ETEO=None, GC=None, D=None, NV=None, MS=None, BD=None, EHD=None, LP=None, PER_C=None, PER_Z=None, PER_S=None, ST=None, CHANNEL=None, RFR=None, TAB_METEO=None, IF=None, Q=None, SL=None, Rf=None, KE=None, Rc=None, TCC=None, TCZ=None, TCS=None, Gc=None, Gz=None, Gs=None, SLC=None, SLZ=None, SLS=None, TCONDC=None, TCONDZ=None, TCONDS=None, W_UP=None, OUT_PATH=None, INTERFLOW=None, T=None, TIMESPAN=None, R=None, I=None, Rn=None, KE_I_METHOD=None, FLOWD_VA=None, CHANNELTRANSPORT=None, Verbose=2):
+def MMFSAGA_Soil_Erosion_Model(
+    DTM=None,
+    S=None,
+    PI=None,
+    CC=None,
+    PH=None,
+    ETEO=None,
+    GC=None,
+    D=None,
+    NV=None,
+    MS=None,
+    BD=None,
+    EHD=None,
+    LP=None,
+    PER_C=None,
+    PER_Z=None,
+    PER_S=None,
+    ST=None,
+    CHANNEL=None,
+    RFR=None,
+    TAB_METEO=None,
+    IF=None,
+    Q=None,
+    SL=None,
+    Rf=None,
+    KE=None,
+    Rc=None,
+    TCC=None,
+    TCZ=None,
+    TCS=None,
+    Gc=None,
+    Gz=None,
+    Gs=None,
+    SLC=None,
+    SLZ=None,
+    SLS=None,
+    TCONDC=None,
+    TCONDZ=None,
+    TCONDS=None,
+    W_UP=None,
+    OUT_PATH=None,
+    INTERFLOW=None,
+    T=None,
+    TIMESPAN=None,
+    R=None,
+    I=None,
+    Rn=None,
+    KE_I_METHOD=None,
+    FLOWD_VA=None,
+    CHANNELTRANSPORT=None, Verbose=2):
     '''
     MMF-SAGA Soil Erosion Model
     ----------
@@ -136,7 +185,56 @@ def MMFSAGA_Soil_Erosion_Model(DTM=None, S=None, PI=None, CC=None, PH=None, ETEO
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_sim_erosion_0(DTM=None, S=None, PI=None, CC=None, PH=None, ETEO=None, GC=None, D=None, NV=None, MS=None, BD=None, EHD=None, LP=None, PER_C=None, PER_Z=None, PER_S=None, ST=None, CHANNEL=None, RFR=None, TAB_METEO=None, IF=None, Q=None, SL=None, Rf=None, KE=None, Rc=None, TCC=None, TCZ=None, TCS=None, Gc=None, Gz=None, Gs=None, SLC=None, SLZ=None, SLS=None, TCONDC=None, TCONDZ=None, TCONDS=None, W_UP=None, OUT_PATH=None, INTERFLOW=None, T=None, TIMESPAN=None, R=None, I=None, Rn=None, KE_I_METHOD=None, FLOWD_VA=None, CHANNELTRANSPORT=None, Verbose=2):
+def run_tool_sim_erosion_0(
+    DTM=None,
+    S=None,
+    PI=None,
+    CC=None,
+    PH=None,
+    ETEO=None,
+    GC=None,
+    D=None,
+    NV=None,
+    MS=None,
+    BD=None,
+    EHD=None,
+    LP=None,
+    PER_C=None,
+    PER_Z=None,
+    PER_S=None,
+    ST=None,
+    CHANNEL=None,
+    RFR=None,
+    TAB_METEO=None,
+    IF=None,
+    Q=None,
+    SL=None,
+    Rf=None,
+    KE=None,
+    Rc=None,
+    TCC=None,
+    TCZ=None,
+    TCS=None,
+    Gc=None,
+    Gz=None,
+    Gs=None,
+    SLC=None,
+    SLZ=None,
+    SLS=None,
+    TCONDC=None,
+    TCONDZ=None,
+    TCONDS=None,
+    W_UP=None,
+    OUT_PATH=None,
+    INTERFLOW=None,
+    T=None,
+    TIMESPAN=None,
+    R=None,
+    I=None,
+    Rn=None,
+    KE_I_METHOD=None,
+    FLOWD_VA=None,
+    CHANNELTRANSPORT=None, Verbose=2):
     '''
     MMF-SAGA Soil Erosion Model
     ----------
