@@ -14,7 +14,13 @@ Spatial and geostatistical analyses of point data.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Variogram(POINTS=None, RESULT=None, FIELD=None, DISTCOUNT=None, DISTMAX=None, NSKIP=None, Verbose=2):
+def Variogram(
+    POINTS=None,
+    RESULT=None,
+    FIELD=None,
+    DISTCOUNT=None,
+    DISTMAX=None,
+    NSKIP=None, Verbose=2):
     '''
     Variogram
     ----------
@@ -45,7 +51,13 @@ def Variogram(POINTS=None, RESULT=None, FIELD=None, DISTCOUNT=None, DISTMAX=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_points_0(POINTS=None, RESULT=None, FIELD=None, DISTCOUNT=None, DISTMAX=None, NSKIP=None, Verbose=2):
+def run_tool_statistics_points_0(
+    POINTS=None,
+    RESULT=None,
+    FIELD=None,
+    DISTCOUNT=None,
+    DISTMAX=None,
+    NSKIP=None, Verbose=2):
     '''
     Variogram
     ----------
@@ -76,7 +88,12 @@ def run_tool_statistics_points_0(POINTS=None, RESULT=None, FIELD=None, DISTCOUNT
         return Tool.Execute(Verbose)
     return False
 
-def Variogram_Cloud(POINTS=None, RESULT=None, FIELD=None, DISTMAX=None, NSKIP=None, Verbose=2):
+def Variogram_Cloud(
+    POINTS=None,
+    RESULT=None,
+    FIELD=None,
+    DISTMAX=None,
+    NSKIP=None, Verbose=2):
     '''
     Variogram Cloud
     ----------
@@ -105,7 +122,12 @@ def Variogram_Cloud(POINTS=None, RESULT=None, FIELD=None, DISTMAX=None, NSKIP=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_points_1(POINTS=None, RESULT=None, FIELD=None, DISTMAX=None, NSKIP=None, Verbose=2):
+def run_tool_statistics_points_1(
+    POINTS=None,
+    RESULT=None,
+    FIELD=None,
+    DISTMAX=None,
+    NSKIP=None, Verbose=2):
     '''
     Variogram Cloud
     ----------
@@ -134,7 +156,14 @@ def run_tool_statistics_points_1(POINTS=None, RESULT=None, FIELD=None, DISTMAX=N
         return Tool.Execute(Verbose)
     return False
 
-def Variogram_Surface(POINTS=None, COUNT=None, VARIANCE=None, COVARIANCE=None, FIELD=None, DISTCOUNT=None, NSKIP=None, Verbose=2):
+def Variogram_Surface(
+    POINTS=None,
+    COUNT=None,
+    VARIANCE=None,
+    COVARIANCE=None,
+    FIELD=None,
+    DISTCOUNT=None,
+    NSKIP=None, Verbose=2):
     '''
     Variogram Surface
     ----------
@@ -167,7 +196,14 @@ def Variogram_Surface(POINTS=None, COUNT=None, VARIANCE=None, COVARIANCE=None, F
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_points_2(POINTS=None, COUNT=None, VARIANCE=None, COVARIANCE=None, FIELD=None, DISTCOUNT=None, NSKIP=None, Verbose=2):
+def run_tool_statistics_points_2(
+    POINTS=None,
+    COUNT=None,
+    VARIANCE=None,
+    COVARIANCE=None,
+    FIELD=None,
+    DISTCOUNT=None,
+    NSKIP=None, Verbose=2):
     '''
     Variogram Surface
     ----------
@@ -200,7 +236,10 @@ def run_tool_statistics_points_2(POINTS=None, COUNT=None, VARIANCE=None, COVARIA
         return Tool.Execute(Verbose)
     return False
 
-def Minimum_Distance_Analysis(POINTS=None, TABLE=None, DIMENSION=None, Verbose=2):
+def Minimum_Distance_Analysis(
+    POINTS=None,
+    TABLE=None,
+    DIMENSION=None, Verbose=2):
     '''
     Minimum Distance Analysis
     ----------
@@ -225,7 +264,10 @@ def Minimum_Distance_Analysis(POINTS=None, TABLE=None, DIMENSION=None, Verbose=2
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_points_3(POINTS=None, TABLE=None, DIMENSION=None, Verbose=2):
+def run_tool_statistics_points_3(
+    POINTS=None,
+    TABLE=None,
+    DIMENSION=None, Verbose=2):
     '''
     Minimum Distance Analysis
     ----------
@@ -250,7 +292,13 @@ def run_tool_statistics_points_3(POINTS=None, TABLE=None, DIMENSION=None, Verbos
         return Tool.Execute(Verbose)
     return False
 
-def Spatial_Point_Pattern_Analysis(POINTS=None, CENTRE=None, STDDIST=None, BBOX=None, WEIGHT=None, STEP=None, Verbose=2):
+def Spatial_Point_Pattern_Analysis(
+    POINTS=None,
+    CENTRE=None,
+    STDDIST=None,
+    BBOX=None,
+    WEIGHT=None,
+    STEP=None, Verbose=2):
     '''
     Spatial Point Pattern Analysis
     ----------
@@ -281,7 +329,13 @@ def Spatial_Point_Pattern_Analysis(POINTS=None, CENTRE=None, STDDIST=None, BBOX=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_points_4(POINTS=None, CENTRE=None, STDDIST=None, BBOX=None, WEIGHT=None, STEP=None, Verbose=2):
+def run_tool_statistics_points_4(
+    POINTS=None,
+    CENTRE=None,
+    STDDIST=None,
+    BBOX=None,
+    WEIGHT=None,
+    STEP=None, Verbose=2):
     '''
     Spatial Point Pattern Analysis
     ----------
