@@ -14,7 +14,14 @@ Tools for table based analyses and calculations.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Function_Fit(SOURCE=None, YFIELD=None, USE_X=None, XFIELD=None, FORMEL=None, ITER=None, LAMBDA=None, Verbose=2):
+def Function_Fit(
+    SOURCE=None,
+    YFIELD=None,
+    USE_X=None,
+    XFIELD=None,
+    FORMEL=None,
+    ITER=None,
+    LAMBDA=None, Verbose=2):
     '''
     Function Fit
     ----------
@@ -70,7 +77,14 @@ Example: m*x+a
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_0(SOURCE=None, YFIELD=None, USE_X=None, XFIELD=None, FORMEL=None, ITER=None, LAMBDA=None, Verbose=2):
+def run_tool_table_calculus_0(
+    SOURCE=None,
+    YFIELD=None,
+    USE_X=None,
+    XFIELD=None,
+    FORMEL=None,
+    ITER=None,
+    LAMBDA=None, Verbose=2):
     '''
     Function Fit
     ----------
@@ -126,7 +140,15 @@ Example: m*x+a
         return Tool.Execute(Verbose)
     return False
 
-def Field_Calculator(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=None, NAME=None, FORMULA=None, SELECTION=None, USE_NODATA=None, Verbose=2):
+def Field_Calculator(
+    TABLE=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELD=None,
+    NAME=None,
+    FORMULA=None,
+    SELECTION=None,
+    USE_NODATA=None, Verbose=2):
     '''
     Field Calculator
     ----------
@@ -206,7 +228,15 @@ def Field_Calculator(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_1(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=None, NAME=None, FORMULA=None, SELECTION=None, USE_NODATA=None, Verbose=2):
+def run_tool_table_calculus_1(
+    TABLE=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELD=None,
+    NAME=None,
+    FORMULA=None,
+    SELECTION=None,
+    USE_NODATA=None, Verbose=2):
     '''
     Field Calculator
     ----------
@@ -286,7 +316,28 @@ def run_tool_table_calculus_1(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None,
         return Tool.Execute(Verbose)
     return False
 
-def Moving_Statistics(INPUT=None, OUTPUT=None, FIELD=None, INDEX=None, MISSING=None, OFFSET=None, LENGTH=None, MEAN=None, FIELD_MEAN=None, MEDIAN=None, FIELD_MEDIAN=None, MIN=None, FIELD_MIN=None, MAX=None, FIELD_MAX=None, STDV=None, FIELD_STDV=None, STDV_LO=None, FIELD_STDV_LO=None, STDV_HI=None, FIELD_STDV_HI=None, Verbose=2):
+def Moving_Statistics(
+    INPUT=None,
+    OUTPUT=None,
+    FIELD=None,
+    INDEX=None,
+    MISSING=None,
+    OFFSET=None,
+    LENGTH=None,
+    MEAN=None,
+    FIELD_MEAN=None,
+    MEDIAN=None,
+    FIELD_MEDIAN=None,
+    MIN=None,
+    FIELD_MIN=None,
+    MAX=None,
+    FIELD_MAX=None,
+    STDV=None,
+    FIELD_STDV=None,
+    STDV_LO=None,
+    FIELD_STDV_LO=None,
+    STDV_HI=None,
+    FIELD_STDV_HI=None, Verbose=2):
     '''
     Moving Statistics
     ----------
@@ -347,7 +398,28 @@ def Moving_Statistics(INPUT=None, OUTPUT=None, FIELD=None, INDEX=None, MISSING=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_5(INPUT=None, OUTPUT=None, FIELD=None, INDEX=None, MISSING=None, OFFSET=None, LENGTH=None, MEAN=None, FIELD_MEAN=None, MEDIAN=None, FIELD_MEDIAN=None, MIN=None, FIELD_MIN=None, MAX=None, FIELD_MAX=None, STDV=None, FIELD_STDV=None, STDV_LO=None, FIELD_STDV_LO=None, STDV_HI=None, FIELD_STDV_HI=None, Verbose=2):
+def run_tool_table_calculus_5(
+    INPUT=None,
+    OUTPUT=None,
+    FIELD=None,
+    INDEX=None,
+    MISSING=None,
+    OFFSET=None,
+    LENGTH=None,
+    MEAN=None,
+    FIELD_MEAN=None,
+    MEDIAN=None,
+    FIELD_MEDIAN=None,
+    MIN=None,
+    FIELD_MIN=None,
+    MAX=None,
+    FIELD_MAX=None,
+    STDV=None,
+    FIELD_STDV=None,
+    STDV_LO=None,
+    FIELD_STDV_LO=None,
+    STDV_HI=None,
+    FIELD_STDV_HI=None, Verbose=2):
     '''
     Moving Statistics
     ----------
@@ -408,7 +480,11 @@ def run_tool_table_calculus_5(INPUT=None, OUTPUT=None, FIELD=None, INDEX=None, M
         return Tool.Execute(Verbose)
     return False
 
-def Principal_Component_Analysis(TABLE=None, PCA=None, METHOD=None, NFIRST=None, Verbose=2):
+def Principal_Component_Analysis(
+    TABLE=None,
+    PCA=None,
+    METHOD=None,
+    NFIRST=None, Verbose=2):
     '''
     Principal Component Analysis
     ----------
@@ -435,7 +511,11 @@ def Principal_Component_Analysis(TABLE=None, PCA=None, METHOD=None, NFIRST=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_7(TABLE=None, PCA=None, METHOD=None, NFIRST=None, Verbose=2):
+def run_tool_table_calculus_7(
+    TABLE=None,
+    PCA=None,
+    METHOD=None,
+    NFIRST=None, Verbose=2):
     '''
     Principal Component Analysis
     ----------
@@ -462,7 +542,11 @@ def run_tool_table_calculus_7(TABLE=None, PCA=None, METHOD=None, NFIRST=None, Ve
         return Tool.Execute(Verbose)
     return False
 
-def Fill_Gaps_in_Ordered_Records(TABLE=None, NOGAPS=None, ORDER=None, METHOD=None, Verbose=2):
+def Fill_Gaps_in_Ordered_Records(
+    TABLE=None,
+    NOGAPS=None,
+    ORDER=None,
+    METHOD=None, Verbose=2):
     '''
     Fill Gaps in Ordered Records
     ----------
@@ -489,7 +573,11 @@ def Fill_Gaps_in_Ordered_Records(TABLE=None, NOGAPS=None, ORDER=None, METHOD=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_8(TABLE=None, NOGAPS=None, ORDER=None, METHOD=None, Verbose=2):
+def run_tool_table_calculus_8(
+    TABLE=None,
+    NOGAPS=None,
+    ORDER=None,
+    METHOD=None, Verbose=2):
     '''
     Fill Gaps in Ordered Records
     ----------
@@ -516,7 +604,12 @@ def run_tool_table_calculus_8(TABLE=None, NOGAPS=None, ORDER=None, METHOD=None,
         return Tool.Execute(Verbose)
     return False
 
-def Fill_Gaps_in_Records(TABLE=None, NOGAPS=None, ORDER=None, FIELD=None, METHOD=None, Verbose=2):
+def Fill_Gaps_in_Records(
+    TABLE=None,
+    NOGAPS=None,
+    ORDER=None,
+    FIELD=None,
+    METHOD=None, Verbose=2):
     '''
     Fill Gaps in Records
     ----------
@@ -545,7 +638,12 @@ def Fill_Gaps_in_Records(TABLE=None, NOGAPS=None, ORDER=None, FIELD=None, METHOD
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_9(TABLE=None, NOGAPS=None, ORDER=None, FIELD=None, METHOD=None, Verbose=2):
+def run_tool_table_calculus_9(
+    TABLE=None,
+    NOGAPS=None,
+    ORDER=None,
+    FIELD=None,
+    METHOD=None, Verbose=2):
     '''
     Fill Gaps in Records
     ----------
@@ -574,7 +672,14 @@ def run_tool_table_calculus_9(TABLE=None, NOGAPS=None, ORDER=None, FIELD=None, M
         return Tool.Execute(Verbose)
     return False
 
-def Find_Field_of_Extreme_Value(INPUT=None, OUTPUT=None, FIELDS=None, EXTREME_ID=None, EXTREME_VALUE=None, TYPE=None, IDENTIFY=None, Verbose=2):
+def Find_Field_of_Extreme_Value(
+    INPUT=None,
+    OUTPUT=None,
+    FIELDS=None,
+    EXTREME_ID=None,
+    EXTREME_VALUE=None,
+    TYPE=None,
+    IDENTIFY=None, Verbose=2):
     '''
     Find Field of Extreme Value
     ----------
@@ -607,7 +712,14 @@ def Find_Field_of_Extreme_Value(INPUT=None, OUTPUT=None, FIELDS=None, EXTREME_ID
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_11(INPUT=None, OUTPUT=None, FIELDS=None, EXTREME_ID=None, EXTREME_VALUE=None, TYPE=None, IDENTIFY=None, Verbose=2):
+def run_tool_table_calculus_11(
+    INPUT=None,
+    OUTPUT=None,
+    FIELDS=None,
+    EXTREME_ID=None,
+    EXTREME_VALUE=None,
+    TYPE=None,
+    IDENTIFY=None, Verbose=2):
     '''
     Find Field of Extreme Value
     ----------
@@ -640,7 +752,15 @@ def run_tool_table_calculus_11(INPUT=None, OUTPUT=None, FIELDS=None, EXTREME_ID=
         return Tool.Execute(Verbose)
     return False
 
-def Minimum_Redundancy_Feature_Selection(DATA=None, SELECTION=None, CLASS=None, VERBOSE=None, MRMR_NFEATURES=None, MRMR_DISCRETIZE=None, MRMR_THRESHOLD=None, MRMR_METHOD=None, Verbose=2):
+def Minimum_Redundancy_Feature_Selection(
+    DATA=None,
+    SELECTION=None,
+    CLASS=None,
+    VERBOSE=None,
+    MRMR_NFEATURES=None,
+    MRMR_DISCRETIZE=None,
+    MRMR_THRESHOLD=None,
+    MRMR_METHOD=None, Verbose=2):
     '''
     Minimum Redundancy Feature Selection
     ----------
@@ -681,7 +801,15 @@ def Minimum_Redundancy_Feature_Selection(DATA=None, SELECTION=None, CLASS=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_12(DATA=None, SELECTION=None, CLASS=None, VERBOSE=None, MRMR_NFEATURES=None, MRMR_DISCRETIZE=None, MRMR_THRESHOLD=None, MRMR_METHOD=None, Verbose=2):
+def run_tool_table_calculus_12(
+    DATA=None,
+    SELECTION=None,
+    CLASS=None,
+    VERBOSE=None,
+    MRMR_NFEATURES=None,
+    MRMR_DISCRETIZE=None,
+    MRMR_THRESHOLD=None,
+    MRMR_METHOD=None, Verbose=2):
     '''
     Minimum Redundancy Feature Selection
     ----------
@@ -722,7 +850,10 @@ def run_tool_table_calculus_12(DATA=None, SELECTION=None, CLASS=None, VERBOSE=No
         return Tool.Execute(Verbose)
     return False
 
-def Field_Statistics(TABLE=None, STATISTICS=None, FIELDS=None, Verbose=2):
+def Field_Statistics(
+    TABLE=None,
+    STATISTICS=None,
+    FIELDS=None, Verbose=2):
     '''
     Field Statistics
     ----------
@@ -747,7 +878,10 @@ def Field_Statistics(TABLE=None, STATISTICS=None, FIELDS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_15(TABLE=None, STATISTICS=None, FIELDS=None, Verbose=2):
+def run_tool_table_calculus_15(
+    TABLE=None,
+    STATISTICS=None,
+    FIELDS=None, Verbose=2):
     '''
     Field Statistics
     ----------
@@ -772,7 +906,21 @@ def run_tool_table_calculus_15(TABLE=None, STATISTICS=None, FIELDS=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Record_Statistics(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELDS=None, MEAN=None, MIN=None, MAX=None, RANGE=None, SUM=None, NUM=None, VAR=None, STDDEV=None, PCTL=None, PCTL_VAL=None, Verbose=2):
+def Record_Statistics(
+    TABLE=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELDS=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    NUM=None,
+    VAR=None,
+    STDDEV=None,
+    PCTL=None,
+    PCTL_VAL=None, Verbose=2):
     '''
     Record Statistics
     ----------
@@ -819,7 +967,21 @@ def Record_Statistics(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELDS=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_16(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELDS=None, MEAN=None, MIN=None, MAX=None, RANGE=None, SUM=None, NUM=None, VAR=None, STDDEV=None, PCTL=None, PCTL_VAL=None, Verbose=2):
+def run_tool_table_calculus_16(
+    TABLE=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELDS=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    NUM=None,
+    VAR=None,
+    STDDEV=None,
+    PCTL=None,
+    PCTL_VAL=None, Verbose=2):
     '''
     Record Statistics
     ----------
@@ -866,7 +1028,21 @@ def run_tool_table_calculus_16(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None
         return Tool.Execute(Verbose)
     return False
 
-def Aggregate_Values_by_Attributes(TABLE=None, AGGREGATED=None, FIELDS=None, STATISTICS=None, STAT_SUM=None, STAT_AVG=None, STAT_MIN=None, STAT_MAX=None, STAT_RNG=None, STAT_DEV=None, STAT_VAR=None, STAT_LST=None, STAT_NUM=None, STAT_NAMING=None, Verbose=2):
+def Aggregate_Values_by_Attributes(
+    TABLE=None,
+    AGGREGATED=None,
+    FIELDS=None,
+    STATISTICS=None,
+    STAT_SUM=None,
+    STAT_AVG=None,
+    STAT_MIN=None,
+    STAT_MAX=None,
+    STAT_RNG=None,
+    STAT_DEV=None,
+    STAT_VAR=None,
+    STAT_LST=None,
+    STAT_NUM=None,
+    STAT_NAMING=None, Verbose=2):
     '''
     Aggregate Values by Attributes
     ----------
@@ -913,7 +1089,21 @@ def Aggregate_Values_by_Attributes(TABLE=None, AGGREGATED=None, FIELDS=None, STA
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_18(TABLE=None, AGGREGATED=None, FIELDS=None, STATISTICS=None, STAT_SUM=None, STAT_AVG=None, STAT_MIN=None, STAT_MAX=None, STAT_RNG=None, STAT_DEV=None, STAT_VAR=None, STAT_LST=None, STAT_NUM=None, STAT_NAMING=None, Verbose=2):
+def run_tool_table_calculus_18(
+    TABLE=None,
+    AGGREGATED=None,
+    FIELDS=None,
+    STATISTICS=None,
+    STAT_SUM=None,
+    STAT_AVG=None,
+    STAT_MIN=None,
+    STAT_MAX=None,
+    STAT_RNG=None,
+    STAT_DEV=None,
+    STAT_VAR=None,
+    STAT_LST=None,
+    STAT_NUM=None,
+    STAT_NAMING=None, Verbose=2):
     '''
     Aggregate Values by Attributes
     ----------
@@ -960,7 +1150,14 @@ def run_tool_table_calculus_18(TABLE=None, AGGREGATED=None, FIELDS=None, STATIST
         return Tool.Execute(Verbose)
     return False
 
-def Confusion_Matrix_Table_Fields(TABLE=None, CONFUSION=None, CLASSES=None, SUMMARY=None, FIELD_1=None, FIELD_2=None, NODATA=None, Verbose=2):
+def Confusion_Matrix_Table_Fields(
+    TABLE=None,
+    CONFUSION=None,
+    CLASSES=None,
+    SUMMARY=None,
+    FIELD_1=None,
+    FIELD_2=None,
+    NODATA=None, Verbose=2):
     '''
     Confusion Matrix (Table Fields)
     ----------
@@ -993,7 +1190,14 @@ def Confusion_Matrix_Table_Fields(TABLE=None, CONFUSION=None, CLASSES=None, SUMM
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_19(TABLE=None, CONFUSION=None, CLASSES=None, SUMMARY=None, FIELD_1=None, FIELD_2=None, NODATA=None, Verbose=2):
+def run_tool_table_calculus_19(
+    TABLE=None,
+    CONFUSION=None,
+    CLASSES=None,
+    SUMMARY=None,
+    FIELD_1=None,
+    FIELD_2=None,
+    NODATA=None, Verbose=2):
     '''
     Confusion Matrix (Table Fields)
     ----------
@@ -1026,7 +1230,20 @@ def run_tool_table_calculus_19(TABLE=None, CONFUSION=None, CLASSES=None, SUMMARY
         return Tool.Execute(Verbose)
     return False
 
-def Record_Aggregation(INPUT=None, OUTPUT=None, FIELD=None, INDEX=None, IDENTIFIER=None, LENGTH=None, MEAN=None, MEDIAN=None, MIN=None, MAX=None, STDV=None, STDV_LO=None, STDV_HI=None, Verbose=2):
+def Record_Aggregation(
+    INPUT=None,
+    OUTPUT=None,
+    FIELD=None,
+    INDEX=None,
+    IDENTIFIER=None,
+    LENGTH=None,
+    MEAN=None,
+    MEDIAN=None,
+    MIN=None,
+    MAX=None,
+    STDV=None,
+    STDV_LO=None,
+    STDV_HI=None, Verbose=2):
     '''
     Record Aggregation
     ----------
@@ -1071,7 +1288,20 @@ def Record_Aggregation(INPUT=None, OUTPUT=None, FIELD=None, INDEX=None, IDENTIFI
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_calculus_20(INPUT=None, OUTPUT=None, FIELD=None, INDEX=None, IDENTIFIER=None, LENGTH=None, MEAN=None, MEDIAN=None, MIN=None, MAX=None, STDV=None, STDV_LO=None, STDV_HI=None, Verbose=2):
+def run_tool_table_calculus_20(
+    INPUT=None,
+    OUTPUT=None,
+    FIELD=None,
+    INDEX=None,
+    IDENTIFIER=None,
+    LENGTH=None,
+    MEAN=None,
+    MEDIAN=None,
+    MIN=None,
+    MAX=None,
+    STDV=None,
+    STDV_LO=None,
+    STDV_HI=None, Verbose=2):
     '''
     Record Aggregation
     ----------
