@@ -14,7 +14,14 @@ Tools for the creation and manipulation of tables.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Create_New_Table(TABLE=None, NAME=None, NFIELDS=None, FIELDS_NAME0=None, FIELDS_TYPE0=None, FIELDS_NAME1=None, FIELDS_TYPE1=None, Verbose=2):
+def Create_New_Table(
+    TABLE=None,
+    NAME=None,
+    NFIELDS=None,
+    FIELDS_NAME0=None,
+    FIELDS_TYPE0=None,
+    FIELDS_NAME1=None,
+    FIELDS_TYPE1=None, Verbose=2):
     '''
     Create New Table
     ----------
@@ -62,7 +69,14 @@ def Create_New_Table(TABLE=None, NAME=None, NFIELDS=None, FIELDS_NAME0=None, FIE
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_0(TABLE=None, NAME=None, NFIELDS=None, FIELDS_NAME0=None, FIELDS_TYPE0=None, FIELDS_NAME1=None, FIELDS_TYPE1=None, Verbose=2):
+def run_tool_table_tools_0(
+    TABLE=None,
+    NAME=None,
+    NFIELDS=None,
+    FIELDS_NAME0=None,
+    FIELDS_TYPE0=None,
+    FIELDS_NAME1=None,
+    FIELDS_TYPE1=None, Verbose=2):
     '''
     Create New Table
     ----------
@@ -110,7 +124,10 @@ def run_tool_table_tools_0(TABLE=None, NAME=None, NFIELDS=None, FIELDS_NAME0=Non
         return Tool.Execute(Verbose)
     return False
 
-def Transpose_Table(INPUT=None, OUTPUT=None, TYPE=None, Verbose=2):
+def Transpose_Table(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None, Verbose=2):
     '''
     Transpose Table
     ----------
@@ -135,7 +152,10 @@ def Transpose_Table(INPUT=None, OUTPUT=None, TYPE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_1(INPUT=None, OUTPUT=None, TYPE=None, Verbose=2):
+def run_tool_table_tools_1(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None, Verbose=2):
     '''
     Transpose Table
     ----------
@@ -160,20 +180,30 @@ def run_tool_table_tools_1(INPUT=None, OUTPUT=None, TYPE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Field_Enumeration(INPUT=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=None, ENUM=None, NAME=None, ORDER=None, Verbose=2):
+def Field_Enumeration(
+    INPUT=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    RESULT_PC=None,
+    FIELD=None,
+    ENUM=None,
+    NAME=None,
+    ORDER=None, Verbose=2):
     '''
     Field Enumeration
     ----------
     [table_tools.2]\n
     Enumeration of a table attribute, i.e. a unique identifier is assigned to identical values of the chosen attribute field. If no attribute is chosen, a simple enumeration is done for all records, and this with respect to the sorting order if the dataset has been indexed.\n
+    The tool can be used with tables, shapes or point clouds.\n
     Arguments
     ----------
     - INPUT [`input table`] : Input
     - RESULT_TABLE [`output table`] : Result
     - RESULT_SHAPES [`output shapes`] : Result
+    - RESULT_PC [`output point cloud`] : Result
     - FIELD [`table field`] : Attribute
-    - ENUM [`table field`] : Enumeration
-    - NAME [`text`] : Enumeration Field Name. Default: ENUM
+    - ENUM [`table field`] : Enumeration. Field to which the enumeration is written. If not set, a new attribute field is created.
+    - NAME [`text`] : Enumeration Field Name. Default: ENUM The field name of the created attribute. If an attribute is chosen, the name is used as prefix.
     - ORDER [`choice`] : Order. Available Choices: [0] ascending [1] descending Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -186,6 +216,7 @@ def Field_Enumeration(INPUT=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=N
         Tool.Set_Input ('INPUT', INPUT)
         Tool.Set_Output('RESULT_TABLE', RESULT_TABLE)
         Tool.Set_Output('RESULT_SHAPES', RESULT_SHAPES)
+        Tool.Set_Output('RESULT_PC', RESULT_PC)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('ENUM', ENUM)
         Tool.Set_Option('NAME', NAME)
@@ -193,20 +224,30 @@ def Field_Enumeration(INPUT=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_2(INPUT=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=None, ENUM=None, NAME=None, ORDER=None, Verbose=2):
+def run_tool_table_tools_2(
+    INPUT=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    RESULT_PC=None,
+    FIELD=None,
+    ENUM=None,
+    NAME=None,
+    ORDER=None, Verbose=2):
     '''
     Field Enumeration
     ----------
     [table_tools.2]\n
     Enumeration of a table attribute, i.e. a unique identifier is assigned to identical values of the chosen attribute field. If no attribute is chosen, a simple enumeration is done for all records, and this with respect to the sorting order if the dataset has been indexed.\n
+    The tool can be used with tables, shapes or point clouds.\n
     Arguments
     ----------
     - INPUT [`input table`] : Input
     - RESULT_TABLE [`output table`] : Result
     - RESULT_SHAPES [`output shapes`] : Result
+    - RESULT_PC [`output point cloud`] : Result
     - FIELD [`table field`] : Attribute
-    - ENUM [`table field`] : Enumeration
-    - NAME [`text`] : Enumeration Field Name. Default: ENUM
+    - ENUM [`table field`] : Enumeration. Field to which the enumeration is written. If not set, a new attribute field is created.
+    - NAME [`text`] : Enumeration Field Name. Default: ENUM The field name of the created attribute. If an attribute is chosen, the name is used as prefix.
     - ORDER [`choice`] : Order. Available Choices: [0] ascending [1] descending Default: 0
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -219,6 +260,7 @@ def run_tool_table_tools_2(INPUT=None, RESULT_TABLE=None, RESULT_SHAPES=None, FI
         Tool.Set_Input ('INPUT', INPUT)
         Tool.Set_Output('RESULT_TABLE', RESULT_TABLE)
         Tool.Set_Output('RESULT_SHAPES', RESULT_SHAPES)
+        Tool.Set_Output('RESULT_PC', RESULT_PC)
         Tool.Set_Option('FIELD', FIELD)
         Tool.Set_Option('ENUM', ENUM)
         Tool.Set_Option('NAME', NAME)
@@ -226,7 +268,18 @@ def run_tool_table_tools_2(INPUT=None, RESULT_TABLE=None, RESULT_SHAPES=None, FI
         return Tool.Execute(Verbose)
     return False
 
-def Join_Attributes_from_a_Table(TABLE_A=None, TABLE_B=None, UNJOINED=None, RESULT_TABLE=None, RESULT_SHAPES=None, ID_A=None, ID_B=None, FIELDS_ALL=None, FIELDS=None, KEEP_ALL=None, CMP_CASE=None, Verbose=2):
+def Join_Attributes_from_a_Table(
+    TABLE_A=None,
+    TABLE_B=None,
+    UNJOINED=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    ID_A=None,
+    ID_B=None,
+    FIELDS_ALL=None,
+    FIELDS=None,
+    KEEP_ALL=None,
+    CMP_CASE=None, Verbose=2):
     '''
     Join Attributes from a Table
     ----------
@@ -267,7 +320,18 @@ def Join_Attributes_from_a_Table(TABLE_A=None, TABLE_B=None, UNJOINED=None, RESU
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_3(TABLE_A=None, TABLE_B=None, UNJOINED=None, RESULT_TABLE=None, RESULT_SHAPES=None, ID_A=None, ID_B=None, FIELDS_ALL=None, FIELDS=None, KEEP_ALL=None, CMP_CASE=None, Verbose=2):
+def run_tool_table_tools_3(
+    TABLE_A=None,
+    TABLE_B=None,
+    UNJOINED=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    ID_A=None,
+    ID_B=None,
+    FIELDS_ALL=None,
+    FIELDS=None,
+    KEEP_ALL=None,
+    CMP_CASE=None, Verbose=2):
     '''
     Join Attributes from a Table
     ----------
@@ -308,7 +372,14 @@ def run_tool_table_tools_3(TABLE_A=None, TABLE_B=None, UNJOINED=None, RESULT_TAB
         return Tool.Execute(Verbose)
     return False
 
-def Change_Date_Format(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, SEP_IN=None, FMT_OUT=None, SEP_OUT=None, Verbose=2):
+def Change_Date_Format(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    FMT_IN=None,
+    SEP_IN=None,
+    FMT_OUT=None,
+    SEP_OUT=None, Verbose=2):
     '''
     Change Date Format
     ----------
@@ -341,7 +412,14 @@ def Change_Date_Format(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, SEP_IN=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_5(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, SEP_IN=None, FMT_OUT=None, SEP_OUT=None, Verbose=2):
+def run_tool_table_tools_5(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    FMT_IN=None,
+    SEP_IN=None,
+    FMT_OUT=None,
+    SEP_OUT=None, Verbose=2):
     '''
     Change Date Format
     ----------
@@ -374,7 +452,12 @@ def run_tool_table_tools_5(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, SEP
         return Tool.Execute(Verbose)
     return False
 
-def Change_Time_Format(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, FMT_OUT=None, Verbose=2):
+def Change_Time_Format(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    FMT_IN=None,
+    FMT_OUT=None, Verbose=2):
     '''
     Change Time Format
     ----------
@@ -403,7 +486,12 @@ def Change_Time_Format(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, FMT_OUT
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_6(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, FMT_OUT=None, Verbose=2):
+def run_tool_table_tools_6(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    FMT_IN=None,
+    FMT_OUT=None, Verbose=2):
     '''
     Change Time Format
     ----------
@@ -432,7 +520,11 @@ def run_tool_table_tools_6(TABLE=None, OUTPUT=None, FIELD=None, FMT_IN=None, FMT
         return Tool.Execute(Verbose)
     return False
 
-def Change_Field_Type(TABLE=None, OUTPUT=None, FIELD=None, TYPE=None, Verbose=2):
+def Change_Field_Type(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    TYPE=None, Verbose=2):
     '''
     Change Field Type
     ----------
@@ -459,7 +551,11 @@ def Change_Field_Type(TABLE=None, OUTPUT=None, FIELD=None, TYPE=None, Verbose=2)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_7(TABLE=None, OUTPUT=None, FIELD=None, TYPE=None, Verbose=2):
+def run_tool_table_tools_7(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    TYPE=None, Verbose=2):
     '''
     Change Field Type
     ----------
@@ -486,7 +582,10 @@ def run_tool_table_tools_7(TABLE=None, OUTPUT=None, FIELD=None, TYPE=None, Verbo
         return Tool.Execute(Verbose)
     return False
 
-def Append_Fields_from_another_Table(INPUT=None, APPEND=None, OUTPUT=None, Verbose=2):
+def Append_Fields_from_another_Table(
+    INPUT=None,
+    APPEND=None,
+    OUTPUT=None, Verbose=2):
     '''
     Append Fields from another Table
     ----------
@@ -511,7 +610,10 @@ def Append_Fields_from_another_Table(INPUT=None, APPEND=None, OUTPUT=None, Verbo
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_8(INPUT=None, APPEND=None, OUTPUT=None, Verbose=2):
+def run_tool_table_tools_8(
+    INPUT=None,
+    APPEND=None,
+    OUTPUT=None, Verbose=2):
     '''
     Append Fields from another Table
     ----------
@@ -536,7 +638,21 @@ def run_tool_table_tools_8(INPUT=None, APPEND=None, OUTPUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Change_Color_Format(TABLE=None, OUTPUT=None, OUTPUT_SHP=None, OUTPUT_PC=None, FIELD_RGB=None, FIELD_RED=None, FIELD_GREEN=None, FIELD_BLUE=None, MODE=None, ATTR_SUFFIX=None, COLOR_DEPTH=None, NORM=None, NORM_RANGE=None, NORM_STDDEV=None, Verbose=2):
+def Change_Color_Format(
+    TABLE=None,
+    OUTPUT=None,
+    OUTPUT_SHP=None,
+    OUTPUT_PC=None,
+    FIELD_RGB=None,
+    FIELD_RED=None,
+    FIELD_GREEN=None,
+    FIELD_BLUE=None,
+    MODE=None,
+    ATTR_SUFFIX=None,
+    COLOR_DEPTH=None,
+    NORM=None,
+    NORM_RANGE=None,
+    NORM_STDDEV=None, Verbose=2):
     '''
     Change Color Format
     ----------
@@ -583,7 +699,21 @@ def Change_Color_Format(TABLE=None, OUTPUT=None, OUTPUT_SHP=None, OUTPUT_PC=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_9(TABLE=None, OUTPUT=None, OUTPUT_SHP=None, OUTPUT_PC=None, FIELD_RGB=None, FIELD_RED=None, FIELD_GREEN=None, FIELD_BLUE=None, MODE=None, ATTR_SUFFIX=None, COLOR_DEPTH=None, NORM=None, NORM_RANGE=None, NORM_STDDEV=None, Verbose=2):
+def run_tool_table_tools_9(
+    TABLE=None,
+    OUTPUT=None,
+    OUTPUT_SHP=None,
+    OUTPUT_PC=None,
+    FIELD_RGB=None,
+    FIELD_RED=None,
+    FIELD_GREEN=None,
+    FIELD_BLUE=None,
+    MODE=None,
+    ATTR_SUFFIX=None,
+    COLOR_DEPTH=None,
+    NORM=None,
+    NORM_RANGE=None,
+    NORM_STDDEV=None, Verbose=2):
     '''
     Change Color Format
     ----------
@@ -630,7 +760,12 @@ def run_tool_table_tools_9(TABLE=None, OUTPUT=None, OUTPUT_SHP=None, OUTPUT_PC=N
         return Tool.Execute(Verbose)
     return False
 
-def Replace_Text(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELD=None, REPLACE=None, Verbose=2):
+def Replace_Text(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None,
+    FIELD=None,
+    REPLACE=None, Verbose=2):
     '''
     Replace Text
     ----------
@@ -659,7 +794,12 @@ def Replace_Text(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELD=None, REPLAC
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_10(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELD=None, REPLACE=None, Verbose=2):
+def run_tool_table_tools_10(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None,
+    FIELD=None,
+    REPLACE=None, Verbose=2):
     '''
     Replace Text
     ----------
@@ -688,7 +828,11 @@ def run_tool_table_tools_10(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELD=N
         return Tool.Execute(Verbose)
     return False
 
-def Delete_Fields(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELDS=None, Verbose=2):
+def Delete_Fields(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None,
+    FIELDS=None, Verbose=2):
     '''
     Delete Fields
     ----------
@@ -715,7 +859,11 @@ def Delete_Fields(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELDS=None, Verb
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_11(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELDS=None, Verbose=2):
+def run_tool_table_tools_11(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None,
+    FIELDS=None, Verbose=2):
     '''
     Delete Fields
     ----------
@@ -742,7 +890,10 @@ def run_tool_table_tools_11(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELDS=
         return Tool.Execute(Verbose)
     return False
 
-def Copy_Selection(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, Verbose=2):
+def Copy_Selection(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None, Verbose=2):
     '''
     Copy Selection
     ----------
@@ -767,7 +918,10 @@ def Copy_Selection(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_15(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, Verbose=2):
+def run_tool_table_tools_15(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None, Verbose=2):
     '''
     Copy Selection
     ----------
@@ -792,7 +946,8 @@ def run_tool_table_tools_15(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Delete_Selection(INPUT=None, Verbose=2):
+def Delete_Selection(
+    INPUT=None, Verbose=2):
     '''
     Delete Selection
     ----------
@@ -813,7 +968,8 @@ def Delete_Selection(INPUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_16(INPUT=None, Verbose=2):
+def run_tool_table_tools_16(
+    INPUT=None, Verbose=2):
     '''
     Delete Selection
     ----------
@@ -834,7 +990,8 @@ def run_tool_table_tools_16(INPUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Invert_Selection(INPUT=None, Verbose=2):
+def Invert_Selection(
+    INPUT=None, Verbose=2):
     '''
     Invert Selection
     ----------
@@ -855,7 +1012,8 @@ def Invert_Selection(INPUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_17(INPUT=None, Verbose=2):
+def run_tool_table_tools_17(
+    INPUT=None, Verbose=2):
     '''
     Invert Selection
     ----------
@@ -876,7 +1034,15 @@ def run_tool_table_tools_17(INPUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Select_by_Numerical_Expression(TABLE=None, COPY=None, FIELD=None, EXPRESSION=None, INVERSE=None, USE_NODATA=None, METHOD=None, POSTJOB=None, Verbose=2):
+def Select_by_Numerical_Expression(
+    TABLE=None,
+    COPY=None,
+    FIELD=None,
+    EXPRESSION=None,
+    INVERSE=None,
+    USE_NODATA=None,
+    METHOD=None,
+    POSTJOB=None, Verbose=2):
     '''
     Select by Numerical Expression
     ----------
@@ -914,7 +1080,15 @@ def Select_by_Numerical_Expression(TABLE=None, COPY=None, FIELD=None, EXPRESSION
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_18(TABLE=None, COPY=None, FIELD=None, EXPRESSION=None, INVERSE=None, USE_NODATA=None, METHOD=None, POSTJOB=None, Verbose=2):
+def run_tool_table_tools_18(
+    TABLE=None,
+    COPY=None,
+    FIELD=None,
+    EXPRESSION=None,
+    INVERSE=None,
+    USE_NODATA=None,
+    METHOD=None,
+    POSTJOB=None, Verbose=2):
     '''
     Select by Numerical Expression
     ----------
@@ -952,7 +1126,16 @@ def run_tool_table_tools_18(TABLE=None, COPY=None, FIELD=None, EXPRESSION=None,
         return Tool.Execute(Verbose)
     return False
 
-def Select_by_String_Expression(TABLE=None, COPY=None, FIELD=None, EXPRESSION=None, CASE=None, COMPARE=None, INVERSE=None, METHOD=None, POSTJOB=None, Verbose=2):
+def Select_by_String_Expression(
+    TABLE=None,
+    COPY=None,
+    FIELD=None,
+    EXPRESSION=None,
+    CASE=None,
+    COMPARE=None,
+    INVERSE=None,
+    METHOD=None,
+    POSTJOB=None, Verbose=2):
     '''
     Select by String Expression
     ----------
@@ -989,7 +1172,16 @@ def Select_by_String_Expression(TABLE=None, COPY=None, FIELD=None, EXPRESSION=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_19(TABLE=None, COPY=None, FIELD=None, EXPRESSION=None, CASE=None, COMPARE=None, INVERSE=None, METHOD=None, POSTJOB=None, Verbose=2):
+def run_tool_table_tools_19(
+    TABLE=None,
+    COPY=None,
+    FIELD=None,
+    EXPRESSION=None,
+    CASE=None,
+    COMPARE=None,
+    INVERSE=None,
+    METHOD=None,
+    POSTJOB=None, Verbose=2):
     '''
     Select by String Expression
     ----------
@@ -1026,7 +1218,11 @@ def run_tool_table_tools_19(TABLE=None, COPY=None, FIELD=None, EXPRESSION=None,
         return Tool.Execute(Verbose)
     return False
 
-def Add_Indicator_Fields_for_Categories(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELD=None, Verbose=2):
+def Add_Indicator_Fields_for_Categories(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None,
+    FIELD=None, Verbose=2):
     '''
     Add Indicator Fields for Categories
     ----------
@@ -1053,7 +1249,11 @@ def Add_Indicator_Fields_for_Categories(TABLE=None, OUT_TABLE=None, OUT_SHAPES=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_20(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELD=None, Verbose=2):
+def run_tool_table_tools_20(
+    TABLE=None,
+    OUT_TABLE=None,
+    OUT_SHAPES=None,
+    FIELD=None, Verbose=2):
     '''
     Add Indicator Fields for Categories
     ----------
@@ -1080,7 +1280,9 @@ def run_tool_table_tools_20(TABLE=None, OUT_TABLE=None, OUT_SHAPES=None, FIELD=N
         return Tool.Execute(Verbose)
     return False
 
-def Copy_Table(TABLE=None, COPY=None, Verbose=2):
+def Copy_Table(
+    TABLE=None,
+    COPY=None, Verbose=2):
     '''
     Copy Table
     ----------
@@ -1103,7 +1305,9 @@ def Copy_Table(TABLE=None, COPY=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_22(TABLE=None, COPY=None, Verbose=2):
+def run_tool_table_tools_22(
+    TABLE=None,
+    COPY=None, Verbose=2):
     '''
     Copy Table
     ----------
@@ -1126,7 +1330,11 @@ def run_tool_table_tools_22(TABLE=None, COPY=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Change_Field_Name(TABLE=None, OUTPUT=None, FIELD=None, NAME=None, Verbose=2):
+def Change_Field_Name(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    NAME=None, Verbose=2):
     '''
     Change Field Name
     ----------
@@ -1153,7 +1361,11 @@ def Change_Field_Name(TABLE=None, OUTPUT=None, FIELD=None, NAME=None, Verbose=2)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_23(TABLE=None, OUTPUT=None, FIELD=None, NAME=None, Verbose=2):
+def run_tool_table_tools_23(
+    TABLE=None,
+    OUTPUT=None,
+    FIELD=None,
+    NAME=None, Verbose=2):
     '''
     Change Field Name
     ----------
@@ -1180,7 +1392,15 @@ def run_tool_table_tools_23(TABLE=None, OUTPUT=None, FIELD=None, NAME=None, Verb
         return Tool.Execute(Verbose)
     return False
 
-def Formatted_Text(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=None, NAME=None, FORMAT=None, SELECTION=None, USE_NODATA=None, Verbose=2):
+def Formatted_Text(
+    TABLE=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELD=None,
+    NAME=None,
+    FORMAT=None,
+    SELECTION=None,
+    USE_NODATA=None, Verbose=2):
     '''
     Formatted Text
     ----------
@@ -1228,7 +1448,15 @@ def Formatted_Text(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_24(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELD=None, NAME=None, FORMAT=None, SELECTION=None, USE_NODATA=None, Verbose=2):
+def run_tool_table_tools_24(
+    TABLE=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELD=None,
+    NAME=None,
+    FORMAT=None,
+    SELECTION=None,
+    USE_NODATA=None, Verbose=2):
     '''
     Formatted Text
     ----------
@@ -1276,7 +1504,28 @@ def run_tool_table_tools_24(TABLE=None, RESULT_TABLE=None, RESULT_SHAPES=None, F
         return Tool.Execute(Verbose)
     return False
 
-def Supervised_Classification_Table_Fields(TABLE=None, TRAIN_SAMPLES=None, RESULT_TABLE=None, RESULT_SHAPES=None, FEATURES=None, NORMALISE=None, TRAIN_WITH=None, TRAIN_FIELD=None, FILE_LOAD=None, FILE_SAVE=None, METHOD=None, THRESHOLD_DIST=None, THRESHOLD_ANGLE=None, THRESHOLD_PROB=None, RELATIVE_PROB=None, WTA_0=None, WTA_1=None, WTA_2=None, WTA_3=None, WTA_4=None, WTA_5=None, Verbose=2):
+def Supervised_Classification_Table_Fields(
+    TABLE=None,
+    TRAIN_SAMPLES=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FEATURES=None,
+    NORMALISE=None,
+    TRAIN_WITH=None,
+    TRAIN_FIELD=None,
+    FILE_LOAD=None,
+    FILE_SAVE=None,
+    METHOD=None,
+    THRESHOLD_DIST=None,
+    THRESHOLD_ANGLE=None,
+    THRESHOLD_PROB=None,
+    RELATIVE_PROB=None,
+    WTA_0=None,
+    WTA_1=None,
+    WTA_2=None,
+    WTA_3=None,
+    WTA_4=None,
+    WTA_5=None, Verbose=2):
     '''
     Supervised Classification (Table Fields)
     ----------
@@ -1341,7 +1590,28 @@ def Supervised_Classification_Table_Fields(TABLE=None, TRAIN_SAMPLES=None, RESUL
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_26(TABLE=None, TRAIN_SAMPLES=None, RESULT_TABLE=None, RESULT_SHAPES=None, FEATURES=None, NORMALISE=None, TRAIN_WITH=None, TRAIN_FIELD=None, FILE_LOAD=None, FILE_SAVE=None, METHOD=None, THRESHOLD_DIST=None, THRESHOLD_ANGLE=None, THRESHOLD_PROB=None, RELATIVE_PROB=None, WTA_0=None, WTA_1=None, WTA_2=None, WTA_3=None, WTA_4=None, WTA_5=None, Verbose=2):
+def run_tool_table_tools_26(
+    TABLE=None,
+    TRAIN_SAMPLES=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FEATURES=None,
+    NORMALISE=None,
+    TRAIN_WITH=None,
+    TRAIN_FIELD=None,
+    FILE_LOAD=None,
+    FILE_SAVE=None,
+    METHOD=None,
+    THRESHOLD_DIST=None,
+    THRESHOLD_ANGLE=None,
+    THRESHOLD_PROB=None,
+    RELATIVE_PROB=None,
+    WTA_0=None,
+    WTA_1=None,
+    WTA_2=None,
+    WTA_3=None,
+    WTA_4=None,
+    WTA_5=None, Verbose=2):
     '''
     Supervised Classification (Table Fields)
     ----------
@@ -1406,7 +1676,16 @@ def run_tool_table_tools_26(TABLE=None, TRAIN_SAMPLES=None, RESULT_TABLE=None, R
         return Tool.Execute(Verbose)
     return False
 
-def Cluster_Analysis_Table_Fields(INPUT=None, STATISTICS=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELDS=None, NORMALISE=None, CLUSTER=None, METHOD=None, NCLUSTER=None, Verbose=2):
+def Cluster_Analysis_Table_Fields(
+    INPUT=None,
+    STATISTICS=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELDS=None,
+    NORMALISE=None,
+    CLUSTER=None,
+    METHOD=None,
+    NCLUSTER=None, Verbose=2):
     '''
     Cluster Analysis (Table Fields)
     ----------
@@ -1443,7 +1722,16 @@ def Cluster_Analysis_Table_Fields(INPUT=None, STATISTICS=None, RESULT_TABLE=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_table_tools_28(INPUT=None, STATISTICS=None, RESULT_TABLE=None, RESULT_SHAPES=None, FIELDS=None, NORMALISE=None, CLUSTER=None, METHOD=None, NCLUSTER=None, Verbose=2):
+def run_tool_table_tools_28(
+    INPUT=None,
+    STATISTICS=None,
+    RESULT_TABLE=None,
+    RESULT_SHAPES=None,
+    FIELDS=None,
+    NORMALISE=None,
+    CLUSTER=None,
+    METHOD=None,
+    NCLUSTER=None, Verbose=2):
     '''
     Cluster Analysis (Table Fields)
     ----------
