@@ -19,7 +19,16 @@ Description
 
 from PySAGA.helper import Tool_Wrapper
 
-def Land_Cover_Scenario_Offset(ROAD_LINES=None, DEM=None, VEGETATION=None, CHANNEL_LINES=None, LANDCOVER=None, ROAD_CLASS=None, CHANNEL_ORDER=None, DEM_SYSTEM=None, LANDCOVER_SYSTEM=None, Verbose=2):
+def Land_Cover_Scenario_Offset(
+    ROAD_LINES=None,
+    DEM=None,
+    VEGETATION=None,
+    CHANNEL_LINES=None,
+    LANDCOVER=None,
+    ROAD_CLASS=None,
+    CHANNEL_ORDER=None,
+    DEM_SYSTEM=None,
+    LANDCOVER_SYSTEM=None, Verbose=2):
     '''
     Land Cover Scenario Offset
     ----------
@@ -59,7 +68,16 @@ def Land_Cover_Scenario_Offset(ROAD_LINES=None, DEM=None, VEGETATION=None, CHANN
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_tta_tools_tta_LandCover(ROAD_LINES=None, DEM=None, VEGETATION=None, CHANNEL_LINES=None, LANDCOVER=None, ROAD_CLASS=None, CHANNEL_ORDER=None, DEM_SYSTEM=None, LANDCOVER_SYSTEM=None, Verbose=2):
+def run_tool_tta_tools_tta_LandCover(
+    ROAD_LINES=None,
+    DEM=None,
+    VEGETATION=None,
+    CHANNEL_LINES=None,
+    LANDCOVER=None,
+    ROAD_CLASS=None,
+    CHANNEL_ORDER=None,
+    DEM_SYSTEM=None,
+    LANDCOVER_SYSTEM=None, Verbose=2):
     '''
     Land Cover Scenario Offset
     ----------
@@ -99,7 +117,15 @@ def run_tool_tta_tools_tta_LandCover(ROAD_LINES=None, DEM=None, VEGETATION=None,
         return Tool.Execute(Verbose)
     return False
 
-def Travel_Time_Calculation(DESTINATIONS=None, LANDCOVER=None, LANDCOVER_TO_TRAVELTIME=None, TRAVELTIME_LUT=None, TRAVELTIME_MINUTES=None, GRID_SYSTEM=None, FIELD_LANDCOVER=None, FIELD_TRAVELTIME=None, Verbose=2):
+def Travel_Time_Calculation(
+    DESTINATIONS=None,
+    LANDCOVER=None,
+    LANDCOVER_TO_TRAVELTIME=None,
+    TRAVELTIME_LUT=None,
+    TRAVELTIME_MINUTES=None,
+    GRID_SYSTEM=None,
+    FIELD_LANDCOVER=None,
+    FIELD_TRAVELTIME=None, Verbose=2):
     '''
     Travel Time Calculation
     ----------
@@ -136,7 +162,15 @@ def Travel_Time_Calculation(DESTINATIONS=None, LANDCOVER=None, LANDCOVER_TO_TRAV
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_tta_tools_tta_TravelTime(DESTINATIONS=None, LANDCOVER=None, LANDCOVER_TO_TRAVELTIME=None, TRAVELTIME_LUT=None, TRAVELTIME_MINUTES=None, GRID_SYSTEM=None, FIELD_LANDCOVER=None, FIELD_TRAVELTIME=None, Verbose=2):
+def run_tool_tta_tools_tta_TravelTime(
+    DESTINATIONS=None,
+    LANDCOVER=None,
+    LANDCOVER_TO_TRAVELTIME=None,
+    TRAVELTIME_LUT=None,
+    TRAVELTIME_MINUTES=None,
+    GRID_SYSTEM=None,
+    FIELD_LANDCOVER=None,
+    FIELD_TRAVELTIME=None, Verbose=2):
     '''
     Travel Time Calculation
     ----------
