@@ -58,9 +58,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -125,9 +125,9 @@ void	SG_UI_Console_Print_StdErr(const CSG_String &Text, SG_Char End, bool bFlush
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -149,9 +149,9 @@ TSG_PFNC_UI_Callback	SG_Get_UI_Callback(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 CSG_UI_Parameter::CSG_UI_Parameter(const CSG_UI_Parameter &Copy)
@@ -164,9 +164,9 @@ CSG_UI_Parameter::CSG_UI_Parameter(const CSG_UI_Parameter &Copy)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -339,9 +339,9 @@ void		SG_UI_Process_Set_Text(const CSG_String &Text)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -359,9 +359,9 @@ bool		SG_UI_Stop_Execution(bool bDialog)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -422,26 +422,23 @@ int			SG_UI_Dlg_Error(const CSG_String &Message, const CSG_String &Caption)
 //---------------------------------------------------------
 void		SG_UI_Dlg_Info(const CSG_String &Message, const CSG_String &Caption)
 {
-	if( gSG_UI_Progress_Lock == 0 )
+	if( gSG_UI_Callback )
 	{
-		if( gSG_UI_Callback )
-		{
-			CSG_UI_Parameter p1(Message), p2(Caption);
+		CSG_UI_Parameter p1(Message), p2(Caption);
 
-			gSG_UI_Callback(CALLBACK_DLG_INFO, p1, p2);
-		}
-		else
-		{
-			SG_UI_Console_Print_StdOut(CSG_String::Format("%s: %s", Caption.c_str(), Message.c_str()), '\n', true);
-		}
+		gSG_UI_Callback(CALLBACK_DLG_INFO, p1, p2);
+	}
+	else
+	{
+		SG_UI_Console_Print_StdOut(CSG_String::Format("%s: %s", Caption.c_str(), Message.c_str()), '\n', true);
 	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -459,9 +456,9 @@ bool		SG_UI_Dlg_Parameters(CSG_Parameters *pParameters, const CSG_String &Captio
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -580,9 +577,9 @@ void		SG_UI_Msg_Flush(void)
 }
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -601,9 +598,9 @@ void		SG_UI_ProgressAndMsg_Reset	(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -705,6 +702,19 @@ bool		SG_UI_DataObject_Colors_Set(CSG_Data_Object *pDataObject, CSG_Colors *pCol
 	return( false );
 }
 
+//---------------------------------------------------------
+bool		SG_UI_DataObject_Classify(CSG_Data_Object *pDataObject, const CSG_MetaData &Options)
+{
+	if( gSG_UI_Progress_Lock == 0 && gSG_UI_Callback && pDataObject )
+	{
+		CSG_UI_Parameter p1(pDataObject), p2((void *)&Options);
+
+		return( gSG_UI_Callback(CALLBACK_DATAOBJECT_CLASSIFY, p1, p2) != 0 );
+	}
+
+	return( false );
+}
+
 //---------------------------------------------------------
 bool		SG_UI_DataObject_Params_Get	(CSG_Data_Object *pDataObject, CSG_Parameters *pParameters)
 {
@@ -772,9 +782,9 @@ bool		SG_UI_ODBC_Update			(const CSG_String &Server)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -809,9 +819,9 @@ void *		SG_UI_Get_Window_Main		(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
