@@ -171,8 +171,7 @@ CSG_String	SG_Color_To_Text	(long Color, bool bHexadecimal)
 //---------------------------------------------------------
 CSG_Colors::CSG_Colors(void)
 {
-	m_Colors	= NULL;
-	m_nColors	= 0;
+	m_Colors = NULL; m_nColors = 0;
 
 	Create();
 }
@@ -180,8 +179,7 @@ CSG_Colors::CSG_Colors(void)
 //---------------------------------------------------------
 CSG_Colors::CSG_Colors(const CSG_Colors &Colors)
 {
-	m_Colors	= NULL;
-	m_nColors	= 0;
+	m_Colors = NULL; m_nColors = 0;
 
 	Create(Colors);
 }
@@ -189,12 +187,19 @@ CSG_Colors::CSG_Colors(const CSG_Colors &Colors)
 //---------------------------------------------------------
 CSG_Colors::CSG_Colors(int nColors, int Palette, bool bRevert)
 {
-	m_Colors	= NULL;
-	m_nColors	= 0;
+	m_Colors = NULL; m_nColors = 0;
 
 	Create(nColors, Palette, bRevert);
 }
 
+//---------------------------------------------------------
+CSG_Colors::CSG_Colors(const CSG_String &Palette, int nColors, bool bRevert)
+{
+	m_Colors = NULL; m_nColors = 0;
+
+	Create(Palette, nColors, bRevert);
+}
+
 //---------------------------------------------------------
 CSG_Colors::~CSG_Colors(void)
 {
@@ -217,8 +222,8 @@ bool CSG_Colors::Create(const CSG_Colors &Colors)
 {
 	if( Colors.m_nColors > 0 )
 	{
-		m_nColors	= Colors.m_nColors;
-		m_Colors	= (long *)SG_Realloc(m_Colors, m_nColors * sizeof(long));
+		m_nColors = Colors.m_nColors;
+		m_Colors  = (long *)SG_Realloc(m_Colors, m_nColors * sizeof(long));
 
 		memcpy(m_Colors, Colors.m_Colors, m_nColors * sizeof(long));
 
@@ -231,16 +236,13 @@ bool CSG_Colors::Create(const CSG_Colors &Colors)
 //---------------------------------------------------------
 bool CSG_Colors::Create(int nColors, int Palette, bool bRevert)
 {
-	if( nColors <= 1 )
-	{
-		nColors	= 11;
-	}
+	return( Set_Palette(Palette, bRevert, nColors) || Set_Palette(SG_COLORS_DEFAULT, bRevert, nColors) );
+}
 
-	Set_Count(nColors);
-
-	Set_Palette(Palette, bRevert, nColors);
-
-	return( true );
+//---------------------------------------------------------
+bool CSG_Colors::Create(const CSG_String &Palette, int nColors, bool bRevert)
+{
+	return( Set_Palette(Palette, bRevert, nColors) || Set_Palette(SG_COLORS_DEFAULT, bRevert, nColors) );
 }
 
 //---------------------------------------------------------
@@ -250,8 +252,7 @@ void CSG_Colors::Destroy(void)
 	{
 		SG_Free(m_Colors);
 
-		m_Colors	= NULL;
-		m_nColors	= 0;
+		m_Colors = NULL; m_nColors = 0;
 	}
 }
 
@@ -281,10 +282,10 @@ bool CSG_Colors::Set_Count(int nColors)
 	//-----------------------------------------------------
 	CSG_Colors	Colors(*this);
 
-	m_nColors	= nColors;
-	m_Colors	= (long *)SG_Realloc(m_Colors, m_nColors * sizeof(long));
+	m_nColors = nColors;
+	m_Colors  = (long *)SG_Realloc(m_Colors, m_nColors * sizeof(long));
 
-	double	dStep	= Get_Count() > 1 ? (Colors.Get_Count() - 1.0) / (Get_Count() - 1.0) : 0.0;
+	double dStep = Get_Count() > 1 ? (Colors.Get_Count() - 1.0) / (Get_Count() - 1.0) : 0.0;
 
 	for(int i=0; i<Get_Count(); i++)
 	{
@@ -438,9 +439,9 @@ int CSG_Colors::Get_Predefined_Count(void)
 }
 
 //---------------------------------------------------------
-CSG_String CSG_Colors::Get_Predefined_Name(int Index)
+CSG_String CSG_Colors::Get_Predefined_Name(int Index, bool bWithIndex)
 {
-	#define MAKE_NAME(name) CSG_String::Format("[%d] %s", Index, name)
+	#define MAKE_NAME(name) (bWithIndex ? CSG_String::Format("[%d] %s", Index, name) : CSG_String(name))
 
 	switch( Index )
 	{
@@ -458,6 +459,10 @@ CSG_String CSG_Colors::Get_Predefined_Name(int Index)
 	case SG_COLORS_WHITE_GREEN      : return( MAKE_NAME(_TL("white-green"      )) );
 	case SG_COLORS_WHITE_BLUE       : return( MAKE_NAME(_TL("white-blue"       )) );
 
+	case SG_COLORS_CYAN_WHITE       : return( MAKE_NAME(_TL("cyan-white"       )) );
+	case SG_COLORS_MAGENTA_WHITE    : return( MAKE_NAME(_TL("magenta-white"    )) );
+	case SG_COLORS_YELLOW_WHITE     : return( MAKE_NAME(_TL("yellow-white"     )) );
+
 	case SG_COLORS_YELLOW_RED       : return( MAKE_NAME(_TL("yellow-red"       )) );
 	case SG_COLORS_YELLOW_GREEN     : return( MAKE_NAME(_TL("yellow-green"     )) );
 	case SG_COLORS_YELLOW_BLUE      : return( MAKE_NAME(_TL("yellow-blue"      )) );
@@ -589,6 +594,25 @@ bool CSG_Colors::Set_Predefined(int Index, bool bRevert, int nColors)
 		Set_Color(2, SG_GET_RGB(  0,   0, 159));
 		break;
 
+	//-----------------------------------------------------
+	case SG_COLORS_CYAN_WHITE:
+		Set_Count(2);
+		Set_Color(0, SG_GET_RGB(  0, 255, 255));
+		Set_Color(1, SG_GET_RGB(255, 255, 255));
+		break;
+
+	case SG_COLORS_MAGENTA_WHITE:
+		Set_Count(2);
+		Set_Color(0, SG_GET_RGB(255,   0, 255));
+		Set_Color(1, SG_GET_RGB(255, 255, 255));
+		break;
+
+	case SG_COLORS_YELLOW_WHITE:
+		Set_Count(2);
+		Set_Color(0, SG_GET_RGB(255, 255,   0));
+		Set_Color(1, SG_GET_RGB(255, 255, 255));
+		break;
+
 	//-----------------------------------------------------
 	case SG_COLORS_YELLOW_RED:
 		Set_Count(3);
@@ -1000,6 +1024,27 @@ bool CSG_Colors::Set_Predefined(int Index, bool bRevert, int nColors)
 	return( true );
 }
 
+//---------------------------------------------------------
+bool CSG_Colors::Set_Predefined(const CSG_String &Name, bool bRevert, int nColors)
+{
+	int Index;
+
+	for(int Index=0; Index<SG_COLORS_COUNT; Index++)
+	{
+		if( Name.Cmp(Get_Predefined_Name(Index, false)) == 0 )
+		{
+			return( Set_Predefined(Index, bRevert, nColors) );
+		}
+	}
+
+	if( Name.asInt(Index) )
+	{
+		return( Set_Predefined(Index, bRevert, nColors) );
+	}
+
+	return( false );
+}
+
 //---------------------------------------------------------
 bool CSG_Colors::Set_Default(int nColors)
 {
