@@ -1340,6 +1340,10 @@ enum ESG_Colors
 	SG_COLORS_WHITE_GREEN,
 	SG_COLORS_WHITE_BLUE,
 
+	SG_COLORS_CYAN_WHITE,
+	SG_COLORS_MAGENTA_WHITE,
+	SG_COLORS_YELLOW_WHITE,
+
 	SG_COLORS_YELLOW_RED,
 	SG_COLORS_YELLOW_GREEN,
 	SG_COLORS_YELLOW_BLUE,
@@ -1416,6 +1420,9 @@ public:
 									CSG_Colors			(int nColors, int Palette = SG_COLORS_DEFAULT, bool bRevert = false);
 	bool							Create				(int nColors, int Palette = SG_COLORS_DEFAULT, bool bRevert = false);
 
+									CSG_Colors			(const CSG_String &Palette, int nColors = 0, bool bRevert = false);
+	bool							Create				(const CSG_String &Palette, int nColors = 0, bool bRevert = false);
+
 	virtual ~CSG_Colors(void);
 
 	void							Destroy				(void);
@@ -1454,9 +1461,11 @@ public:
 	}
 
 	static int						Get_Predefined_Count(void);
-	static CSG_String				Get_Predefined_Name	(int Identifier);
-	bool							Set_Predefined		(int Index, bool bRevert = false, int nColors = 0);
-	bool							Set_Palette			(int Index, bool bRevert = false, int nColors = 0)	{	return( Set_Predefined(Index, bRevert, nColors) );	}
+	static CSG_String				Get_Predefined_Name	(int Index, bool bWithIndex = true);
+	bool							Set_Predefined		(int Index             , bool bRevert = false, int nColors = 0);
+	bool							Set_Predefined		(const CSG_String &Name, bool bRevert = false, int nColors = 0);
+	bool							Set_Palette			(int Index             , bool bRevert = false, int nColors = 0)	{	return( Set_Predefined(Index, bRevert, nColors) );	}
+	bool							Set_Palette			(const CSG_String &Name, bool bRevert = false, int nColors = 0)	{	return( Set_Predefined(Name, bRevert, nColors) );	}
 	bool							Set_Default			(int nColors = 11);
 	bool							Set_Ramp			(long Color_A, long Color_B);
 	bool							Set_Ramp			(long Color_A, long Color_B, int iColor_A, int iColor_B);
