@@ -55,9 +55,10 @@
 #include <wx/dir.h>
 #include <wx/wxcrtvararg.h>
 #include <wx/wfstream.h>
+#include <wx/txtstrm.h>
 #include <wx/zipstrm.h>
 #include <wx/tarstrm.h>
-#include <wx/txtstrm.h>
+#include <wx/zstream.h>
 #include <wx/log.h>
 #include <wx/version.h>
 
@@ -385,9 +386,13 @@ size_t CSG_File::Write(const CSG_String &Buffer) const
 		return( Write((void *)s.data(), sizeof(char), s.length()) );
 	}
 
-	CSG_Buffer s(Buffer.to_ASCII()); // returns NULL terminated char sequence, Get_Size() count includes terminating NULL!!!
+	CSG_String s(Buffer);
 
-	return( s.Get_Size() > 1 ? Write((void *)s.Get_Data(), sizeof(char), s.Get_Size() - 1) : 0 );
+	return( s.Length() > 0 ? Write((void *)s.b_str(), sizeof(char), s.Length()) : 0 );
+
+//	CSG_Buffer s(Buffer.to_ASCII()); // returns NULL terminated char sequence, Get_Size() count includes terminating NULL!!!
+
+//	return( s.Get_Size() > 1 ? Write((void *)s.Get_Data(), sizeof(char), s.Get_Size() - 1) : 0 );
 }
 
 //---------------------------------------------------------
@@ -872,6 +877,85 @@ bool CSG_Archive::Extract(const SG_Char *File, const SG_Char *_toFile)
 }
 
 
+///////////////////////////////////////////////////////////
+//                                                       //
+//                                                       //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_ZLib::CSG_ZLib(void)
+{
+	// nop
+}
+
+//---------------------------------------------------------
+bool CSG_ZLib::is_GZip_Supported(void)
+{
+	return( wxZlibInputStream::CanHandleGZip() );
+}
+
+//---------------------------------------------------------
+CSG_String CSG_ZLib::Compress(const CSG_String &File, const CSG_String &_Target)
+{
+	if( SG_File_Exists(File) )
+	{
+		wxFFileInputStream Input(File.c_str());
+
+		if( Input.IsOk() && Input.CanRead() )
+		{
+			CSG_String Target(_Target);
+
+			if( Target.is_Empty() )
+			{
+				Target = File + ".gz";
+			}
+
+			wxZlibOutputStream Output(new wxFFileOutputStream(Target.c_str()));
+
+			if( Output.IsOk() )
+			{
+				Output.Write(Input);
+
+				return( Target );
+			}
+		}
+	}
+
+	return( "" );
+}
+
+//---------------------------------------------------------
+CSG_String CSG_ZLib::Uncompress(const CSG_String &File, const CSG_String &_Target)
+{
+	if( SG_File_Exists(File) )
+	{
+		wxZlibInputStream Input(new wxFFileInputStream(File.c_str()));
+
+		if( Input.IsOk() && Input.CanRead() )
+		{
+			CSG_String Target(_Target);
+
+			if( Target.is_Empty() )
+			{
+				Target = SG_File_Make_Path(SG_File_Get_Path(File), SG_File_Get_Name(File, false), "");
+			}
+
+			wxFFileOutputStream Output(Target.c_str());
+
+			if( Output.IsOk() )
+			{
+				Output.Write(Input);
+
+				return( Target );
+			}
+		}
+	}
+
+	return( "" );
+}
+
+
 ///////////////////////////////////////////////////////////
 //                                                       //
 //                                                       //
@@ -923,21 +1007,24 @@ CSG_String		SG_Dir_Get_Temp(void)
 }
 
 //---------------------------------------------------------
-bool			SG_Dir_List_Subdirectories	(CSG_Strings &List, const CSG_String &Directory)
+bool			SG_Dir_List_Subdirectories	(CSG_Strings &List, const CSG_String &Directory, bool bRecursive)
 {
-	List.Clear();
-
-	wxDir	Dir;
+	List.Clear(); wxDir Dir;
 
 	if( Dir.Open(Directory.c_str()) )
 	{
-		wxString	FileName;
+		wxString FileName;
 
 		if( Dir.GetFirst(&FileName, wxEmptyString, wxDIR_DIRS) )
 		{
 			do
 			{
-				List	+= SG_File_Make_Path(Directory, &FileName);
+				List += SG_File_Make_Path(Directory, &FileName);
+
+				if( bRecursive )
+				{
+					CSG_Strings _List; SG_Dir_List_Subdirectories(_List, SG_File_Make_Path(Directory, &FileName), bRecursive); List += _List;
+				}
 			}
 			while( Dir.GetNext(&FileName) );
 		}
@@ -947,20 +1034,13 @@ bool			SG_Dir_List_Subdirectories	(CSG_Strings &List, const CSG_String &Director
 }
 
 //---------------------------------------------------------
-bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory)
+bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, const CSG_String &Extension, bool bRecursive)
 {
-	return( SG_Dir_List_Files(List, Directory, "") );
-}
-
-bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, const CSG_String &Extension)
-{
-	List.Clear();
-
-	wxDir	Dir;
+	List.Clear(); wxDir Dir;
 
 	if( Dir.Open(Directory.c_str()) )
 	{
-		wxString	FileName;
+		wxString FileName;
 
 		if( Dir.GetFirst(&FileName, wxEmptyString, wxDIR_FILES) )
 		{
@@ -968,11 +1048,20 @@ bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, cons
 			{
 				if( Extension.is_Empty() || SG_File_Cmp_Extension(&FileName, Extension) )
 				{
-					List	+= SG_File_Make_Path(Directory, &FileName);
+					List += SG_File_Make_Path(Directory, &FileName);
 				}
 			}
 			while( Dir.GetNext(&FileName) );
 		}
+
+		if( bRecursive && Dir.GetFirst(&FileName, wxEmptyString, wxDIR_DIRS) )
+		{
+			do
+			{
+				CSG_Strings _List; SG_Dir_List_Files(_List, SG_File_Make_Path(Directory, &FileName), Extension, bRecursive); List += _List;
+			}
+			while( Dir.GetNext(&FileName) );
+		}
 	}
 
 	return( List.Get_Count() > 0 );
