@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -63,9 +63,9 @@ BYTE CSG_Grid::m_Bitmask[8] = { 0x1, 0x2, 0x4, 0x8, 0x10, 0x20, 0x40, 0x80 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -123,9 +123,9 @@ CSG_Grid * SG_Create_Grid(TSG_Data_Type Type, int NX, int NY, double Cellsize, d
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -201,7 +201,7 @@ CSG_Grid::CSG_Grid(TSG_Data_Type Type, int NX, int NY, double Cellsize, double x
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -228,7 +228,7 @@ void CSG_Grid::_On_Construction(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -359,9 +359,9 @@ bool CSG_Grid::Create(TSG_Data_Type Type, int NX, int NY, double Cellsize, doubl
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//					Destruction							 //
-//														 //
+//                                                       //
+//                    Destruction                        //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -393,7 +393,7 @@ bool CSG_Grid::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -432,9 +432,9 @@ double CSG_Grid::Get_Offset(void) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						Checks							 //
-//														 //
+//                                                       //
+//                       Checks                          //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -482,9 +482,9 @@ bool CSG_Grid::is_Compatible(int NX, int NY, double Cellsize, double xMin, doubl
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//					value access by row					 //
-//														 //
+//                                                       //
+//                value access by row                    //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -523,33 +523,33 @@ bool CSG_Grid::Set_Row(int y, const CSG_Vector &Values)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //		Value access by Position (-> Interpolation)		 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-double CSG_Grid::Get_Value(const TSG_Point &p, TSG_Grid_Resampling Resampling, bool bByteWise) const
+double CSG_Grid::Get_Value(const TSG_Point &p, CSG_Grid_Resampling Resampling, bool bByteWise) const
 {
 	double	Value;
 
 	return( Get_Value(p.x, p.y, Value, Resampling, false, bByteWise) ? Value : Get_NoData_Value() );
 }
 
-double CSG_Grid::Get_Value(double x, double y, TSG_Grid_Resampling Resampling, bool bByteWise) const
+double CSG_Grid::Get_Value(double x, double y, CSG_Grid_Resampling Resampling, bool bByteWise) const
 {
 	double	Value;
 
 	return( Get_Value(x, y, Value, Resampling, false, bByteWise) ? Value : Get_NoData_Value() );
 }
 
-bool CSG_Grid::Get_Value(const TSG_Point &p, double &Value, TSG_Grid_Resampling Resampling, bool bNoData, bool bByteWise) const
+bool CSG_Grid::Get_Value(const TSG_Point &p, double &Value, CSG_Grid_Resampling Resampling, bool bNoData, bool bByteWise) const
 {
 	return( Get_Value(p.x, p.y, Value, Resampling, bNoData, bByteWise) );
 }
 
 //---------------------------------------------------------
-bool CSG_Grid::Get_Value(double x, double y, double &Value, TSG_Grid_Resampling Resampling, bool bNoData, bool bByteWise) const
+bool CSG_Grid::Get_Value(double x, double y, double &Value, CSG_Grid_Resampling Resampling, bool bNoData, bool bByteWise) const
 {
 	if(	m_System.Get_Extent(true).Contains(x, y) )
 	{
@@ -560,10 +560,10 @@ bool CSG_Grid::Get_Value(double x, double y, double &Value, TSG_Grid_Resampling
 		{
 			switch( Resampling )
 			{
-			case GRID_RESAMPLING_NearestNeighbour: return( _Get_ValAtPos_NearestNeighbour(Value, ix, iy, dx, dy           ) );
-			case GRID_RESAMPLING_Bilinear        : return( _Get_ValAtPos_BiLinear        (Value, ix, iy, dx, dy, bByteWise) );
-			case GRID_RESAMPLING_BicubicSpline   : return( _Get_ValAtPos_BiCubicSpline   (Value, ix, iy, dx, dy, bByteWise) );
-			case GRID_RESAMPLING_BSpline: default: return( _Get_ValAtPos_BSpline         (Value, ix, iy, dx, dy, bByteWise) );
+			case CSG_Grid_Resampling::NearestNeighbour  : return( _Get_ValAtPos_NearestNeighbour(Value, ix, iy, dx, dy           ) );
+			case CSG_Grid_Resampling::Bilinear          : return( _Get_ValAtPos_BiLinear        (Value, ix, iy, dx, dy, bByteWise) );
+			case CSG_Grid_Resampling::Bicubic_1         : return( _Get_ValAtPos_BiCubic_1       (Value, ix, iy, dx, dy, bByteWise) );
+			case CSG_Grid_Resampling::Bicubic_2: default: return( _Get_ValAtPos_BiCubic_2       (Value, ix, iy, dx, dy, bByteWise) );
 			}
 		}
 	}
@@ -575,7 +575,7 @@ bool CSG_Grid::Get_Value(double x, double y, double &Value, TSG_Grid_Resampling
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -593,7 +593,7 @@ inline bool CSG_Grid::_Get_ValAtPos_NearestNeighbour(double &Value, int x, int y
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -656,11 +656,11 @@ inline bool CSG_Grid::_Get_ValAtPos_BiLinear(double &Value, int x, int y, double
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-inline double CSG_Grid::_Get_ValAtPos_BiCubicSpline(double dx, double dy, double v_xy[4][4]) const
+inline double CSG_Grid::_Get_ValAtPos_BiCubic_1(double dx, double dy, double v_xy[4][4]) const
 {
 	#define BiCubicSpline(d, v) (v[1] + 0.5 * d * (v[2] - v[0] + d * (2 * v[0] - 5 * v[1] + 4 * v[2] - v[3] + d * (3 * (v[1] - v[2]) + v[3] - v[0]))))
 
@@ -675,7 +675,7 @@ inline double CSG_Grid::_Get_ValAtPos_BiCubicSpline(double dx, double dy, double
 }
 
 //---------------------------------------------------------
-inline bool CSG_Grid::_Get_ValAtPos_BiCubicSpline(double &Value, int x, int y, double dx, double dy, bool bByteWise) const
+inline bool CSG_Grid::_Get_ValAtPos_BiCubic_1(double &Value, int x, int y, double dx, double dy, bool bByteWise) const
 {
 	if( !bByteWise )
 	{
@@ -683,7 +683,7 @@ inline bool CSG_Grid::_Get_ValAtPos_BiCubicSpline(double &Value, int x, int y, d
 
 		if( _Get_ValAtPos_Fill4x4Submatrix(x, y, v_xy) )
 		{
-			Value	= _Get_ValAtPos_BiCubicSpline(dx, dy, v_xy);
+			Value	= _Get_ValAtPos_BiCubic_1(dx, dy, v_xy);
 
 			return( true );
 		}
@@ -695,10 +695,10 @@ inline bool CSG_Grid::_Get_ValAtPos_BiCubicSpline(double &Value, int x, int y, d
 		if( _Get_ValAtPos_Fill4x4Submatrix(x, y, v_xy) )
 		{
 			Value	= SG_GET_LONG(
-				_Get_ValAtPos_BiCubicSpline(dx, dy, v_xy[0]),
-				_Get_ValAtPos_BiCubicSpline(dx, dy, v_xy[1]),
-				_Get_ValAtPos_BiCubicSpline(dx, dy, v_xy[2]),
-				_Get_ValAtPos_BiCubicSpline(dx, dy, v_xy[3])
+				_Get_ValAtPos_BiCubic_1(dx, dy, v_xy[0]),
+				_Get_ValAtPos_BiCubic_1(dx, dy, v_xy[1]),
+				_Get_ValAtPos_BiCubic_1(dx, dy, v_xy[2]),
+				_Get_ValAtPos_BiCubic_1(dx, dy, v_xy[3])
 			);
 
 			return( true );
@@ -710,11 +710,11 @@ inline bool CSG_Grid::_Get_ValAtPos_BiCubicSpline(double &Value, int x, int y, d
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-inline double CSG_Grid::_Get_ValAtPos_BSpline(double dx, double dy, double v_xy[4][4]) const
+inline double CSG_Grid::_Get_ValAtPos_BiCubic_2(double dx, double dy, double v_xy[4][4]) const
 {
 	double	Rx[4], Ry[4];
 
@@ -753,7 +753,7 @@ inline double CSG_Grid::_Get_ValAtPos_BSpline(double dx, double dy, double v_xy[
 }
 
 //---------------------------------------------------------
-inline bool CSG_Grid::_Get_ValAtPos_BSpline(double &Value, int x, int y, double dx, double dy, bool bByteWise) const
+inline bool CSG_Grid::_Get_ValAtPos_BiCubic_2(double &Value, int x, int y, double dx, double dy, bool bByteWise) const
 {
 	if( !bByteWise )
 	{
@@ -761,7 +761,7 @@ inline bool CSG_Grid::_Get_ValAtPos_BSpline(double &Value, int x, int y, double
 
 		if( _Get_ValAtPos_Fill4x4Submatrix(x, y, v_xy) )
 		{
-			Value	= _Get_ValAtPos_BSpline(dx, dy, v_xy);
+			Value	= _Get_ValAtPos_BiCubic_2(dx, dy, v_xy);
 
 			return( true );
 		}
@@ -773,10 +773,10 @@ inline bool CSG_Grid::_Get_ValAtPos_BSpline(double &Value, int x, int y, double
 		if( _Get_ValAtPos_Fill4x4Submatrix(x, y, v_xy) )
 		{
 			Value	= SG_GET_LONG(
-				_Get_ValAtPos_BSpline(dx, dy, v_xy[0]),
-				_Get_ValAtPos_BSpline(dx, dy, v_xy[1]),
-				_Get_ValAtPos_BSpline(dx, dy, v_xy[2]),
-				_Get_ValAtPos_BSpline(dx, dy, v_xy[3])
+				_Get_ValAtPos_BiCubic_2(dx, dy, v_xy[0]),
+				_Get_ValAtPos_BiCubic_2(dx, dy, v_xy[1]),
+				_Get_ValAtPos_BiCubic_2(dx, dy, v_xy[2]),
+				_Get_ValAtPos_BiCubic_2(dx, dy, v_xy[3])
 			);
 
 			return( true );
@@ -788,7 +788,7 @@ inline bool CSG_Grid::_Get_ValAtPos_BSpline(double &Value, int x, int y, double
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -948,9 +948,9 @@ inline bool CSG_Grid::_Get_ValAtPos_Fill4x4Submatrix(int x, int y, double v_xy[4
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						Statistics						 //
-//														 //
+//                                                       //
+//                      Statistics                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1080,7 +1080,7 @@ double CSG_Grid::Get_Percentile(double Percentile, bool bFromHistogram)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1159,7 +1159,7 @@ bool CSG_Grid::Get_Statistics(const CSG_Rect &rWorld, CSG_Simple_Statistics &Sta
 }
 
 //---------------------------------------------------------
-#define SG_GRID_HISTOGRAM_CLASSES_DEFAULT	255
+#define SG_GRID_HISTOGRAM_CLASSES_DEFAULT 256
 
 //---------------------------------------------------------
 /**
@@ -1177,7 +1177,7 @@ const CSG_Histogram & CSG_Grid::Get_Histogram(size_t nClasses)
 
 	if( m_Histogram.Get_Statistics().Get_Count() < 1 )
 	{
-		m_Histogram.Create(nClasses > 1 ? nClasses : SG_GRID_HISTOGRAM_CLASSES_DEFAULT, Get_Min(), Get_Max(), this, (size_t)Get_Max_Samples());
+		m_Histogram.Create(nClasses > 1 ? nClasses : SG_GRID_HISTOGRAM_CLASSES_DEFAULT, this, 0., 0., (size_t)Get_Max_Samples());
 	}
 
 	return( m_Histogram );
@@ -1186,60 +1186,57 @@ const CSG_Histogram & CSG_Grid::Get_Histogram(size_t nClasses)
 //---------------------------------------------------------
 bool CSG_Grid::Get_Histogram(const CSG_Rect &rWorld, CSG_Histogram &Histogram, size_t nClasses)	const
 {
-	CSG_Simple_Statistics	Statistics;
+	CSG_Simple_Statistics Statistics;
 
 	if( !Get_Statistics(rWorld, Statistics) )
 	{
 		return( false );
 	}
 
-	int	xMin	= Get_System().Get_xWorld_to_Grid(rWorld.Get_XMin()); if( xMin <  0        ) xMin = 0;
-	int	yMin	= Get_System().Get_yWorld_to_Grid(rWorld.Get_YMin()); if( yMin <  0        ) yMin = 0;
-	int	xMax	= Get_System().Get_xWorld_to_Grid(rWorld.Get_XMax()); if( xMax >= Get_NX() ) xMax = Get_NX() - 1;
-	int	yMax	= Get_System().Get_yWorld_to_Grid(rWorld.Get_YMax()); if( yMax >= Get_NY() ) yMax = Get_NY() - 1;
+	int xMin = Get_System().Get_xWorld_to_Grid(rWorld.Get_XMin()); if( xMin <  0        ) { xMin =            0; }
+	int yMin = Get_System().Get_yWorld_to_Grid(rWorld.Get_YMin()); if( yMin <  0        ) { yMin =            0; }
+	int xMax = Get_System().Get_xWorld_to_Grid(rWorld.Get_XMax()); if( xMax >= Get_NX() ) { xMax = Get_NX() - 1; }
+	int yMax = Get_System().Get_yWorld_to_Grid(rWorld.Get_YMax()); if( yMax >= Get_NY() ) { yMax = Get_NY() - 1; }
 
 	if( xMin > xMax || yMin > yMax )
 	{
-		return( false );	// no overlap
+		return( false ); // no overlap
 	}
 
 	Histogram.Create(nClasses > 1 ? nClasses : SG_GRID_HISTOGRAM_CLASSES_DEFAULT, Statistics.Get_Minimum(), Statistics.Get_Maximum());
 
-	int		nx		= 1 + (xMax - xMin);
-	int		ny		= 1 + (yMax - yMin);
-	sLong	nCells	= nx * ny;
+	int        nx = 1 + (xMax - xMin);
+	int        ny = 1 + (yMax - yMin);
+	sLong  nCells = (sLong)nx * (sLong)ny;
 
-	double	Offset = Get_Offset(), Scaling = is_Scaled() ? Get_Scaling() : 0.;
+	double Offset = Get_Offset(), Scaling = is_Scaled() ? Get_Scaling() : 0.;
 
 	if( Get_Max_Samples() > 0 && Get_Max_Samples() < nCells )
 	{
-		double	d = (double)nCells / (double)Get_Max_Samples();
+		double d = (double)nCells / (double)Get_Max_Samples();
 
 		for(double i=0; i<(double)nCells; i+=d)
 		{
-			int	y	= yMin + (int)i / nx;
-			int	x	= xMin + (int)i % nx;
+			int y = yMin + (int)i / nx;
+			int x = xMin + (int)i % nx;
 
-			double	Value	= asDouble(x, y, false);
+			double Value = asDouble(x, y, false);
 
 			if( !is_NoData_Value(Value) )
 			{
-				Histogram	+= Scaling ? Offset + Scaling * Value : Value;
+				Histogram += Scaling ? Offset + Scaling * Value : Value;
 			}
 		}
 	}
 	else
 	{
-		for(int y=yMin; y<=yMax; y++)
+		for(int y=yMin; y<=yMax; y++) for(int x=xMin; x<=xMax; x++)
 		{
-			for(int x=xMin; x<=xMax; x++)
-			{
-				double	Value	= asDouble(x, y, false);
+			double Value = asDouble(x, y, false);
 
-				if( !is_NoData_Value(Value) )
-				{
-					Histogram	+= Scaling ? Offset + Scaling * Value : Value;
-				}
+			if( !is_NoData_Value(Value) )
+			{
+				Histogram += Scaling ? Offset + Scaling * Value : Value;
 			}
 		}
 	}
@@ -1249,15 +1246,14 @@ bool CSG_Grid::Get_Histogram(const CSG_Rect &rWorld, CSG_Histogram &Histogram, s
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						Index							 //
-//														 //
+//                                                       //
+//                        Index                          //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CSG_Grid::_Set_Index(void)
 {
-	//-----------------------------------------------------
 	if( m_Index == NULL && (m_Index = (sLong *)SG_Malloc((size_t)Get_NCells() * sizeof(sLong))) == NULL )
 	{
 		SG_UI_Msg_Add_Error(_TL("could not create index: insufficient memory"));
@@ -1417,9 +1413,9 @@ bool CSG_Grid::_Set_Index(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
