@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -68,9 +68,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -79,9 +79,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Grid File						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -146,28 +146,48 @@ const SG_Char	gSG_Grid_File_Key_Names[GRID_FILE_KEY_Count][32]	=
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef enum
+enum class CSG_Grid_Resampling
 {
-	GRID_RESAMPLING_NearestNeighbour	= 0,
-	GRID_RESAMPLING_Bilinear,
-	GRID_RESAMPLING_BicubicSpline,
-	GRID_RESAMPLING_BSpline,
+	NearestNeighbour = 0x001,
+	Bilinear         = 0x002,
+	Bicubic_1        = 0x004,
+	Bicubic_2        = 0x008,
 
-	GRID_RESAMPLING_Mean_Nodes,
-	GRID_RESAMPLING_Mean_Cells,
-	GRID_RESAMPLING_Minimum,
-	GRID_RESAMPLING_Maximum,
-	GRID_RESAMPLING_Majority,
+	Mean_Nodes       = 0x010,
+	Mean_Cells       = 0x020,
 
-	GRID_RESAMPLING_Undefined
-}
-TSG_Grid_Resampling;
+	Minimum          = 0x040,
+	Maximum          = 0x080,
+	Majority         = 0x100,
+
+	//-----------------------------------------------------
+	Interpolations   = NearestNeighbour|Bilinear|Bicubic_1|Bicubic_2,
+	Means            = Mean_Nodes|Mean_Cells,
+	Extremes         = Maximum|Minimum,
+	Aggregations     = Means|Extremes|Majority,
+	All              = Interpolations|Aggregations,
+	Undefined        = 0x000
+};
+
+// deprecated, for backward compatibility only >>
+#define GRID_RESAMPLING_NearestNeighbour CSG_Grid_Resampling::NearestNeighbour
+#define GRID_RESAMPLING_Bilinear         CSG_Grid_Resampling::Bilinear
+#define GRID_RESAMPLING_BicubicSpline    CSG_Grid_Resampling::Bicubic_1
+#define GRID_RESAMPLING_BSpline          CSG_Grid_Resampling::Bicubic_2
+#define GRID_RESAMPLING_Mean_Nodes       CSG_Grid_Resampling::Mean_Nodes
+#define GRID_RESAMPLING_Mean_Cells       CSG_Grid_Resampling::Mean_Cells
+#define GRID_RESAMPLING_Minimum          CSG_Grid_Resampling::Minimum
+#define GRID_RESAMPLING_Maximum          CSG_Grid_Resampling::Maximum
+#define GRID_RESAMPLING_Majority         CSG_Grid_Resampling::Majority
+#define GRID_RESAMPLING_Undefined        CSG_Grid_Resampling::Undefined
+#define TSG_Grid_Resampling              CSG_Grid_Resampling
+// << deprecated, for backward compatibility only
 
 //---------------------------------------------------------
 typedef enum
@@ -181,9 +201,9 @@ TSG_Grid_Operation;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					CSG_Grid_System						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -402,9 +422,9 @@ private:	///////////////////////////////////////////////
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						CSG_Grid						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -467,9 +487,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						CSG_Grid						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -619,8 +639,8 @@ public:		///////////////////////////////////////////////
 	bool							Assign_NoData				(void);
 
 	virtual bool					Assign						(double Value = 0.);
-	virtual bool					Assign						(CSG_Data_Object *pObject                          , bool bProgress = false);
-	virtual bool					Assign						(CSG_Grid *pGrid, TSG_Grid_Resampling Interpolation, bool bProgress = false);
+	virtual bool					Assign						(CSG_Data_Object *pObject                   , bool bProgress = false);
+	virtual bool					Assign						(CSG_Grid *pGrid, CSG_Grid_Resampling Method, bool bProgress = false);
 
 	void							Flip						(void);
 	void							Mirror						(void);
@@ -634,8 +654,8 @@ public:		///////////////////////////////////////////////
 
 	int								Get_Gradient_NeighborDir	(int x, int y, bool bDown = true, bool bNoEdges = true)	const;
 	bool							Get_Gradient				(int x, int y      , double &Slope, double &Aspect)	const;
-	bool							Get_Gradient				(double x, double y, double &Slope, double &Aspect, TSG_Grid_Resampling Interpolation)	const;
-	bool							Get_Gradient				(const TSG_Point &p, double &Slope, double &Aspect, TSG_Grid_Resampling Interpolation)	const;
+	bool							Get_Gradient				(double x, double y, double &Slope, double &Aspect, CSG_Grid_Resampling Interpolation)	const;
+	bool							Get_Gradient				(const TSG_Point &p, double &Slope, double &Aspect, CSG_Grid_Resampling Interpolation)	const;
 
 
 	//-----------------------------------------------------
@@ -751,10 +771,10 @@ public:		///////////////////////////////////////////////
 	//-----------------------------------------------------
 	// Get Value...
 
-	double							Get_Value	(double x, double y,                TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline                      , bool bByteWise = false) const;
-	double							Get_Value	(const TSG_Point &p,                TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline                      , bool bByteWise = false) const;
-	bool							Get_Value	(double x, double y, double &Value, TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline, bool bNoData = false, bool bByteWise = false) const;
-	bool							Get_Value	(const TSG_Point &p, double &Value, TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline, bool bNoData = false, bool bByteWise = false) const;
+	double							Get_Value	(double x, double y,                CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2                      , bool bByteWise = false) const;
+	double							Get_Value	(const TSG_Point &p,                CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2                      , bool bByteWise = false) const;
+	bool							Get_Value	(double x, double y, double &Value, CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2, bool bNoData = false, bool bByteWise = false) const;
+	bool							Get_Value	(const TSG_Point &p, double &Value, CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2, bool bNoData = false, bool bByteWise = false) const;
 
 	virtual BYTE					asByte		(int x, int y, bool bScaled = true) const	{	return( SG_ROUND_TO_BYTE (asDouble(x, y, bScaled)) );	}
 	virtual BYTE					asByte		(     sLong i, bool bScaled = true) const	{	return( SG_ROUND_TO_BYTE (asDouble(   i, bScaled)) );	}
@@ -961,7 +981,7 @@ private:	///////////////////////////////////////////////
 	CSG_Grid &					_Operation_Arithmetic	(const CSG_Grid &Grid, TSG_Grid_Operation Operation);
 	CSG_Grid &					_Operation_Arithmetic	(double Value        , TSG_Grid_Operation Operation);
 
-	bool						_Assign_Interpolated	(CSG_Grid *pSource, TSG_Grid_Resampling Interpolation, bool bProgress);
+	bool						_Assign_Interpolated	(CSG_Grid *pSource, CSG_Grid_Resampling Interpolation, bool bProgress);
 	bool						_Assign_MeanValue		(CSG_Grid *pSource, bool bAreaProportional           , bool bProgress);
 	bool						_Assign_ExtremeValue	(CSG_Grid *pSource, bool bMaximum                    , bool bProgress);
 	bool						_Assign_Majority		(CSG_Grid *pSource                                   , bool bProgress);
@@ -972,11 +992,11 @@ private:	///////////////////////////////////////////////
 
 	bool						_Get_ValAtPos_NearestNeighbour	(double &Value, int x, int y, double dx, double dy                )	const;
 	bool						_Get_ValAtPos_BiLinear			(double &Value, int x, int y, double dx, double dy, bool bByteWise)	const;
-	bool						_Get_ValAtPos_BiCubicSpline		(double &Value, int x, int y, double dx, double dy, bool bByteWise)	const;
-	bool						_Get_ValAtPos_BSpline			(double &Value, int x, int y, double dx, double dy, bool bByteWise)	const;
+	bool						_Get_ValAtPos_BiCubic_1			(double &Value, int x, int y, double dx, double dy, bool bByteWise)	const;
+	bool						_Get_ValAtPos_BiCubic_2			(double &Value, int x, int y, double dx, double dy, bool bByteWise)	const;
 
-	double						_Get_ValAtPos_BiCubicSpline		(double dx, double dy, double z_xy[4][4])	const;
-	double						_Get_ValAtPos_BSpline			(double dx, double dy, double z_xy[4][4])	const;
+	double						_Get_ValAtPos_BiCubic_1			(double dx, double dy, double z_xy[4][4])	const;
+	double						_Get_ValAtPos_BiCubic_2			(double dx, double dy, double z_xy[4][4])	const;
 
 	bool						_Get_ValAtPos_Fill4x4Submatrix	(int x, int y, double z_xy[4][4]   )	const;
 	bool						_Get_ValAtPos_Fill4x4Submatrix	(int x, int y, double z_xy[4][4][4])	const;
@@ -985,9 +1005,9 @@ private:	///////////////////////////////////////////////
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Functions						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1039,9 +1059,9 @@ SAGA_API_DLL_EXPORT CSG_String				SG_Grid_Get_File_Extension_Default	(void);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
 //                                                       //
-//														 //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1089,9 +1109,9 @@ public:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1180,9 +1200,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
