@@ -56,9 +56,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //				Data Assignments - Value				 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -112,18 +112,18 @@ bool CSG_Grid::Assign(double Value)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //				Data Assignments - Grid					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CSG_Grid::Assign(CSG_Data_Object *pObject, bool bProgress)
 {
-	return( pObject && Assign(pObject->asGrid(), GRID_RESAMPLING_Undefined) );
+	return( pObject && Assign(pObject->asGrid(), CSG_Grid_Resampling::Undefined) );
 }
 
-bool CSG_Grid::Assign(CSG_Grid *pGrid, TSG_Grid_Resampling Interpolation, bool bProgress)
+bool CSG_Grid::Assign(CSG_Grid *pGrid, CSG_Grid_Resampling Method, bool bProgress)
 {
 	if(	!is_Valid() || !pGrid || !pGrid->is_Valid() || is_Intersecting(pGrid->Get_Extent()) == INTERSECTION_None )
 	{
@@ -156,28 +156,28 @@ bool CSG_Grid::Assign(CSG_Grid *pGrid, TSG_Grid_Resampling Interpolation, bool b
 	&& fmod(Get_XMin() - pGrid->Get_XMin(), Get_Cellsize()) == 0.
 	&& fmod(Get_YMin() - pGrid->Get_YMin(), Get_Cellsize()) == 0.	)
 	{
-		bResult = _Assign_Interpolated(pGrid, GRID_RESAMPLING_NearestNeighbour, bProgress);
+		bResult = _Assign_Interpolated(pGrid, CSG_Grid_Resampling::NearestNeighbour, bProgress);
 	}
 
 	//---------------------------------------------------------
-	else switch( Interpolation )
+	else switch( Method )
 	{
-	case GRID_RESAMPLING_NearestNeighbour:
-	case GRID_RESAMPLING_Bilinear        :
-	case GRID_RESAMPLING_BicubicSpline   :
-	case GRID_RESAMPLING_BSpline         : bResult = _Assign_Interpolated(pGrid, Interpolation                              , bProgress); break;
+	case CSG_Grid_Resampling::NearestNeighbour:
+	case CSG_Grid_Resampling::Bilinear        :
+	case CSG_Grid_Resampling::Bicubic_1       :
+	case CSG_Grid_Resampling::Bicubic_2       : bResult = _Assign_Interpolated(pGrid, Method                                   , bProgress); break;
 
-	case GRID_RESAMPLING_Mean_Nodes      :
-	case GRID_RESAMPLING_Mean_Cells      : bResult = _Assign_MeanValue   (pGrid, Interpolation != GRID_RESAMPLING_Mean_Nodes, bProgress); break;
+	case CSG_Grid_Resampling::Mean_Nodes      :
+	case CSG_Grid_Resampling::Mean_Cells      : bResult = _Assign_MeanValue   (pGrid, Method != CSG_Grid_Resampling::Mean_Nodes, bProgress); break;
 
-	case GRID_RESAMPLING_Minimum         :
-	case GRID_RESAMPLING_Maximum         : bResult = _Assign_ExtremeValue(pGrid, Interpolation == GRID_RESAMPLING_Maximum   , bProgress); break;
+	case CSG_Grid_Resampling::Minimum         :
+	case CSG_Grid_Resampling::Maximum         : bResult = _Assign_ExtremeValue(pGrid, Method == CSG_Grid_Resampling::Maximum   , bProgress); break;
 
-	case GRID_RESAMPLING_Majority        : bResult = _Assign_Majority    (pGrid                                             , bProgress); break;
+	case CSG_Grid_Resampling::Majority        : bResult = _Assign_Majority    (pGrid                                           , bProgress); break;
 
-	default                              : bResult = Get_Cellsize() < pGrid->Get_Cellsize()
-			? _Assign_Interpolated(pGrid, GRID_RESAMPLING_BSpline, bProgress)  // Down-Scaling...
-			: _Assign_MeanValue   (pGrid, true                   , bProgress); // Up-Scaling...
+	default                                   : bResult = Get_Cellsize() < pGrid->Get_Cellsize()
+		? _Assign_Interpolated(pGrid, CSG_Grid_Resampling::Bicubic_2, bProgress)  // Down-Scaling...
+		: _Assign_MeanValue   (pGrid, true                          , bProgress); // Up-Scaling...
 		break;
 	}
 
@@ -204,7 +204,7 @@ bool CSG_Grid::Assign(CSG_Grid *pGrid, TSG_Grid_Resampling Interpolation, bool b
 }
 
 //---------------------------------------------------------
-bool CSG_Grid::_Assign_Interpolated(CSG_Grid *pGrid, TSG_Grid_Resampling Interpolation, bool bProgress)
+bool CSG_Grid::_Assign_Interpolated(CSG_Grid *pGrid, CSG_Grid_Resampling Interpolation, bool bProgress)
 {
 	for(int y=0; y<Get_NY() && (!bProgress || SG_UI_Process_Set_Progress(y, Get_NY())); y++)
 	{
@@ -352,7 +352,7 @@ bool CSG_Grid::_Assign_MeanValue(CSG_Grid *pGrid, bool bAreaProportional, bool b
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -416,15 +416,15 @@ bool CSG_Grid::_Assign_Majority(CSG_Grid *pGrid, bool bProgress)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Operatoren							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CSG_Grid & CSG_Grid::operator = (const CSG_Grid &Grid)
 {
-	Assign(Grid.asGrid(), GRID_RESAMPLING_Undefined, false);
+	Assign(Grid.asGrid(), CSG_Grid_Resampling::Undefined, false);
 
 	return( *this );
 }
@@ -578,9 +578,9 @@ CSG_Grid & CSG_Grid::Divide			(double Value)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Operatoren							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -588,11 +588,11 @@ CSG_Grid & CSG_Grid::_Operation_Arithmetic(const CSG_Grid &Grid, TSG_Grid_Operat
 {
 	if( is_Intersecting(Grid.Get_Extent()) )
 	{
-		TSG_Grid_Resampling	Interpolation	=
+		CSG_Grid_Resampling	Interpolation	=
 			Get_Cellsize() == Grid.Get_Cellsize() && fmod(Get_XMin() - Grid.Get_XMin(), Get_Cellsize()) == 0.
 		&&	Get_Cellsize() == Grid.Get_Cellsize() && fmod(Get_YMin() - Grid.Get_YMin(), Get_Cellsize()) == 0.
-		?	GRID_RESAMPLING_NearestNeighbour
-		:	GRID_RESAMPLING_BSpline;
+		?	CSG_Grid_Resampling::NearestNeighbour
+		:	CSG_Grid_Resampling::Bicubic_2;
 
 		#pragma omp parallel for
 		for(int y=0; y<Get_NY(); y++)
@@ -686,9 +686,9 @@ CSG_Grid & CSG_Grid::_Operation_Arithmetic(double Value, TSG_Grid_Operation Oper
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Grid-Operations - A					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -751,9 +751,9 @@ void CSG_Grid::Mirror(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Grid-Operations - B					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -856,9 +856,9 @@ bool CSG_Grid::DeStandardise(double Mean, double StdDev)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -965,7 +965,7 @@ bool CSG_Grid::Get_Gradient(int x, int y, double &Slope, double &Aspect) const
   * Aspect is zero for the North direction and increases clockwise.
 */
 //---------------------------------------------------------
-bool CSG_Grid::Get_Gradient(double x, double y, double &Slope, double &Aspect, TSG_Grid_Resampling Interpolation) const
+bool CSG_Grid::Get_Gradient(double x, double y, double &Slope, double &Aspect, CSG_Grid_Resampling Interpolation) const
 {
 	double	z, iz, dz[4];
 
@@ -1014,16 +1014,16 @@ bool CSG_Grid::Get_Gradient(double x, double y, double &Slope, double &Aspect, T
   * Aspect is zero for the North direction and increases clockwise.
 */
 //---------------------------------------------------------
-bool CSG_Grid::Get_Gradient(const TSG_Point &p, double &Incline, double &Azimuth, TSG_Grid_Resampling Interpolation) const
+bool CSG_Grid::Get_Gradient(const TSG_Point &p, double &Incline, double &Azimuth, CSG_Grid_Resampling Interpolation) const
 {
 	return( Get_Gradient(p.x, p.y, Incline, Azimuth, Interpolation) );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
