@@ -54,9 +54,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -71,9 +71,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -81,9 +81,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						CSG_Grids						 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -104,9 +104,9 @@ TSG_Grids_File_Format;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						CSG_Grids						 //
-//														 //
+//                                                       //
+//                      CSG_Grids                        //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -146,6 +146,9 @@ public:		///////////////////////////////////////////////
 									CSG_Grids			(int NX, int NY, int NZ = 0, double Cellsize = 0., double xMin = 0., double yMin = 0., double zMin = 0., TSG_Data_Type Type = SG_DATATYPE_Undefined);
 	virtual bool					Create				(int NX, int NY, int NZ = 0, double Cellsize = 0., double xMin = 0., double yMin = 0., double zMin = 0., TSG_Data_Type Type = SG_DATATYPE_Undefined);
 
+									CSG_Grids			(const CSG_Table &Attributes, int zAttribute = 0);
+	virtual bool					Create				(const CSG_Table &Attributes, int zAttribute = 0);
+
 	virtual bool					Destroy				(void);
 
 
@@ -210,7 +213,7 @@ public:		///////////////////////////////////////////////
 	//-----------------------------------------------------
 	// Attributes...
 
-	bool							Set_Z_Attribute		(int Field);
+	bool							Set_Z_Attribute		(int Field, bool bSetNameField = false);
 	int								Get_Z_Attribute		(void)	const	{	return( m_Z_Attribute );	}
 
 	bool							Set_Z_Name_Field	(int Field);
@@ -257,7 +260,7 @@ public:		///////////////////////////////////////////////
 	bool							Del_Grids			(       bool bDetach = false);
 
 	const CSG_Grid &				Get_Grid			(int i)	const	{	return( *m_pGrids[i] );	}
-	CSG_Grid *						Get_Grid_Ptr		(int i)	const	{	return(  m_pGrids[i] );	}
+	CSG_Grid *						Get_Grid_Ptr		(int i)	const	{	return( i >= 0 && i < Get_NZ() ? m_pGrids[i] : NULL );	}
 	CSG_String						Get_Grid_Name		(int i, int Style = 0)	const;
 
 	sLong							Get_Memory_Size		(void)	const	{	return( m_pGrids[0]->Get_Memory_Size() * Get_NZ() );	}
@@ -335,8 +338,8 @@ public:		///////////////////////////////////////////////
 	void							Assign_NoData				(void);
 
 	virtual bool					Assign						(double Value = 0.);
-	virtual bool					Assign						(CSG_Data_Object *pObject);
-	virtual bool					Assign						(CSG_Grids *pGrids, TSG_Grid_Resampling Interpolation);
+	virtual bool					Assign						(CSG_Data_Object *pObject                            , bool bProgress = false);
+	virtual bool					Assign						(CSG_Grids *pGrids, CSG_Grid_Resampling Interpolation, bool bProgress = false);
 
 
 	//-----------------------------------------------------
@@ -377,10 +380,10 @@ public:		///////////////////////////////////////////////
 	//-----------------------------------------------------
 	// Get Value...
 
-	double							Get_Value	(double x, double y, double z,                TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline, TSG_Grid_Resampling ZResampling = GRID_RESAMPLING_Undefined) const;
-	double							Get_Value	(const TSG_Point_3D         &p,                TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline, TSG_Grid_Resampling ZResampling = GRID_RESAMPLING_Undefined) const;
-	bool							Get_Value	(double x, double y, double z, double &Value, TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline, TSG_Grid_Resampling ZResampling = GRID_RESAMPLING_Undefined) const;
-	bool							Get_Value	(const TSG_Point_3D         &p, double &Value, TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline, TSG_Grid_Resampling ZResampling = GRID_RESAMPLING_Undefined) const;
+	double							Get_Value	(double x, double y, double z,                CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2, CSG_Grid_Resampling ZResampling = CSG_Grid_Resampling::Undefined) const;
+	double							Get_Value	(const TSG_Point_3D        &p,                CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2, CSG_Grid_Resampling ZResampling = CSG_Grid_Resampling::Undefined) const;
+	bool							Get_Value	(double x, double y, double z, double &Value, CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2, CSG_Grid_Resampling ZResampling = CSG_Grid_Resampling::Undefined) const;
+	bool							Get_Value	(const TSG_Point_3D        &p, double &Value, CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2, CSG_Grid_Resampling ZResampling = CSG_Grid_Resampling::Undefined) const;
 
 	virtual BYTE					asByte		(int x, int y, int z, bool bScaled = true) const	{	return( SG_ROUND_TO_BYTE (asDouble(x, y, z, bScaled)) );	}
 	virtual BYTE					asByte		(sLong             i, bool bScaled = true) const	{	return( SG_ROUND_TO_BYTE (asDouble(      i, bScaled)) );	}
@@ -551,7 +554,7 @@ private:	///////////////////////////////////////////////
 	bool							_Save_Data				(CSG_File &Stream, CSG_Grid *pGrid);
 
 	//-----------------------------------------------------
-	bool							_Assign_Interpolated	(CSG_Grids *pSource, TSG_Grid_Resampling Interpolation);
+	bool							_Assign_Interpolated	(CSG_Grids *pSource, CSG_Grid_Resampling Interpolation);
 	bool							_Assign_MeanValue		(CSG_Grids *pSource, bool bVolumeProportional);
 	bool							_Assign_ExtremeValue	(CSG_Grids *pSource, bool bMaximum);
 	bool							_Assign_Majority		(CSG_Grids *pSource);
@@ -564,9 +567,9 @@ private:	///////////////////////////////////////////////
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Functions						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -599,11 +602,14 @@ SAGA_API_DLL_EXPORT CSG_Grids *		SG_Create_Grids		(const CSG_Grid_System &System
 /** Safe construction of a grid collection */
 SAGA_API_DLL_EXPORT CSG_Grids *		SG_Create_Grids		(int NX, int NY, int NZ = 0, double Cellsize = 0., double xMin = 0., double yMin = 0., double zMin = 0., TSG_Data_Type Type = SG_DATATYPE_Undefined);
 
+/** Safe construction of a grid collection */
+SAGA_API_DLL_EXPORT CSG_Grids *		SG_Create_Grids		(const CSG_Table &Attributes, int zAttribute = 0);
+
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
