@@ -54,9 +54,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -95,7 +95,28 @@ bool CSG_Index::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Index::Invert(void)
+{
+	if( m_nValues > 0 )
+	{
+		for(sLong a=0, b=m_nValues-1; a<b; a++, b--)
+		{
+			sLong i = m_Index[a]; m_Index[a] = m_Index[b]; m_Index[b] = i;
+		}
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -142,7 +163,7 @@ bool CSG_Index::Create(sLong nValues, CSG_Index_Compare *pCompare)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -180,7 +201,7 @@ bool CSG_Index::Create(sLong nValues, int *Values, bool bAscending)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -220,7 +241,7 @@ bool CSG_Index::Create(sLong nValues, double *Values, bool bAscending)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -255,7 +276,7 @@ bool CSG_Index::Create(sLong nValues, TSG_PFNC_Compare fCompare)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -363,7 +384,7 @@ bool CSG_Index::_Set_Array(sLong nValues)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -490,9 +511,9 @@ bool CSG_Index::_Set_Index(CSG_Index_Compare *pCompare)
 }
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -549,7 +570,7 @@ void CSG_PriorityQueue::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -643,7 +664,7 @@ void CSG_PriorityQueue::Add(CSG_PriorityQueueItem *pItem)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -685,9 +706,9 @@ CSG_PriorityQueue::CSG_PriorityQueueItem * CSG_PriorityQueue::Poll(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
