@@ -60,9 +60,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -73,9 +73,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -121,7 +121,7 @@ bool CSG_Trend::CParams::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -136,7 +136,7 @@ CSG_Trend::CSG_Trend(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -182,7 +182,7 @@ bool CSG_Trend::Init_Parameter(const SG_Char &Variable, double Value)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -216,9 +216,9 @@ void CSG_Trend::Set_Data(const CSG_Points &Data, bool bAdd)
 		Clr_Data();
 	}
 
-	for(int i=0; i<Data.Get_Count(); i++)
+	for(sLong i=0; i<Data.Get_Count(); i++)
 	{
-		Add_Data(Data.Get_X(i), Data.Get_Y(i));
+		Add_Data(Data[i].x, Data[i].y);
 	}
 }
 
@@ -235,7 +235,7 @@ bool CSG_Trend::Add_Data(double x, double y)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -266,7 +266,7 @@ bool CSG_Trend::Set_Max_Lambda(double Lambda)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -360,7 +360,7 @@ bool CSG_Trend::Get_Trend(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -462,7 +462,7 @@ CSG_String CSG_Trend::Get_Formula(int Type)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -711,7 +711,7 @@ bool CSG_Trend::_Get_mrqcof(CSG_Vector &Parameters, CSG_Matrix &Alpha, CSG_Vecto
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -739,9 +739,9 @@ void CSG_Trend::_Get_Function(double &y, double *dy_da, double x, const double *
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -825,8 +825,8 @@ bool CSG_Trend_Polynom::Get_Trend(void)
 	CSG_Matrix	X, Xt, C;
 
 	//-----------------------------------------------------
-	X .Create(m_Order + 1, m_y.Get_N());
-	Xt.Create(m_y.Get_N(), m_Order + 1);
+	X .Create((sLong)m_Order + 1, m_y.Get_Size());
+	Xt.Create(m_y.Get_Size(), (uLong)m_Order + 1);
 
 	for(i=0, Ym=0.; i<m_y.Get_N(); i++)
 	{
@@ -880,9 +880,9 @@ double CSG_Trend_Polynom::Get_Value(double x)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
