@@ -947,7 +947,11 @@ bool CSG_MetaData::from_XML(const char *_XML, size_t Length, const char *Encodin
 
 	wxXmlDocument XML; wxMemoryInputStream Stream((const void *)_XML, Length);
 
+#if wxCHECK_VERSION(3, 3, 0)
+	if( XML.Load(Stream) )
+#else
 	if( XML.Load(Stream, Encoding) )
+#endif
 	{
 		_Load(XML.GetRoot());
 
@@ -1089,28 +1093,46 @@ bool CSG_MetaData::from_JSON(const CSG_String &JSON)
 
 	Set_Name("root");
 
-	CSG_MetaData	*pNode	= this;
-
-	const SG_Char	*pc	= JSON.c_str();
+	CSG_MetaData *pNode = this; const SG_Char *pc = JSON.c_str();
 
 	while( *pc )
 	{
-		CSG_String	Element;
+		CSG_String Element;
 
-		for(bool bQuota=false;;)
+		for(bool bQuota=false; *pc; )
 		{
 			SG_Char c = *pc++;
 			
-			if( !c || c == '\n' ) { break; } else
+			if( c == '\0' || c == ',' )
 			{
-				if( c == '\"' )
+				break;
+			}
+			else if( c == '{' || c == '[' )
+			{
+				Element += c;
+
+				break;
+			}
+			else if( c == '}' || c == ']' )
+			{
+				if( Element.is_Empty() )
 				{
-					Element += c; bQuota = !bQuota;
+					Element = c;
 				}
-				else if( bQuota || (c != ' ' && c != '\t' && c != ',') )
+				else
 				{
-					Element += c;
+					pc--;
 				}
+
+				break;
+			}
+			else if( c == '\"' )
+			{
+				Element += c; bQuota = !bQuota;
+			}
+			else if( bQuota || (c != ' ' && c != '\n' && c != '\t') )
+			{
+				Element += c;
 			}
 		}
 
@@ -1121,7 +1143,7 @@ bool CSG_MetaData::from_JSON(const CSG_String &JSON)
 		}
 		else if( Element.Find('[') >= 0 )	// array begins
 		{
-			pNode	= pNode->Add_Child(Element.AfterFirst('\"').BeforeFirst('\"'));
+			pNode = pNode->Add_Child(Element.AfterFirst('\"').BeforeFirst('\"'));
 
 			pNode->Add_Property("array", 1);
 		}
@@ -1129,40 +1151,40 @@ bool CSG_MetaData::from_JSON(const CSG_String &JSON)
 		{
 			if( pNode != this )
 			{
-				pNode	= pNode->Get_Parent();
+				pNode = pNode->Get_Parent();
 			}
 		}
 		else if( Element.Find('{') >= 0 )	// object begins
 		{
-			Element	= Element.AfterFirst('\"').BeforeFirst('\"');
+			Element = Element.AfterFirst('\"').BeforeFirst('\"');
 
 			if( !Element.is_Empty() )
 			{
-				pNode	= pNode->Add_Child(Element);
+				pNode = pNode->Add_Child(Element);
 			}
 			else if( pNode->Get_Property("array") )
 			{
-				pNode	= pNode->Add_Child(CSG_String::Format("%d", pNode->Get_Children_Count()));
+				pNode = pNode->Add_Child(CSG_String::Format("%d", pNode->Get_Children_Count()));
 			}
 		}
 		else if( Element.Find('}') >= 0 )	// object ends
 		{
 			if( pNode != this )
 			{
-				pNode	= pNode->Get_Parent();
+				pNode = pNode->Get_Parent();
 			}
 		}
 		else
 		{
-			CSG_String	Key  (Element.AfterFirst('\"').BeforeFirst('\"'));
-			CSG_String	Value(Element.AfterFirst(':'));
+			CSG_String key(Element.AfterFirst('\"').BeforeFirst('\"'));
+			CSG_String val(Element.AfterFirst(':')); val.Trim();
 
-			if( Value.Find('\"') > -1 )
+			if( val.Find('\"') == 0 )
 			{
-				Value	= Value.AfterFirst('\"').BeforeFirst('\"');
+				val = val.AfterFirst('\"').BeforeFirst('\"');
 			}
 
-			pNode->Add_Child(Key, Value);
+			pNode->Add_Child(key, val);
 		}
 	}
 
@@ -1170,9 +1192,35 @@ bool CSG_MetaData::from_JSON(const CSG_String &JSON)
 }
 
 //---------------------------------------------------------
-bool CSG_MetaData::to_JSON(CSG_String &JSON)	const
+bool CSG_MetaData::to_JSON(CSG_String &JSON) const
 {
-	return( false );
+	if( Get_Parent() )
+	{
+		JSON += "\"" + Get_Name() + "\": ";
+	}
+
+	if( Get_Children_Count() )
+	{
+		JSON += "{";
+
+		for(int i=0; i<Get_Children_Count(); i++)
+		{
+			if( i > 0 )
+			{
+				JSON += ",";
+			}
+
+			Get_Child(i)->to_JSON(JSON);
+		}
+
+		JSON += "}";
+	}
+	else
+	{
+		JSON += " \"" + Get_Content() + "\"";
+	}
+
+	return( true );
 }
 
 
