@@ -805,10 +805,11 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int CSG_Parameter::_Set_Value(int               Value)	{	return( SG_PARAMETER_DATA_SET_FALSE );	}
-int CSG_Parameter::_Set_Value(double            Value)	{	return( SG_PARAMETER_DATA_SET_FALSE );	}
-int CSG_Parameter::_Set_Value(const CSG_String &Value)	{	return( SG_PARAMETER_DATA_SET_FALSE );	}
-int CSG_Parameter::_Set_Value(void             *Value)	{	return( SG_PARAMETER_DATA_SET_FALSE );	}
+int CSG_Parameter::_Set_Value(int                 Value) { return( SG_PARAMETER_DATA_SET_FALSE ); }
+int CSG_Parameter::_Set_Value(double              Value) { return( SG_PARAMETER_DATA_SET_FALSE ); }
+int CSG_Parameter::_Set_Value(CSG_Grid_Resampling Value) { return( SG_PARAMETER_DATA_SET_FALSE ); }
+int CSG_Parameter::_Set_Value(const CSG_String   &Value) { return( SG_PARAMETER_DATA_SET_FALSE ); }
+int CSG_Parameter::_Set_Value(void               *Value) { return( SG_PARAMETER_DATA_SET_FALSE ); }
 
 //---------------------------------------------------------
 bool CSG_Parameter::Set_Value(int Value)
@@ -840,6 +841,21 @@ bool CSG_Parameter::Set_Value(double Value)
 	return( true );
 }
 
+//---------------------------------------------------------
+bool CSG_Parameter::Set_Value(CSG_Grid_Resampling Value)
+{
+	switch( _Set_Value(Value) )
+	{
+	case SG_PARAMETER_DATA_SET_FALSE:
+		return( false );
+
+	case SG_PARAMETER_DATA_SET_CHANGED:
+		has_Changed();
+	}
+
+	return( true );
+}
+
 //---------------------------------------------------------
 bool CSG_Parameter::Set_Value(const char       *Value)	{	return( Set_Value(CSG_String(Value)) );	}
 bool CSG_Parameter::Set_Value(const wchar_t    *Value)	{	return( Set_Value(CSG_String(Value)) );	}
