@@ -56,9 +56,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -99,7 +99,7 @@ CSG_Parameters::~CSG_Parameters(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -195,7 +195,7 @@ void CSG_Parameters::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -427,7 +427,7 @@ void CSG_Parameters::Set_Enabled(const CSG_String &Identifier, bool bEnabled)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -437,9 +437,9 @@ CSG_Parameter * CSG_Parameters::Add_Parameter(CSG_Parameter *pParameter)
 }
 
 //---------------------------------------------------------
-CSG_Parameter * CSG_Parameters::Add_Node(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
+CSG_Parameter * CSG_Parameters::Add_Node(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, bool bCollapsed)
 {
-	return( _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Node, PARAMETER_INFORMATION) );
+	return( _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Node, bCollapsed ? PARAMETER_GUI_COLLAPSED|PARAMETER_INFORMATION : PARAMETER_INFORMATION) );
 }
 
 //---------------------------------------------------------
@@ -635,9 +635,44 @@ CSG_Parameter * CSG_Parameters::Add_FixedTable(const CSG_String &ParentID, const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+CSG_Parameter * CSG_Parameters::Add_Grid_Resampling(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Grid_Resampling Methods, CSG_Grid_Resampling Default)
+{
+	CSG_String Choices; int Choice = 0, nChoices = 0;
+
+	#define ADD_METHOD(method, name) if( ((int)Methods & (int)method) != 0 ) { if( !Choices.is_Empty() ) { Choices += "|"; } Choices += CSG_String::Format("{%d}", (int)method); Choices += name; if( method == Default ) { Choice = nChoices; } nChoices++; }
+
+	ADD_METHOD(CSG_Grid_Resampling::NearestNeighbour, _TL("Nearest Neighbour"));
+	ADD_METHOD(CSG_Grid_Resampling::Bilinear        , _TL("Bilinear"));
+	ADD_METHOD(CSG_Grid_Resampling::Bicubic_1       , CSG_String::Format("%s 1", _TL("Cubic")));
+	ADD_METHOD(CSG_Grid_Resampling::Bicubic_2       , CSG_String::Format("%s 2", _TL("Cubic")));
+	ADD_METHOD(CSG_Grid_Resampling::Mean_Nodes      , _TL("Mean Value"));
+	ADD_METHOD(CSG_Grid_Resampling::Mean_Cells      , _TL("Mean Value (cell area weighted)"));
+	ADD_METHOD(CSG_Grid_Resampling::Minimum         , _TL("Minimum Value"));
+	ADD_METHOD(CSG_Grid_Resampling::Maximum         , _TL("Maximum Value"));
+	ADD_METHOD(CSG_Grid_Resampling::Majority        , _TL("Majority"));
+
+	//-----------------------------------------------------
+	if( nChoices > 0 )
+	{
+		CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choice, 0);
+
+		pParameter->asChoice()->Set_Items(Choices);
+
+		bool bCallback = Set_Callback(false);
+		pParameter->Set_Value  (Choice);
+		pParameter->Set_Default(Choice);
+		Set_Callback(bCallback);
+
+		return( pParameter );
+	}
+
+	return( NULL );
+}
+
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grid_System(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Grid_System *pInit)
 {
@@ -718,7 +753,7 @@ CSG_Parameter * CSG_Parameters::Add_Grid_List(const CSG_String &ParentID, const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -778,7 +813,7 @@ CSG_Parameter * CSG_Parameters::Add_Grids_List(const CSG_String &ParentID, const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -856,7 +891,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_List(const CSG_String &ParentID, const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -891,7 +926,7 @@ CSG_Parameter * CSG_Parameters::Add_Shapes_List(const CSG_String &ParentID, cons
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -922,7 +957,7 @@ CSG_Parameter * CSG_Parameters::Add_TIN_List(const CSG_String &ParentID, const C
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -953,7 +988,7 @@ CSG_Parameter * CSG_Parameters::Add_PointCloud_List(const CSG_String &ParentID,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -969,7 +1004,7 @@ CSG_Parameter * CSG_Parameters::Add_Parameters(const CSG_String &ParentID, const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1074,7 +1109,7 @@ CSG_Parameter * CSG_Parameters::_Add_String(const CSG_String &ParentID, const CS
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1170,7 +1205,7 @@ CSG_Parameter * CSG_Parameters::_Add(CSG_Parameter *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1331,9 +1366,9 @@ bool CSG_Parameters::Del_Parameters(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Callback						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1396,7 +1431,7 @@ bool CSG_Parameters::_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1471,7 +1506,7 @@ bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, const wchar_t *Value, i
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1503,7 +1538,7 @@ bool CSG_Parameters::Restore_Defaults(bool bClearData)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1567,7 +1602,7 @@ bool CSG_Parameters::Assign_Parameters(CSG_Parameters *pSource)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1901,7 +1936,7 @@ bool CSG_Parameters::DataObjects_Set_Projection(const CSG_Projection &Projection
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1960,7 +1995,7 @@ bool CSG_Parameters::Msg_String(bool bOptionsOnly)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2067,9 +2102,9 @@ bool CSG_Parameters::Set_History(CSG_MetaData &MetaData, bool bOptions, bool bDa
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Grid System						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2098,9 +2133,9 @@ bool CSG_Parameters::Reset_Grid_System(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Serialize						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2288,9 +2323,9 @@ bool CSG_Parameters::Serialize_Compatibility(CSG_File &Stream)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
