@@ -98,6 +98,7 @@
 #define PARAMETER_IGNORE_PROJECTION			0x10
 #define PARAMETER_NOT_FOR_GUI				0x20
 #define PARAMETER_NOT_FOR_CMD				0x40
+#define PARAMETER_GUI_COLLAPSED				0x80
 
 #define PARAMETER_INPUT_OPTIONAL			(PARAMETER_INPUT  | PARAMETER_OPTIONAL)
 #define PARAMETER_OUTPUT_OPTIONAL			(PARAMETER_OUTPUT | PARAMETER_OPTIONAL)
@@ -228,6 +229,9 @@ public:	///////////////////////////////////////////////////
 	bool							Set_Enabled				(bool bEnabled  = true);
 	bool							is_Enabled				(bool bCheckEnv = true)	const;
 
+	bool							Set_Collapsed			(bool bOn = true);
+	bool							is_Collapsed			(void)	const	{	return( !!(m_Constraint & PARAMETER_GUI_COLLAPSED ) );	}
+
 	virtual bool					is_Valid				(void)	const	{	return( true );	}
 	bool							is_Input				(void)	const	{	return( !!(m_Constraint & PARAMETER_INPUT      ) );	}
 	bool							is_Output				(void)	const	{	return( !!(m_Constraint & PARAMETER_OUTPUT     ) );	}
@@ -241,8 +245,8 @@ public:	///////////////////////////////////////////////////
 	bool							is_Compatible			(CSG_Parameter *pParameter)	const;
 	bool							is_Value_Equal			(CSG_Parameter *pParameter)	const;
 
-	void							Set_UseInGUI			(bool bDoUse = false);
-	void							Set_UseInCMD			(bool bDoUse = false);
+	void							Set_UseInGUI			(bool bOn = false);
+	void							Set_UseInCMD			(bool bOn = false);
 
 	bool							do_UseInGUI				(void)	const;
 	bool							do_UseInCMD				(void)	const;
@@ -257,13 +261,14 @@ public:	///////////////////////////////////////////////////
 	bool							Set_Children_Enabled	(bool bEnabled = true);
 
 	//-----------------------------------------------------
-	virtual bool					Set_Value				(int               Value);
-	virtual bool					Set_Value				(double            Value);
-	virtual bool					Set_Value				(const CSG_String &Value);
-	virtual bool					Set_Value				(const char       *Value);
-	virtual bool					Set_Value				(const wchar_t    *Value);
-	virtual bool					Set_Value				(void             *Value);
-	virtual bool					Set_Value				(CSG_Parameter    *Value);
+	virtual bool					Set_Value				(int                 Value);
+	virtual bool					Set_Value				(double              Value);
+	virtual bool					Set_Value				(CSG_Grid_Resampling Value);
+	virtual bool					Set_Value				(const CSG_String   &Value);
+	virtual bool					Set_Value				(const char         *Value);
+	virtual bool					Set_Value				(const wchar_t      *Value);
+	virtual bool					Set_Value				(void               *Value);
+	virtual bool					Set_Value				(CSG_Parameter      *Value);
 
 	virtual bool					Toggle_Value			(void);
 
@@ -288,6 +293,7 @@ public:	///////////////////////////////////////////////////
 	CSG_Colors                    *	asColors				(void)	const;
 	const SG_Char                 *	asFont					(void)	const;
 	CSG_Grid_System               *	asGrid_System			(void)	const;
+	CSG_Grid_Resampling				asGrid_Resampling		(void)	const;
 
 	CSG_Data_Object               *	asDataObject			(void)	const;
 	CSG_Grid                      *	asGrid					(void)	const;
@@ -331,10 +337,11 @@ protected: ////////////////////////////////////////////////
 	CSG_String						m_String;
 
 
-	virtual int						_Set_Value				(int               Value);
-	virtual int						_Set_Value				(double            Value);
-	virtual int						_Set_Value				(const CSG_String &Value);
-	virtual int						_Set_Value				(void             *Value);
+	virtual int						_Set_Value				(int                 Value);
+	virtual int						_Set_Value				(double              Value);
+	virtual int						_Set_Value				(CSG_Grid_Resampling Value);
+	virtual int						_Set_Value				(const CSG_String   &Value);
+	virtual int						_Set_Value				(void               *Value);
 
 	virtual void					_Set_String				(void);
 
@@ -692,9 +699,10 @@ protected:
 	CSG_Strings					m_Items, m_Data;
 
 
-	virtual int					_Set_Value				(int               Value);
-	virtual int					_Set_Value				(double            Value);
-	virtual int					_Set_Value				(const CSG_String &Value);
+	virtual int					_Set_Value				(int                 Value);
+	virtual int					_Set_Value				(double              Value);
+	virtual int					_Set_Value				(CSG_Grid_Resampling Value);
+	virtual int					_Set_Value				(const CSG_String   &Value);
 
 	virtual void				_Set_String				(void);
 
@@ -1034,6 +1042,7 @@ protected:
 	CSG_Grid_System				m_System;
 
 
+	virtual int					_Set_Value				(const CSG_String &Value);
 	virtual int					_Set_Value				(void *Value);
 
 	virtual void				_Set_String				(void);
@@ -1774,7 +1783,7 @@ public:
 	//-----------------------------------------------------
 	CSG_Parameter *				Add_Parameter			(CSG_Parameter *pParameter);
 
-	CSG_Parameter *				Add_Node				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description);
+	CSG_Parameter *				Add_Node				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, bool bCollapsed = false);
 
 	CSG_Parameter *				Add_Value				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, TSG_Parameter_Type Type, double Value = 0.0, double Minimum = 0.0, bool bMinimum = false, double Maximum = 0.0, bool bMaximum = false);
 	CSG_Parameter *				Add_Info_Value			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, TSG_Parameter_Type Type, double Value = 0.0);
@@ -1804,6 +1813,7 @@ public:
 	CSG_Parameter *				Add_Font				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const SG_Char *pInit = NULL);
 	CSG_Parameter *				Add_FixedTable			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Table     *pInit = NULL);
 
+	CSG_Parameter *				Add_Grid_Resampling		(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Grid_Resampling Methods = CSG_Grid_Resampling::Interpolations, CSG_Grid_Resampling Default = CSG_Grid_Resampling::Bicubic_2);
 	CSG_Parameter *				Add_Grid_System			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Grid_System *pInit = NULL);
 	CSG_Parameter *				Add_Grid				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint, bool bSystem_Dependent = true, TSG_Data_Type Preferred_Type = SG_DATATYPE_Undefined);
 	CSG_Parameter *				Add_Grid_or_Const		(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, double Value = 0.0, double Minimum = 0.0, bool bMinimum = false, double Maximum = 0.0, bool bMaximum = false, bool bSystem_Dependent = true);
