@@ -58,12 +58,12 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define PC_FILE_VERSION		"SGPC01"
+#define PC_FILE_VERSION "SGPC01"
 
-#define PC_STR_NBYTES		32
-#define PC_DAT_NBYTES		32
-
-#define PC_GET_NBYTES(type)	(type == SG_DATATYPE_String ? PC_STR_NBYTES : type == SG_DATATYPE_Date ? PC_DAT_NBYTES : (int)SG_Data_Type_Get_Size(type))
+#define PC_SIZE_STRING       32
+#define PC_SIZE_DATE         32
+#define PC_SIZE_TYPE(type)   (type == SG_DATATYPE_String ? PC_SIZE_STRING : type == SG_DATATYPE_Date ? PC_SIZE_DATE : (int)SG_Data_Type_Get_Size(type))
+#define PC_SIZE_FIELD(field) PC_SIZE_TYPE(m_Field_Info[field]->m_Type)
 
 
 ///////////////////////////////////////////////////////////
@@ -116,16 +116,14 @@ CSG_PointCloud * SG_Create_PointCloud(CSG_PointCloud *pStructure)
 CSG_PointCloud::CSG_PointCloud(void)
 	: CSG_Shapes()
 {
-	_On_Construction();
-
-	Create();
+	_On_Construction(); Create();
 }
 
 bool CSG_PointCloud::Create(void)
 {
 	Destroy();
 
-	Add_Field("", SG_DATATYPE_Undefined);	// add x, y, z fields
+	Add_Field("", SG_DATATYPE_Undefined); // add x, y, z fields
 
 	return( true );
 }
@@ -171,9 +169,9 @@ bool CSG_PointCloud::Create(CSG_PointCloud *pTemplate)
 
 	if( pTemplate && pTemplate->m_nFields > 0 )
 	{
-		for(int iField=0; iField<pTemplate->m_nFields; iField++)
+		for(int i=0; i<pTemplate->m_nFields; i++)
 		{
-			_Add_Field(pTemplate->Get_Field_Name(iField), pTemplate->Get_Field_Type(iField));
+			_Add_Field(pTemplate->m_Field_Info[i]->m_Name, pTemplate->m_Field_Info[i]->m_Type);
 		}
 
 		return( true );
@@ -188,19 +186,6 @@ void CSG_PointCloud::_On_Construction(void)
 	m_Type         = SHAPE_TYPE_Point;
 	m_Vertex_Type  = SG_VERTEX_TYPE_XYZ;
 
-	m_nFields      = 0;
-	m_Field_Name   = NULL;
-	m_Field_Type   = NULL;
-	m_Field_Stats  = NULL;
-	m_Field_Offset = NULL;
-
-	m_Points       = NULL;
-	m_nRecords     = 0;
-	m_nPointBytes  = 0;
-
-	m_Cursor       = NULL;
-	m_bXYZPrecDbl  = true;
-
 	Set_NoData_Value(-999999);
 
 	Set_Update_Flag();
@@ -227,16 +212,15 @@ bool CSG_PointCloud::Destroy(void)
 
 	if( m_nFields > 0 )
 	{
-		for(int iField=0; iField<m_nFields; iField++)
+		for(int i=0; i<m_nFields; i++)
 		{
-			delete(m_Field_Name [iField]);
-			delete(m_Field_Stats[iField]);
+			delete(m_Field_Info[i]);
 		}
 
-		SG_Free(m_Field_Name  );
-		SG_Free(m_Field_Type  );
-		SG_Free(m_Field_Stats );
-		SG_Free(m_Field_Offset);
+		SG_Free(m_Field_Info  ); m_Field_Info   = NULL;
+		SG_Free(m_Field_Offset); m_Field_Offset = NULL;
+
+		m_nFields = 0;
 
 		_On_Construction();
 	}
@@ -249,7 +233,7 @@ bool CSG_PointCloud::Destroy(void)
 
 ///////////////////////////////////////////////////////////
 //                                                       //
-//						File							 //
+//                         File                          //
 //                                                       //
 ///////////////////////////////////////////////////////////
 
@@ -548,11 +532,11 @@ bool CSG_PointCloud::_Save(CSG_File &Stream)
 
 	for(int iField=0; iField<m_nFields; iField++)
 	{
-		Stream.Write(&m_Field_Type[iField], sizeof(TSG_Data_Type));
+		Stream.Write(&m_Field_Info[iField]->m_Type, sizeof(TSG_Data_Type));
 
-		iBuffer = (int)m_Field_Name[iField]->Length(); if( iBuffer >= 1024 - 1 ) iBuffer	= 1024 - 1;
+		iBuffer = (int)m_Field_Info[iField]->m_Name.Length(); if( iBuffer >= 1024 - 1 ) iBuffer	= 1024 - 1;
 		Stream.Write(&iBuffer, sizeof(int));
-		Stream.Write((void *)m_Field_Name[iField]->b_str(), sizeof(char), iBuffer);
+		Stream.Write((void *)m_Field_Info[iField]->m_Name.b_str(), sizeof(char), iBuffer);
 	}
 
 	_Shape_Flush();
@@ -665,22 +649,19 @@ bool CSG_PointCloud::is_Compatible(CSG_PointCloud *pPointCloud) const
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_PointCloud::Add_Field(const CSG_String &Name, TSG_Data_Type Type, int iField)
+bool CSG_PointCloud::Add_Field(const CSG_String &Name, TSG_Data_Type Type, int Field)
 {
 	if( m_nFields == 0 ) { _Add_Field(SG_T("X"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float); }
 	if( m_nFields == 1 ) { _Add_Field(SG_T("Y"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float); }
 	if( m_nFields == 2 ) { _Add_Field(SG_T("Z"), m_bXYZPrecDbl ? SG_DATATYPE_Double : SG_DATATYPE_Float); }
 
-	return( m_nFields >= 3 && _Add_Field(Name, Type, iField) );
+	return( m_nFields >= 3 && _Add_Field(Name, Type, Field) );
 }
 
 //---------------------------------------------------------
 bool CSG_PointCloud::_Add_Field(const SG_Char *Name, TSG_Data_Type Type, int Field)
 {
-	#define m_Field_Size(FIELD)	PC_GET_NBYTES(m_Field_Type[FIELD])
-
-	//-----------------------------------------------------
-	if( !Name || PC_GET_NBYTES(Type) <= 0 )
+	if( !Name || PC_SIZE_TYPE(Type) <= 0 )
 	{
 		return( false );
 	}
@@ -696,7 +677,7 @@ bool CSG_PointCloud::_Add_Field(const SG_Char *Name, TSG_Data_Type Type, int Fie
 	}
 
 	//-----------------------------------------------------
-	int nFieldBytes = PC_GET_NBYTES(Type);
+	int nFieldBytes = PC_SIZE_TYPE(Type);
 
 	if( m_nFields < 1 )
 	{
@@ -706,25 +687,19 @@ bool CSG_PointCloud::_Add_Field(const SG_Char *Name, TSG_Data_Type Type, int Fie
 	m_nFields++; m_nPointBytes += nFieldBytes;
 
 	//-----------------------------------------------------
-	m_Field_Name   = (CSG_String            **)SG_Realloc(m_Field_Name  , m_nFields * sizeof(CSG_String            *));
-	m_Field_Type   = (TSG_Data_Type          *)SG_Realloc(m_Field_Type  , m_nFields * sizeof(TSG_Data_Type          ));
-	m_Field_Stats  = (CSG_Simple_Statistics **)SG_Realloc(m_Field_Stats , m_nFields * sizeof(CSG_Simple_Statistics *));
-	m_Field_Offset = (int                    *)SG_Realloc(m_Field_Offset, m_nFields * sizeof(int                    ));
+	m_Field_Offset = (int             *)SG_Realloc(m_Field_Offset, m_nFields * sizeof(int             ));
+	m_Field_Info   = (CSG_Field_Info **)SG_Realloc(m_Field_Info  , m_nFields * sizeof(CSG_Field_Info *));
 
-	for(int iField=m_nFields-1; iField>Field; iField--)
+	for(int i=m_nFields-1; i>Field; i--)
 	{
-		m_Field_Name [iField] = m_Field_Name [iField - 1];
-		m_Field_Type [iField] = m_Field_Type [iField - 1];
-		m_Field_Stats[iField] = m_Field_Stats[iField - 1];
+		m_Field_Info[i] = m_Field_Info[i - 1];
 	}
 
-	m_Field_Name [Field] = new CSG_String(Name);
-	m_Field_Type [Field] = Type;
-	m_Field_Stats[Field] = new CSG_Simple_Statistics();
+	m_Field_Info[Field] = new CSG_Field_Info(Name, Type);
 
-	for(int iField=0, Offset=1; iField<m_nFields; iField++)
+	for(int i=0, Offset=1; i<m_nFields; i++)
 	{
-		m_Field_Offset[iField] = Offset; Offset+=m_Field_Size(iField);
+		m_Field_Offset[i] = Offset; Offset += PC_SIZE_FIELD(i);
 	}
 
 	//-----------------------------------------------------
@@ -752,23 +727,20 @@ bool CSG_PointCloud::_Add_Field(const SG_Char *Name, TSG_Data_Type Type, int Fie
 }
 
 //---------------------------------------------------------
-bool CSG_PointCloud::Del_Field(int Index)
+bool CSG_PointCloud::Del_Field(int Field)
 {
-	#define m_Field_Size(FIELD)	PC_GET_NBYTES(m_Field_Type[FIELD])
-
-	//-----------------------------------------------------
-	if( Index < 3 || Index >= m_nFields )
+	if( Field < 3 || Field >= m_nFields )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	int nFieldBytes = PC_GET_NBYTES(m_Field_Type[Index]);
+	int nFieldBytes = PC_SIZE_FIELD(Field);
 
 	m_nFields--; m_nPointBytes -= nFieldBytes;
 
 	//-----------------------------------------------------
-	int Offset = m_Field_Offset[Index], nMoveBytes = Index < m_nFields ? (m_nPointBytes + nFieldBytes) - m_Field_Offset[Index + 1] : 0;
+	int Offset = m_Field_Offset[Field], nMoveBytes = Field < m_nFields ? (m_nPointBytes + nFieldBytes) - m_Field_Offset[Field + 1] : 0;
 
 	#pragma omp parallel for
 	for(sLong i=0; i<m_nRecords; i++)
@@ -782,24 +754,19 @@ bool CSG_PointCloud::Del_Field(int Index)
 	}
 
 	//-----------------------------------------------------
-	delete(m_Field_Name [Index]);
-	delete(m_Field_Stats[Index]);
+	delete(m_Field_Info[Field]);
 
-	for(int iField=Index, Offset=m_Field_Offset[Index]; iField<m_nFields; iField++)
+	for(int i=Field, Offset=m_Field_Offset[Field]; i<m_nFields; i++)
 	{
-		m_Field_Name  [iField] = m_Field_Name [iField + 1];
-		m_Field_Type  [iField] = m_Field_Type [iField + 1];
-		m_Field_Stats [iField] = m_Field_Stats[iField + 1];
-		m_Field_Offset[iField] = Offset; Offset += m_Field_Size(iField);
+		m_Field_Info  [i] = m_Field_Info[i + 1];
+		m_Field_Offset[i] = Offset; Offset += PC_SIZE_FIELD(i);
 	}
 
-	m_Field_Name   = (CSG_String            **)SG_Realloc(m_Field_Name  , m_nFields * sizeof(CSG_String            *));
-	m_Field_Type   = (TSG_Data_Type          *)SG_Realloc(m_Field_Type  , m_nFields * sizeof(TSG_Data_Type          ));
-	m_Field_Stats  = (CSG_Simple_Statistics **)SG_Realloc(m_Field_Stats , m_nFields * sizeof(CSG_Simple_Statistics *));
-	m_Field_Offset = (int                    *)SG_Realloc(m_Field_Offset, m_nFields * sizeof(int                    ));
+	m_Field_Info   = (CSG_Field_Info **)SG_Realloc(m_Field_Info  , m_nFields * sizeof(CSG_Field_Info *));
+	m_Field_Offset = (int             *)SG_Realloc(m_Field_Offset, m_nFields * sizeof(int             ));
 
 	//-----------------------------------------------------
-	m_Shapes.Del_Field(Index);
+	m_Shapes.Del_Field(Field);
 
 	Set_Modified();
 
@@ -807,7 +774,7 @@ bool CSG_PointCloud::Del_Field(int Index)
 }
 
 //---------------------------------------------------------
-bool CSG_PointCloud::Mov_Field(int Index, int Position)
+bool CSG_PointCloud::Mov_Field(int Field, int Position)
 {
 	if( Position < 0 )
 	{
@@ -818,36 +785,36 @@ bool CSG_PointCloud::Mov_Field(int Index, int Position)
 		Position = m_nFields - 1;
 	}
 
-	if( Index < 3 || Index >= m_nFields || Index == Position )
+	if( Field < 3 || Field >= m_nFields || Field == Position )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	if( Position > Index )
+	if( Position > Field )
 	{
 		Position++;
 	}
 
-	if( !Add_Field(Get_Field_Name(Index), Get_Field_Type(Index), Position) )
+	if( !Add_Field(m_Field_Info[Field]->m_Name, m_Field_Info[Field]->m_Type, Position) )
 	{
 		return( false );
 	}
 
-	if( Position < Index )
+	if( Position < Field )
 	{
-		Index++;
+		Field++;
 	}
 
-	size_t Size = PC_GET_NBYTES(m_Field_Type[Index]);
+	size_t Size = PC_SIZE_FIELD(Field);
 
 	#pragma omp parallel for
 	for(sLong i=0; i<m_nRecords; i++)
 	{
-		memcpy(m_Points[i] + m_Field_Offset[Position], m_Points[i] + m_Field_Offset[Index], Size);
+		memcpy(m_Points[i] + m_Field_Offset[Position], m_Points[i] + m_Field_Offset[Field], Size);
 	}
 
-	if( !Del_Field(Index) )
+	if( !Del_Field(Field) )
 	{
 		return( false );
 	}
@@ -887,7 +854,7 @@ bool CSG_PointCloud::Set_Field_Type(int iField, TSG_Data_Type Type)
 		return( false );
 	}
 
-	if( Type == m_Field_Type[iField] )
+	if( Type == m_Field_Info[iField]->m_Type )
 	{
 		return( true );
 	}
@@ -912,13 +879,13 @@ bool CSG_PointCloud::Set_Field_Type(int iField, TSG_Data_Type Type)
 }
 
 //---------------------------------------------------------
-bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int iField, double Value)
+bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int Field, double Value)
 {
-	if( pPoint && iField >= 0 && iField < m_nFields )
+	if( pPoint && Field >= 0 && Field < m_nFields )
 	{
-		pPoint = ((char *)pPoint) + m_Field_Offset[iField];
+		pPoint = ((char *)pPoint) + m_Field_Offset[Field];
 
-		switch( m_Field_Type[iField] )
+		switch( m_Field_Info[Field]->m_Type )
 		{
 		case SG_DATATYPE_Byte  : *((BYTE   *)pPoint) = (BYTE  )Value ; break;
 		case SG_DATATYPE_Char  : *((char   *)pPoint) = (char  )Value ; break;
@@ -935,13 +902,13 @@ bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int iField, double Value)
 		default                :                                       break;
 		}
 
-		m_Field_Stats[iField]->Invalidate();
+		m_Field_Info[Field]->Reset_Statistics();
 
 		Set_Modified();
 
-		if( iField < 3 )
+		if( Field < 3 )
 		{
-			Set_Update_Flag();	// extent might have changed
+			Set_Update_Flag(); // extent might have changed
 		}
 
 		return( true );
@@ -951,13 +918,13 @@ bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int iField, double Value)
 }
 
 //---------------------------------------------------------
-double CSG_PointCloud::_Get_Field_Value(char *pPoint, int iField) const
+double CSG_PointCloud::_Get_Field_Value(char *pPoint, int Field) const
 {
-	if( pPoint && iField >= 0 && iField < m_nFields )
+	if( pPoint && Field >= 0 && Field < m_nFields )
 	{
-		pPoint += m_Field_Offset[iField];
+		pPoint += m_Field_Offset[Field];
 
-		switch( m_Field_Type[iField] )
+		switch( m_Field_Info[Field]->m_Type )
 		{
 		case SG_DATATYPE_Byte  : return( (double)*((BYTE   *)pPoint) );
 		case SG_DATATYPE_Char  : return( (double)*((char   *)pPoint) );
@@ -979,21 +946,21 @@ double CSG_PointCloud::_Get_Field_Value(char *pPoint, int iField) const
 }
 
 //---------------------------------------------------------
-bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int iField, const SG_Char *Value)
+bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int Field, const SG_Char *Value)
 {
-	if( pPoint && iField >= 0 && iField < m_nFields && Value )
+	if( pPoint && Field >= 0 && Field < m_nFields && Value )
 	{
 		CSG_String s(Value);
 
-		switch( m_Field_Type[iField] )
+		switch( m_Field_Info[Field]->m_Type )
 		{
-		default: { double d; return( s.asDouble(d) && _Set_Field_Value(pPoint, iField, d) ); }
+		default: { double d; return( s.asDouble(d) && _Set_Field_Value(pPoint, Field, d) ); }
 
 		case SG_DATATYPE_Date  :
 		case SG_DATATYPE_String:
-			pPoint	+= m_Field_Offset[iField];
-			memset(pPoint, 0, PC_STR_NBYTES);
-			memcpy(pPoint, s.b_str(), s.Length() > PC_STR_NBYTES ? PC_STR_NBYTES : s.Length());
+			pPoint	+= m_Field_Offset[Field];
+			memset(pPoint, 0, PC_SIZE_STRING);
+			memcpy(pPoint, s.b_str(), s.Length() > PC_SIZE_STRING ? PC_SIZE_STRING : s.Length());
 			break;
 		}
 
@@ -1004,26 +971,24 @@ bool CSG_PointCloud::_Set_Field_Value(char *pPoint, int iField, const SG_Char *V
 }
 
 //---------------------------------------------------------
-bool CSG_PointCloud::_Get_Field_Value(char *pPoint, int iField, CSG_String &Value)	const
+bool CSG_PointCloud::_Get_Field_Value(char *pPoint, int Field, CSG_String &Value)	const
 {
-	if( pPoint && iField >= 0 && iField < m_nFields )
+	if( pPoint && Field >= 0 && Field < m_nFields )
 	{
-		switch( m_Field_Type[iField] )
+		switch( m_Field_Info[Field]->m_Type )
 		{
-		default:
-			Value.Printf("%f", _Get_Field_Value(pPoint, iField));
-			break;
+		default: Value.Printf("%f", _Get_Field_Value(pPoint, Field)); break;
 
-		case SG_DATATYPE_Date:
+		case SG_DATATYPE_Date  :
 		case SG_DATATYPE_String:
 			{
-				char	s[PC_STR_NBYTES + 1];
+				char s[PC_SIZE_STRING + 1];
 
-				memcpy(s, pPoint + m_Field_Offset[iField], PC_STR_NBYTES);
+				memcpy(s, pPoint + m_Field_Offset[Field], PC_SIZE_STRING);
 
-				s[PC_STR_NBYTES]	= '\0';
+				s[PC_SIZE_STRING] = '\0';
 
-				Value	= s;
+				Value = s;
 			}
 			break;
 		}
@@ -1177,7 +1142,7 @@ bool CSG_PointCloud::Del_Points(void)
 		SG_Free(m_Points[i]);
 	}
 
-	m_Array_Points.Destroy();
+	m_Array_Points.Set_Array(0);
 
 	m_nRecords = 0;
 	m_Points   = NULL;
@@ -1243,22 +1208,15 @@ bool CSG_PointCloud::On_Update(void)
 	{
 		_Shape_Flush();
 
-		_Stats_Update(0);
-		_Stats_Update(1);
-		_Stats_Update(2);
+		for(int iField=0; iField<m_nFields; iField++)
+		{
+			m_Field_Info[iField]->Reset_Statistics();
+		}
 
-		m_Extent.Assign(
-			m_Field_Stats[0]->Get_Minimum(), m_Field_Stats[1]->Get_Minimum(),
-			m_Field_Stats[0]->Get_Maximum(), m_Field_Stats[1]->Get_Maximum()
-		);
+		m_Extent.Create(Get_Minimum(0), Get_Minimum(1), Get_Maximum(0), Get_Maximum(1));
 
-		m_ZMin = m_Field_Stats[2]->Get_Minimum();
-		m_ZMax = m_Field_Stats[2]->Get_Maximum();
-
-        for(int iField=3; iField<m_nFields; iField++)
-        {
-            m_Field_Stats[iField]->Invalidate();
-        }
+		m_ZMin = Get_Minimum(2);
+		m_ZMax = Get_Maximum(2);
 	}
 
 	return( true );
@@ -1267,52 +1225,31 @@ bool CSG_PointCloud::On_Update(void)
 //---------------------------------------------------------
 bool CSG_PointCloud::_Stats_Update(int Field) const
 {
-	if( Field < 0 || Field >= m_nFields || m_nRecords < 1 )
+	if( Field >= 3 ) // attributes, else => always get full statistics for x, y, z coordinates!
+	{
+		return( CSG_Table::_Stats_Update(Field) );
+	}
+
+	if( Field < 0 || m_nRecords < 1 )
 	{
 		return( false );
 	}
 
-	CSG_Simple_Statistics &Statistics = *m_Field_Stats[Field];
+	CSG_Simple_Statistics &Statistics = m_Field_Info[Field]->m_Statistics;
 
 	if( Statistics.is_Evaluated() )
 	{
 		return( true );
 	}
 
-	if( Field > 2 && Get_Max_Samples() > 0 && Get_Max_Samples() < m_nRecords )
+	char **pPoint = m_Points;
+
+	for(sLong i=0; i<m_nRecords; i++, pPoint++)
 	{
-		double d = (double)m_nRecords / (double)Get_Max_Samples();
-
-		for(double i=0; i<(double)m_nRecords; i+=d)
-		{
-			double Value = Get_Value((sLong)i, Field);
-
-			if( Field < 3 || is_NoData_Value(Value) == false )
-			{
-				Statistics += Value;
-			}
-		}
-
-		Statistics.Set_Count(Statistics.Get_Count() >= Get_Max_Samples() ? m_nRecords	// any no-data cells ?
-			: (sLong)(m_nRecords * (double)Statistics.Get_Count() / (double)Get_Max_Samples())
-		);
-	}
-	else
-	{
-		char **pPoint = m_Points;
-
-		for(sLong i=0; i<m_nRecords; i++, pPoint++)
-		{
-			double Value = _Get_Field_Value(*pPoint, Field);
-
-			if( Field < 3 || is_NoData_Value(Value) == false )
-			{
-				Statistics += Value;
-			}
-		}
+		Statistics += _Get_Field_Value(*pPoint, Field);
 	}
 
-	return( Statistics.Evaluate() );	// evaluate! prevent values to be added more than once!
+	return( Statistics.Evaluate() ); // evaluate! prevent values to be added more than once!
 }
 
 
@@ -1598,9 +1535,9 @@ bool CSG_PointCloud::is_Selected(sLong Index)	const
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Shape * CSG_PointCloud::Get_Selection(sLong Index)
+CSG_Table_Record * CSG_PointCloud::Get_Selection(sLong Index) const
 {
-	return( Index < Get_Selection_Count() ? _Shape_Get(Get_Selection_Index(Index)) : NULL );
+	return( Index < Get_Selection_Count() ? ((CSG_PointCloud *)this)->_Shape_Get(Get_Selection_Index(Index)) : NULL );
 }
 
 //---------------------------------------------------------
