@@ -58,9 +58,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -95,7 +95,7 @@ CSG_Tool::~CSG_Tool(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -108,7 +108,7 @@ void CSG_Tool::Destroy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -249,9 +249,9 @@ bool CSG_Tool::has_CMD(void) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -394,9 +394,9 @@ bool CSG_Tool::Execute(bool bAddHistory)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -443,9 +443,9 @@ bool CSG_Tool::Get_Projection(CSG_Projection &Projection)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Parameters						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -486,9 +486,9 @@ int CSG_Tool::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *p
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Extra Parameters					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -536,7 +536,7 @@ bool CSG_Tool::Dlg_Parameters(const CSG_String &Identifier)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -552,7 +552,7 @@ bool CSG_Tool::Dlg_Parameters(CSG_Parameters &Parameters, const CSG_String &Capt
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -612,9 +612,9 @@ bool CSG_Tool::Delete_Manager(bool bDetachData, bool bReset)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -645,9 +645,9 @@ bool CSG_Tool::Settings_Pop(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Progress						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -684,9 +684,9 @@ bool CSG_Tool::Stop_Execution(bool bDialog)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Message							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -790,9 +790,9 @@ bool CSG_Tool::Error_Fmt(const wchar_t *Format, ...)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //			DataObjects / GUI Interaction				 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -812,7 +812,7 @@ bool CSG_Tool::DataObject_Add(CSG_Data_Object *pDataObject, bool bShow)
 }
 
 //---------------------------------------------------------
-void CSG_Tool::DataObject_Update_All(void)
+bool CSG_Tool::DataObject_Update_All(void)
 {
 	for(int i=0; i<Parameters.Get_Count(); i++)
 	{
@@ -831,13 +831,15 @@ void CSG_Tool::DataObject_Update_All(void)
 			}
 		}
 	}
+
+	return( true );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //		Static Data Message/Progress Functions			 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -967,9 +969,9 @@ void CSG_Tool::Message_Fmt(const wchar_t *Format, ...)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //		Static Data Object Property Functions			 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -980,15 +982,14 @@ bool CSG_Tool::DataObject_Update(CSG_Data_Object *pDataObject, int Show)
 
 bool CSG_Tool::DataObject_Update(CSG_Data_Object *pDataObject, double Minimum, double Maximum, int Show)
 {
-	CSG_Parameters	P;
+	CSG_Parameters P;
 
 	return( DataObject_Get_Parameters(pDataObject, P)
-		&&  P.Set_Parameter("STRETCH_UPDATE"   , false  )	// internal update flag
-		&&  P.Set_Parameter("STRETCH_DEFAULT"  , 3      )	// manual
+		&&  P.Set_Parameter("STRETCH_DEFAULT"  , 3      ) // manual
 		&&  P.Set_Parameter("METRIC_ZRANGE.MIN", Minimum)
 		&&  P.Set_Parameter("METRIC_ZRANGE.MAX", Maximum)
 		&&  SG_UI_DataObject_Update(pDataObject, Show, &P)
-		);
+	);
 }
 
 //---------------------------------------------------------
@@ -999,16 +1000,17 @@ bool CSG_Tool::DataObject_Get_Colors(CSG_Data_Object *pDataObject, CSG_Colors &C
 
 bool CSG_Tool::DataObject_Set_Colors(CSG_Data_Object *pDataObject, const CSG_Colors &Colors)
 {
-	CSG_Colors	c(Colors);
-
-	return( SG_UI_DataObject_Colors_Set(pDataObject, &c) );
+	CSG_Colors c; return( c.Create(Colors) && SG_UI_DataObject_Colors_Set(pDataObject, &c) );
 }
 
-bool CSG_Tool::DataObject_Set_Colors(CSG_Data_Object *pDataObject, int nColors, int Palette, bool bRevert)
+bool CSG_Tool::DataObject_Set_Colors(CSG_Data_Object *pDataObject, int nColors, int Colors, bool bRevert)
 {
-	CSG_Colors	c(nColors, Palette, bRevert);
+	CSG_Colors c; return( c.Set_Predefined(Colors, bRevert, nColors) && SG_UI_DataObject_Colors_Set(pDataObject, &c) );
+}
 
-	return( SG_UI_DataObject_Colors_Set(pDataObject, &c) );
+bool CSG_Tool::DataObject_Set_Colors(CSG_Data_Object *pDataObject, const CSG_String &Colors, int nColors, bool bRevert)
+{
+	CSG_Colors c; return( c.Set_Predefined(Colors, bRevert, nColors) && SG_UI_DataObject_Colors_Set(pDataObject, &c) );
 }
 
 //---------------------------------------------------------
@@ -1127,9 +1129,151 @@ bool CSG_Tool::DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#define INIT_STRETCH_OPTIONS(method) { if( !pDataObject || (pDataObject->asTable(true) && (Field < 0 || Field >= pDataObject->asTable(true)->Get_Field_Count())) ) { return( false ); }\
+	if( Colors >= 0 ) { DataObject_Set_Colors(pDataObject, -1, Colors); }\
+	DataObject_Set_Parameter(pDataObject, "COLORS_TYPE"      , 3); /* graduated colors */\
+	DataObject_Set_Parameter(pDataObject, "STRETCH_DEFAULT"  , method);\
+	DataObject_Set_Parameter(pDataObject, "METRIC_SCALE_MODE", Interval_Mode);\
+	DataObject_Set_Parameter(pDataObject, "METRIC_SCALE_LOG" , Interval_Log );\
+	if( pDataObject->asTable(true) )\
+	{	DataObject_Set_Parameter(pDataObject, "METRIC_FIELD" , Field);\
+		DataObject_Set_Parameter(pDataObject, "METRIC_MORMAL", pDataObject->asTable(true)->Get_Field_Count());\
+	}\
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Set_Stretch_Linear(CSG_Data_Object *pDataObject, int Field, double Minimum, double Maximum, int Interval_Mode, double Interval_Log, int Colors, bool bUpdateNow)
+{
+	INIT_STRETCH_OPTIONS(0);
+
+	DataObject_Set_Parameter(pDataObject, "STRETCH_LINEAR.MIN", Minimum);
+	DataObject_Set_Parameter(pDataObject, "STRETCH_LINEAR.MAX", Maximum);
+
+	return( bUpdateNow ? DataObject_Update(pDataObject) : true );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Set_Stretch_StdDev(CSG_Data_Object *pDataObject, int Field, double StdDev, bool bKeepInRange, int Interval_Mode, double Interval_Log, int Colors, bool bUpdateNow)
+{
+	INIT_STRETCH_OPTIONS(1);
+
+	DataObject_Set_Parameter(pDataObject, "STRETCH_STDDEV" , StdDev      );
+	DataObject_Set_Parameter(pDataObject, "STRETCH_INRANGE", bKeepInRange);
+	DataObject_Update(pDataObject);
+
+	return( bUpdateNow ? DataObject_Update(pDataObject) : true );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Set_Stretch_Percentile(CSG_Data_Object *pDataObject, int Field, double Minimum, double Maximum, int Interval_Mode, double Interval_Log, int Colors, bool bUpdateNow)
+{
+	INIT_STRETCH_OPTIONS(2);
+
+	DataObject_Set_Parameter(pDataObject, "STRETCH_PCTL.MIN", Minimum);
+	DataObject_Set_Parameter(pDataObject, "STRETCH_PCTL.MAX", Maximum);
+
+	return( bUpdateNow ? DataObject_Update(pDataObject) : true );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Set_Stretch(CSG_Data_Object *pDataObject, int Field, double Minimum, double Maximum, int Interval_Mode, double Interval_Log, int Colors, bool bUpdateNow)
+{
+	INIT_STRETCH_OPTIONS(3);
+
+	DataObject_Set_Parameter(pDataObject, "METRIC_ZRANGE.MIN", Minimum);
+	DataObject_Set_Parameter(pDataObject, "METRIC_ZRANGE.MAX", Maximum);
+
+	return( bUpdateNow ? DataObject_Update(pDataObject) : true );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#define INIT_CLASSIFY_OPTIONS(method) if( !pDataObject || (pDataObject->asTable(true) && (Field < 0 || Field >= pDataObject->asTable(true)->Get_Field_Count())) ) { return( false ); }\
+	CSG_MetaData Options; Options.Add_Child("METHOD", method); Options.Add_Child("COLORS", Colors); Options.Add_Child("FIELD", Field);
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Classify_Unique(CSG_Data_Object *pDataObject, int Field, int maxClasses, int Colors)
+{
+	INIT_CLASSIFY_OPTIONS(0);
+
+	Options.Add_Child("MAXCLASSES", maxClasses);
+
+	return( SG_UI_DataObject_Classify(pDataObject, Options) );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Classify_Equal(CSG_Data_Object *pDataObject, int Field, int Classes, int Colors)
+{
+	INIT_CLASSIFY_OPTIONS(1);
+
+	Options.Add_Child("CLASSES", Classes);
+
+	return( SG_UI_DataObject_Classify(pDataObject, Options) );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Classify_Defined(CSG_Data_Object *pDataObject, int Field, double Interval, bool bOffset, double Offset, int Colors)
+{
+	INIT_CLASSIFY_OPTIONS(2);
+
+	Options.Add_Child("INTERVAL", Interval); if( bOffset ) { Options.Add_Child("OFFSET", Offset); }
+
+	return( SG_UI_DataObject_Classify(pDataObject, Options) );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Classify_Quantile(CSG_Data_Object *pDataObject, int Field, int Classes, bool bHistogram, int Colors)
+{
+	INIT_CLASSIFY_OPTIONS(3);
+
+	Options.Add_Child("CLASSES", Classes); Options.Add_Child("HISTOGRAM", bHistogram ? 1 : 0);
+
+	return( SG_UI_DataObject_Classify(pDataObject, Options) );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Classify_Geometric(CSG_Data_Object *pDataObject, int Field, int Classes, bool bIncreasing, int Colors)
+{
+	INIT_CLASSIFY_OPTIONS(4);
+
+	Options.Add_Child("CLASSES", Classes); Options.Add_Child("INCREASING", bIncreasing ? 1 : 0);
+
+	return( SG_UI_DataObject_Classify(pDataObject, Options) );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Classify_Natural(CSG_Data_Object *pDataObject, int Field, int Classes, int Colors)
+{
+	INIT_CLASSIFY_OPTIONS(5);
+
+	Options.Add_Child("CLASSES", Classes);
+
+	return( SG_UI_DataObject_Classify(pDataObject, Options) );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::DataObject_Classify_StdDev(CSG_Data_Object *pDataObject, int Field, double StdDev, double StdDev_Max, int Colors)
+{
+	INIT_CLASSIFY_OPTIONS(6);
+
+	Options.Add_Child("STDDEV", StdDev); Options.Add_Child("STDDEV_MAX", StdDev_Max);
+
+	return( SG_UI_DataObject_Classify(pDataObject, Options) );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1197,9 +1341,9 @@ bool CSG_Tool::Set_Parameter(const wchar_t    *ID, const wchar_t    *Value, int
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1272,9 +1416,9 @@ CSG_Grid_System * CSG_Tool::Get_Grid_System(void) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1313,9 +1457,9 @@ void CSG_Tool::_Update_Parameter_States(CSG_Parameters *pParameters)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Script							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1343,7 +1487,7 @@ CSG_String CSG_Tool::Get_Script(Script_Format Format, bool bHeader, int Argument
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1556,7 +1700,7 @@ void CSG_Tool::_Get_Script_CMD(CSG_String &Script, CSG_Parameters *pParameters,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1694,7 +1838,7 @@ void CSG_Tool::_Get_Script_CMD_Usage(CSG_Parameters *pParameters, wxCmdLineParse
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1971,7 +2115,7 @@ void CSG_Tool::_Get_Script_Python(CSG_String &Script, CSG_Parameters *pParameter
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2307,20 +2451,20 @@ bool CSG_Tool::_Get_Script_Python_Wrap(const CSG_Parameter &Parameter, int Const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//						History							 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_MetaData CSG_Tool::_Get_Output_History(void)
+CSG_MetaData CSG_Tool::Get_History(int Depth)
 {
 	CSG_MetaData History;
 
 	History.Set_Name(SG_META_HISTORY);
 	History.Add_Property("saga-version", SAGA_VERSION);
 
-	if( SG_Get_History_Depth() )
+	if( Depth )
 	{
 		CSG_MetaData *pTool = History.Add_Child("TOOL");
 
@@ -2337,25 +2481,46 @@ CSG_MetaData CSG_Tool::_Get_Output_History(void)
 		pOutput->Add_Property("id"  , "");
 		pOutput->Add_Property("name", "");
 
-		pTool->Del_Children(SG_Get_History_Depth(), SG_T("TOOL"));
+		pTool->Del_Children(Depth, SG_T("TOOL"));
 	}
 
 	return( History );
 }
 
+//---------------------------------------------------------
+bool CSG_Tool::Set_History(CSG_Data_Object *pDataObject, int Depth)
+{
+	if( pDataObject )
+	{
+		CSG_MetaData History(Get_History(Depth));
+
+		CSG_MetaData *pOutput = History("TOOL") ? History["TOOL"]("OUTPUT") : NULL;
+
+		if( pOutput )
+		{
+			pOutput->Set_Property("name", pDataObject->Get_Name());
+		}
+
+		pDataObject->Get_History() = History;
+
+		return( true );
+	}
+
+	return( false );
+}
+
 //---------------------------------------------------------
 void CSG_Tool::_Set_Output_History(void)
 {
-	CSG_MetaData	History(_Get_Output_History());
+	CSG_MetaData History(Get_History(SG_Get_History_Depth()));
 
-	//-----------------------------------------------------
 	for(int j=-1; j<Get_Parameters_Count(); j++)
 	{
-		CSG_Parameters	*pParameters	= j < 0 ? &Parameters : Get_Parameters(j);
+		CSG_Parameters *pParameters = j < 0 ? &Parameters : Get_Parameters(j);
 
 		for(int i=0; i<pParameters->Get_Count(); i++)
 		{
-			CSG_Parameter	*pParameter	= pParameters->Get_Parameter(i);
+			CSG_Parameter *pParameter = pParameters->Get_Parameter(i);
 
 			if( pParameter->is_Output() )//&& (pParameter->is_Enabled() || !has_GUI()) )
 			{
@@ -2368,23 +2533,21 @@ void CSG_Tool::_Set_Output_History(void)
 //---------------------------------------------------------
 bool CSG_Tool::DataObject_Set_History(CSG_Parameter *pParameter, CSG_MetaData *pHistory)
 {
-	if( !pParameter )
+	if( !pParameter && !((pParameter->is_DataObject() && pParameter->asDataObject()) || !(pParameter->is_DataObject_List() && pParameter->asList()->Get_Item_Count() > 0)) )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	CSG_MetaData	History;
+	CSG_MetaData History;
 
 	if( !pHistory )
 	{
-		History		= _Get_Output_History();
-
-		pHistory	= &History;
+		History = Get_History(SG_Get_History_Depth()); pHistory = &History;
 	}
 
 	//-----------------------------------------------------
-	CSG_MetaData	*pOutput	= pHistory->Get_Child("TOOL") ? pHistory->Get_Child("TOOL")->Get_Child("OUTPUT") : NULL;
+	CSG_MetaData *pOutput = pHistory->Get_Child("TOOL") ? pHistory->Get_Child("TOOL")->Get_Child("OUTPUT") : NULL;
 
 	if( pOutput )
 	{
@@ -2394,19 +2557,14 @@ bool CSG_Tool::DataObject_Set_History(CSG_Parameter *pParameter, CSG_MetaData *p
 	}
 
 	//-----------------------------------------------------
-	if( pParameter->is_DataObject() )
+	if( pParameter->is_DataObject() && pParameter->asDataObject() )
 	{
-		if( pParameter->asDataObject() )
+		if( pOutput )
 		{
-			if( pOutput )
-			{
-				pOutput->Set_Content(pParameter->asDataObject()->Get_Name());
-			}
-
-			pParameter->asDataObject()->Get_History().Assign(*pHistory);
-
-			return( true );
+			pOutput->Set_Content(pParameter->asDataObject()->Get_Name());
 		}
+
+		pParameter->asDataObject()->Get_History().Assign(*pHistory);
 	}
 
 	//-----------------------------------------------------
@@ -2421,19 +2579,17 @@ bool CSG_Tool::DataObject_Set_History(CSG_Parameter *pParameter, CSG_MetaData *p
 
 			pParameter->asList()->Get_Item(j)->Get_History().Assign(*pHistory);
 		}
-
-		return( true );
 	}
 
 	//-----------------------------------------------------
-	return( false );
+	return( true );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
