@@ -54,9 +54,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -70,9 +70,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -126,7 +126,7 @@ void CSG_Tool_Chain::Set_Library_Menu(const CSG_String &Menu)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -387,7 +387,7 @@ bool CSG_Tool_Chain::Create(const CSG_MetaData &Chain)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -432,7 +432,7 @@ void CSG_Tool_Chain::Add_References(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -460,7 +460,7 @@ int CSG_Tool_Chain::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parame
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -485,7 +485,7 @@ bool CSG_Tool_Chain::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -638,7 +638,7 @@ bool CSG_Tool_Chain::Data_Update(const CSG_String &ID, bool bShow)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -738,30 +738,28 @@ bool CSG_Tool_Chain::Data_Finalize(void)
 
 		if( Parameter.Cmp_Name("output") )
 		{
-			CSG_Parameter	*pParameter	= Parameters(Parameter.Get_Property("varname"));
+			CSG_Parameter *pParameter = Parameters(Parameter.Get_Property("varname"));
 
 			if( pParameter && pParameter->is_DataObject() && pParameter->asDataObject() && pParameter->asDataObject() != DATAOBJECT_CREATE )
 			{
 				if( Parameter("colours") )
 				{
-					DataObject_Set_Colors(pParameter->asDataObject(), 11,
-						Parameter["colours"].Get_Content().asInt(), IS_TRUE_PROPERTY(Parameter["colours"], "revert")
-					);
+					DataObject_Set_Colors(pParameter->asDataObject(), Parameter["colours"].Get_Content(), 0, IS_TRUE_PROPERTY(Parameter["colours"], "revert"));
 				}
 
 				if( Parameter("output_name") )
 				{
 					if( IS_TRUE_PROPERTY(Parameter["output_name"], "input") )
 					{
-						CSG_Parameter	*pInput	= Parameters(Parameter["output_name"].Get_Content());
+						CSG_Parameter *pInput = Parameters(Parameter["output_name"].Get_Content());
 
 						if( pInput && pInput->is_DataObject() && pInput->asDataObject() )
 						{
-							CSG_String	Suffix;
+							CSG_String Suffix;
 
 							if( Parameter["output_name"].Get_Property("suffix", Suffix) && !Suffix.is_Empty() )
 							{
-								Suffix	= " [" + Suffix + "]";
+								Suffix = " [" + Suffix + "]";
 							}
 
 							pParameter->asDataObject()->Set_Name(pInput->asDataObject()->Get_Name() + Suffix);
@@ -782,7 +780,7 @@ bool CSG_Tool_Chain::Data_Finalize(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -810,7 +808,7 @@ bool CSG_Tool_Chain::Parameter_isCompatible(TSG_Parameter_Type A, TSG_Parameter_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -831,7 +829,7 @@ bool CSG_Tool_Chain::Message(const CSG_MetaData &Message)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -972,7 +970,7 @@ bool CSG_Tool_Chain::Check_Condition(const CSG_MetaData &Condition, CSG_Paramete
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1227,7 +1225,7 @@ bool CSG_Tool_Chain::ForEach_File(const CSG_MetaData &Commands, const CSG_String
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1348,7 +1346,7 @@ bool CSG_Tool_Chain::Tool_Run(const CSG_MetaData &Tool, bool bShowError)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1370,7 +1368,7 @@ bool CSG_Tool_Chain::Tool_Check_Condition(const CSG_MetaData &Tool)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1734,9 +1732,9 @@ bool CSG_Tool_Chain::Tool_Finalize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2000,9 +1998,9 @@ bool CSG_Tool_Chain::_Get_Script_Parameters(CSG_MetaData &Parameters, CSG_Parame
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2082,7 +2080,7 @@ CSG_Tool_Chains::~CSG_Tool_Chains(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2119,7 +2117,7 @@ CSG_Tool * CSG_Tool_Chains::Get_Tool(int Index, TSG_Tool_Type Type) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2165,9 +2163,9 @@ bool CSG_Tool_Chains::Delete_Tools(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2345,9 +2343,9 @@ bool CSG_Tool_Chain::_Save_History_Add_Input(const CSG_MetaData &History, CSG_Me
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
