@@ -72,27 +72,23 @@
 void					CMD_Set_Tool			(class CCMD_Tool *pCMD_Tool);
 
 //---------------------------------------------------------
-void					CMD_Set_Show_Messages	(bool bOn);
 bool					CMD_Get_Show_Messages	(void);
+bool					CMD_Set_Show_Messages	(bool bOn);
 
-void					CMD_Set_Show_Progress	(bool bOn);
 bool					CMD_Get_Show_Progress	(void);
+bool					CMD_Set_Show_Progress	(bool bOn);
 
-void					CMD_Set_Interactive		(bool bOn);
 bool					CMD_Get_Interactive		(void);
+bool					CMD_Set_Interactive		(bool bOn);
 
-void					CMD_Set_XML				(bool bOn);
+bool					CMD_Set_XML				(bool bOn);
 bool					CMD_Get_XML				(void);
 
-void					CMD_Set_UTF8			(bool bOn);
-bool					CMD_Get_UTF8			(void);
-
 //---------------------------------------------------------
-void					CMD_Print				(              const CSG_String &Text, const CSG_String &XML_Tag = "");
-void					CMD_Print				(FILE *Stream, const CSG_String &Text, const CSG_String &XML_Tag = "");
+void					CMD_Print				(const CSG_String &Text, const CSG_String &XML_Tag = "");
 
-void					CMD_Print_Error			(const CSG_String &Error);
-void					CMD_Print_Error			(const CSG_String &Error, const CSG_String &Info);
+void					CMD_Print_Error			(const CSG_String &Text);
+void					CMD_Print_Error			(const CSG_String &Text, const CSG_String &Info);
 
 //---------------------------------------------------------
 void					CMD_Get_Pause			(void);
