@@ -96,6 +96,9 @@ public:
 
 	CSG_Parameters				m_Parameters;
 
+	CSG_Parameters &			Get_Parameters			(bool bUpdate = true);
+	bool						Set_Parameters			(CSG_Parameters *pParameters = NULL);
+
 	virtual bool				Update_Parameters		(bool bSave);
 	virtual bool				Update_View				(bool bStatistics = false);
 
@@ -165,7 +168,7 @@ protected:
 
 private:
 
-	class CSG_3DView_Twin		*m_pTwin { NULL };
+	class CSG_3DView_Twin		*m_pTwin = NULL;
 
 
 	static int					_On_Parameter_Changed	(CSG_Parameter *pParameter, int Flags);
@@ -177,6 +180,33 @@ private:
 };
 
 
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+class SGDI_API_DLL_EXPORT CSG_3DView_Legend : public wxPanel
+{
+public:
+	CSG_3DView_Legend(wxWindow *pParent, CSG_Parameter *pColors, CSG_Parameter *pRange, const wxSize &Size = wxSize(200, 40));
+
+
+protected:
+
+	CSG_Parameter				*m_pColors = NULL, *m_pRange = NULL;
+
+
+	void						On_Paint				(wxPaintEvent &event);
+
+	void						Draw					(wxDC &dc, const wxRect &r);
+
+
+private:
+
+	DECLARE_EVENT_TABLE()
+};
+
+
 ///////////////////////////////////////////////////////////
 //                                                       //
 //                                                       //
