@@ -91,7 +91,7 @@ CSG_3DView_Canvas::CSG_3DView_Canvas(void)
 	m_North       = 1;
 	m_North_Size  = 15.;
 	m_Labels      = 1; // frontal axes
-	m_Label_Dir   = 1; // cross axis
+	m_Label_Dir   = 0; // along axis
 	m_Label_Res   = 50;
 	m_Label_Scale = 1.;
 	m_Label_zType = SG_DATATYPE_Undefined; // number
@@ -820,6 +820,12 @@ int CSG_3DView_Canvas::Get_Color(double Value)
 	return( (int)Value );
 }
 
+//---------------------------------------------------------
+int CSG_3DView_Canvas::Get_Color(double Value, double Dim)
+{
+	return( Dim_Color((int)Value, Dim) );
+}
+
 //---------------------------------------------------------
 int CSG_3DView_Canvas::Dim_Color(int Color, double Dim)
 {
