@@ -56,9 +56,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -120,9 +120,9 @@ void		Draw_Edge(wxDC &dc, int Edge_Style, wxRect r)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -141,9 +141,9 @@ void		Draw_Rect(wxDC &dc, wxColour Color, wxRect r)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -189,9 +189,9 @@ void		Draw_FillRect(wxDC &dc, wxColour Color, wxRect r)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -333,9 +333,9 @@ void			Draw_Text			(wxDC &dc, int Align, int x, int y, double Angle, const wxStr
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -344,43 +344,41 @@ void			Draw_Text			(wxDC &dc, int Align, int x, int y, double Angle, const wxStr
 //---------------------------------------------------------
 void		Draw_Scale(wxDC &dc, const wxRect &r, double zMin, double zMax, int Orientation, int Tick, int Style, const wxString &Unit, bool bUseDCFont)
 {
-	//-----------------------------------------------------
-	int	Width	= Orientation != SCALE_VERTICAL ? r.GetWidth() : r.GetHeight();
-	int	Height	= Orientation != SCALE_VERTICAL ? r.GetHeight() : r.GetWidth();
+	int Width  = Orientation != SCALE_VERTICAL ? r.GetWidth() : r.GetHeight();
+	int Height = Orientation != SCALE_VERTICAL ? r.GetHeight() : r.GetWidth();
 
 	if( zMin >= zMax || Width < 5 || Height < 5 )
 	{
 		return;
 	}
 
+	//-----------------------------------------------------
+	wxPen   oldPen  (dc.GetPen  ());
+	wxBrush oldBrush(dc.GetBrush());
+	wxFont  oldFont (dc.GetFont ());
+
 	//-----------------------------------------------------
 	if( Style & SCALE_STYLE_GLOOMING )
 	{
-		Style	^= SCALE_STYLE_GLOOMING;
+		Style ^= SCALE_STYLE_GLOOMING;
 
-		wxRect	rTmp;
+		wxRect rTmp; wxColour oldColour(dc.GetTextForeground());
 
-		dc.SetPen     (wxPen(*wxWHITE));
-		dc.SetTextForeground(*wxWHITE);
+		dc.SetPen(wxPen(*wxWHITE)); dc.SetTextForeground(*wxWHITE);
 
-		rTmp	= r; rTmp.Offset( 0,  1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
-		rTmp	= r; rTmp.Offset( 1,  1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
-		rTmp	= r; rTmp.Offset( 1,  0); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
-		rTmp	= r; rTmp.Offset( 1, -1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
-		rTmp	= r; rTmp.Offset( 0, -1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
-		rTmp	= r; rTmp.Offset(-1, -1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
-		rTmp	= r; rTmp.Offset(-1,  0); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
-		rTmp	= r; rTmp.Offset(-1,  1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit);
+		rTmp = r; rTmp.Offset( 0,  1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
+		rTmp = r; rTmp.Offset( 1,  1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
+		rTmp = r; rTmp.Offset( 1,  0); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
+		rTmp = r; rTmp.Offset( 1, -1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
+		rTmp = r; rTmp.Offset( 0, -1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
+		rTmp = r; rTmp.Offset(-1, -1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
+		rTmp = r; rTmp.Offset(-1,  0); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
+		rTmp = r; rTmp.Offset(-1,  1); Draw_Scale(dc, rTmp, zMin, zMax, Orientation, Tick, Style, Unit, bUseDCFont);
 
-		dc.SetPen     (wxPen(*wxBLACK));
-		dc.SetTextForeground(*wxBLACK);
+		dc.SetPen(oldPen); dc.SetTextForeground(oldColour);
 	}
 
 	//-----------------------------------------------------
-	wxPen	oldPen  (dc.GetPen  ());
-	wxBrush	oldBrush(dc.GetBrush());
-	wxFont	oldFont (dc.GetFont ());
-
 	if( bUseDCFont )
 	{
 		wxFont Font(dc.GetFont());
@@ -516,16 +514,16 @@ void		Draw_Scale(wxDC &dc, const wxRect &r, double zMin, double zMax, int Orient
 }
 
 //---------------------------------------------------------
-void		Draw_Scale(wxDC &dc, const wxRect &r, double zMin, double zMax, bool bHorizontal, bool bAscendent, bool bTickAtTop)
+void		Draw_Scale(wxDC &dc, const wxRect &r, double zMin, double zMax, bool bHorizontal, bool bAscendent, bool bTickAtTop, const wxString &Unit, bool bUseDCFont)
 {
-	Draw_Scale(dc, r, zMin, zMax, bHorizontal ? SCALE_HORIZONTAL : SCALE_VERTICAL, bTickAtTop ? SCALE_TICK_TOP : SCALE_TICK_BOTTOM, bAscendent ? SCALE_STYLE_DEFAULT : SCALE_STYLE_DESCENDENT);
+	Draw_Scale(dc, r, zMin, zMax, bHorizontal ? SCALE_HORIZONTAL : SCALE_VERTICAL, bTickAtTop ? SCALE_TICK_TOP : SCALE_TICK_BOTTOM, bAscendent ? SCALE_STYLE_DEFAULT : SCALE_STYLE_DESCENDENT, Unit, bUseDCFont);
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -592,9 +590,9 @@ bool		Draw_Ruler(wxDC &dc, const wxRect &r, bool bHorizontal, double zMin, doubl
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
