@@ -45,15 +45,6 @@
 //                                                       //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
 //---------------------------------------------------------
 #include <wx/dataobj.h>
 #include <wx/html/htmlwin.h>
@@ -68,9 +59,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -100,9 +91,9 @@ IMPLEMENT_CLASS(CActive_Info_Control, wxHtmlWindow)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -115,21 +106,21 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CActive_Info::CActive_Info(wxWindow *pParent)
 	: wxPanel(pParent, ID_WND_ACTIVE_INFO , wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER)
 {
-	m_pItem			= NULL;
+	m_pItem       = NULL;
 
-	m_pSelections	= new wxChoice(this, ID_COMBOBOX_SELECT, wxDefaultPosition, wxDefaultSize, 0, NULL, 0);
+	m_pSelections = new wxChoice(this, ID_COMBOBOX_SELECT, wxDefaultPosition, wxDefaultSize, 0, NULL, 0);
 
-	m_pControl		= new CActive_Info_Control(this);
+	m_pControl    = new CActive_Info_Control(this);
 
 	//-----------------------------------------------------
-	wxBoxSizer	*pSizer	= new wxBoxSizer(wxVERTICAL);
+	wxBoxSizer *pSizer = new wxBoxSizer(wxVERTICAL);
 
 	pSizer->Add(m_pSelections, 0, wxEXPAND|wxLEFT|wxRIGHT);
 	pSizer->Add(m_pControl   , 1, wxEXPAND|wxALL);
@@ -139,7 +130,7 @@ CActive_Info::CActive_Info(wxWindow *pParent)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -155,7 +146,7 @@ void CActive_Info::Set_Item(CWKSP_Shapes *pItem)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -166,13 +157,13 @@ inline CSG_Shapes * CActive_Info::_Get_Shapes(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CActive_Info::On_Choice(wxCommandEvent &event)
 {
-	CSG_Shapes	*pShapes	= _Get_Shapes();
+	CSG_Shapes *pShapes = _Get_Shapes();
 
 	if( pShapes && m_pSelections->GetSelection() < pShapes->Get_Selection_Count() )
 	{
@@ -190,7 +181,7 @@ void CActive_Info::Set_Info(void)
 
 	m_pSelections->Clear();
 
-	CSG_Shapes	*pShapes	= _Get_Shapes();
+	CSG_Shapes *pShapes = _Get_Shapes();
 
 	if( pShapes )
 	{
@@ -217,13 +208,11 @@ void CActive_Info::Set_Info(void)
 //---------------------------------------------------------
 void CActive_Info::_Set_Info(void)
 {
-	CSG_Shape	*pShape	= _Get_Shapes() ? _Get_Shapes()->Get_Selection(m_pItem->Edit_Get_Index()) : NULL;
+	CSG_Shape *pShape = _Get_Shapes() ? (CSG_Shape *)_Get_Shapes()->Get_Selection(m_pItem->Edit_Get_Index()) : NULL;
 
 	if( pShape )
 	{
-		wxString	Page(pShape->asString(m_pItem->Get_Field_Info()));
-
-		wxFileName	fn(Page);
+		wxString Page(pShape->asString(m_pItem->Get_Field_Info())); wxFileName fn(Page);
 
 		if( fn.IsRelative() )
 		{
@@ -256,9 +245,9 @@ void CActive_Info::_Set_Info(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
