@@ -64,9 +64,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -79,7 +79,7 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -125,7 +125,7 @@ CDLG_About::CDLG_About(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -136,7 +136,7 @@ void CDLG_About::Set_Position(wxRect r)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -147,7 +147,7 @@ void CDLG_About::_On_Link_Clicked(wxHtmlLinkEvent& event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -178,22 +178,22 @@ wxString CDLG_About::_Get_Version(void)
 	#if defined(COMPILER)
 		if( *COMPILER )
 		{
-			s	+= "<hr><i>Compiled with</i><br>[ " COMPILER " ]<br>";
+			s += "<hr><i>Compiled with</i><br>[ " COMPILER " ]<br>";
 
 			#if defined(_SAGA_MSW) && defined(_MSC_VER) && _MSC_VER >= 1900
-				s	+= "[ Microsoft Visual Studio "
+				s += "[ Microsoft Visual Studio ";
 				#if   _MSC_VER == 1900
-					"2015 (14)"
-				#elif _MSC_VER <= 1920
-					"2017 (15)"
-				#elif _MSC_VER <= 1930
-					"2019 (16)"
-				#elif _MSC_VER <= 1940
-					"2022 (17)"
+					s += "2015 (14)";
+				#elif _MSC_VER >= 1910 && _MSC_VER < 1920
+					s += "2017 (15)";
+				#elif _MSC_VER >= 1920 && _MSC_VER < 1930
+					s += wxString::Format("2019 (16.%d)", _MSC_VER - 1920);
+				#elif _MSC_VER >= 1930 && _MSC_VER < 1950
+					s += wxString::Format("2022 (17.%d)", _MSC_VER - 1930);
 				#else
-					"(unknown version)"
+					s += "(unknown version)";
 				#endif
-				" ]<br>";
+				s += " ]<br>";
 			#endif
 		}
 	#endif
@@ -239,7 +239,7 @@ wxString CDLG_About::_Get_Version(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -258,7 +258,7 @@ wxString CDLG_About::_Get_Citation(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1121,9 +1121,9 @@ wxString CDLG_About::_Get_LGPL(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
