@@ -66,9 +66,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -107,7 +107,7 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -143,9 +143,9 @@ public:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -153,16 +153,19 @@ IMPLEMENT_CLASS(CParameters_Control, wxPanel)
 
 //---------------------------------------------------------
 BEGIN_EVENT_TABLE(CParameters_Control, wxPanel)
-	EVT_SIZE			(CParameters_Control::On_Size)
-	EVT_KEY_DOWN		(CParameters_Control::On_Key)
+	EVT_SIZE     (CParameters_Control::On_Size)
+	EVT_KEY_DOWN (CParameters_Control::On_Key)
 
-	EVT_PG_SELECTED		(ID_WND_PARM, CParameters_Control::On_PG_Selected)
-	EVT_PG_CHANGED		(ID_WND_PARM, CParameters_Control::On_PG_Changed)
+	EVT_PG_SELECTED      (ID_WND_PARM, CParameters_Control::On_PG_Selected)
+	EVT_PG_CHANGED       (ID_WND_PARM, CParameters_Control::On_PG_Changed)
+
+	EVT_PG_ITEM_COLLAPSED(ID_WND_PARM, CParameters_Control::On_PG_Collapsed)
+	EVT_PG_ITEM_EXPANDED (ID_WND_PARM, CParameters_Control::On_PG_Expanded)
 END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -200,7 +203,7 @@ CParameters_Control::~CParameters_Control(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -246,9 +249,35 @@ void CParameters_Control::On_PG_Changed(wxPropertyGridEvent &event)
 	event.Skip();
 }
 
+//---------------------------------------------------------
+void CParameters_Control::On_PG_Collapsed(wxPropertyGridEvent &event)
+{
+	CSG_Parameter *pParameter = _Get_Parameter(event.GetProperty());
+
+	if( pParameter && (pParameter = m_pOriginal->Get_Parameter(pParameter->Get_Identifier())) )
+	{
+		pParameter->Set_Collapsed(true);
+	}
+
+	event.Skip();
+}
+
+//---------------------------------------------------------
+void CParameters_Control::On_PG_Expanded(wxPropertyGridEvent &event)
+{
+	CSG_Parameter *pParameter = _Get_Parameter(event.GetProperty());
+
+	if( pParameter && (pParameter = m_pOriginal->Get_Parameter(pParameter->Get_Identifier())) )
+	{
+		pParameter->Set_Collapsed(false);
+	}
+
+	event.Skip();
+}
+
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -357,7 +386,7 @@ bool CParameters_Control::Save(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -419,7 +448,7 @@ bool CParameters_Control::Set_Parameters(CSG_Parameters *pParameters)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -598,11 +627,11 @@ wxPGProperty * CParameters_Control::_Get_Property(wxPGProperty *pParent, CSG_Par
 		break;
 
 	case PARAMETER_TYPE_Degree          :
-		ADD_PROPERTY(new CParameters_PG_Degree(Name, ID, pParameter            ), false);
+		ADD_PROPERTY(new CParameters_PG_Degree(Name, ID, pParameter             ), false);
 		break;
 
 	case PARAMETER_TYPE_Date            :
-		ADD_PROPERTY(new wxDateProperty       (Name, ID, pParameter->asDouble()), false);	// from JDN
+		ADD_PROPERTY(new wxDateProperty       (Name, ID, pParameter->asDouble() ), false);	// from JDN
 		pProperty->SetAttribute(wxPG_DATE_PICKER_STYLE, wxDP_DROPDOWN|wxDP_SHOWCENTURY);
 		break;
 
@@ -672,7 +701,7 @@ wxPGProperty * CParameters_Control::_Get_Property(wxPGProperty *pParent, CSG_Par
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -698,7 +727,7 @@ bool CParameters_Control::_Get_Enabled(CSG_Parameter *pParameter)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -979,16 +1008,32 @@ void CParameters_Control::_Init_Pararameters(void)
 	{
 		for(int i=0; i<m_pParameters->Get_Count(); i++)
 		{
-			m_pParameters->Get_Parameter(i)->has_Changed(PARAMETER_CHECK_ENABLE);
+			CSG_Parameter *pParameter = m_pParameters->Get_Parameter(i);
+
+			pParameter->has_Changed(PARAMETER_CHECK_ENABLE);
+
+			wxPGProperty *pProperty = m_pPG->GetProperty(_Get_Identifier(pParameter));
+
+			if( pProperty )
+			{
+				if( pParameter->is_Collapsed() )
+				{
+					m_pPG->Collapse(pProperty);
+				}
+				else
+				{
+					m_pPG->Expand  (pProperty);
+				}
+			}
 		}
 	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
