@@ -234,17 +234,19 @@ BEGIN_EVENT_TABLE(CSAGA_Frame, MDI_ParentFrame)
 	EVT_MENU     (ID_CMD_FRAME_INFO_SHOW       , CSAGA_Frame::On_INFO_Show)
 	EVT_UPDATE_UI(ID_CMD_FRAME_INFO_SHOW       , CSAGA_Frame::On_INFO_Show_UI)
 
-	EVT_MENU_RANGE		(ID_CMD_WKSP_FIRST     , ID_CMD_WKSP_LAST     , CSAGA_Frame::On_Command_Workspace)
-	EVT_UPDATE_UI_RANGE	(ID_CMD_WKSP_FIRST     , ID_CMD_WKSP_LAST     , CSAGA_Frame::On_Command_Workspace_UI)
-	EVT_MENU_RANGE		(ID_CMD_DATA_FIRST     , ID_CMD_DATA_LAST     , CSAGA_Frame::On_Command_Data)
-	EVT_UPDATE_UI_RANGE	(ID_CMD_DATA_FIRST     , ID_CMD_DATA_LAST     , CSAGA_Frame::On_Command_Data_UI)
-	EVT_MENU_RANGE		(ID_CMD_TOOL_FIRST     , ID_CMD_TOOL_LAST     , CSAGA_Frame::On_Command_Tool)
-	EVT_UPDATE_UI_RANGE	(ID_CMD_TOOL_FIRST     , ID_CMD_TOOL_LAST     , CSAGA_Frame::On_Command_Tool_UI)
+	EVT_MENU_RANGE     (ID_CMD_WKSP_FIRST     , ID_CMD_WKSP_LAST     , CSAGA_Frame::On_Command_Workspace)
+	EVT_UPDATE_UI_RANGE(ID_CMD_WKSP_FIRST     , ID_CMD_WKSP_LAST     , CSAGA_Frame::On_Command_Workspace_UI)
+	EVT_MENU_RANGE     (ID_CMD_DATA_FIRST     , ID_CMD_DATA_LAST     , CSAGA_Frame::On_Command_Data)
+	EVT_UPDATE_UI_RANGE(ID_CMD_DATA_FIRST     , ID_CMD_DATA_LAST     , CSAGA_Frame::On_Command_Data_UI)
+	EVT_MENU_RANGE     (ID_CMD_TOOL_FIRST     , ID_CMD_TOOL_LAST     , CSAGA_Frame::On_Command_Tool)
+	EVT_UPDATE_UI_RANGE(ID_CMD_TOOL_FIRST     , ID_CMD_TOOL_LAST     , CSAGA_Frame::On_Command_Tool_UI)
 
-	EVT_MENU_RANGE		(ID_CMD_CHILD_FIRST    , ID_CMD_CHILD_LAST    , CSAGA_Frame::On_Command_Child)
-	EVT_UPDATE_UI_RANGE	(ID_CMD_MAP_FIRST      , ID_CMD_MAP_LAST      , CSAGA_Frame::On_Command_Child_UI)
-	EVT_UPDATE_UI_RANGE	(ID_CMD_HISTOGRAM_FIRST, ID_CMD_HISTOGRAM_LAST, CSAGA_Frame::On_Command_Child_UI)
-	EVT_UPDATE_UI_RANGE	(ID_CMD_DIAGRAM_FIRST  , ID_CMD_DIAGRAM_LAST  , CSAGA_Frame::On_Command_Child_UI)
+	EVT_MENU_RANGE     (ID_CMD_CHILD_FIRST    , ID_CMD_CHILD_LAST    , CSAGA_Frame::On_Command_Child)
+	EVT_UPDATE_UI_RANGE(ID_CMD_MAP_FIRST      , ID_CMD_MAP_LAST      , CSAGA_Frame::On_Command_Child_UI)
+	EVT_UPDATE_UI_RANGE(ID_CMD_HISTOGRAM_FIRST, ID_CMD_HISTOGRAM_LAST, CSAGA_Frame::On_Command_Child_UI)
+	EVT_UPDATE_UI_RANGE(ID_CMD_DIAGRAM_FIRST  , ID_CMD_DIAGRAM_LAST  , CSAGA_Frame::On_Command_Child_UI)
+
+	EVT_MENU_HIGHLIGHT_ALL(CSAGA_Frame::On_Menu_Highlight_All)
 END_EVENT_TABLE()
 
 
@@ -331,7 +333,7 @@ CSAGA_Frame::CSAGA_Frame(void)
 		m_pLayout->LoadPerspective(s, false);
 	}
 
-	Set_Pane_Caption(m_pINFO       , m_pINFO       ->GetName());	// captions might have been modified by perspective, so update again...
+	Set_Pane_Caption(m_pINFO       , m_pINFO       ->GetName()); // captions might have been modified by perspective, so update again...
 	Set_Pane_Caption(m_pWKSP       , m_pWKSP       ->GetName());
 	Set_Pane_Caption(m_pData_Source, m_pData_Source->GetName());
 	Set_Pane_Caption(m_pActive     , m_pActive     ->GetName());
@@ -346,9 +348,9 @@ CSAGA_Frame::CSAGA_Frame(void)
 	m_pTB_Histogram   = CVIEW_Histogram    ::_Create_ToolBar();
 	m_pTB_ScatterPlot = CVIEW_ScatterPlot  ::_Create_ToolBar();
 
-	_Bar_Show(m_pTB_Main, true);
+	m_pTB_Child = m_pTB_Data = NULL;
 
-	m_pLayout->Update();
+	_Bar_Show(m_pTB_Main, true, true);
 
 	//-----------------------------------------------------
 	long l; wxRect r, rDefault = wxGetClientDisplayRect();
@@ -434,14 +436,12 @@ CSAGA_Frame::~CSAGA_Frame(void)
 
 	SG_Set_UI_Callback(NULL);
 
-	g_pSAGA_Frame	= NULL;
+	g_pSAGA_Frame = NULL;
 }
 
 
 ///////////////////////////////////////////////////////////
 //                                                       //
-//                                                       //
-//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -487,7 +487,7 @@ void CSAGA_Frame::On_Size(wxSizeEvent &event)
 {
 	if( wxDisplay::GetFromWindow(this) == wxNOT_FOUND )
 	{
-		wxRect	r	= wxGetClientDisplayRect();	r.Deflate((int)(0.1 * r.GetWidth()), (int)(0.1 * r.GetHeight()));
+		wxRect r = wxGetClientDisplayRect(); r.Deflate((int)(0.1 * r.GetWidth()), (int)(0.1 * r.GetHeight()));
 
 		SetSize(r);
 	}
@@ -498,7 +498,16 @@ void CSAGA_Frame::On_Size(wxSizeEvent &event)
 
 ///////////////////////////////////////////////////////////
 //                                                       //
-//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CSAGA_Frame::On_Menu_Highlight_All(wxMenuEvent &event)
+{
+	if( event.GetId() ) { event.Skip(); } // prevents crash introduced with wxWidgets-3.3.0, msw => opening mdi-child's system menu when it is maximized!
+}
+
+
+///////////////////////////////////////////////////////////
 //                                                       //
 ///////////////////////////////////////////////////////////
 
@@ -532,8 +541,6 @@ void CSAGA_Frame::On_Tips(wxCommandEvent &WXUNUSED(event))
 
 ///////////////////////////////////////////////////////////
 //                                                       //
-//                                                       //
-//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1127,48 +1134,34 @@ void CSAGA_Frame::On_Child_Activates(int View_ID)
 	}
 
 	//-----------------------------------------------------
-	wxMenu *pMenu = NULL; wxString Title;
+	wxMenu *pMenu = NULL; wxToolBarBase *pTB_Child = NULL; wxString Title;
 
 	switch( View_ID )
 	{
-	case ID_VIEW_TABLE        : pMenu = m_pMN_Table      ; Title = _TL("Table"      ); break;
-	case ID_VIEW_TABLE_DIAGRAM: pMenu = m_pMN_Diagram    ; Title = _TL("Diagram"    ); break;
-	case ID_VIEW_MAP          : pMenu = m_pMN_Map        ; Title = _TL("Map"        ); break;
-	case ID_VIEW_MAP_3D       : pMenu = m_pMN_Map_3D     ; Title = _TL("3D View"    ); break;
-	case ID_VIEW_HISTOGRAM    : pMenu = m_pMN_Histogram  ; Title = _TL("Histogram"  ); break;
-	case ID_VIEW_SCATTERPLOT  : pMenu = m_pMN_ScatterPlot; Title = _TL("Scatterplot"); break;
-	case ID_VIEW_LAYOUT       : pMenu = m_pMN_Layout     ; Title = _TL("Layout"     ); break;
-	}
-
-	bool bChanged = false;
-
-	if( pMenu )
-	{
-		if( GetMenuBar()->GetMenuCount() < 5 )
-		{
-			bChanged = true; GetMenuBar()->Insert (2, pMenu, Title);
-		}
-		else if( GetMenuBar()->GetMenu(2) != pMenu )
-		{
-			bChanged = true; GetMenuBar()->Replace(2, pMenu, Title);
-		}
-	}
-	else if( GetMenuBar()->GetMenuCount() == 5 )
-	{
-		bChanged = true; GetMenuBar()->Remove(2);
+	case ID_VIEW_TABLE        : pMenu = m_pMN_Table      ; pTB_Child = m_pTB_Table      ; Title = _TL("Table"      ); break;
+	case ID_VIEW_TABLE_DIAGRAM: pMenu = m_pMN_Diagram    ; pTB_Child = m_pTB_Diagram    ; Title = _TL("Diagram"    ); break;
+	case ID_VIEW_MAP          : pMenu = m_pMN_Map        ; pTB_Child = m_pTB_Map        ; Title = _TL("Map"        ); break;
+	case ID_VIEW_MAP_3D       : pMenu = m_pMN_Map_3D     ; pTB_Child = m_pTB_Map_3D     ; Title = _TL("3D View"    ); break;
+	case ID_VIEW_HISTOGRAM    : pMenu = m_pMN_Histogram  ; pTB_Child = m_pTB_Histogram  ; Title = _TL("Histogram"  ); break;
+	case ID_VIEW_SCATTERPLOT  : pMenu = m_pMN_ScatterPlot; pTB_Child = m_pTB_ScatterPlot; Title = _TL("Scatterplot"); break;
+	case ID_VIEW_LAYOUT       : pMenu = m_pMN_Layout     ; pTB_Child = m_pTB_Layout     ; Title = _TL("Layout"     ); break;
 	}
 
 	//-----------------------------------------------------
-	if( bChanged )
+	if     ( pMenu != NULL && GetMenuBar()->GetMenuCount() < 5  ) { GetMenuBar()->Insert (2, pMenu, Title); }
+	else if( pMenu != NULL && GetMenuBar()->GetMenu(2) != pMenu ) { GetMenuBar()->Replace(2, pMenu, Title); }
+	else if( pMenu == NULL && GetMenuBar()->GetMenuCount() == 5 ) { GetMenuBar()->Remove (2              ); }
+
+	//-----------------------------------------------------
+	if( m_pTB_Child != pTB_Child )
 	{
-		_Bar_Show(m_pTB_Main       , true                            );
-		_Bar_Show(m_pTB_Table      , View_ID == ID_VIEW_TABLE        );
-		_Bar_Show(m_pTB_Diagram    , View_ID == ID_VIEW_TABLE_DIAGRAM);
-		_Bar_Show(m_pTB_Map        , View_ID == ID_VIEW_MAP          );
-		_Bar_Show(m_pTB_Map_3D     , View_ID == ID_VIEW_MAP_3D       );
-		_Bar_Show(m_pTB_Histogram  , View_ID == ID_VIEW_HISTOGRAM    );
-		_Bar_Show(m_pTB_ScatterPlot, View_ID == ID_VIEW_SCATTERPLOT  );
-		_Bar_Show(m_pTB_Layout     , View_ID == ID_VIEW_LAYOUT       );
+		if( m_pTB_Child ) { _Bar_Show(m_pTB_Child, false, false); }
+
+		m_pTB_Child = pTB_Child;
+
+		if( m_pTB_Child ) { _Bar_Show(m_pTB_Child,  true, false); }
+
+		_ToolBars_Arrange();
 	}
 }
 
@@ -1249,13 +1242,21 @@ wxMenuBar * CSAGA_Frame::_Create_MenuBar(void)
 	//-----------------------------------------------------
 	wxMenuBar *pMenuBar = new wxMenuBar;
 
-	pMenuBar->Append(g_pData ->Get_Menu_Files()->Get_Menu(), _TL("File"         ));	// 0
-	pMenuBar->Append(g_pTools->Get_Menu_Tools()            , _TL("Geoprocessing"));	// 1
-	pMenuBar->Append(pMenu_Window                          , _TL("Window"       ));	// 2
-	pMenuBar->Append(pMenu_Help                            , _TL("?"            ));	// 3
+#if defined(__WXMAC__)
+	wxMenu *OSX_pMenu_Window = pMenu_Window; pMenu_Window = new wxMenu;
+#endif
+
+	pMenuBar->Append(g_pData ->Get_Menu_Files()->Get_Menu(), _TL("File"         )); // 0
+	pMenuBar->Append(g_pTools->Get_Menu_Tools()            , _TL("Geoprocessing")); // 1
+	pMenuBar->Append(pMenu_Window                          , _TL("Window"       )); // 2
+	pMenuBar->Append(pMenu_Help                            , _TL("?"            )); // 3
 
 	SetMenuBar(pMenuBar);
 
+#if defined(__WXMAC__)
+	pMenuBar->Replace(2, OSX_pMenu_Window                  , _TL("Window"       )); // 2
+#endif
+
 	return( pMenuBar );
 }
 
@@ -1280,7 +1281,7 @@ wxToolBarBase * CSAGA_Frame::_Create_ToolBar(void)
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_FRAME_DATA_SOURCE_SHOW);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_FRAME_INFO_SHOW);
 	CMD_ToolBar_Add_Separator(pToolBar);
-	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_TOOL_SEARCH);
+	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_TOOL_RUN);
 	CMD_ToolBar_Add_Separator(pToolBar);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_FRAME_HELP);
 
@@ -1292,18 +1293,60 @@ wxToolBarBase * CSAGA_Frame::_Create_ToolBar(void)
 //---------------------------------------------------------
 void CSAGA_Frame::Add_Toolbar(wxToolBarBase *pToolBar, const wxString &Name)
 {
-	pToolBar->Realize();
+	wxAuiPaneInfo Pane; pToolBar->Realize(); pToolBar->Hide();
 
-	m_pLayout->AddPane(pToolBar, wxAuiPaneInfo()
-		.Name         (wxString::Format("PANE_%d", pToolBar->GetId()))
-		.Caption      (Name)
-		.ToolbarPane  ()
-		.Top          ()
-		.LeftDockable (false)
-		.RightDockable(false)
-		.Hide         ()
-		.BestSize     (pToolBar->GetBestSize())
-	);
+	Pane.Name         (wxString::Format("TOOLBAR%d", pToolBar->GetId()));
+	Pane.Caption      (Name);
+	Pane.ToolbarPane  ();
+	Pane.Top          ();
+	Pane.LeftDockable (false);
+	Pane.RightDockable(false);
+	Pane.Hide         ();
+	Pane.BestSize     (pToolBar->GetBestSize());
+
+	m_pLayout->AddPane(pToolBar, Pane);
+}
+
+//---------------------------------------------------------
+void CSAGA_Frame::Show_Toolbar_Data(wxToolBarBase *pToolBar)
+{
+	if( !g_pData->Get_Parameter("SHOW_TOOLBAR")->asBool() )
+	{
+		pToolBar = NULL;
+	}
+
+	if( m_pTB_Data != pToolBar )
+	{
+		if( m_pTB_Data )
+		{
+			_Bar_Show(m_pTB_Data, false, false);
+		}
+
+		m_pTB_Data = pToolBar;
+
+		if( m_pTB_Data )
+		{
+			_Bar_Show(m_pTB_Data,  true, false);
+		}
+
+		_ToolBars_Arrange();
+	}
+}
+
+//---------------------------------------------------------
+void CSAGA_Frame::_ToolBars_Arrange(void)
+{
+	#define SET_TB_POSITION(pToolBar) if( pToolBar ) { wxAuiPaneInfo Pane(m_pLayout->GetPane(pToolBar)); if( Pane.IsOk() && Pane.IsDocked() ) {\
+		Pane.Position(Position++); m_pLayout->GetPane(pToolBar) = Pane; }\
+	}
+
+	int Position = 0;
+
+	SET_TB_POSITION(m_pTB_Main );
+	SET_TB_POSITION(m_pTB_Child);
+	SET_TB_POSITION(m_pTB_Data );
+
+	m_pLayout->GetManager(m_pTB_Main)->Update();
 }
 
 
@@ -1319,7 +1362,7 @@ void CSAGA_Frame::Set_Pane_Caption(wxWindow *pWindow, const wxString &Caption)
 	if( m_pLayout && pWindow )
 	{
 		m_pLayout->GetPane(pWindow).Caption(Caption);
-		m_pLayout->Update();
+		m_pLayout->GetManager(pWindow)->Update();
 	}
 }
 
@@ -1354,12 +1397,12 @@ void CSAGA_Frame::_Bar_Toggle(wxWindow *pWindow)
 {
 	if( m_pLayout->GetPane(pWindow).IsOk() )
 	{
-		_Bar_Show(pWindow, !m_pLayout->GetPane(pWindow).IsShown());
+		_Bar_Show(pWindow, !m_pLayout->GetPane(pWindow).IsShown(), true);
 	}
 }
 
 //---------------------------------------------------------
-void CSAGA_Frame::_Bar_Show(wxWindow *pWindow, bool bShow)
+void CSAGA_Frame::_Bar_Show(wxWindow *pWindow, bool bShow, bool bUpdate)
 {
 	wxAuiPaneInfo Pane(m_pLayout->GetPane(pWindow));
 
@@ -1367,14 +1410,12 @@ void CSAGA_Frame::_Bar_Show(wxWindow *pWindow, bool bShow)
 	{
 		Pane.Show(bShow);
 
-		if( bShow && Pane.IsToolbar() && Pane.IsDocked() )
+		m_pLayout->GetPane(pWindow) = Pane;
+
+		if( bUpdate )
 		{
-			Pane.Position(pWindow == m_pTB_Main ? 0 : 1);
+			m_pLayout->GetManager(pWindow)->Update();
 		}
-
-		m_pLayout->GetPane(pWindow)	= Pane;
-
-		m_pLayout->GetManager(pWindow)->Update();
 	}
 }
 
