@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -76,9 +76,9 @@ class CSAGA_Frame_Layout;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -121,6 +121,8 @@ public:
 
 	void						Add_Toolbar					(class wxToolBarBase *pToolBar, const wxString &Name);
 
+	void						Show_Toolbar_Data			(class wxToolBarBase *pToolBar);
+
 
 private: //------------------------------------------------
 
@@ -134,7 +136,7 @@ private: //------------------------------------------------
 
 	class wxMenu				*m_pMN_Table, *m_pMN_Diagram, *m_pMN_Map, *m_pMN_Map_3D, *m_pMN_Histogram, *m_pMN_ScatterPlot, *m_pMN_Layout;
 
-	class wxToolBarBase			*m_pTB_Table, *m_pTB_Diagram, *m_pTB_Map, *m_pTB_Map_3D, *m_pTB_Histogram, *m_pTB_ScatterPlot, *m_pTB_Layout, *m_pTB_Main;
+	class wxToolBarBase			*m_pTB_Data, *m_pTB_Child, *m_pTB_Table, *m_pTB_Diagram, *m_pTB_Map, *m_pTB_Map_3D, *m_pTB_Histogram, *m_pTB_ScatterPlot, *m_pTB_Layout, *m_pTB_Main;
 
 	class CINFO					*m_pINFO;
 
@@ -151,9 +153,11 @@ private: //------------------------------------------------
 	class wxMenuBar *			_Create_MenuBar				(void);
 	class wxToolBarBase *		_Create_ToolBar				(void);
 
+	void						_ToolBars_Arrange			(void);
+
 	void						_Bar_Add					(wxWindow *pWindow, int Position, int Row);
 	void						_Bar_Toggle					(wxWindow *pWindow);
-	void						_Bar_Show					(wxWindow *pWindow, bool bShow);
+	void						_Bar_Show					(wxWindow *pWindow, bool bShow, bool bUpdate);
 
 	//-----------------------------------------------------
 	void						On_Close					(wxCloseEvent    &event);
@@ -206,6 +210,8 @@ private: //------------------------------------------------
 	void						On_Command_Child			(wxCommandEvent  &event);
 	void						On_Command_Child_UI			(wxUpdateUIEvent &event);
 
+	void						On_Menu_Highlight_All		(wxMenuEvent     &event);
+
 
 	//-----------------------------------------------------
 	DECLARE_EVENT_TABLE()
@@ -213,9 +219,9 @@ private: //------------------------------------------------
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -223,9 +229,9 @@ extern CSAGA_Frame				*g_pSAGA_Frame;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
