@@ -71,17 +71,17 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define IS_BAND_WISE_FIT(pLayer)	(m_pLayer->Get_Type() == WKSP_ITEM_Grids && m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_OVERLAY && m_pLayer->Get_Parameter("OVERLAY_FIT")->asInt() != 0)
+#define IS_BAND_WISE_FIT (m_pLayer->Get_Type() == WKSP_ITEM_Grids && m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_OVERLAY && m_pLayer->Get_Parameter("OVERLAY_FIT")->asInt() != 0)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -102,30 +102,28 @@ BEGIN_EVENT_TABLE(CVIEW_Histogram, CVIEW_Base)
 	EVT_MENU      (ID_CMD_HISTOGRAM_GAUSSIAN    , CVIEW_Histogram::On_Gaussian)
 	EVT_MENU      (ID_CMD_HISTOGRAM_SET_MINMAX  , CVIEW_Histogram::On_Set_MinMax)
 	EVT_MENU      (ID_CMD_HISTOGRAM_AS_TABLE    , CVIEW_Histogram::On_AsTable)
-	EVT_MENU      (ID_CMD_HISTOGRAM_TO_CLIPBOARD, CVIEW_Histogram::On_ToClipboard)
+	EVT_MENU      (ID_CMD_VIEW_CLIPBOARD_COPY   , CVIEW_Histogram::On_ToClipboard)
 END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CVIEW_Histogram::CVIEW_Histogram(CWKSP_Layer *pLayer)
-	: CVIEW_Base(pLayer, ID_VIEW_HISTOGRAM, pLayer->Get_Name(), ID_IMG_WND_HISTOGRAM)
+	: CVIEW_Base(pLayer, ID_VIEW_HISTOGRAM, wxString::Format("%s | %s", _TL("Histogram"), pLayer->Get_Object()->Get_Name()), ID_IMG_WND_HISTOGRAM)
 {
-	SYS_Set_Color_BG_Window(this);
-
 	m_pLayer         = pLayer;
 
 	m_bCumulative    = false;
 	m_bGaussian      = false;
-	m_Gaussian_Color = 0;
 	m_Gaussian_Size  = 1;
 	m_bColored       = true;
 
 	m_XLabeling      = 0;
 
+	m_Color_Mode     = 0;
 	m_Margin_Left    = 30;
 	m_Margin_Bottom  = m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_LUT ? 100 : 30;
 
@@ -136,13 +134,13 @@ CVIEW_Histogram::CVIEW_Histogram(CWKSP_Layer *pLayer)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 wxMenu * CVIEW_Histogram::_Create_Menu(void)
 {
-	wxMenu	*pMenu	= new wxMenu;
+	wxMenu *pMenu = new wxMenu;
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_HISTOGRAM_PARAMETERS);
 	pMenu->AppendSeparator();
@@ -150,7 +148,7 @@ wxMenu * CVIEW_Histogram::_Create_Menu(void)
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_HISTOGRAM_GAUSSIAN);
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_HISTOGRAM_AS_TABLE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_HISTOGRAM_TO_CLIPBOARD);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_VIEW_CLIPBOARD_COPY);
 
 	return( pMenu );
 }
@@ -158,13 +156,13 @@ wxMenu * CVIEW_Histogram::_Create_Menu(void)
 //---------------------------------------------------------
 wxToolBarBase * CVIEW_Histogram::_Create_ToolBar(void)
 {
-	wxToolBarBase	*pToolBar	= CMD_ToolBar_Create(ID_TB_VIEW_HISTOGRAM);
+	wxToolBarBase *pToolBar = CMD_ToolBar_Create(ID_TB_VIEW_HISTOGRAM);
 
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_HISTOGRAM_PARAMETERS);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_HISTOGRAM_CUMULATIVE);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_HISTOGRAM_GAUSSIAN);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_HISTOGRAM_AS_TABLE);
-	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_HISTOGRAM_TO_CLIPBOARD);
+	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_VIEW_CLIPBOARD_COPY);
 
 	CMD_ToolBar_Add(pToolBar, _TL("Histogram"));
 
@@ -173,26 +171,28 @@ wxToolBarBase * CVIEW_Histogram::_Create_ToolBar(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CVIEW_Histogram::Do_Update(void)
 {
-	if( IS_BAND_WISE_FIT(pLayer) )
+	if( IS_BAND_WISE_FIT )
 	{
-		m_pLayer->Get_Classifier()->Set_Metric(0, 1, m_pLayer->Get_Value_Minimum(), m_pLayer->Get_Value_Maximum());
+		m_pLayer->Get_Classifier()->Set_Metric(0, 1., m_pLayer->Get_Stretch_Minimum(), m_pLayer->Get_Stretch_Maximum());
 	}
 
 	if( m_pLayer->Get_Classifier()->Histogram_Update() )
 	{
 		Refresh();
 	}
+
+	Update();
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -212,7 +212,7 @@ void CVIEW_Histogram::On_Paint(wxPaintEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -220,6 +220,9 @@ void CVIEW_Histogram::Draw(wxDC &dc)
 {
 	wxFont Font; Font.SetFamily(wxFONTFAMILY_SWISS); dc.SetFont(Font);
 
+	dc.SetPen           (SYS_Get_Color_Foreground(m_Color_Mode));
+	dc.SetTextForeground(SYS_Get_Color_Foreground(m_Color_Mode));
+
 	Draw_Histogram(dc);
 	Draw_Frame    (dc);
 }
@@ -253,11 +256,13 @@ void CVIEW_Histogram::Draw_Bar(wxDC &dc, wxColour Color, int x[2], int y[3], int
 
 	if( y[1] >= y[2] )
 	{
-		Color = SYS_Get_Color(wxSYS_COLOUR_WINDOW);
+		bool bDark = m_Color_Mode == 0 ? wxSystemSettings::GetAppearance().IsUsingDarkBackground() : m_Color_Mode == 2;
+
+		Color = SYS_Get_Color_Background(m_Color_Mode);
 
 		for(int ix=x[0]; ix<x[1]; ix++)
 		{
-			wxColour Next(StdDev[0] <= ix && ix <= StdDev[1] ? wxColour(222, 222, 222) : Color);
+			wxColour Next(StdDev[0] <= ix && ix <= StdDev[1] ? (bDark ? wxColour(96, 96, 96) : wxColour(192, 192, 192)) : Color);
 
 			if( Invert[0] <= ix && ix <= Invert[1] )
 			{
@@ -281,7 +286,7 @@ void CVIEW_Histogram::Draw_Histogram(wxDC &dc)
 {
 	wxRect r(Get_Histogram_Box(dc.GetSize()));
 
-	const CSG_Histogram	&Histogram	= m_pLayer->Get_Classifier()->Histogram_Get();
+	const CSG_Histogram &Histogram = m_pLayer->Get_Classifier()->Histogram_Get();
 
 	if( Histogram.Get_Class_Count() < 1 || Histogram.Get_Element_Count() < 1 )
 	{
@@ -299,8 +304,8 @@ void CVIEW_Histogram::Draw_Histogram(wxDC &dc)
 
 		if( s.Get_Count() > 0 )
 		{
-			double	Minimum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(0.);
-			double	Maximum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(1.);
+			double Minimum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(0.);
+			double Maximum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(1.);
 
 			double dx = (Maximum - Minimum) / (double)r.GetWidth();
 
@@ -318,7 +323,9 @@ void CVIEW_Histogram::Draw_Histogram(wxDC &dc)
 	}
 
 	//-----------------------------------------------------
-	wxColor Color = SYS_Get_Color(wxSYS_COLOUR_ACTIVECAPTION); // wxSYS_COLOUR_BTNSHADOW);
+	bool bDark = m_Color_Mode == 0 ? wxSystemSettings::GetAppearance().IsUsingDarkBackground() : m_Color_Mode == 2;
+
+	wxColor Color = bDark ? wxColour(200, 200, 200) : SYS_Get_Color(wxSYS_COLOUR_ACTIVECAPTION); // wxSYS_COLOUR_BTNSHADOW);
 
 	double dx = (double)r.GetWidth() / (double)Histogram.Get_Class_Count();
 
@@ -326,23 +333,23 @@ void CVIEW_Histogram::Draw_Histogram(wxDC &dc)
 
 	for(size_t iClass=0; iClass<Histogram.Get_Class_Count(); iClass++)
 	{
-		double	Value	= m_bCumulative
+		double Value = m_bCumulative
 			? Histogram.Get_Cumulative(iClass) / (double)Histogram.Get_Element_Count  ()
 			: Histogram.Get_Elements  (iClass) / (double)Histogram.Get_Element_Maximum();
 
 		x[0] = x[1]; x[1] = r.GetLeft() + (int)(dx * (iClass + 1.));
 		y[1] = y[0] - (int)((r.GetHeight() - 1) * Value);
 
-		if( m_bColored && m_pLayer->Get_Classifier()->Get_Mode() != CLASSIFY_OVERLAY && m_pLayer->Get_Classifier()->Get_Mode() != CLASSIFY_SHADE )
+		if( m_bColored && m_pLayer->Get_Classifier()->Get_Mode() != CLASSIFY_OVERLAY )
 		{
-			Color	= m_pLayer->Get_Classifier()->Get_Class_Color(iClass);
+			Color = m_pLayer->Get_Classifier()->Get_Class_Color(iClass);
 		}
 
 		Draw_Bar(dc, Color, x, y, Invert, StdDev);
 	}
 
 	//-----------------------------------------------------
-	if( s.Get_Count() > 0 )
+	if( s.Get_Count() > 0 ) // plot gaussian normal distribution
 	{
 		#define FUNC_NORMAL(X) (m_bCumulative\
 			? (1. / (1. + exp(-((X - s.Get_Mean()) / (0.5 * s.Get_StdDev())))) - y0)\
@@ -354,8 +361,8 @@ void CVIEW_Histogram::Draw_Histogram(wxDC &dc)
 			dc.DrawLine(ix, r.GetBottom(), ix, r.GetBottom() - (int)(dy * FUNC_NORMAL(X)));\
 		}
 
-		double	Minimum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(0.);
-		double	Maximum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(1.);
+		double Minimum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(0.);
+		double Maximum = m_pLayer->Get_Classifier()->Get_RelativeToMetric(1.);
 
 		double dx = (Maximum - Minimum) / (double)r.GetWidth(), dy = r.GetHeight() - 1;
 
@@ -363,18 +370,18 @@ void CVIEW_Histogram::Draw_Histogram(wxDC &dc)
 
 		if( m_bCumulative )
 		{
-			dy	/= (yMax - yMin); y0 = yMin;
+			dy /= (yMax - yMin); y0 = yMin;
 		}
 		else if( s.Get_Mean() < Minimum )
 		{
-			dy	/= yMin;
+			dy /= yMin;
 		}
 		else if( s.Get_Mean() > Maximum )
 		{
-			dy	/= yMax;
+			dy /= yMax;
 		}
 
-		wxPen oldPen(dc.GetPen()); dc.SetPen(wxPen(Get_Color_asWX(m_Gaussian_Color), m_Gaussian_Size));
+		wxPen oldPen(dc.GetPen()); dc.SetPen(wxPen(SYS_Get_Color_Foreground(m_Color_Mode), m_Gaussian_Size));
 
 		DRAW_LINE(s.Get_Mean()                 );
 		DRAW_LINE(s.Get_Mean() - s.Get_StdDev());
@@ -400,7 +407,7 @@ void CVIEW_Histogram::Draw_Frame(wxDC &dc)
 
 	const int FontSize  = 12;
 
-	dc.SetPen(*wxBLACK_PEN);
+	wxPen oldPen(dc.GetPen()); dc.SetPen(SYS_Get_Color_Foreground(m_Color_Mode));
 
 	Draw_Edge(dc, EDGE_STYLE_SIMPLE, r);
 
@@ -423,15 +430,15 @@ void CVIEW_Histogram::Draw_Frame(wxDC &dc)
 	//-----------------------------------------------------
 	if( m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_LUT )
 	{
-		double	dx	= r.GetWidth() / (double)Histogram.Get_Class_Count(), n;
+		double dx = r.GetWidth() / (double)Histogram.Get_Class_Count(), n = 0.;
 
 		for(size_t iClass=0; iClass<Histogram.Get_Class_Count(); iClass++, n+=dx)
 		{
 			if( iClass == 0 || n > (FontSize + 5) )
 			{
-				n	= 0.;
+				n = 0.;
 
-				int	ix	= r.GetLeft() + (int)(dx * (0.5 + iClass));
+				int ix = r.GetLeft() + (int)(dx * (0.5 + iClass));
 				dc.DrawLine(ix, r.GetBottom(), ix, r.GetBottom() + 5);
 				Draw_Text(dc, TEXTALIGN_TOPRIGHT, ix, r.GetBottom() + 7, 45.,
 					m_pLayer->Get_Classifier()->Get_Class_Name(iClass)
@@ -472,6 +479,8 @@ void CVIEW_Histogram::Draw_Frame(wxDC &dc)
 			}
 		break; }
 	}
+
+	dc.SetPen(oldPen);
 }
 
 //---------------------------------------------------------
@@ -501,7 +510,7 @@ wxRect CVIEW_Histogram::Get_Histogram_Box(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -518,7 +527,7 @@ void CVIEW_Histogram::On_Mouse_Motion(wxMouseEvent &event)
 //---------------------------------------------------------
 void CVIEW_Histogram::On_Mouse_LDown(wxMouseEvent &event)
 {
-	if( IS_BAND_WISE_FIT(pLayer) )
+	if( IS_BAND_WISE_FIT )
 	{
 		return;
 	}
@@ -527,7 +536,6 @@ void CVIEW_Histogram::On_Mouse_LDown(wxMouseEvent &event)
 	{
 	case CLASSIFY_GRADUATED:
 	case CLASSIFY_DISCRETE :
-	case CLASSIFY_SHADE    :
 	case CLASSIFY_OVERLAY  :
 		m_bMouse_Down = true;
 		m_Mouse_Move = m_Mouse_Down = event.GetPosition();
@@ -545,12 +553,9 @@ void CVIEW_Histogram::On_Mouse_LUp(wxMouseEvent &event)
 	{
 		ReleaseMouse();
 
-		m_bMouse_Down = false;
-		m_Mouse_Move  = event.GetPosition();
+		m_bMouse_Down = false; m_Mouse_Move = event.GetPosition(); wxRect r(Get_Histogram_Box());
 
-		wxRect r(Get_Histogram_Box());
-
-		m_pLayer->Set_Color_Range(
+		m_pLayer->Set_Stretch_Range(
 			m_pLayer->Get_Classifier()->Get_RelativeToMetric((double)(m_Mouse_Down.x - r.GetLeft()) / (double)r.GetWidth()),
 			m_pLayer->Get_Classifier()->Get_RelativeToMetric((double)(m_Mouse_Move.x - r.GetLeft()) / (double)r.GetWidth())
 		);
@@ -560,9 +565,9 @@ void CVIEW_Histogram::On_Mouse_LUp(wxMouseEvent &event)
 //---------------------------------------------------------
 void CVIEW_Histogram::On_Mouse_RDown(wxMouseEvent &event)
 {
-	wxMenu	Menu;
+	wxMenu Menu;
 
-	if( !IS_BAND_WISE_FIT(pLayer) )
+	if( !IS_BAND_WISE_FIT )
 	{
 		CMD_Menu_Add_Item(&Menu, false, ID_CMD_HISTOGRAM_SET_MINMAX);
 		Menu.AppendSeparator();
@@ -576,7 +581,7 @@ void CVIEW_Histogram::On_Mouse_RDown(wxMouseEvent &event)
 
 	Menu.AppendSeparator();
 	CMD_Menu_Add_Item(&Menu, false, ID_CMD_HISTOGRAM_AS_TABLE);
-	CMD_Menu_Add_Item(&Menu, false, ID_CMD_HISTOGRAM_TO_CLIPBOARD);
+	CMD_Menu_Add_Item(&Menu, false, ID_CMD_VIEW_CLIPBOARD_COPY);
 
 	Menu.AppendSeparator();
 	CMD_Menu_Add_Item(&Menu, false, ID_CMD_HISTOGRAM_PARAMETERS);
@@ -586,7 +591,7 @@ void CVIEW_Histogram::On_Mouse_RDown(wxMouseEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -611,7 +616,6 @@ void CVIEW_Histogram::On_Command_UI(wxUpdateUIEvent &event)
 	case ID_CMD_HISTOGRAM_GAUSSIAN:
 		if( m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_DISCRETE
 		||  m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_GRADUATED
-		||  m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_SHADE
 		||  m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_OVERLAY )
 		{
 			event.Enable(true);
@@ -642,18 +646,20 @@ void CVIEW_Histogram::On_Properties(wxCommandEvent &event)
 		CSG_String::Format("%s|%s", _TL("horizontal"), _TL("diagonal"), _TL("vertical")), m_XLabeling
 	);
 
+	P.Add_Bool  (""        , "GAUSSIAN"      , _TL("Normal Distribution"), _TL(""), m_bGaussian  );
+	P.Add_Int   ("GAUSSIAN", "GAUSSIAN_SIZE" , _TL("Line Width"         ), _TL(""), m_Gaussian_Size, 1, true);
+
+	P.Add_Choice(""        , "COLOR_MODE"    , _TL("Color Mode"         ), _TL(""),
+		CSG_String::Format("%s|%s|%s", _TL("system"), _TL("light"), _TL("dark"))  , m_Color_Mode
+	);
+
 	P.Add_Node  (""        , "MARGINS"       , _TL("Margins"            ), _TL(""));
 	P.Add_Int   ("MARGINS" , "MARGIN_LEFT"   , _TL("Left"               ), _TL(""), m_Margin_Left  , 10, true);
 	P.Add_Int   ("MARGINS" , "MARGIN_BOTTOM" , _TL("Bottom"             ), _TL(""), m_Margin_Bottom, 10, true);
 
-	P.Add_Bool  (""        , "GAUSSIAN"      , _TL("Normal Distribution"), _TL(""), m_bGaussian  );
-	P.Add_Color ("GAUSSIAN", "GAUSSIAN_COLOR", _TL("Color"              ), _TL(""), m_Gaussian_Color);
-	P.Add_Int   ("GAUSSIAN", "GAUSSIAN_SIZE" , _TL("Line Width"         ), _TL(""), m_Gaussian_Size, 1, true);
-
 	//-----------------------------------------------------
 	P.Set_Enabled("NCLASSES",
 		m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_GRADUATED
-	||	m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_SHADE
 	||	m_pLayer->Get_Classifier()->Get_Mode() == CLASSIFY_OVERLAY
 	);
 
@@ -668,12 +674,14 @@ void CVIEW_Histogram::On_Properties(wxCommandEvent &event)
 
 		m_bCumulative    = P("CUMULATIVE"    )->asBool();
 		m_bColored       = P("COLORED"       )->asBool();
-		m_XLabeling      = P("XLABELING"     )->asInt();
-		m_Margin_Left    = P("MARGIN_LEFT"   )->asInt();
-		m_Margin_Bottom  = P("MARGIN_BOTTOM" )->asInt();
+		m_XLabeling      = P("XLABELING"     )->asInt ();
 		m_bGaussian      = P("GAUSSIAN"      )->asBool();
-		m_Gaussian_Color = P("GAUSSIAN_COLOR")->asInt();
-		m_Gaussian_Size  = P("GAUSSIAN_SIZE" )->asInt();
+		m_Gaussian_Size  = P("GAUSSIAN_SIZE" )->asInt ();
+		m_Color_Mode     = P("COLOR_MODE"    )->asInt ();
+		m_Margin_Left    = P("MARGIN_LEFT"   )->asInt ();
+		m_Margin_Bottom  = P("MARGIN_BOTTOM" )->asInt ();
+
+		SetBackgroundColour(SYS_Get_Color_Background(m_Color_Mode));
 
 		Refresh();
 	}
@@ -682,7 +690,7 @@ void CVIEW_Histogram::On_Properties(wxCommandEvent &event)
 //---------------------------------------------------------
 void CVIEW_Histogram::On_Cumulative(wxCommandEvent &event)
 {
-	m_bCumulative	= !m_bCumulative;
+	m_bCumulative = !m_bCumulative;
 
 	Refresh();
 }
@@ -690,7 +698,7 @@ void CVIEW_Histogram::On_Cumulative(wxCommandEvent &event)
 //---------------------------------------------------------
 void CVIEW_Histogram::On_Gaussian(wxCommandEvent &event)
 {
-	m_bGaussian	= !m_bGaussian;
+	m_bGaussian = !m_bGaussian;
 
 	Refresh();
 }
@@ -698,22 +706,19 @@ void CVIEW_Histogram::On_Gaussian(wxCommandEvent &event)
 //---------------------------------------------------------
 void CVIEW_Histogram::On_Set_MinMax(wxCommandEvent &event)
 {
-	m_pLayer->Set_Color_Range(
-		m_pLayer->Get_Value_Minimum(),
-		m_pLayer->Get_Value_Maximum()
-	);
+	m_pLayer->Set_Stretch_FullRange();
 }
 
 //---------------------------------------------------------
 void CVIEW_Histogram::On_AsTable(wxCommandEvent &event)
 {
-	CWKSP_Layer_Classify	*pClassifier	= ((CWKSP_Layer *)m_pOwner)->Get_Classifier();
+	CWKSP_Layer_Classify *pClassifier = ((CWKSP_Layer *)m_pOwner)->Get_Classifier();
 
 	if( pClassifier->Get_Class_Count() > 0 )
 	{
-		CSG_Data_Object	*pObject	= ((CWKSP_Layer *)m_pOwner)->Get_Object();
+		CSG_Data_Object *pObject = ((CWKSP_Layer *)m_pOwner)->Get_Object();
 
-		CSG_Table	*pTable	= new CSG_Table;
+		CSG_Table *pTable = SG_Create_Table();
 
 		pTable->Fmt_Name("%s: %s", _TL("Histogram"), pObject->Get_Name());
 
@@ -726,20 +731,20 @@ void CVIEW_Histogram::On_AsTable(wxCommandEvent &event)
 		pTable->Add_Field(_TL("CENTER"), SG_DATATYPE_Double);
 		pTable->Add_Field(_TL("MAX"   ), SG_DATATYPE_Double);
 
-		double	dArea	= pObject->asGrid() != NULL ? pObject->asGrid()->Get_Cellarea() : 1.;
+		double dArea = pObject->asGrid() != NULL ? pObject->asGrid()->Get_Cellarea() : 1.;
 
 		for(int i=0; i<pClassifier->Get_Class_Count(); i++)
 		{
-			CSG_Table_Record	*pRecord	= pTable->Add_Record();
+			CSG_Table_Record &Class = *pTable->Add_Record();
 
-			pRecord->Set_Value(0, i + 1);
-			pRecord->Set_Value(1, pClassifier->Histogram_Get().Get_Elements  (i) * dArea);
-			pRecord->Set_Value(2, pClassifier->Histogram_Get().Get_Elements  (i));
-			pRecord->Set_Value(3, pClassifier->Histogram_Get().Get_Cumulative(i));
-			pRecord->Set_Value(4, pClassifier->Get_Class_Name                (i).wx_str());
-			pRecord->Set_Value(5, pClassifier->Get_Class_Value_Minimum       (i));
-			pRecord->Set_Value(6, pClassifier->Get_Class_Value_Center        (i));
-			pRecord->Set_Value(7, pClassifier->Get_Class_Value_Maximum       (i));
+			Class.Set_Value(0, i + 1);
+			Class.Set_Value(1, pClassifier->Histogram_Get().Get_Elements  (i) * dArea);
+			Class.Set_Value(2, pClassifier->Histogram_Get().Get_Elements  (i));
+			Class.Set_Value(3, pClassifier->Histogram_Get().Get_Cumulative(i));
+			Class.Set_Value(4, pClassifier->Get_Class_Name                (i).wx_str());
+			Class.Set_Value(5, pClassifier->Get_Class_Value_Minimum       (i));
+			Class.Set_Value(6, pClassifier->Get_Class_Value_Center        (i));
+			Class.Set_Value(7, pClassifier->Get_Class_Value_Maximum       (i));
 		}
 
 		g_pData->Add(pTable);
@@ -753,7 +758,7 @@ void CVIEW_Histogram::On_ToClipboard(wxCommandEvent &event)
 
 	wxMemoryDC dc(Bitmap);
 
-	dc.SetBackground(*wxWHITE_BRUSH); dc.Clear();
+	dc.SetBackground(SYS_Get_Color_Background(m_Color_Mode)); dc.Clear();
 
 	Draw(dc);
 
@@ -770,9 +775,9 @@ void CVIEW_Histogram::On_ToClipboard(wxCommandEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
