@@ -61,6 +61,7 @@
 #include "res_commands.h"
 #include "res_dialogs.h"
 
+#include "wksp_layer.h"
 #include "wksp_map.h"
 
 #include "view_layout_info.h"
@@ -493,7 +494,7 @@ public:
 	{
 		Adjust_Size();
 
-		wxRect	rDC(m_pLayout->Get_Paper2DC(m_Rect)), rMap(((CLayout_Map *)m_pLayout->Get_Stock_Item(CVIEW_Layout_Info::Item_Type_Map))->Get_Rect_DC());
+		wxRect	rDC(m_pLayout->Get_Paper2DC(m_Rect));//, rMap(((CLayout_Map *)m_pLayout->Get_Stock_Item(CVIEW_Layout_Info::Item_Type_Map))->Get_Rect_DC());
 
 		wxFont	Font, oldFont(dc.GetFont()); wxColour Color, oldColor = dc.GetTextForeground();
 
