@@ -66,9 +66,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -81,41 +81,46 @@ BEGIN_EVENT_TABLE(CVIEW_Map, CVIEW_Base)
 	EVT_SIZE              (CVIEW_Map::On_Size)
 	EVT_KEY_DOWN          (CVIEW_Map::On_Key_Down)
 
-	EVT_MENU(ID_CMD_MAP_3D_SHOW                  , CVIEW_Map::On_Map_3D_Show)
-	EVT_MENU(ID_CMD_MAP_LAYOUT_SHOW              , CVIEW_Map::On_Map_Layout_Show)
-	EVT_MENU(ID_CMD_MAP_SCALEBAR                 , CVIEW_Map::On_Map_ScaleBar)
-	EVT_MENU(ID_CMD_MAP_NORTH_ARROW              , CVIEW_Map::On_Map_North_Arrow)
-	EVT_MENU(ID_CMD_MAP_GRATICULE_ADD            , CVIEW_Map::On_Map_Graticule)
-	EVT_MENU(ID_CMD_MAP_BASEMAP_ADD              , CVIEW_Map::On_Map_BaseMap)
-	EVT_MENU(ID_CMD_MAP_SAVE_IMAGE               , CVIEW_Map::On_Map_Save_Image)
-	EVT_MENU(ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE     , CVIEW_Map::On_Map_Save_Image_On_Change)
-	EVT_MENU(ID_CMD_MAPS_SAVE_IMAGE_TO_KMZ       , CVIEW_Map::On_Map_Save_Image_To_KMZ)
-	EVT_MENU(ID_CMD_MAPS_SAVE_IMAGE_TO_MEMORY    , CVIEW_Map::On_Map_Save_Image_To_Memory)
-	EVT_MENU(ID_CMD_MAPS_SAVE_TO_CLIPBOARD       , CVIEW_Map::On_Map_Save_Image_Clipboard)
-	EVT_MENU(ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND, CVIEW_Map::On_Map_Save_Image_ClipboardL)
+	EVT_MENU(ID_CMD_MAPS_PROJECTION              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_3D_SHOW                  , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_LAYOUT_SHOW              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_SCALEBAR                 , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_NORTH_ARROW              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_GRATICULE_ADD            , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_BASEMAP_ADD              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_SAVE_IMAGE               , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE     , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAPS_SAVE_IMAGE_TO_KMZ       , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAPS_SAVE_IMAGE_TO_MEMORY    , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAPS_SAVE_TO_CLIPBOARD       , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND, CVIEW_Map::On_Command)
 
-	EVT_MENU(ID_CMD_MAP_ZOOM_FULL                , CVIEW_Map::On_Map_Zoom_Full)
-	EVT_MENU(ID_CMD_MAP_ZOOM_BACK                , CVIEW_Map::On_Map_Zoom_Back)
-	EVT_MENU(ID_CMD_MAP_ZOOM_FORWARD             , CVIEW_Map::On_Map_Zoom_Forward)
-	EVT_MENU(ID_CMD_MAP_ZOOM_ACTIVE              , CVIEW_Map::On_Map_Zoom_Active)
-	EVT_MENU(ID_CMD_MAP_PAN_ACTIVE               , CVIEW_Map::On_Map_PanTo_Active)
-	EVT_MENU(ID_CMD_MAP_ZOOM_SELECTION           , CVIEW_Map::On_Map_Zoom_Selection)
-	EVT_MENU(ID_CMD_MAP_PAN_SELECTION            , CVIEW_Map::On_Map_PanTo_Selection)
-	EVT_MENU(ID_CMD_MAP_ZOOM_EXTENT              , CVIEW_Map::On_Map_Zoom_Extent)
-	EVT_MENU(ID_CMD_MAP_SYNCHRONIZE              , CVIEW_Map::On_Map_Zoom_Synchronize)
-	EVT_MENU(ID_CMD_MAP_CROSSHAIR                , CVIEW_Map::On_Map_CrossHair)
+	EVT_MENU(ID_CMD_MAP_ZOOM_FULL                , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_ZOOM_BACK                , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_ZOOM_FORWARD             , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_ZOOM_EXTENT              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_ZOOM_ACTIVE              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_PAN_ACTIVE               , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_ZOOM_SELECTION           , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_PAN_SELECTION            , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_ZOOM_LAYER_ACTIVE        , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_PAN_LAYER_ACTIVE         , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_ZOOM_LAYER_SELECTION     , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_PAN_LAYER_SELECTION      , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_SYNCHRONIZE              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_CROSSHAIR                , CVIEW_Map::On_Command)
 
-	EVT_MENU(ID_CMD_MAP_MODE_ZOOM                , CVIEW_Map::On_Map_Mode_Zoom)
-	EVT_MENU(ID_CMD_MAP_MODE_PAN                 , CVIEW_Map::On_Map_Mode_Pan)
-	EVT_MENU(ID_CMD_MAP_MODE_SELECT              , CVIEW_Map::On_Map_Mode_Select)
-	EVT_MENU(ID_CMD_MAP_MODE_DISTANCE            , CVIEW_Map::On_Map_Mode_Distance)
+	EVT_MENU(ID_CMD_MAP_MODE_ZOOM                , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_MODE_PAN                 , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_MODE_SELECT              , CVIEW_Map::On_Command)
+	EVT_MENU(ID_CMD_MAP_MODE_DISTANCE            , CVIEW_Map::On_Command)
 END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -142,48 +147,54 @@ CVIEW_Map::CVIEW_Map(CWKSP_Map *pMap, int Frame_Width)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 wxMenu * CVIEW_Map::_Create_Menu(void)
 {
-	wxMenu *pMenu = new wxMenu;
+	wxMenu *pTopMenu = new wxMenu, *pMenu; pMenu = pTopMenu;
 
-//	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_TOOLBAR);
-//	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_3D_SHOW);
-	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_LAYOUT_SHOW);
-	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_SCALEBAR);
-	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_NORTH_ARROW);
-	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_GRATICULE_ADD);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_BASEMAP_ADD);
 	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_SAVE_IMAGE);
-//	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_IMAGE_TO_MEMORY);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_IMAGE_TO_KMZ);
-	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_TO_CLIPBOARD);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND);
-	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_BACK);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_FORWARD);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_FULL);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_ACTIVE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_PAN_ACTIVE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_SELECTION);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_EXTENT);
+	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_3D_SHOW);
+	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_LAYOUT_SHOW);
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_SYNCHRONIZE);
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_CROSSHAIR);
 	pMenu->AppendSeparator();
+	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_SCALEBAR);
+	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_NORTH_ARROW);
+	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_MODE_SELECT);
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_MODE_ZOOM);
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_MODE_PAN);
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_MODE_DISTANCE);
+	pMenu->AppendSeparator();
+
+	pTopMenu->Append(ID_CMD_WKSP_FIRST, _TL("Zoom Extent"), pMenu = new wxMenu());
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_BACK);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_FORWARD);
+	pMenu->AppendSeparator();
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_FULL);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_ACTIVE);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_PAN_ACTIVE);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_SELECTION);
+	pMenu->AppendSeparator();
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_EXTENT);
+	pMenu = pTopMenu;
+
+	pTopMenu->Append(ID_CMD_WKSP_FIRST, _TL("Copy and Save"), pMenu = new wxMenu());
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_TO_CLIPBOARD);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND);
+	pMenu->AppendSeparator();
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_SAVE_IMAGE);
+//	CMD_Menu_Add_Item(pMenu, true , ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_IMAGE_TO_MEMORY);
+	pMenu->AppendSeparator();
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_SAVE_IMAGE_TO_KMZ);
+	pMenu = pTopMenu;
 
 	return( pMenu );
 }
@@ -196,13 +207,15 @@ wxToolBarBase * CVIEW_Map::_Create_ToolBar(void)
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_BACK);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_FORWARD);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_FULL);
-	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_ACTIVE);
-	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_PAN_ACTIVE);
-	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_SELECTION);
+//	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_ACTIVE);
+//	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_PAN_ACTIVE);
+//	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_SELECTION);
 //	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP_ZOOM_EXTENT);
 	CMD_ToolBar_Add_Separator(pToolBar);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_SYNCHRONIZE);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_CROSSHAIR);
+	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_SCALEBAR);
+	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAPS_PROJECTION);
 	CMD_ToolBar_Add_Separator(pToolBar);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_MODE_SELECT);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_MODE_ZOOM);
@@ -212,9 +225,6 @@ wxToolBarBase * CVIEW_Map::_Create_ToolBar(void)
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_3D_SHOW);
 	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_LAYOUT_SHOW);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAPS_SAVE_TO_CLIPBOARD);
-	CMD_ToolBar_Add_Separator(pToolBar);
-	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_SCALEBAR);
-	CMD_ToolBar_Add_Item(pToolBar, true , ID_CMD_MAP_NORTH_ARROW);
 
 	CMD_ToolBar_Add(pToolBar, _TL("Map"));
 
@@ -223,7 +233,7 @@ wxToolBarBase * CVIEW_Map::_Create_ToolBar(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -234,7 +244,7 @@ void CVIEW_Map::Do_Update(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -314,7 +324,7 @@ void CVIEW_Map::On_Key_Down(wxKeyEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -380,260 +390,97 @@ void CVIEW_Map::Ruler_Refresh(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+void CVIEW_Map::On_Command(wxCommandEvent &event)
+{
+	switch( event.GetId() )
+	{
+	default: CVIEW_Base::On_Command(event); break;
+
+	case ID_CMD_MAP_CROSSHAIR                : g_pMaps->Toggle_CrossHair (); break;
+
+	case ID_CMD_MAP_3D_SHOW                  : m_pMap->View_3D_Toggle    (); break;
+	case ID_CMD_MAP_LAYOUT_SHOW              : m_pMap->View_Layout_Toggle(); break;
+
+	case ID_CMD_MAP_NORTH_ARROW              : m_pMap->Set_North_Arrow  (!m_pMap->is_North_Arrow  ()); break;
+	case ID_CMD_MAP_SYNCHRONIZE              : m_pMap->Set_Synchronising(!m_pMap->is_Synchronising()); break;
+	case ID_CMD_MAP_SCALEBAR                 : m_pMap->Set_ScaleBar     (!m_pMap->is_ScaleBar     ()); break;
+	case ID_CMD_MAPS_PROJECTION              : m_pMap->Set_Projection(); break;
+
+	case ID_CMD_MAP_GRATICULE_ADD            : m_pMap->Add_Graticule (); break;
+	case ID_CMD_MAP_BASEMAP_ADD              : m_pMap->Add_BaseMap   (); break;
+
+	case ID_CMD_MAP_SAVE_IMAGE               : m_pMap->SaveAs_Image          (); break;
+	case ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE     : m_pMap->SaveAs_Image_On_Change(); break;
+	case ID_CMD_MAPS_SAVE_IMAGE_TO_KMZ       : m_pMap->SaveAs_Image_To_KMZ   (m_pControl->GetClientSize().x, m_pControl->GetClientSize().y); break;
+	case ID_CMD_MAPS_SAVE_IMAGE_TO_MEMORY    : m_pMap->SaveAs_Image_To_Memory(m_pControl->GetClientSize().x, m_pControl->GetClientSize().y); break;
+	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD       : m_pMap->SaveAs_Image_Clipboard  (false); break;
+	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND: m_pMap->SaveAs_Image_Clipboard  ( true); break;
+
+	case ID_CMD_MAP_ZOOM_BACK                : m_pMap->Set_Extent_Back              (); break;
+	case ID_CMD_MAP_ZOOM_FORWARD             : m_pMap->Set_Extent_Forward           (); break;
+	case ID_CMD_MAP_ZOOM_FULL                : m_pMap->Set_Extent_Full              (); break;
+
+	case ID_CMD_MAP_ZOOM_LAYER_ACTIVE        :
+	case ID_CMD_MAP_ZOOM_ACTIVE              : m_pMap->Set_Extent_Active       (false); break;
+	case ID_CMD_MAP_PAN_LAYER_ACTIVE         :
+	case ID_CMD_MAP_PAN_ACTIVE               : m_pMap->Set_Extent_Active       ( true); break;
+	case ID_CMD_MAP_ZOOM_LAYER_SELECTION     :
+	case ID_CMD_MAP_ZOOM_SELECTION           : m_pMap->Set_Extent_Selection    (false); break;
+	case ID_CMD_MAP_PAN_LAYER_SELECTION      :
+	case ID_CMD_MAP_PAN_SELECTION            : m_pMap->Set_Extent_Selection    ( true); break;
+	case ID_CMD_MAP_ZOOM_EXTENT              : m_pMap->Set_Extent                   (); break;
+
+	case ID_CMD_MAP_MODE_ZOOM                : m_pControl->Set_Mode(MAP_MODE_ZOOM    ); break;
+	case ID_CMD_MAP_MODE_PAN                 : m_pControl->Set_Mode(MAP_MODE_PAN     ); break;
+	case ID_CMD_MAP_MODE_SELECT              : m_pControl->Set_Mode(MAP_MODE_SELECT  ); break;
+	case ID_CMD_MAP_MODE_DISTANCE            : m_pControl->Set_Mode(MAP_MODE_DISTANCE); break;
+	}
+}
+
 //---------------------------------------------------------
 void CVIEW_Map::On_Command_UI(wxUpdateUIEvent &event)
 {
 	switch( event.GetId() )
 	{
-	case ID_CMD_MAP_3D_SHOW:
-		event.Check(m_pMap->View_3D_Get() != NULL);
-		break;
+	default: CVIEW_Base::On_Command_UI(event); break;
 
-	case ID_CMD_MAP_LAYOUT_SHOW:
-		event.Check(m_pMap->View_Layout_Get() != NULL);
-		break;
+	case ID_CMD_MAP_3D_SHOW             : event.Check(m_pMap->View_3D_Get    () != NULL); break;
+	case ID_CMD_MAP_LAYOUT_SHOW         : event.Check(m_pMap->View_Layout_Get() != NULL); break;
 
-	case ID_CMD_MAP_SCALEBAR:
-		event.Check(m_pMap->is_ScaleBar());
-		break;
+	case ID_CMD_MAP_CROSSHAIR           : event.Check(g_pMaps->is_CrossHair ()); break;
 
-	case ID_CMD_MAP_NORTH_ARROW:
-		event.Check(m_pMap->is_North_Arrow());
-		break;
+	case ID_CMD_MAP_SCALEBAR            : event.Check(m_pMap->is_ScaleBar   ()); break;
+	case ID_CMD_MAP_NORTH_ARROW         : event.Check(m_pMap->is_North_Arrow()); break;
 
-	case ID_CMD_MAP_SYNCHRONIZE:
-		event.Enable(m_pMap->Get_Manager()->Get_Count() > 1);
-		event.Check (m_pMap->is_Synchronising());
-		break;
+	case ID_CMD_MAP_SYNCHRONIZE         : event.Check(m_pMap->is_Synchronising()); event.Enable(m_pMap->Get_Manager()->Get_Count() > 1); break;
 
-	case ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE:
-		event.Check(m_pMap->is_Image_Save_Mode());
-		break;
+	case ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE: event.Check(m_pMap->is_Image_Save_Mode()); break;
 
-	case ID_CMD_MAP_MODE_ZOOM:
-		event.Check(m_pControl->Get_Mode() == MAP_MODE_ZOOM);
-		break;
+	case ID_CMD_MAP_MODE_ZOOM           : event.Check(m_pControl->Get_Mode() == MAP_MODE_ZOOM  ); break;
+	case ID_CMD_MAP_MODE_PAN            : event.Check(m_pControl->Get_Mode() == MAP_MODE_PAN      || m_pControl->Get_Mode() == MAP_MODE_PAN_DOWN    ); break;
+	case ID_CMD_MAP_MODE_SELECT         : event.Check(m_pControl->Get_Mode() == MAP_MODE_SELECT); break;
+	case ID_CMD_MAP_MODE_DISTANCE       : event.Check(m_pControl->Get_Mode() == MAP_MODE_DISTANCE || m_pControl->Get_Mode() == MAP_MODE_DISTANCE_GET); break;
 
-	case ID_CMD_MAP_MODE_PAN:
-		event.Check(m_pControl->Get_Mode() == MAP_MODE_PAN || m_pControl->Get_Mode() == MAP_MODE_PAN_DOWN);
-		break;
+	case ID_CMD_MAP_ZOOM_ACTIVE         : event.Enable(g_pActive->Get_Active_Layer() != NULL); break;
+	case ID_CMD_MAP_PAN_ACTIVE          : event.Enable(g_pActive->Get_Active_Layer() != NULL); break;
+	case ID_CMD_MAP_ZOOM_SELECTION      : event.Enable(g_pActive->Get_Active_Layer() && g_pActive->Get_Active_Layer()->Get_Object()->asShapes() && g_pActive->Get_Active_Layer()->Get_Object()->asShapes()->Get_Selection_Count() > 0); break;
+	case ID_CMD_MAP_ZOOM_BACK           : event.Enable(m_pMap->Set_Extent_Back   (true)); break;
+	case ID_CMD_MAP_ZOOM_FORWARD        : event.Enable(m_pMap->Set_Extent_Forward(true)); break;
 
-	case ID_CMD_MAP_MODE_SELECT:
-		event.Check(m_pControl->Get_Mode() == MAP_MODE_SELECT);
-		break;
-
-	case ID_CMD_MAP_MODE_DISTANCE:
-		event.Check(m_pControl->Get_Mode() == MAP_MODE_DISTANCE || m_pControl->Get_Mode() == MAP_MODE_DISTANCE_GET);
-		break;
-
-	case ID_CMD_MAP_ZOOM_ACTIVE:
-		event.Enable(g_pActive->Get_Active_Layer() != NULL);
-		break;
-
-	case ID_CMD_MAP_PAN_ACTIVE:
-		event.Enable(g_pActive->Get_Active_Layer() != NULL);
-		break;
-
-	case ID_CMD_MAP_ZOOM_SELECTION:
-		event.Enable(g_pActive->Get_Active_Layer()
-			&& g_pActive->Get_Active_Layer()->Get_Object()->asShapes()
-			&& g_pActive->Get_Active_Layer()->Get_Object()->asShapes()->Get_Selection_Count() > 0
-		);
-		break;
-
-	case ID_CMD_MAP_ZOOM_BACK:
-		event.Enable(m_pMap->Set_Extent_Back(true));
-		break;
-
-	case ID_CMD_MAP_ZOOM_FORWARD:
-		event.Enable(m_pMap->Set_Extent_Forward(true));
-		break;
-
-	case ID_CMD_MAP_CROSSHAIR:
-		event.Check(g_pMaps->is_CrossHair());
-		break;
-
-	case ID_CMD_MAP_GRATICULE_ADD:
-	case ID_CMD_MAP_BASEMAP_ADD:
-		event.Enable(m_pMap->Get_Count() > 0 && m_pMap->Get_Projection().is_Okay());
-		break;
+	case ID_CMD_MAP_GRATICULE_ADD       :
+	case ID_CMD_MAP_BASEMAP_ADD         : event.Enable(m_pMap->Get_Count() > 0 && m_pMap->Get_Projection().is_Okay()); break;
 	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_3D_Show(wxCommandEvent &event)
-{
-	m_pMap->View_3D_Toggle();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Layout_Show(wxCommandEvent &event)
-{
-	m_pMap->View_Layout_Toggle();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Save_Image(wxCommandEvent &event)
-{
-	m_pMap->SaveAs_Image();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Save_Image_On_Change(wxCommandEvent &event)
-{
-	m_pMap->SaveAs_Image_On_Change();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Save_Image_To_KMZ(wxCommandEvent &event)
-{
-	m_pMap->SaveAs_Image_To_KMZ(m_pControl->GetClientSize().x, m_pControl->GetClientSize().y);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Save_Image_To_Memory(wxCommandEvent &event)
-{
-	m_pMap->SaveAs_Image_To_Memory(m_pControl->GetClientSize().x, m_pControl->GetClientSize().y);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Save_Image_Clipboard(wxCommandEvent &event)
-{
-	m_pMap->SaveAs_Image_Clipboard(false);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Save_Image_ClipboardL(wxCommandEvent &event)
-{
-	m_pMap->SaveAs_Image_Clipboard(true);
-}
-
-
-///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Zoom_Full(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent_Full();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Zoom_Back(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent_Back();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Zoom_Forward(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent_Forward();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Zoom_Active(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent_Active(false);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_PanTo_Active(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent_Active(true);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Zoom_Selection(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent_Selection(false);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_PanTo_Selection(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent_Selection(true);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Zoom_Extent(wxCommandEvent &event)
-{
-	m_pMap->Set_Extent();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_ScaleBar(wxCommandEvent &event)
-{
-	m_pMap->Set_ScaleBar(!m_pMap->is_ScaleBar());
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_North_Arrow(wxCommandEvent &event)
-{
-	m_pMap->Set_North_Arrow(!m_pMap->is_North_Arrow());
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Graticule(wxCommandEvent &event)
-{
-	m_pMap->Add_Graticule();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_BaseMap(wxCommandEvent &event)
-{
-	m_pMap->Add_BaseMap();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Zoom_Synchronize(wxCommandEvent &event)
-{
-	m_pMap->Set_Synchronising(!m_pMap->is_Synchronising());
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_CrossHair(wxCommandEvent &event)
-{
-	g_pMaps->Toggle_CrossHair();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Mode_Zoom(wxCommandEvent &event)
-{
-	m_pControl->Set_Mode(MAP_MODE_ZOOM);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Mode_Pan(wxCommandEvent &event)
-{
-	m_pControl->Set_Mode(MAP_MODE_PAN);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Mode_Select(wxCommandEvent &event)
-{
-	m_pControl->Set_Mode(MAP_MODE_SELECT);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map::On_Map_Mode_Distance(wxCommandEvent &event)
-{
-	m_pControl->Set_Mode(MAP_MODE_DISTANCE);
-}
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
