@@ -67,9 +67,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -83,7 +83,7 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -107,7 +107,7 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -131,7 +131,7 @@ CVIEW_Map_Control::~CVIEW_Map_Control(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -167,22 +167,38 @@ inline void CVIEW_Map_Control::_Set_StatusBar(const TSG_Point &Point)
 	{
 		bBuisy = true;
 
-		if( m_pMap->Get_Parameter("GCS_POSITION")->asBool() && m_pMap->Get_Projection().is_Okay() )
-		{
-			CSG_Projection GCS; GCS.Set_GCS_WGS84(); TSG_Point Position = Point;
+		//-------------------------------------------------
+		int Position = m_pMap->Get_Parameter("GCS_POSITION")->asInt(); wxString Coordinates[2];
 
-			if( SG_Get_Projected(m_pMap->Get_Projection(), GCS, Position) )
+		if( Position > 0 && m_pMap->Get_Projection().is_Okay() )
+		{
+			CSG_Projection GCS; GCS.Set_GCS_WGS84(); TSG_Point GCS_Point = Point;
+
+			if( SG_Get_Projected(m_pMap->Get_Projection(), GCS, GCS_Point) )
 			{
-				STATUSBAR_Set_Text(wxString::Format("X %s", SG_Double_To_Degree(Position.x).c_str()), STATUSBAR_VIEW_X);
-				STATUSBAR_Set_Text(wxString::Format("Y %s", SG_Double_To_Degree(Position.y).c_str()), STATUSBAR_VIEW_Y);
+				if( Position == 1 )
+				{
+					Coordinates[0].Printf("LON %s", SG_Double_To_Degree(GCS_Point.x).c_str());
+					Coordinates[1].Printf("LAT %s", SG_Double_To_Degree(GCS_Point.y).c_str());
+				}
+				else
+				{
+					Coordinates[0].Printf("LON %f", GCS_Point.x);
+					Coordinates[1].Printf("LAT %f", GCS_Point.y);
+				}
 			}
 		}
-		else
+
+		if( Coordinates[0].IsEmpty() )
 		{
-			STATUSBAR_Set_Text(wxString::Format("X %f", Point.x), STATUSBAR_VIEW_X);
-			STATUSBAR_Set_Text(wxString::Format("Y %f", Point.y), STATUSBAR_VIEW_Y);
+			Coordinates[0].Printf("X %f", Point.x);
+			Coordinates[1].Printf("Y %f", Point.y);
 		}
 
+		STATUSBAR_Set_Text(Coordinates[0], STATUSBAR_VIEW_X);
+		STATUSBAR_Set_Text(Coordinates[1], STATUSBAR_VIEW_Y);
+
+		//-------------------------------------------------
 		if( m_Mode == MAP_MODE_DISTANCE_GET )
 		{
 			STATUSBAR_Set_Text(m_Measure.Get_Measure(Point), STATUSBAR_VIEW_Z);
@@ -221,7 +237,7 @@ inline void CVIEW_Map_Control::_Set_StatusBar(const TSG_Point &Point)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -264,7 +280,7 @@ inline double CVIEW_Map_Control::_Get_Client2World(double Length, bool bToActive
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -285,7 +301,7 @@ void CVIEW_Map_Control::Set_CrossHair_Off(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -343,7 +359,7 @@ bool CVIEW_Map_Control::_Zoom(bool bZoomIn)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -380,7 +396,7 @@ bool CVIEW_Map_Control::_Move(const wxPoint &Move, bool bUpdate)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -507,7 +523,7 @@ void CVIEW_Map_Control::_Draw_Edit_Moves(wxDC &dc)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -573,73 +589,53 @@ void CVIEW_Map_Control::Refresh_Map(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Key_Down(wxKeyEvent &event)
 {
-	if( m_pMap->Get_Map_Layer_Active(true) && Get_Active_Layer()->Edit_On_Key_Down(event.GetKeyCode()) )
+	if( !m_pMap->Get_Map_Layer_Active(true) || !Get_Active_Layer()->Edit_On_Key_Down(event.GetKeyCode()) )
 	{
-		return;
-	}
-
-	switch( event.GetKeyCode() )
-	{
-	default:
-		event.Skip();
-		break;
-
-	case WXK_PAGEUP:
-		_Zoom( true);
-		break;
-
-	case WXK_PAGEDOWN:
-		_Zoom(false);
-		break;
-
-	case WXK_LEFT:
-		_Move(wxPoint(-10,   0), true);
-		break;
-
-	case WXK_RIGHT:
-		_Move(wxPoint( 10,   0), true);
-		break;
-
-	case WXK_UP:
-		_Move(wxPoint(  0, -10), true);
-		break;
-
-	case WXK_DOWN:
-		_Move(wxPoint(  0,  10), true);
-		break;
-
-	case WXK_F2:
-		m_pMap->SaveAs_Image();
-		break;
-
-	case 'C':
-		if( event.GetModifiers() == wxMOD_CONTROL )
+		switch( event.GetKeyCode() )
 		{
-			m_pMap->SaveAs_Image_Clipboard(false);
-		}
-		else if( event.GetModifiers() == wxMOD_ALT )
-		{
-			m_pMap->SaveAs_Image_Clipboard(GetClientSize().x, GetClientSize().y, -1);
-		}
-		break;
+		default: event.Skip(); break;
 
-	case 'L':
-		if( event.GetModifiers() == wxMOD_CONTROL )
-		{
-			m_pMap->SaveAs_Image_Clipboard(true);
+		case WXK_PAGEUP  : _Zoom( true); break;
+		case WXK_PAGEDOWN: _Zoom(false); break;
+
+		case WXK_LEFT    : _Move(wxPoint(-10,   0), true); break;
+		case WXK_RIGHT   : _Move(wxPoint( 10,   0), true); break;
+		case WXK_UP      : _Move(wxPoint(  0, -10), true); break;
+		case WXK_DOWN    : _Move(wxPoint(  0,  10), true); break;
+
+		case WXK_F2:
+			m_pMap->SaveAs_Image();
+			break;
+
+		case 'C':
+			if( event.GetModifiers() == wxMOD_CONTROL )
+			{
+				m_pMap->SaveAs_Image_Clipboard(false);
+			}
+			else if( event.GetModifiers() == wxMOD_ALT )
+			{
+				m_pMap->SaveAs_Image_Clipboard(GetClientSize().x, GetClientSize().y, -1);
+			}
+			break;
+
+		case 'L':
+			if( event.GetModifiers() == wxMOD_CONTROL )
+			{
+				m_pMap->SaveAs_Image_Clipboard(true);
+			}
 		}
 	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -660,7 +656,7 @@ bool CVIEW_Map_Control::_Check_Interactive(bool bProjection)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -847,20 +843,20 @@ void CVIEW_Map_Control::On_Mouse_LDClick(wxMouseEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Mouse_RDown(wxMouseEvent &event)
 {
+	m_pParent->Activate();
+
 	SetFocus();
 
 	m_Mouse_Down = m_Mouse_Move = event.GetPosition();
 
 	m_Drag_Mode	= TOOL_INTERACTIVE_DRAG_NONE;
 
-	m_pParent->Activate();
-
 	switch( m_Mode )
 	{
 	//-----------------------------------------------------
@@ -989,7 +985,7 @@ void CVIEW_Map_Control::On_Mouse_RDClick(wxMouseEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1064,7 +1060,7 @@ void CVIEW_Map_Control::On_Mouse_MUp(wxMouseEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1141,7 +1137,7 @@ void CVIEW_Map_Control::On_Mouse_Motion(wxMouseEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1166,7 +1162,7 @@ void CVIEW_Map_Control::On_Mouse_Wheel(wxMouseEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1177,9 +1173,9 @@ void CVIEW_Map_Control::On_Mouse_Lost(wxMouseCaptureLostEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
