@@ -72,9 +72,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -82,9 +82,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -174,9 +174,9 @@ int Scatter_Plot_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -195,9 +195,9 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -212,11 +212,9 @@ CVIEW_ScatterPlot::CVIEW_ScatterPlot(CWKSP_Data_Item *pItem)
 
 	switch( m_pItem->Get_Type() )
 	{
-	case WKSP_ITEM_Grid      : m_pGrid  = pItem->Get_Object()->asGrid      (); break;
-	case WKSP_ITEM_Grids     : m_pGrids = pItem->Get_Object()->asGrids     (); break;
-	case WKSP_ITEM_Shapes    : m_pTable = pItem->Get_Object()->asShapes    (); break;
-	case WKSP_ITEM_PointCloud: m_pTable = pItem->Get_Object()->asPointCloud(); break;
-	default                  : m_pTable = pItem->Get_Object()->asTable     (); break;
+	case WKSP_ITEM_Grid : m_pGrid  = pItem->Get_Object()->asGrid     (); break;
+	case WKSP_ITEM_Grids: m_pGrids = pItem->Get_Object()->asGrids    (); break;
+	default             : m_pTable = pItem->Get_Object()->asTable(true); break;
 	}
 
 	m_Parameters.Set_Name(CSG_String::Format("%s: %s", _TL("Scatterplot"), m_pItem->Get_Object()->Get_Name()));
@@ -241,7 +239,7 @@ CVIEW_ScatterPlot::CVIEW_ScatterPlot(CWKSP_Data_Item *pItem)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -252,7 +250,7 @@ void CVIEW_ScatterPlot::Do_Update(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -285,7 +283,7 @@ wxToolBarBase * CVIEW_ScatterPlot::_Create_ToolBar(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -325,15 +323,9 @@ void CVIEW_ScatterPlot::_On_Construction(void)
 			), 0
 		);
 
-		m_Parameters.Add_Choice("POINTS",
+		m_Parameters.Add_Grid_Resampling("POINTS",
 			"RESAMPLING", _TL("Resampling"),
-			_TL(""),
-			CSG_String::Format("%s|%s|%s|%s",
-				_TL("Nearest Neighbour"),
-				_TL("Bilinear Interpolation"),
-				_TL("Bicubic Spline Interpolation"),
-				_TL("B-Spline Interpolation")
-			), 3
+			_TL("")
 		);
 
 		Range[0] = m_pGrid->Get_Min(); Range[1] = m_pGrid->Get_Max();
@@ -489,7 +481,7 @@ void CVIEW_ScatterPlot::_On_Construction(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -561,7 +553,7 @@ void CVIEW_ScatterPlot::On_ToClipboard(wxCommandEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -574,7 +566,7 @@ void CVIEW_ScatterPlot::On_Size(wxSizeEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -807,7 +799,7 @@ void CVIEW_ScatterPlot::_Draw_Frame(wxDC &dc, wxRect r)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -909,7 +901,7 @@ bool CVIEW_ScatterPlot::_Initialize_Count(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -968,7 +960,7 @@ bool CVIEW_ScatterPlot::_Initialize_Grids(CSG_Grid *pGrid_X, CSG_Grid *pGrid_Y)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -977,15 +969,7 @@ bool CVIEW_ScatterPlot::_Initialize_Shapes(void)
 	CSG_Shapes *pPoints = m_Parameters("POINTS")->asShapes();
 	int           Field = m_Parameters("FIELD" )->asInt();
 
-	TSG_Grid_Resampling	Resampling;
-
-	switch( m_Parameters("RESAMPLING")->asInt() )
-	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+	CSG_Grid_Resampling Resampling = m_Parameters("RESAMPLING")->asGrid_Resampling();
 
 	CHECK_DATA(m_pGrid);
 	CHECK_DATA(pPoints);
@@ -1018,7 +1002,7 @@ bool CVIEW_ScatterPlot::_Initialize_Shapes(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1057,9 +1041,9 @@ bool CVIEW_ScatterPlot::_Initialize_Table(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
