@@ -62,9 +62,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -131,9 +131,9 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -180,7 +180,7 @@ CVIEW_Table_Control::~CVIEW_Table_Control(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -215,7 +215,7 @@ bool CVIEW_Table_Control::Save(const wxString &File, int Format)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -224,7 +224,7 @@ class CVIEW_Table_CellRenderer_Color : public wxGridCellStringRenderer
 public:
 	CVIEW_Table_CellRenderer_Color(void) {}
 
-	virtual wxGridCellRenderer *	Clone	(void) {  return( new CVIEW_Table_CellRenderer_Color ); }
+	virtual wxGridCellRenderer *	Clone	(void) const { return( new CVIEW_Table_CellRenderer_Color ); }
 
 	virtual void					Draw	(wxGrid &grid, wxGridCellAttr &attr, wxDC &dc, const wxRect &rect, int row, int col, bool isSelected)
 	{
@@ -256,7 +256,7 @@ wxGridCellRenderer * CVIEW_Table_Control::GetDefaultRendererForCell(int row, int
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -296,7 +296,7 @@ bool CVIEW_Table_Control::Update_Float_Format(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -313,7 +313,7 @@ bool CVIEW_Table_Control::Update_Selection(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -353,7 +353,7 @@ bool CVIEW_Table_Control::_Update_Records(bool bViews)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -410,7 +410,7 @@ bool CVIEW_Table_Control::_Update_Selection(bool bViews)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -451,7 +451,7 @@ void CVIEW_Table_Control::On_Selected(wxGridRangeSelectEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -462,7 +462,7 @@ void CVIEW_Table_Control::On_Changed(wxGridEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -562,7 +562,7 @@ void CVIEW_Table_Control::On_LDClick_Label(wxGridEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -666,7 +666,7 @@ void CVIEW_Table_Control::On_RClick_Label(wxGridEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -711,7 +711,7 @@ void CVIEW_Table_Control::On_Sel_Clear_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -728,7 +728,7 @@ void CVIEW_Table_Control::On_Autosize_Rows(wxCommandEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -755,7 +755,7 @@ void CVIEW_Table_Control::On_Cell_Open(wxCommandEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -766,7 +766,7 @@ void CVIEW_Table_Control::On_ToClipboard(wxCommandEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -946,7 +946,7 @@ void CVIEW_Table_Control::On_Field_Del_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -991,7 +991,7 @@ void CVIEW_Table_Control::On_Field_Hide_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1030,7 +1030,7 @@ void CVIEW_Table_Control::On_Field_Rename_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1085,7 +1085,7 @@ void CVIEW_Table_Control::On_Field_Type_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1106,7 +1106,7 @@ void CVIEW_Table_Control::On_Field_Sort_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1186,7 +1186,7 @@ void CVIEW_Table_Control::On_Field_Calc_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1247,9 +1247,9 @@ void CVIEW_Table_Control::On_Record_Clr_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
