@@ -1,6 +1,3 @@
-/**********************************************************
- * Version $Id$
- *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -50,24 +47,15 @@
 //                                                       //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
 //---------------------------------------------------------
 #ifndef _HEADER_INCLUDED__SAGA_GUI__WKSP_Base_Item_H
 #define _HEADER_INCLUDED__SAGA_GUI__WKSP_Base_Item_H
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -80,21 +68,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-#define LAYER_DRAW_FLAG_NOEDITS		0x01
-#define LAYER_DRAW_FLAG_NOLABELS	0x02
-#define LAYER_DRAW_FLAG_THUMBNAIL	0x04
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -137,9 +113,9 @@ TWKSP_Item;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -160,6 +136,7 @@ public:
 	const wxString &				Set_Unique_ID			(const wxString &ID);
 	bool							Cmp_Unique_ID			(const wxString &ID);
 
+	virtual class wxToolBarBase *	Get_ToolBar				(void)       { return( NULL ); }
 	virtual wxMenu *				Get_Menu				(void)       { return( NULL ); }
 
 	virtual bool					On_Command				(int Cmd_ID);
@@ -199,11 +176,11 @@ protected:
 
 private:
 
-	int								m_ID;
+	int								m_ID = 0;
 
 	wxString						m_Unique_ID;
 
-	CWKSP_Base_Manager				*m_pManager;
+	CWKSP_Base_Manager				*m_pManager = NULL;
 
 
 	bool							_On_Data_Deletion		(CSG_Parameters &Parameters, CSG_Data_Object *pObject);
@@ -212,9 +189,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
