@@ -76,17 +76,15 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CWKSP_Data_Item::CWKSP_Data_Item(CSG_Data_Object *pObject)
 {
-	m_pObject	= pObject;
-
-	m_bUpdating	= false;
+	m_pObject = pObject; m_bUpdating = false;
 }
 
 //---------------------------------------------------------
@@ -95,15 +93,11 @@ CWKSP_Data_Item::~CWKSP_Data_Item(void)
 	CSG_Data_Object	*pObject = m_pObject; m_pObject = NULL;
 
 	//-----------------------------------------------------
-	g_pSAGA_Frame->Freeze();
-
 	for(int i=m_Views.GetCount()-1; i>=0; i--)
 	{
 		((CVIEW_Base *)m_Views[i])->Do_Destroy();
 	}
 
-	g_pSAGA_Frame->Thaw();
-
 	//-----------------------------------------------------
 	if( pObject )
 	{
@@ -125,7 +119,7 @@ bool CWKSP_Data_Item::On_Data_Deletion(CSG_Data_Object *pObject)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -162,65 +156,36 @@ bool CWKSP_Data_Item::On_Command(int Cmd_ID)
 {
 	switch( Cmd_ID )
 	{
-	default:
-		return( CWKSP_Base_Item::On_Command(Cmd_ID) );
+	default: return( CWKSP_Base_Item::On_Command(Cmd_ID) );
 
-	case ID_CMD_DATA_SAVE:
-		Save(m_pObject->Get_File_Name());
-		break;
+	case ID_CMD_DATA_FORCE_UPDATE : Force_Update (); break;
+	case ID_CMD_DATA_SETTINGS_LOAD: Load_Settings(); break;
+	case ID_CMD_DATA_SETTINGS_COPY: Copy_Settings(); break;
 
-	case ID_CMD_DATA_SAVEAS:
-		Save();
-		break;
+	case ID_CMD_DATA_RELOAD       : if( m_pObject->Reload() ) { DataObject_Changed(); } break;
+	case ID_CMD_DATA_DEL_FILES    : if( m_pObject->Delete() ) { g_pActive->Update_Description(); } break;
 
-	case ID_CMD_DATA_SAVETODB:
+	case ID_CMD_DATA_SAVE         : Save(m_pObject->Get_File_Name()); break;
+	case ID_CMD_DATA_SAVEAS       : Save(); break;
+	case ID_CMD_DATA_SAVETODB     :
 		switch( Get_Type() )
 		{
-		case WKSP_ITEM_Table :	PGSQL_Save_Table ((CSG_Table  *)m_pObject);	break;
-		case WKSP_ITEM_Shapes:	PGSQL_Save_Shapes((CSG_Shapes *)m_pObject);	break;
-		case WKSP_ITEM_Grid  :	PGSQL_Save_Grid  ((CSG_Grid   *)m_pObject);	break;
-		case WKSP_ITEM_Grids :	PGSQL_Save_Grids ((CSG_Grids  *)m_pObject);	break;
-
-		default:	break;
+		case WKSP_ITEM_Table      : PGSQL_Save_Table ((CSG_Table  *)m_pObject);	break;
+		case WKSP_ITEM_Shapes     : PGSQL_Save_Shapes((CSG_Shapes *)m_pObject);	break;
+		case WKSP_ITEM_Grid       : PGSQL_Save_Grid  ((CSG_Grid   *)m_pObject);	break;
+		case WKSP_ITEM_Grids      : PGSQL_Save_Grids ((CSG_Grids  *)m_pObject);	break;
+		default                   : break;
 		}
 		break;
 
-	case ID_CMD_DATA_RELOAD:
-		if( m_pObject->Reload() )
-		{
-			DataObject_Changed();
-		}
-		break;
-
-	case ID_CMD_DATA_DEL_FILES:
-		if( m_pObject->Delete() )
-		{
-			g_pActive->Update_Description();
-		}
-		break;
-
-	case ID_CMD_DATA_METADATA:
+	case ID_CMD_DATA_METADATA     :
 		if( m_pObject->Get_MetaData().Get_Children_Count() > 0 )
 		{
-			CSG_Parameters	P;
-
-			Add_Metadata2Parameters(m_pObject->Get_MetaData(), P);
+			CSG_Parameters P; Add_Metadata2Parameters(m_pObject->Get_MetaData(), P);
 
 			DLG_Parameters(&P, wxString::Format("%s [%s]", _TL("View Metadata"), m_pObject->Get_Name()));
 		}
 		break;
-
-	case ID_CMD_DATA_FORCE_UPDATE:
-		Force_Update();
-		break;
-
-	case ID_CMD_DATA_SETTINGS_LOAD:
-		Load_Settings();
-		break;
-
-	case ID_CMD_DATA_SETTINGS_COPY:
-		Copy_Settings();
-		break;
 	}
 
 	return( true );
@@ -231,24 +196,12 @@ bool CWKSP_Data_Item::On_Command_UI(wxUpdateUIEvent &event)
 {
 	switch( event.GetId() )
 	{
-	default:
-		return( CWKSP_Base_Item::On_Command_UI(event) );
+	default: return( CWKSP_Base_Item::On_Command_UI(event) );
 
-	case ID_CMD_DATA_SAVE:
-		event.Enable(m_pObject->is_Modified() && m_pObject->Get_File_Name() && *(m_pObject->Get_File_Name()));
-		break;
-
-	case ID_CMD_DATA_SAVETODB:
-		event.Enable(PGSQL_has_Connections());
-		break;
-
-	case ID_CMD_DATA_RELOAD:
-		event.Enable(m_pObject->is_Modified() && SG_File_Exists(m_pObject->Get_File_Name(false)));
-		break;
-
-	case ID_CMD_DATA_DEL_FILES:
-		event.Enable(m_pObject->is_File_Native() && SG_File_Exists(m_pObject->Get_File_Name()) );
-		break;
+	case ID_CMD_DATA_SAVE      : event.Enable(m_pObject->is_Modified() && m_pObject->Get_File_Name() && *(m_pObject->Get_File_Name())); break;
+	case ID_CMD_DATA_SAVETODB  : event.Enable(PGSQL_has_Connections()); break;
+	case ID_CMD_DATA_RELOAD    : event.Enable(m_pObject->is_Modified() && SG_File_Exists(m_pObject->Get_File_Name(false))); break;
+	case ID_CMD_DATA_DEL_FILES : event.Enable(m_pObject->is_File_Native() && SG_File_Exists(m_pObject->Get_File_Name()) ); break;
 	}
 
 	return( true );
@@ -256,7 +209,7 @@ bool CWKSP_Data_Item::On_Command_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -280,7 +233,7 @@ wxString CWKSP_Data_Item::Get_Name(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -289,17 +242,13 @@ void CWKSP_Data_Item::On_Create_Parameters(void)
 	CWKSP_Base_Item::On_Create_Parameters();
 
 	//-----------------------------------------------------
-	// Nodes...
+	// General...
 
 	m_Parameters.Add_Node("", "NODE_GENERAL", _TL("General"), _TL(""));
 
-
-	//-----------------------------------------------------
-	// General...
-
 	if( g_pData->Get_Parameter("NAME_BY_FILE")->asBool() && *m_pObject->Get_File_Name() )
 	{
-		CSG_String	Name(SG_File_Get_Name(m_pObject->Get_File_Name(), false));
+		CSG_String Name(SG_File_Get_Name(m_pObject->Get_File_Name(), false));
 
 		if( !Name.is_Empty() )
 		{
@@ -307,14 +256,58 @@ void CWKSP_Data_Item::On_Create_Parameters(void)
 		}
 	}
 
-	m_Parameters.Add_String("NODE_GENERAL", "OBJECT_NAME"  , _TL("Name"       ), _TL(""), m_pObject->Get_Name());
-	m_Parameters.Add_String("NODE_GENERAL", "OBJECT_DESC"  , _TL("Description"), _TL(""), m_pObject->Get_Description(), true);
-	m_Parameters.Add_Range ("NODE_GENERAL", "OBJECT_NODATA", _TL("No Data"    ), _TL(""));
+	m_Parameters.Add_String("NODE_GENERAL",
+		"OBJECT_NAME"  , _TL("Name"),
+		_TL(""),
+		m_pObject->Get_Name()
+	);
+
+	m_Parameters.Add_String("NODE_GENERAL",
+		"OBJECT_DESC"  , _TL("Description"),
+		_TL(""),
+		m_pObject->Get_Description(), true
+	);
+
+	//-----------------------------------------------------
+	// Values...
+
+	m_Parameters.Add_Node("", "NODE_VALUES", _TL("Values"), _TL(""));
+
+	m_Parameters.Add_Double("NODE_VALUES",
+		"MAX_SAMPLES"       , _TL("Sample Size"), m_pObject->asTable(true)
+		? _TL("Maximum number of samples used to build statistics and histograms expressed as percentage of the total number of records.")
+		: _TL("Maximum number of samples used to build statistics and histograms expressed as percentage of the total number of cells."  ),
+		100., 0., true, 100., true
+	);
+
+	m_Parameters.Add_Range ("NODE_VALUES",
+		"OBJECT_NODATA", _TL("Data Exclusion"),
+		_TL("The no-data value range to be used for data exclusion.")
+	);
+
+	if( m_pObject->asTable(true) )
+	{
+		m_Parameters.Add_Choice("NODE_VALUES",
+			"TABLE_FLT_STYLE"   , _TL("Floating Point Numbers"),
+			_TL("Specify floating point decimal precision in table and similar views."),
+			CSG_String::Format("%s|%s|%s",
+				_TL("system default"),
+				_TL("compact"),
+				_TL("fix number of decimals")
+			), g_pData->Get_Parameter("TABLE_FLT_STYLE")->asInt()
+		);
+
+		m_Parameters.Add_Int("TABLE_FLT_STYLE",
+			"TABLE_FLT_DECIMALS", _TL("Decimals"),
+			_TL(""),
+			g_pData->Get_Parameter("TABLE_FLT_DECIMALS")->asInt(), 0, true
+		);
+	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -372,7 +365,26 @@ bool CWKSP_Data_Item::Save(const wxString &File_Name)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+int CWKSP_Data_Item::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags)
+{
+	if( Flags & PARAMETER_CHECK_ENABLE )
+	{
+		if( pParameter->Cmp_Identifier("TABLE_FLT_STYLE") )
+		{
+			pParameters->Set_Enabled("TABLE_FLT_DECIMALS", pParameter->asInt() == 2); // fix number of decimals
+		}
+	}
+
+	return( CWKSP_Base_Item::On_Parameter_Changed(pParameters, pParameter, Flags) );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -395,28 +407,42 @@ void CWKSP_Data_Item::Parameters_Changed(void)
 //---------------------------------------------------------
 void CWKSP_Data_Item::On_Parameters_Changed(void)
 {
-	m_pObject->Set_Name       (m_Parameters("OBJECT_NAME")->asString());
-	m_pObject->Set_Description(m_Parameters("OBJECT_DESC")->asString());
-	m_pObject->Set_NoData_Value_Range(
-		m_Parameters("OBJECT_NODATA")->asRange()->Get_Min(),
-		m_Parameters("OBJECT_NODATA")->asRange()->Get_Max()
-	);
+	m_pObject->Set_Name              (m_Parameters["OBJECT_NAME"      ].asString());
+	m_pObject->Set_Description       (m_Parameters["OBJECT_DESC"      ].asString());
+	m_pObject->Set_NoData_Value_Range(m_Parameters["OBJECT_NODATA.MIN"].asDouble(),
+	                                  m_Parameters["OBJECT_NODATA.MAX"].asDouble());
+
+	//-----------------------------------------------------
+	sLong nElements = m_pObject->asTable(true) ? m_pObject->asTable(true)->Get_Count() : m_pObject->asGrid() ? m_pObject->asGrid()->Get_NCells() : m_pObject->asGrids() ? m_pObject->asGrids()->Get_NCells() : 0L;
+
+	if( nElements > 0 )
+	{
+		m_pObject->Set_Max_Samples((sLong)((double)nElements * m_Parameters["MAX_SAMPLES"].asDouble() / 100.));
+	}
 }
 
 //---------------------------------------------------------
 bool CWKSP_Data_Item::DataObject_Changed(void)
 {
-	m_Parameters.Set_Name(CSG_String::Format("%02d. %s", 1 + Get_ID(), m_pObject->Get_Name()));
+	m_Parameters.Set_Name(m_pObject->Get_Name());
 
 	m_Parameters.Set_Parameter("OBJECT_NAME"      , m_pObject->Get_Name             ());
 	m_Parameters.Set_Parameter("OBJECT_DESC"      , m_pObject->Get_Description      ());
 	m_Parameters.Set_Parameter("OBJECT_NODATA.MIN", m_pObject->Get_NoData_Value(false));
 	m_Parameters.Set_Parameter("OBJECT_NODATA.MAX", m_pObject->Get_NoData_Value(true ));
 
+	//-----------------------------------------------------
+	sLong nElements = m_pObject->asTable(true) ? m_pObject->asTable(true)->Get_Count() : m_pObject->asGrid() ? m_pObject->asGrid()->Get_NCells() : m_pObject->asGrids() ? m_pObject->asGrids()->Get_NCells() : 0L;
+
+	if( nElements > 0 )
+	{
+		m_Parameters["MAX_SAMPLES"].Set_Value(nElements <= m_pObject->Get_Max_Samples() ? 100. : 100. * (double)m_pObject->Get_Max_Samples() / (double)nElements);
+	}
+
 	//-----------------------------------------------------
 	On_DataObject_Changed();
 
-	g_pActive->Update(this, false);
+	g_pActive->Update_Item(this, false);
 
 	Parameters_Changed();
 
@@ -431,7 +457,7 @@ void CWKSP_Data_Item::On_DataObject_Changed(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -444,7 +470,7 @@ bool CWKSP_Data_Item::Add_ScatterPlot(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -507,7 +533,7 @@ bool CWKSP_Data_Item::Update_Views(bool bAll)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -590,9 +616,9 @@ bool CWKSP_Data_Item::Copy_Settings(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
