@@ -51,9 +51,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -65,9 +65,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -82,9 +82,9 @@ public:
 
 	virtual wxString				Get_Name				(void);
 
-	CSG_Data_Object *				Get_Object				(void)       { return( m_pObject     ); }
+	CSG_Data_Object *				Get_Object				(void)    { return( m_pObject     ); }
 
-	virtual CSG_Parameters *		Get_Parameters			(void)       { return( &m_Parameters ); }
+	virtual CSG_Parameters *		Get_Parameters			(void)    { return( &m_Parameters ); }
 
 	virtual void					Parameters_Changed		(void);
 	bool							DataObject_Changed		(void);
@@ -93,7 +93,6 @@ public:
 	bool							Save					(const wxString &File_Name);
 
 	virtual bool					Show					(int Flags = 0)	= 0;
-	virtual bool					Update					(CWKSP_Data_Item *pChanged) { return( pChanged == this ); }
 
 	virtual bool					View_Opened				(class MDI_ChildFrame *pView);
 	virtual bool					View_Closes				(class MDI_ChildFrame *pView);
@@ -111,10 +110,11 @@ public:
 
 protected:
 
-	CSG_Data_Object					*m_pObject;
+	CSG_Data_Object					*m_pObject = NULL;
 
 
 	virtual void					On_Create_Parameters	(void);
+	virtual int						On_Parameter_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags);
 	virtual void					On_Parameters_Changed	(void);
 	virtual void					On_DataObject_Changed	(void);
 	virtual bool					On_Data_Deletion		(CSG_Data_Object *pObject);
@@ -125,7 +125,7 @@ protected:
 
 private:
 
-	bool							m_bUpdating;
+	bool							m_bUpdating = false;
 
 	wxArrayPtrVoid					m_Views;
 
@@ -133,9 +133,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
