@@ -54,6 +54,7 @@
 
 #include <wx/filename.h>
 #include <wx/clipbrd.h>
+#include <wx/fs_mem.h>
 
 #include <saga_api/saga_api.h>
 
@@ -97,7 +98,7 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CWKSP_Data_Manager	*g_pData	= NULL;
+CWKSP_Data_Manager *g_pData = NULL;
 
 
 ///////////////////////////////////////////////////////////
@@ -109,6 +110,9 @@ CWKSP_Data_Manager	*g_pData	= NULL;
 //---------------------------------------------------------
 CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 {
+	wxMemoryFSHandler::AddFile("preview_data.png", "dummy");
+
+	//-----------------------------------------------------
 	g_pData        = this;
 
 	m_pTables      = NULL;
@@ -121,10 +125,20 @@ CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 	m_pMenu_Files  = new CWKSP_Data_Menu_Files;
 
 	//-----------------------------------------------------
-	m_Parameters.Add_Bool (""          , "THUMBNAILS"        , _TL("Thumbnails"     ), _TL(""), true);
-	m_Parameters.Add_Int  ("THUMBNAILS", "THUMBNAIL_SIZE"    , _TL("Size"           ), _TL(""), 50, 10, true);
-	m_Parameters.Add_Color("THUMBNAILS", "THUMBNAIL_SELCOLOR", _TL("Selection Color"), _TL(""), Get_Color_asInt(SYS_Get_Color(wxSYS_COLOUR_BTNSHADOW)));
-	m_Parameters.Add_Bool ("THUMBNAILS", "THUMBNAIL_CATEGORY", _TL("Show Categories"), _TL(""), true);
+	m_Parameters.Add_Bool (""          , "THUMBNAILS"        , _TL("Thumbnails"         ), _TL(""), true);
+	m_Parameters.Add_Int  ("THUMBNAILS", "THUMBNAIL_SIZE"    , _TL("Size"               ), _TL(""), 50, 10, true);
+	m_Parameters.Add_Color("THUMBNAILS", "THUMBNAIL_SELCOLOR", _TL("Selection Color"    ), _TL(""), Get_Color_asInt(SYS_Get_Color(wxSYS_COLOUR_BTNSHADOW)));
+	m_Parameters.Add_Bool ("THUMBNAILS", "THUMBNAIL_CATEGORY", _TL("Show Categories"    ), _TL(""), true);
+
+	m_Parameters.Add_Node (""          , "NODE_DESC"         , _TL("Description"        ), _TL(""));
+	m_Parameters.Add_Bool ("NODE_DESC" , "PREVIEW"           , _TL("Preview"            ), _TL("Show a preview in description."), false);
+	m_Parameters.Add_Int  ("PREVIEW"   , "PREVIEW_SIZE"      , _TL("Size"               ), _TL(""), 200, 10, true);
+
+	m_Parameters.Add_Bool("",
+		"SHOW_TOOLBAR"          , _TL("Show Toolbar"),
+		_TL("Show toolbar with data layer related commands."),
+		true
+	);
 
 	m_Parameters.Add_Bool("",
 		"SHOW_FILE_SOURCES"     , _TL("Show Data File Source Browser"),
@@ -219,14 +233,15 @@ CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 	);
 
 	m_Parameters.Add_Choice("NODE_DATA"      , "STRETCH_DEFAULT", _TL("Histogram Stretch Defaults"), _TL("Histogram stretch applied by default to new data."), CSG_String::Format("%s|%s|%s",
-		_TL("Linear"), _TL("Standard Deviation"), _TL("Percent Clip")), 1
-	);
+		_TL("Linear"), _TL("Standard Deviation"), _TL("Percent Clip")), 2
+	)->Set_Collapsed();
 
 	m_Parameters.Add_Range ("STRETCH_DEFAULT", "STRETCH_LINEAR" , _TL("Linear"                    ), _TL("Linear percent stretch allows you to trim extreme values from both ends of the histogram using the percentage specified here."), 5., 95., 0., true, 100., true);
 	m_Parameters.Add_Double("STRETCH_DEFAULT", "STRETCH_STDDEV" , _TL("Standard Deviation"        ), _TL(""), 2., 0., true);
+	m_Parameters.Add_Bool  ("STRETCH_STDDEV" , "STRETCH_INRANGE", _TL("Keep in Range"             ), _TL(""), false);
 	m_Parameters.Add_Range ("STRETCH_DEFAULT", "STRETCH_PCTL"   , _TL("Percent Clip"              ), _TL(""), 2., 98., 0., true, 100., true);
 
-	SG_DataObject_Set_Max_Samples(1000000);	// defaults to one million
+	SG_DataObject_Set_Max_Samples(1e06); // defaults to 1 million
 
 	m_Parameters.Add_Int("NODE_DATA",
 		"DATA_SAMPLE_MAX"       , _TL("Maximum Samples"),
@@ -488,6 +503,35 @@ bool CWKSP_Data_Manager::Finalise(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+wxString CWKSP_Data_Manager::Set_Description_Image(CWKSP_Layer *pLayer)
+{
+	wxString s;
+
+	if( m_Parameters["PREVIEW"].asBool() && pLayer->Get_Extent().Get_Area() > 0. )
+	{
+		int nx, ny; double x2y = pLayer->Get_Extent().Get_XRange() / pLayer->Get_Extent().Get_YRange();
+
+		if( x2y > 1. ) { nx = m_Parameters["PREVIEW_SIZE"].asInt(); ny = (int)(nx / x2y); }
+		else           { ny = m_Parameters["PREVIEW_SIZE"].asInt(); nx = (int)(ny * x2y); }
+
+		wxMemoryFSHandler::RemoveFile("preview_data.png");
+
+		wxMemoryFSHandler::AddFile("preview_data.png", pLayer->Get_Thumbnail(nx, ny), wxBITMAP_TYPE_PNG);
+	
+		s = "<img src=\"memory:preview_data.png\">";
+
+		s = "<table border=\"1\"><th><tr>" + s + "</tr></th></table><hr>";
+	}
+
+	return( s );
+}
+
+
 ///////////////////////////////////////////////////////////
 //                                                       //
 ///////////////////////////////////////////////////////////
@@ -807,6 +851,11 @@ int CWKSP_Data_Manager::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 			pParameter->Set_Children_Enabled(pParameter->asBool());
 		}
 
+		if(	pParameter->Cmp_Identifier("PREVIEW") )
+		{
+			pParameter->Set_Children_Enabled(pParameter->asBool());
+		}
+
 		if(	pParameter->Cmp_Identifier("GRID_CACHE_MODE") )
 		{
 			pParameters->Set_Enabled("GRID_CACHE_THRSHLD", pParameter->asInt() != 0);
@@ -1706,10 +1755,18 @@ bool CWKSP_Data_Manager::Set_Colors(CSG_Data_Object *pObject, CSG_Colors *pColor
 	return( pLayer && pLayer->Set_Colors(pColors) );
 }
 
+//---------------------------------------------------------
+bool CWKSP_Data_Manager::Classify(CSG_Data_Object *pObject, const CSG_MetaData &Options)
+{
+	CWKSP_Layer	*pLayer	= Get_Layer(pObject);
+
+	return( pLayer && pLayer->Classify(Options) );
+}
+
 //---------------------------------------------------------
 bool CWKSP_Data_Manager::Get_Parameters(CSG_Data_Object *pObject, CSG_Parameters *pParameters)
 {
-	CWKSP_Data_Item	*pItem	= pParameters ? Get(pObject) : NULL;
+	CWKSP_Data_Item *pItem = pParameters ? Get(pObject) : NULL;
 
 	return( pItem && pParameters->Assign(pItem->Get_Parameters()) );
 }
@@ -1717,7 +1774,7 @@ bool CWKSP_Data_Manager::Get_Parameters(CSG_Data_Object *pObject, CSG_Parameters
 //---------------------------------------------------------
 bool CWKSP_Data_Manager::Set_Parameters(CSG_Data_Object *pObject, CSG_Parameters *pParameters)
 {
-	CWKSP_Data_Item	*pItem	= pParameters ? Get(pObject) : NULL;
+	CWKSP_Data_Item *pItem = pParameters ? Get(pObject) : NULL;
 
 	if( pItem && pItem->Get_Parameters()->Assign_Values(pParameters) )
 	{
