@@ -208,27 +208,36 @@ void CWKSP_Data_Menu_File::Update(void)
 	}
 
 	//-----------------------------------------------------
-	else
+	else // if( m_Files.GetCount() > 0 )
 	{
-		if( m_pMenu->GetMenuItemCount() == m_Offset && m_Offset > 0 )
+		size_t Offset = m_Offset;
+
+		if( Offset > 0 )
 		{
-			m_pMenu->AppendSeparator();
+			if( m_pMenu->GetMenuItemCount() == Offset )
+			{
+				m_pMenu->AppendSeparator();
+			}
+
+			Offset++;
 		}
 
-		for(size_t i=m_pMenu->GetMenuItemCount(); i>m_Offset + 1 + m_Files.GetCount(); i--)
+		for(size_t i=m_pMenu->GetMenuItemCount(); i>Offset + m_Files.GetCount(); i--)
 		{
 			m_pMenu->Destroy(m_pMenu->GetMenuItems()[i - 1]);
 		}
 
-		for(size_t i=0; i<m_Files.GetCount(); i++)
+		for(size_t i=0, id=m_CmdID[0]; i<m_Files.GetCount(); i++, id++)
 		{
-			if( m_pMenu->GetMenuItemCount() <= m_Offset + 1 + i )
+			if( Offset + i < m_pMenu->GetMenuItemCount() )
 			{
-				m_pMenu->Append  (m_CmdID[0] + i, m_Files[i]);
+				wxMenuItem *pItem = m_pMenu->GetMenuItems()[Offset + i];
+
+				pItem->SetId(id); pItem->SetItemLabel(m_Files[i]);
 			}
-			else //if( m_pMenu->GetLabel(m_CmdID[0] + i).Cmp(m_Files[i]) )
+			else
 			{
-				m_pMenu->SetLabel(m_CmdID[0] + i, m_Files[i]);
+				m_pMenu->Append(id, m_Files[i]);
 			}
 		}
 	}
