@@ -51,9 +51,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -62,9 +62,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -78,26 +78,22 @@ public:
 	CSG_Grids *					Get_Grids				(void)	{	return( (CSG_Grids *)m_pObject );	}
 
 	CSG_Grid *					Get_Grid				(void);
-	CSG_Grid *					Get_Grid				(int i);
+	CSG_Grid *					Get_Grid				(int Band);
 
 	virtual wxString			Get_Description			(void);
 
+	virtual wxToolBarBase *		Get_ToolBar				(void);
 	virtual wxMenu *			Get_Menu				(void);
 
 	virtual bool				On_Command				(int Cmd_ID);
 	virtual bool				On_Command_UI			(wxUpdateUIEvent &event);
 
 	virtual wxString			Get_Value				(CSG_Point ptWorld, double Epsilon);
-	virtual double				Get_Value_Minimum		(void);
-	virtual double				Get_Value_Maximum		(void);
-	virtual double				Get_Value_Range			(void);
-	virtual double				Get_Value_Mean			(void);
-	virtual double				Get_Value_StdDev		(void);
 
 	virtual TSG_Rect			Edit_Get_Extent			(void)	{	return( Get_Extent() );	}
 	virtual bool				Edit_Set_Attributes		(void);
 
-	bool						Fit_Colors				(const CSG_Rect &rWorld);
+	virtual bool				Set_Stretch_Extent		(const CSG_Rect &Extent);
 
 	virtual bool				asImage					(CSG_Grid *pImage);
 
@@ -123,9 +119,9 @@ protected:
 
 private:
 
-	int							m_Fit_Colors;
+	int							m_Stretch_Extent = -1;
 
-	double						m_Alpha[2];
+	CTransparency				m_Alpha;
 
 	CWKSP_Layer_Classify		m_Classify[3];
 
@@ -133,24 +129,46 @@ private:
 	CSG_String					_Get_List_Attributes	(void);
 	CSG_String					_Get_List_Bands			(int Attribute = -1);
 
-	bool						_Fit_Colors				(const CSG_Rect &rWorld, CSG_Data_Object *pObject, CWKSP_Layer_Classify *pClassify, const CSG_String &Suffix = "");
+	CSG_Grid *					_Get_Grid				(int Band, const CSG_Parameters &Parameters);
 
-	void						_LUT_Create				(void);
+	bool						_Get_Stretch_Extent		(const CSG_Rect &Extent, CSG_Data_Object *pObject, double &Minimum, double &Maximum) const;
 
 	bool						_Save_Image				(void);
 	bool						_Save_Image_Clipboard	(void);
 
-	void						_Draw_Grid_Nodes		(CSG_Map_DC &dc_Map, TSG_Grid_Resampling Resampling);
-	void						_Draw_Grid_Nodes		(CSG_Map_DC &dc_Map, TSG_Grid_Resampling Resampling, CSG_Grid *pBands[4], bool bBandWise, int yDC, int axDC, int bxDC);
-	void						_Draw_Grid_Cells		(CSG_Map_DC &dc_Map);
+	void						_Draw_Cells				(CSG_Map_DC &dc_Map);
+	void						_Draw_Points			(CSG_Map_DC &dc_Map);
+
+	bool						_Draw_Get_Color			(int &Color, int x, int y          );
+	bool						_Draw_Get_Color			(int &Color, const CSG_Point &Point);
+
+
+private:
+
+	class CBands
+	{
+	public:
+
+		bool					bOverlay, bBandStatistics;
+
+		CSG_Grid_Resampling		Resampling;
+
+		CSG_Grid				*pBands[3];
+
+		void					Set_Bands				(CSG_Grid *pB0, CSG_Grid *pB1, CSG_Grid *pB2) { pBands[0] = pB0; pBands[1] = pB1; pBands[2] = pB2; }
+
+		CSG_Grid *				operator []				(int i) { return( pBands[i] ); }
+	};
+
+	CBands						m_Bands;
 
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
