@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -67,9 +67,23 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#define LAYER_DRAW_FLAG_THUMBNAIL 0x01
+#define LAYER_DRAW_FLAG_SELECTION 0x02
+#define LAYER_DRAW_FLAG_HIGHLIGHT 0x04
+#define LAYER_DRAW_FLAG_NOEDITS   0x08
+#define LAYER_DRAW_FLAG_NOLABELS  0x10
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -88,14 +102,21 @@ public:
 	CSG_Colors *					Get_Colors				(void);
 	bool							Get_Colors				(CSG_Colors *pColors);
 	bool							Set_Colors				(CSG_Colors *pColors);
-	bool							Set_Color_Range			(double Minimum, double Maximum);
 
 	virtual wxString				Get_Value				(CSG_Point ptWorld, double Epsilon)	= 0;
-	virtual double					Get_Value_Minimum		(void)								= 0;
-	virtual double					Get_Value_Maximum		(void)								= 0;
-	virtual double					Get_Value_Range			(void)								= 0;
-	virtual double					Get_Value_Mean			(void)								= 0;
-	virtual double					Get_Value_StdDev		(void)								= 0;
+
+	wxString						Get_Field_Naming		(void) const;
+	bool							Get_Field_Value			(sLong Index, int Field, int Normalize, double Scale, wxString &Value) const;
+	bool							Get_Field_Value			(sLong Index, int Field, int Normalize, double Scale, double   &Value) const;
+	
+	double							Get_Stretch_Minimum		(void) const;
+	double							Get_Stretch_Maximum		(void) const;
+	double							Get_Stretch_Range		(void) const;
+	bool							Set_Stretch_Range		(double Minimum, double Maximum);
+	bool							Set_Stretch_FullRange	(void);
+	virtual bool					Set_Stretch_Extent		(const CSG_Rect &Extent)	{	return( false );	}
+
+	bool							Classify				(const CSG_MetaData &Options);
 
 	bool							Draw					(CSG_Map_DC &dc_Map, int Flags = 0, CSG_Data_Object *pObject = NULL);
 
@@ -107,7 +128,6 @@ public:
 
 	virtual bool					Show					(class CWKSP_Map *pMap);
 	virtual bool					Show					(int Flags = 0);
-	virtual bool					Update					(CWKSP_Layer *pChanged);
 	virtual bool					View_Closes				(class MDI_ChildFrame *pView);
 	virtual bool					asImage					(CSG_Grid *pImage)		{	return( false );	}
 
@@ -127,19 +147,15 @@ public:
 	virtual bool					Edit_Do_Mouse_Move_Draw	(bool bMouseDown);
 	virtual bool					Edit_Set_Index			(int Index);
 	virtual bool					Edit_Set_Attributes		(void)	{	return( false );	}
-	int								Edit_Get_Index			(void);
+	virtual int						Edit_Get_Index			(void)	{	return( 0     );	}
 	CSG_Table *						Edit_Get_Attributes		(void);
 
 
 protected:
 
-	int								m_Edit_Index;
-
-	CSG_Parameter_Range				*m_pZRange;
-
 	CSG_Point						m_Edit_Mouse_Down;
 
-	CSG_Table						m_Edit_Attributes;
+	CSG_Table						m_Edit_Attributes, m_Normalization;
 
 	class CWKSP_Layer_Classify		*m_pClassify;
 
@@ -150,6 +166,8 @@ protected:
 	wxBitmap						m_Thumbnail;
 
 
+	static bool						Add_ToolBar_Defaults	(class wxToolBarBase *pToolBar);
+
 	virtual void					On_Create_Parameters	(void);
 	virtual void					On_DataObject_Changed	(void);
 	virtual void					On_Parameters_Changed	(void);
@@ -161,9 +179,14 @@ protected:
 
 	virtual void					On_Draw					(CSG_Map_DC &dc_Map, int Flags)	= 0;
 
-	void							ColorsParms_Add			(void);
-	void							ColorsParms_On_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags);
-	bool							ColorsParms_Adjust		(CSG_Parameters  &Parameters, CSG_Data_Object *pObject = NULL, const CSG_String &Suffix = "");
+	bool							Set_Stretch				(CSG_Parameters &Parameters, CSG_Data_Object *pObject = NULL, const CSG_String &Suffix = "");
+
+	bool							Set_Normalization		(int Field_Value, int Field_Normalize, double Scale_Normalize, sLong maxSamples = 0);
+
+	bool							Set_Fields_Choice		(CSG_Parameter *pChoice, bool bNumeric, bool bAddNone, bool bSelectNone = false);
+	static int						Get_Fields_Choice		(CSG_Parameter *pChoice);
+
+	bool							Can_Add_To_Active_Map	(void);
 
 
 private:
@@ -172,13 +195,114 @@ private:
 
 	void							_Set_Projection			(void);
 
+	CSG_Table *						_Get_Field_Table		(int &Field, const CSG_Parameters &Parameters);
+
+	bool							_Add_To_Active_Map		(void);
+
+
+	//-----------------------------------------------------
+	CSG_Parameters					m_Classify;
+
+	static int						_Classify_Callback		(CSG_Parameter *pParameter, int Flags);
+
+	bool							_Classify				(void);
+
+
+public:
+
+	//-----------------------------------------------------
+	class CTransparency
+	{
+	public:
+
+		bool						Create					(CSG_Grid *pGrid, double Minimum, double Maximum)
+		{
+			m_pGrid = pGrid && Minimum != Maximum ? pGrid : NULL;
+
+			if( m_pGrid )
+			{
+				m_Minimum = Minimum; m_Scale = 255. / (Maximum - Minimum);
+			}
+
+			return( m_pGrid != NULL );
+		}
+
+		bool						is_Okay					(void) const { return( m_pGrid != NULL ); }
+
+		BYTE						Get_Alpha				(const CSG_Point &Point) const
+		{
+			return( Get_Alpha(Point.x, Point.y) );
+		}
+
+		BYTE						Get_Alpha				(double x, double y) const
+		{
+			if( m_pGrid )
+			{
+				double Alpha;
+
+				if( m_pGrid->Get_Value(x, y, Alpha) )
+				{
+					Alpha = (Alpha - m_Minimum) * m_Scale;
+
+					return( Alpha <= 0. ? 0 : Alpha >= 255. ? 255 : (BYTE)Alpha );
+				}
+
+				return( 0 );
+			}
+
+			return( 255 );
+		}
+
+		BYTE						Get_Alpha				(const CSG_Grid_System &System, int x, int y) const
+		{
+			return( Get_Alpha(System.Get_xGrid_to_World(x), System.Get_yGrid_to_World(y)) );
+		}
+
+		bool						Set_Alpha				(int &Color, const CSG_Point &Point) const
+		{
+			return( Set_Alpha(Color, Point.x, Point.y) );
+		}
+
+		bool						Set_Alpha				(int &Color, double x, double y) const
+		{
+			if( m_pGrid )
+			{
+				((BYTE *)&Color)[3] = Get_Alpha(x, y);
+
+				return( true );
+			}
+
+			return( false );
+		}
+
+		bool						Set_Alpha				(int &Color, const CSG_Grid_System &System, int x, int y) const
+		{
+			if( m_pGrid )
+			{
+				((BYTE *)&Color)[3] = Get_Alpha(System.Get_xGrid_to_World(x), System.Get_yGrid_to_World(y));
+
+				return( true );
+			}
+
+			return( false );
+		}
+
+
+	private:
+
+		double					m_Minimum = 0., m_Scale = 1.;
+
+		CSG_Grid				*m_pGrid = NULL;
+
+	};
+
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -186,9 +310,9 @@ CWKSP_Layer *						Get_Active_Layer		(void);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
