@@ -56,12 +56,13 @@
 #include "wksp_grids.h"
 #include "wksp_shapes.h"
 #include "wksp_pointcloud.h"
+#include "wksp_tin.h"
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -70,6 +71,12 @@ CSG_Scaler::CSG_Scaler(void)
 	Create(0., 0.);
 }
 
+//-----------------------------------------------------
+CSG_Scaler::CSG_Scaler(const CSG_Scaler &Scaler)
+{
+	Create(Scaler);
+}
+
 //-----------------------------------------------------
 CSG_Scaler::CSG_Scaler(double Minimum, double Maximum, double Interval)
 {
@@ -82,19 +89,33 @@ bool CSG_Scaler::Create(double Minimum, double Maximum, double Interval)
 	return( Set_Interval(Interval) && Set_Range(Minimum, Maximum) );
 }
 
+//-----------------------------------------------------
+bool CSG_Scaler::Create(const CSG_Scaler &Scaler)
+{
+	return( Set_Interval(Scaler.Get_Interval()) && Set_Range(Scaler.Get_Minimum(), Scaler.Get_Maximum()) );
+}
+
+//-----------------------------------------------------
+CSG_Scaler & CSG_Scaler::operator =	(const CSG_Scaler &Scaler)
+{
+	Create(Scaler);
+
+	return( *this );
+}
+
 //-----------------------------------------------------
 bool CSG_Scaler::Set_Range(double Minimum, double Maximum)
 {
-	m_Minimum	= Minimum < Maximum ? Minimum : Maximum;
-	m_Range		= Minimum < Maximum ? Maximum - Minimum : Minimum - Maximum;
+	m_Minimum = Minimum < Maximum ? Minimum : Maximum;
+	m_Range   = Minimum < Maximum ? Maximum - Minimum : Minimum - Maximum;
 
 	return( m_Range > 0. );
 }
 
 bool CSG_Scaler::Set_Interval(double Interval)
 {
-	m_Interval	= Interval < 0. ? DECREASING : Interval > 0. ? INCREASING : LINEAR;
-	m_LogRange	= fabs(Interval);
+	m_Interval = Interval < 0. ? DECREASING : Interval > 0. ? INCREASING : LINEAR;
+	m_LogRange = fabs(Interval);
 
 	return( true );
 }
@@ -102,52 +123,50 @@ bool CSG_Scaler::Set_Interval(double Interval)
 //-----------------------------------------------------
 bool CSG_Scaler::Set_Linear(CSG_Table *pTable, int Field, double Interval, double Minimum, double Maximum)
 {
-	Minimum	= pTable->Get_Minimum(Field) + pTable->Get_Range(Field) * Minimum / 100.;
-	Maximum	= pTable->Get_Minimum(Field) + pTable->Get_Range(Field) * Maximum / 100.;
+	Minimum = pTable->Get_Minimum(Field) + pTable->Get_Range(Field) * Minimum / 100.;
+	Maximum = pTable->Get_Minimum(Field) + pTable->Get_Range(Field) * Maximum / 100.;
 
 	return( Create(Minimum, Maximum, Interval) );
 }
 
 bool CSG_Scaler::Set_StdDev(CSG_Table *pTable, int Field, double Interval, double StdDev, bool bKeepInRange)
 {
-	double	Minimum	= pTable->Get_Mean(Field) - StdDev * pTable->Get_StdDev(Field); if( bKeepInRange && Minimum < pTable->Get_Minimum(Field) ) Minimum = pTable->Get_Minimum(Field);
-	double	Maximum	= pTable->Get_Mean(Field) + StdDev * pTable->Get_StdDev(Field); if( bKeepInRange && Maximum > pTable->Get_Maximum(Field) ) Maximum = pTable->Get_Maximum(Field);
+	double Minimum = pTable->Get_Mean(Field) - StdDev * pTable->Get_StdDev(Field); if( bKeepInRange && Minimum < pTable->Get_Minimum(Field) ) { Minimum = pTable->Get_Minimum(Field); }
+	double Maximum = pTable->Get_Mean(Field) + StdDev * pTable->Get_StdDev(Field); if( bKeepInRange && Maximum > pTable->Get_Maximum(Field) ) { Maximum = pTable->Get_Maximum(Field); }
 
 	return( Create(Minimum, Maximum, Interval) );
 }
 
 bool CSG_Scaler::Set_Percentile(CSG_Table *pTable, int Field, double Interval, double Minimum, double Maximum)
 {
-	return( false );
+	Minimum = pTable->Get_Histogram(Field).Get_Percentile(Minimum);
+	Maximum = pTable->Get_Histogram(Field).Get_Percentile(Maximum);
 
-	//	double	Minimum	= pTable->Get_Percentile(Field,        Percentile);
-	//	double	Maximum	= pTable->Get_Percentile(Field, 100. - Percentile);
-
-	//	return( Create(Minimum, Maximum, Interval) );
+	return( Create(Minimum, Maximum, Interval) );
 }
 
 
 //-----------------------------------------------------
 bool CSG_Scaler::Set_Linear(CSG_Grid *pGrid, double Interval, double Minimum, double Maximum)
 {
-	Minimum	= pGrid->Get_Min() + pGrid->Get_Range() * Minimum / 100.;
-	Maximum	= pGrid->Get_Min() + pGrid->Get_Range() * Maximum / 100.;
+	Minimum = pGrid->Get_Min() + pGrid->Get_Range() * Minimum / 100.;
+	Maximum = pGrid->Get_Min() + pGrid->Get_Range() * Maximum / 100.;
 
 	return( Create(Minimum, Maximum, Interval) );
 }
 
 bool CSG_Scaler::Set_StdDev(CSG_Grid *pGrid, double Interval, double StdDev, bool bKeepInRange)
 {
-	double	Minimum	= pGrid->Get_Mean() - StdDev * pGrid->Get_StdDev(); if( bKeepInRange && Minimum < pGrid->Get_Min() ) Minimum = pGrid->Get_Min();
-	double	Maximum	= pGrid->Get_Mean() + StdDev * pGrid->Get_StdDev(); if( bKeepInRange && Maximum > pGrid->Get_Max() ) Maximum = pGrid->Get_Max();
+	double Minimum = pGrid->Get_Mean() - StdDev * pGrid->Get_StdDev(); if( bKeepInRange && Minimum < pGrid->Get_Min() ) { Minimum = pGrid->Get_Min(); }
+	double Maximum = pGrid->Get_Mean() + StdDev * pGrid->Get_StdDev(); if( bKeepInRange && Maximum > pGrid->Get_Max() ) { Maximum = pGrid->Get_Max(); }
 
 	return( Create(Minimum, Maximum, Interval) );
 }
 
 bool CSG_Scaler::Set_Percentile(CSG_Grid *pGrid, double Interval, double Minimum, double Maximum)
 {
-	Minimum	= pGrid->Get_Percentile(Minimum);
-	Maximum	= pGrid->Get_Percentile(Maximum);
+	Minimum = pGrid->Get_Percentile(Minimum);
+	Maximum = pGrid->Get_Percentile(Maximum);
 
 	return( Create(Minimum, Maximum, Interval) );
 }
@@ -155,46 +174,43 @@ bool CSG_Scaler::Set_Percentile(CSG_Grid *pGrid, double Interval, double Minimum
 //-----------------------------------------------------
 bool CSG_Scaler::Set_Linear(CSG_Grids *pGrids, double Interval, double Minimum, double Maximum)
 {
-	Minimum	= pGrids->Get_Min() + pGrids->Get_Range() * Minimum / 100.;
-	Maximum	= pGrids->Get_Min() + pGrids->Get_Range() * Maximum / 100.;
+	Minimum = pGrids->Get_Min() + pGrids->Get_Range() * Minimum / 100.;
+	Maximum = pGrids->Get_Min() + pGrids->Get_Range() * Maximum / 100.;
 
 	return( Create(Minimum, Maximum, Interval) );
 }
 
 bool CSG_Scaler::Set_StdDev(CSG_Grids *pGrids, double Interval, double StdDev, bool bKeepInRange)
 {
-	double	Minimum	= pGrids->Get_Mean() - StdDev * pGrids->Get_StdDev(); if( bKeepInRange && Minimum < pGrids->Get_Min() ) Minimum = pGrids->Get_Min();
-	double	Maximum	= pGrids->Get_Mean() + StdDev * pGrids->Get_StdDev(); if( bKeepInRange && Maximum > pGrids->Get_Max() ) Maximum = pGrids->Get_Max();
+	double Minimum = pGrids->Get_Mean() - StdDev * pGrids->Get_StdDev(); if( bKeepInRange && Minimum < pGrids->Get_Min() ) { Minimum = pGrids->Get_Min(); }
+	double Maximum = pGrids->Get_Mean() + StdDev * pGrids->Get_StdDev(); if( bKeepInRange && Maximum > pGrids->Get_Max() ) { Maximum = pGrids->Get_Max(); }
 
 	return( Create(Minimum, Maximum, Interval) );
 }
 
 bool CSG_Scaler::Set_Percentile(CSG_Grids *pGrids, double Interval, double Minimum, double Maximum)
 {
-	Minimum	= pGrids->Get_Percentile(Minimum);
-	Maximum	= pGrids->Get_Percentile(Maximum);
+	Minimum = pGrids->Get_Percentile(Minimum);
+	Maximum = pGrids->Get_Percentile(Maximum);
 
 	return( Create(Minimum, Maximum, Interval) );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CWKSP_Layer_Classify::CWKSP_Layer_Classify(void)
 {
-	m_Count			= 64;
-
-	m_Mode			= CLASSIFY_SINGLE;
-	m_Shade_Mode	= SHADE_MODE_DSC_GREY;
-
-	m_pLayer		= NULL;
-	m_pColors		= NULL;
-	m_pLUT			= NULL;
+	m_Count   = 64;
+	m_Mode    = CLASSIFY_SINGLE;
+	m_pLayer  = NULL;
+	m_pColors = NULL;
+	m_pLUT    = NULL;
 }
 
 //---------------------------------------------------------
@@ -203,21 +219,19 @@ CWKSP_Layer_Classify::~CWKSP_Layer_Classify(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CWKSP_Layer_Classify::Initialise(CWKSP_Layer *pLayer, CSG_Table *pLUT, CSG_Colors *pColors)
 {
-	m_pLayer	= pLayer;
-	m_pLUT		= pLUT;
-	m_pColors	= pColors;
+	m_pLayer  = pLayer;
+	m_pLUT    = pLUT;
+	m_pColors = pColors;
 
-	m_Count		=  m_pLayer->Get_Object()->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid
-				|| m_pLayer->Get_Object()->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grids
-				|| m_pLayer->Get_Object()->Get_ObjectType() == SG_DATAOBJECT_TYPE_PointCloud ? 64 : 16;
+	m_Count   = m_pLayer->Get_Object()->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid
+	         || m_pLayer->Get_Object()->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grids
+	         || m_pLayer->Get_Object()->Get_ObjectType() == SG_DATAOBJECT_TYPE_PointCloud ? 64 : 16;
 
 	//-----------------------------------------------------
 	if( m_pLUT && m_pLUT->Get_Count() == 0 )
@@ -244,7 +258,7 @@ bool CWKSP_Layer_Classify::Initialise(CWKSP_Layer *pLayer, CSG_Table *pLUT, CSG_
 		CSG_Table_Record *pRecord;
 
 		pRecord	= m_pLUT->Add_Record();
-		pRecord->Set_Value(LUT_COLOR		, Colours[Colour]); Colour = ++Colour % nColours;
+		pRecord->Set_Value(LUT_COLOR		, Colours[Colour]); Colour = (Colour + 1) % nColours;
 		pRecord->Set_Value(LUT_TITLE		, _TL("Class 1"));
 		pRecord->Set_Value(LUT_DESCRIPTION	, _TL("First Class"));
 		pRecord->Set_Value(LUT_MIN			, 0.0);
@@ -268,9 +282,7 @@ bool CWKSP_Layer_Classify::Initialise(CWKSP_Layer *pLayer, CSG_Table *pLUT, CSG_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -278,7 +290,7 @@ double CWKSP_Layer_Classify::Get_Class_Value_Minimum(int iClass)
 {
 	switch( m_Mode )
 	{
-	case CLASSIFY_LUT:
+	case CLASSIFY_LUT      :
 		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			return( m_pLUT->Get_Record(iClass)->asDouble(LUT_MIN) );
@@ -286,10 +298,9 @@ double CWKSP_Layer_Classify::Get_Class_Value_Minimum(int iClass)
 		break;
 
 	case CLASSIFY_GRADUATED:
-	case CLASSIFY_DISCRETE:
-	case CLASSIFY_SHADE:
-	case CLASSIFY_OVERLAY:
-		if( m_zRange > 0.0 )
+	case CLASSIFY_DISCRETE :
+	case CLASSIFY_OVERLAY  :
+		if( m_zRange > 0. )
 		{
 			return( Get_RelativeToMetric(iClass / (double)Get_Class_Count()) );
 		}
@@ -305,7 +316,7 @@ double CWKSP_Layer_Classify::Get_Class_Value_Maximum(int iClass)
 {
 	switch( m_Mode )
 	{
-	case CLASSIFY_LUT:
+	case CLASSIFY_LUT      :
 		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			return( m_pLUT->Get_Record(iClass)->asDouble(LUT_MAX) );
@@ -313,10 +324,9 @@ double CWKSP_Layer_Classify::Get_Class_Value_Maximum(int iClass)
 		break;
 
 	case CLASSIFY_GRADUATED:
-	case CLASSIFY_DISCRETE:
-	case CLASSIFY_SHADE:
-	case CLASSIFY_OVERLAY:
-		if( m_zRange > 0.0 )
+	case CLASSIFY_DISCRETE :
+	case CLASSIFY_OVERLAY  :
+		if( m_zRange > 0. )
 		{
 			return( Get_RelativeToMetric((1.0 + iClass) / (double)Get_Class_Count()) );
 		}
@@ -332,7 +342,7 @@ double CWKSP_Layer_Classify::Get_Class_Value_Center(int iClass)
 {
 	switch( m_Mode )
 	{
-	case CLASSIFY_LUT:
+	case CLASSIFY_LUT      :
 		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			return( 0.5 * (m_pLUT->Get_Record(iClass)->asDouble(LUT_MIN) + m_pLUT->Get_Record(iClass)->asDouble(LUT_MAX)) );
@@ -340,10 +350,9 @@ double CWKSP_Layer_Classify::Get_Class_Value_Center(int iClass)
 		break;
 
 	case CLASSIFY_GRADUATED:
-	case CLASSIFY_DISCRETE:
-	case CLASSIFY_SHADE:
-	case CLASSIFY_OVERLAY:
-		if( m_zRange > 0.0 )
+	case CLASSIFY_DISCRETE :
+	case CLASSIFY_OVERLAY  :
+		if( m_zRange > 0. )
 		{
 			return( Get_RelativeToMetric((0.5 + iClass) / (double)Get_Class_Count()) );
 		}
@@ -358,11 +367,11 @@ double CWKSP_Layer_Classify::Get_Class_Value_Center(int iClass)
 //---------------------------------------------------------
 wxString CWKSP_Layer_Classify::Get_Class_Name(int iClass)
 {
-	CSG_String	s;
+	CSG_String s;
 
 	switch( m_Mode )
 	{
-	case CLASSIFY_LUT:
+	case CLASSIFY_LUT      :
 		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			s.Printf(SG_T("%s"), m_pLUT->Get_Record(iClass)->asString(LUT_TITLE));
@@ -370,11 +379,10 @@ wxString CWKSP_Layer_Classify::Get_Class_Name(int iClass)
 		break;
 
 	case CLASSIFY_GRADUATED:
-	case CLASSIFY_DISCRETE:
-	case CLASSIFY_SHADE:
-	case CLASSIFY_OVERLAY:
-		s	= SG_Get_String(Get_Class_Value_Minimum(iClass), -2) + SG_T(" < ")
-			+ SG_Get_String(Get_Class_Value_Maximum(iClass), -2);
+	case CLASSIFY_DISCRETE :
+	case CLASSIFY_OVERLAY  :
+		s = SG_Get_String(Get_Class_Value_Minimum(iClass), -2) + SG_T(" < ")
+		  + SG_Get_String(Get_Class_Value_Maximum(iClass), -2);
 		break;
 
 	default: break;
@@ -399,9 +407,9 @@ wxString CWKSP_Layer_Classify::Get_Class_Name_byValue(const wxString &Value)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Unique							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -412,9 +420,9 @@ void CWKSP_Layer_Classify::Set_Unique_Color(int Color)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Metric							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -446,23 +454,23 @@ CSG_Colors CWKSP_Layer_Classify::Get_Class_Colors(void)	const
 //---------------------------------------------------------
 void CWKSP_Layer_Classify::Set_Metric(int Mode, double LogFactor, double zMin, double zMax)
 {
-	m_zMode		= Mode;
-	m_zMin		= zMin < zMax ? zMin : zMax;
-	m_zRange	= zMin < zMax ? (zMax - zMin) : (zMin - zMax);
-	m_zLogRange	= LogFactor;
-	m_zLogMax	= log(1.0 + m_zLogRange);
+	m_zMode     = Mode;
+	m_zMin      = zMin < zMax ? zMin : zMax;
+	m_zRange    = zMin < zMax ? (zMax - zMin) : (zMin - zMax);
+	m_zLogRange = pow(10., LogFactor);
+	m_zLogMax   = log(1. + m_zLogRange);
 
-	if( m_zRange <= 0.0 || (m_zMode != 0 && m_zLogRange <= 0.0) )
+	if( m_zRange <= 0. || (m_zMode != 0 && m_zLogRange <= 0.) )
 	{
-		m_zRange	= 0.0;
+		m_zRange = 0.;
 	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Lookup Table					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -595,9 +603,9 @@ int CWKSP_Layer_Classify::_LUT_Get_Class(const CSG_String &Value)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -653,9 +661,9 @@ void CWKSP_Layer_Classify::Metric2EqualElements(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Histogram						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -673,15 +681,15 @@ bool CWKSP_Layer_Classify::Histogram_Update(void)
 	//-----------------------------------------------------
 	STATUSBAR_Set_Text(_TL("Build Histogram..."));
 
-	m_Histogram.Create(Get_Class_Count(), 0, Get_Class_Count() - 1);
+	m_Histogram.Create(Get_Class_Count(), 0., Get_Class_Count() - 1.);
 
 	switch( m_pLayer->Get_Type() )
 	{
-	case WKSP_ITEM_Grid:
+	case WKSP_ITEM_Grid      :
 		_Histogram_Update(((CWKSP_Grid  *)m_pLayer)->Get_Grid ());
 		break;
 
-	case WKSP_ITEM_Grids:
+	case WKSP_ITEM_Grids     :
 		if( m_Mode == CLASSIFY_OVERLAY )
 		{
 			_Histogram_Update(((CWKSP_Grids *)m_pLayer)->Get_Grids());
@@ -692,17 +700,27 @@ bool CWKSP_Layer_Classify::Histogram_Update(void)
 		}
 		break;
 
-	case WKSP_ITEM_Shapes:
-		_Histogram_Update(((CWKSP_Shapes *)m_pLayer)->Get_Shapes(),
-			((CWKSP_Shapes *)m_pLayer)->Get_Field_Value (),
-			((CWKSP_Shapes *)m_pLayer)->Get_Field_Normal(),
-			((CWKSP_Shapes *)m_pLayer)->Get_Scale_Normal()
+	case WKSP_ITEM_Shapes    :
+		_Histogram_Update(m_pLayer->Get_Object()->asTable(true),
+			((CWKSP_Shapes     *)m_pLayer)->Get_Field_Value (),
+			((CWKSP_Shapes     *)m_pLayer)->Get_Field_Normal(),
+			((CWKSP_Shapes     *)m_pLayer)->Get_Scale_Normal()
 		);
 		break;
 
 	case WKSP_ITEM_PointCloud:
-		_Histogram_Update(((CWKSP_PointCloud *)m_pLayer)->Get_PointCloud(),
-			((CWKSP_PointCloud *)m_pLayer)->Get_Field_Value()
+		_Histogram_Update(m_pLayer->Get_Object()->asTable(true),
+			((CWKSP_PointCloud *)m_pLayer)->Get_Field_Value (),
+			((CWKSP_PointCloud *)m_pLayer)->Get_Field_Normal(),
+			((CWKSP_PointCloud *)m_pLayer)->Get_Scale_Normal()
+		);
+		break;
+
+	case WKSP_ITEM_TIN       :
+		_Histogram_Update(m_pLayer->Get_Object()->asTable(true),
+			((CWKSP_TIN        *)m_pLayer)->Get_Field_Value (),
+			((CWKSP_TIN        *)m_pLayer)->Get_Field_Normal(),
+			((CWKSP_TIN        *)m_pLayer)->Get_Scale_Normal()
 		);
 		break;
 
@@ -722,7 +740,7 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Grid *pGrid)
 {
 	if( pGrid->Get_Max_Samples() > 0 && pGrid->Get_Max_Samples() < pGrid->Get_NCells() )
 	{
-		double	d	= (double)pGrid->Get_NCells() / (double)pGrid->Get_Max_Samples();
+		double d = (double)pGrid->Get_NCells() / (double)pGrid->Get_Max_Samples();
 
 		for(double i=0; i<(double)pGrid->Get_NCells() && PROGRESSBAR_Set_Position(i, (double)pGrid->Get_NCells()); i+=d)
 		{
@@ -734,12 +752,12 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Grid *pGrid)
 
 		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < (size_t)pGrid->Get_Max_Samples() )	// any no-data cells ?
 		{
-			d	*= (double)m_Histogram.Get_Element_Count() / (double)pGrid->Get_Max_Samples();
+			d *= (double)m_Histogram.Get_Element_Count() / (double)pGrid->Get_Max_Samples();
 		}
 
 		m_Histogram.Scale_Element_Count(d);
 
-		m_Statistics	= pGrid->Get_Statistics();
+		m_Statistics = pGrid->Get_Statistics();
 
 		return( true );
 	}
@@ -752,7 +770,7 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Grid *pGrid)
 		}
 	}
 
-	m_Statistics	= pGrid->Get_Statistics();
+	m_Statistics = pGrid->Get_Statistics();
 
 	return( true );
 }
@@ -762,24 +780,24 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Grids *pGrids)
 {
 	if( pGrids->Get_Max_Samples() > 0 && pGrids->Get_Max_Samples() < pGrids->Get_NCells() )
 	{
-		double	d	= (double)pGrids->Get_NCells() / (double)pGrids->Get_Max_Samples();
+		double d = (double)pGrids->Get_NCells() / (double)pGrids->Get_Max_Samples();
 
 		for(double i=0; i<(double)pGrids->Get_NCells() && PROGRESSBAR_Set_Position(i, (double)pGrids->Get_NCells()); i+=d)
 		{
 			if( !pGrids->is_NoData((sLong)i) )
 			{
-				m_Histogram	+= Get_Class(pGrids->asDouble((sLong)i));
+				m_Histogram += Get_Class(pGrids->asDouble((sLong)i));
 			}
 		}
 
 		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < (size_t)pGrids->Get_Max_Samples() )	// any no-data cells ?
 		{
-			d	*= (double)m_Histogram.Get_Element_Count() / (double)pGrids->Get_Max_Samples();
+			d *= (double)m_Histogram.Get_Element_Count() / (double)pGrids->Get_Max_Samples();
 		}
 
 		m_Histogram.Scale_Element_Count(d);
 
-		m_Statistics	= pGrids->Get_Statistics();
+		m_Statistics = pGrids->Get_Statistics();
 
 		return( true );
 	}
@@ -788,57 +806,57 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Grids *pGrids)
 	{
 		if( !pGrids->is_NoData(i) )
 		{
-			m_Histogram	+= Get_Class(pGrids->asDouble(i));
+			m_Histogram += Get_Class(pGrids->asDouble(i));
 		}
 	}
 
-	m_Statistics	= pGrids->Get_Statistics();
+	m_Statistics = pGrids->Get_Statistics();
 
 	return( true );
 }
 
 //---------------------------------------------------------
-bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Shapes *pShapes, int Attribute, int Normalize, double Scale)
+bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Table *pTable, int Field, int Normalize, double Scale)
 {
-	if( Attribute < 0 || Attribute >= pShapes->Get_Field_Count() )
+	if( !pTable || Field < 0 || Field >= pTable->Get_Field_Count() )
 	{
 		return( false );
 	}
 
-	if( pShapes->Get_Max_Samples() > 0 && pShapes->Get_Max_Samples() < pShapes->Get_Count() )
+	if( pTable->Get_Max_Samples() > 0 && pTable->Get_Max_Samples() < pTable->Get_Count() )
 	{
-		double	d	= (double)pShapes->Get_Count() / (double)pShapes->Get_Max_Samples();
+		double d = (double)pTable->Get_Count() / (double)pTable->Get_Max_Samples();
 
-		for(double i=0; i<(double)pShapes->Get_Count() && PROGRESSBAR_Set_Position(i, (double)pShapes->Get_Count()); i+=d)
+		for(double i=0; i<(double)pTable->Get_Count() && PROGRESSBAR_Set_Position(i, (double)pTable->Get_Count()); i+=d)
 		{
-			CSG_Shape	*pShape	= pShapes->Get_Shape((int)i);
+			CSG_Table_Record &Record = *pTable->Get_Record((int)i);
 
 			if( m_Mode == CLASSIFY_LUT )
 			{
 				m_Histogram	+= SG_Data_Type_is_Numeric(m_pLUT->Get_Field_Type(LUT_MIN))
-					? Get_Class(pShape->asDouble(Attribute))
-					: Get_Class(pShape->asString(Attribute));
+					? Get_Class(Record.asDouble(Field))
+					: Get_Class(Record.asDouble(Field));
 			}
-			else if( !pShape->is_NoData(Attribute) )
+			else if( !Record.is_NoData(Field) )
 			{
-				double z = pShape->asDouble(Attribute);
+				double z = Record.asDouble(Field);
 
 				if( Normalize < 0 )
 				{
 					m_Histogram += Get_Class(z); m_Statistics += z;
 				}
-				else if( !pShape->is_NoData(Normalize) && pShape->asDouble(Normalize) )
+				else if( !Record.is_NoData(Normalize) && Record.asDouble(Normalize) )
 				{
-					z *= Scale / pShape->asDouble(Normalize);
+					z *= Scale / Record.asDouble(Normalize);
 
 					m_Histogram += Get_Class(z); m_Statistics += z;
 				}
 			}
 		}
 
-		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < (size_t)pShapes->Get_Max_Samples() )	// any no-data cells ?
+		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < (size_t)pTable->Get_Max_Samples() )	// any no-data cells ?
 		{
-			d	*= (double)m_Histogram.Get_Element_Count() / (double)pShapes->Get_Max_Samples();
+			d *= (double)m_Histogram.Get_Element_Count() / (double)pTable->Get_Max_Samples();
 		}
 
 		m_Histogram.Scale_Element_Count(d);
@@ -846,27 +864,27 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Shapes *pShapes, int Attribute,
 		return( true );
 	}
 
-	for(sLong i=0; i<pShapes->Get_Count() && PROGRESSBAR_Set_Position(i, pShapes->Get_Count()); i++)
+	for(sLong i=0; i<pTable->Get_Count() && PROGRESSBAR_Set_Position(i, pTable->Get_Count()); i++)
 	{
-		CSG_Shape	*pShape	= pShapes->Get_Shape(i);
+		CSG_Table_Record &Record = *pTable->Get_Record(i);
 
 		if( m_Mode == CLASSIFY_LUT )
 		{
 			m_Histogram	+= SG_Data_Type_is_Numeric(m_pLUT->Get_Field_Type(LUT_MIN))
-				? Get_Class(pShape->asDouble(Attribute))
-				: Get_Class(pShape->asString(Attribute));
+				? Get_Class(Record.asDouble(Field))
+				: Get_Class(Record.asString(Field));
 		}
-		else if( !pShape->is_NoData(Attribute) )
+		else if( !Record.is_NoData(Field) )
 		{
-			double z = pShape->asDouble(Attribute);
+			double z = Record.asDouble(Field);
 
 			if( Normalize < 0 )
 			{
 				m_Histogram += Get_Class(z); m_Statistics += z;
 			}
-			else if( !pShape->is_NoData(Normalize) && pShape->asDouble(Normalize) )
+			else if( !Record.is_NoData(Normalize) && Record.asDouble(Normalize) )
 			{
-				z *= Scale / pShape->asDouble(Normalize);
+				z *= Scale / Record.asDouble(Normalize);
 
 				m_Histogram += Get_Class(z); m_Statistics += z;
 			}
@@ -878,9 +896,9 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Shapes *pShapes, int Attribute,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
