@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -65,9 +65,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -78,8 +78,7 @@ enum
 	CLASSIFY_DISCRETE,
 	CLASSIFY_GRADUATED,
 	CLASSIFY_OVERLAY,
-	CLASSIFY_RGB,
-	CLASSIFY_SHADE
+	CLASSIFY_RGB
 };
 
 //---------------------------------------------------------
@@ -115,9 +114,9 @@ enum
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -133,9 +132,14 @@ public:
 	//-----------------------------------------------------
 	CSG_Scaler(void);
 
+								CSG_Scaler			(const CSG_Scaler &Scaler);
+	bool						Create				(const CSG_Scaler &Scaler);
+
 								CSG_Scaler			(double Minimum, double Maximum, double Interval = 0.);
 	bool						Create				(double Minimum, double Maximum, double Interval = 0.);
 
+	CSG_Scaler &				operator =			(const CSG_Scaler &Scaler);
+
 	//-----------------------------------------------------
 	bool						Set_Linear			(CSG_Table *pTable, int Field, double Interval, double Minimum, double Maximum);
 	bool						Set_StdDev			(CSG_Table *pTable, int Field, double Interval, double StdDev, bool bKeepInRange);
@@ -164,18 +168,13 @@ public:
 	{
 		if( m_Range > 0. )
 		{
-			Value	= (Value - m_Minimum) / m_Range;
+			Value = (Value - m_Minimum) / m_Range;
 
 			switch( m_Interval )
 			{
-			default:
-				return( Value );
-
-			case INCREASING:
-				return( Value <= 0. ? 0. :      (log(1. + m_LogRange * (     Value)) / log(1. + m_LogRange)) );
-
-			case DECREASING:
-				return( Value >= 1. ? 1. : 1. - (log(1. + m_LogRange * (1. - Value)) / log(1. + m_LogRange)) );
+			default        : return( Value );
+			case INCREASING: return( Value <= 0. ? 0. :      (log(1. + m_LogRange * (     Value)) / log(1. + m_LogRange)) );
+			case DECREASING: return( Value >= 1. ? 1. : 1. - (log(1. + m_LogRange * (1. - Value)) / log(1. + m_LogRange)) );
 			}
 		}
 
@@ -189,16 +188,9 @@ public:
 		{
 			switch( m_Interval )
 			{
-			default:
-				break;
-
-			case INCREASING:
-				Value	=      ((exp(log(1. + m_LogRange) * (     Value)) - 1.) / m_LogRange);
-				break;
-
-			case DECREASING:
-				Value	= 1. - ((exp(log(1. + m_LogRange) * (1. - Value)) - 1.) / m_LogRange);
-				break;
+			default        :                                                                              break;
+			case INCREASING: Value =      ((exp(log(1. + m_LogRange) * (     Value)) - 1.) / m_LogRange); break;
+			case DECREASING: Value = 1. - ((exp(log(1. + m_LogRange) * (1. - Value)) - 1.) / m_LogRange); break;
 			}
 
 			return( m_Minimum + (m_Range * Value) );
@@ -210,17 +202,17 @@ public:
 
 protected:
 
-	TInterval		m_Interval;
+	TInterval		m_Interval = LINEAR;
 
-	double			m_Minimum, m_Range, m_LogRange;
+	double			m_Minimum = 0., m_Range = 0., m_LogRange = 0.;
 
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -235,9 +227,6 @@ public: ///////////////////////////////////////////////////
 	void						Set_Mode				(int Mode)	{	m_Mode			= Mode;	}
 	int							Get_Mode				(void)		{	return( m_Mode );		}
 
-	void						Set_Shade_Mode			(int Mode)	{	m_Shade_Mode	= Mode;	}
-	int							Get_Shade_Mode			(void)		{	return( m_Shade_Mode );	}
-
 	void						Set_Unique_Color		(int Color);
 	int							Get_Unique_Color		(void)		{	return( m_UNI_Color );	}
 
@@ -258,7 +247,6 @@ public: ///////////////////////////////////////////////////
 			return( m_pLUT->Get_Count() );
 
 		case CLASSIFY_GRADUATED:
-		case CLASSIFY_SHADE    :
 		case CLASSIFY_OVERLAY  :
 			return( m_Count );
 
@@ -280,7 +268,6 @@ public: ///////////////////////////////////////////////////
 
 		case CLASSIFY_GRADUATED:
 		case CLASSIFY_DISCRETE :
-		case CLASSIFY_SHADE    :
 		case CLASSIFY_OVERLAY  :
 			return( _METRIC_Get_Class(Value) );
 		}
@@ -336,7 +323,6 @@ public: ///////////////////////////////////////////////////
 			break;
 
 		case CLASSIFY_GRADUATED:
-		case CLASSIFY_SHADE    :
 		case CLASSIFY_OVERLAY  :
 			Get_Class_Color_byValue(Get_RelativeToMetric(iClass / (double)m_Count), Color);
 			break;
@@ -401,28 +387,6 @@ public: ///////////////////////////////////////////////////
 				return( true );
 			}
 
-		case CLASSIFY_SHADE    :
-			{
-				int	iClass	= (int)(255.0 * Get_MetricToRelative(Value));
-
-				if( iClass < 0 ) iClass = 0; else if( iClass > 255 ) iClass = 255;
-
-				switch( m_Shade_Mode )
-				{
-				default:
-				case SHADE_MODE_DSC_GREY   : Color = SG_GET_RGB(255 - iClass, 255 - iClass, 255 - iClass);	break;
-				case SHADE_MODE_DSC_CYAN   : Color = SG_GET_RGB(255 - iClass, 255         , 255         );	break;
-				case SHADE_MODE_DSC_MAGENTA: Color = SG_GET_RGB(255         , 255 - iClass, 255         );	break;
-				case SHADE_MODE_DSC_YELLOW : Color = SG_GET_RGB(255         , 255         , 255 - iClass);	break;
-				case SHADE_MODE_ASC_GREY   : Color = SG_GET_RGB(      iClass,       iClass,       iClass);	break;
-				case SHADE_MODE_ASC_CYAN   : Color = SG_GET_RGB(      iClass, 255         , 255         );	break;
-				case SHADE_MODE_ASC_MAGENTA: Color = SG_GET_RGB(255         ,       iClass, 255         );	break;
-				case SHADE_MODE_ASC_YELLOW : Color = SG_GET_RGB(255         , 255         ,       iClass);	break;
-				}
-
-				return( true );
-			}
-
 		case CLASSIFY_OVERLAY  :
 			{
 				int	iClass	= (int)(255.0 * Get_MetricToRelative(Value));
@@ -535,7 +499,7 @@ public: ///////////////////////////////////////////////////
 
 protected: ////////////////////////////////////////////////
 
-	int							m_Mode, m_zMode, m_Shade_Mode, m_Count, m_UNI_Color;
+	int							m_Mode, m_zMode, m_Count, m_UNI_Color;
 
 	double						m_zMin, m_zRange, m_zLogRange, m_zLogMax;
 
@@ -578,15 +542,15 @@ protected: ////////////////////////////////////////////////
 	//-----------------------------------------------------
 	bool						_Histogram_Update		(CSG_Grid  *pGrid );
 	bool						_Histogram_Update		(CSG_Grids *pGrids);
-	bool						_Histogram_Update		(CSG_Shapes *pShapes, int Attribute, int Normalize = -1, double Scale = 1.);
+	bool						_Histogram_Update		(CSG_Table *pTable, int Field, int Normalize = -1, double Scale = 1.);
 
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
