@@ -370,7 +370,6 @@ void CWKSP_Layer_Legend::_Draw_Boxes(wxDC &dc, int y, int Style, double zFactor)
 	switch( m_pClassify->Get_Mode() )
 	{
 	case CLASSIFY_GRADUATED:
-	case CLASSIFY_SHADE    :
 		_Draw_Continuum(dc, m_Position.y, zFactor);
 		break;
 
@@ -430,7 +429,7 @@ void CWKSP_Layer_Legend::_Draw_Point(wxDC &dc, CWKSP_Shapes_Point *pLayer)
 	}
 
 	//-----------------------------------------------------
-	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Name_Attribute());
+	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Field_Naming());
 	_Draw_Boxes(dc, m_Position.y, pLayer->Get_Outline() ? BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL : BOX_STYLE_RECT|BOX_STYLE_FILL);
 }
 
@@ -468,28 +467,28 @@ void CWKSP_Layer_Legend::_Draw_Line(wxDC &dc, CWKSP_Shapes_Line *pLayer)
 	//-----------------------------------------------------
 	dc.SetPen  (pLayer->Get_Def_Pen());
 
-	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Name_Attribute());
+	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Field_Naming());
 	_Draw_Boxes(dc, m_Position.y, BOX_STYLE_LINE);
 }
 
 //---------------------------------------------------------
 void CWKSP_Layer_Legend::_Draw_Polygon(wxDC &dc, CWKSP_Shapes_Polygon *pLayer)
 {
-	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Name_Attribute());
+	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Field_Naming());
 	_Draw_Boxes(dc, m_Position.y, pLayer->Get_Outline() ? BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL : BOX_STYLE_RECT|BOX_STYLE_FILL);
 }
 
 //---------------------------------------------------------
 void CWKSP_Layer_Legend::_Draw_TIN(wxDC &dc, CWKSP_TIN *pLayer)
 {
-	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Name_Attribute());
+	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Field_Naming());
 	_Draw_Boxes(dc, m_Position.y, BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL);
 }
 
 //---------------------------------------------------------
 void CWKSP_Layer_Legend::_Draw_PointCloud(wxDC &dc, CWKSP_PointCloud *pLayer)
 {
-	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Name_Attribute());
+	_Draw_Title(dc, FONT_SUBTITLE, pLayer->Get_Field_Naming());
 	_Draw_Boxes(dc, m_Position.y, BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL);
 }
 
@@ -499,8 +498,7 @@ void CWKSP_Layer_Legend::_Draw_Grid(wxDC &dc, CWKSP_Grid *pLayer)
 	switch( m_pClassify->Get_Mode() )
 	{
 	case CLASSIFY_GRADUATED:
-	case CLASSIFY_DISCRETE:
-	case CLASSIFY_SHADE:
+	case CLASSIFY_DISCRETE :
 		if( !pLayer->Get_Grid()->Get_Unit().is_Empty() )
 		{
 			_Draw_Title(dc, FONT_SUBTITLE, wxString::Format("[%s]", pLayer->Get_Grid()->Get_Unit().c_str()));
@@ -510,8 +508,8 @@ void CWKSP_Layer_Legend::_Draw_Grid(wxDC &dc, CWKSP_Grid *pLayer)
 		_Draw_Boxes(dc, m_Position.y, BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL);
 		break;
 
-	case CLASSIFY_RGB:
-	case CLASSIFY_OVERLAY:
+	case CLASSIFY_RGB      :
+	case CLASSIFY_OVERLAY  :
 		_Draw_Layer_Image(dc, m_Position.y, pLayer);
 		break;
 	}
@@ -523,8 +521,7 @@ void CWKSP_Layer_Legend::_Draw_Grids(wxDC &dc, CWKSP_Grids *pLayer)
 	switch( m_pClassify->Get_Mode() )
 	{
 	case CLASSIFY_GRADUATED:
-	case CLASSIFY_DISCRETE:
-	case CLASSIFY_SHADE:
+	case CLASSIFY_DISCRETE :
 		if( *pLayer->Get_Grids()->Get_Unit() )
 		{
 			_Draw_Title(dc, FONT_SUBTITLE, wxString::Format("[%s]", pLayer->Get_Grids()->Get_Unit()));
@@ -534,8 +531,8 @@ void CWKSP_Layer_Legend::_Draw_Grids(wxDC &dc, CWKSP_Grids *pLayer)
 		_Draw_Boxes(dc, m_Position.y, BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL);
 		break;
 
-	case CLASSIFY_RGB:
-	case CLASSIFY_OVERLAY:
+	case CLASSIFY_RGB      :
+	case CLASSIFY_OVERLAY  :
 	//	_Draw_Layer_Image(dc, m_Position.y, pLayer);
 		_Draw_Box(dc, m_Position.y, BOX_HEIGHT, BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL, 0, SG_GET_RGB(255,   0,   0), pLayer->Get_Grid(0)->Get_Name());
 		_Draw_Box(dc, m_Position.y, BOX_HEIGHT, BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL, 0, SG_GET_RGB(  0, 255,   0), pLayer->Get_Grid(1)->Get_Name());
@@ -580,14 +577,13 @@ void CWKSP_Layer_Legend::_Draw_Layer_Image(wxDC &dc, int ay, CWKSP_Layer *pLayer
 //---------------------------------------------------------
 void CWKSP_Layer_Legend::_Draw_Continuum(wxDC &dc, int y, double zFactor)
 {
-	//-----------------------------------------------------
-	double	zMin	= m_pClassify->Get_RelativeToMetric(0.0);
-	double	zMax	= m_pClassify->Get_RelativeToMetric(1.0);
+	double zMin = m_pClassify->Get_RelativeToMetric(0.);
+	double zMax = m_pClassify->Get_RelativeToMetric(1.);
 
 	//-----------------------------------------------------
 	if( zMin >= zMax )
 	{
-		if( m_pLayer->Get_Value_Range() > 0.0 )
+		if( m_pLayer->Get_Stretch_Range() > 0. )
 		{
 			_Draw_Box(dc, y, BOX_HEIGHT, BOX_STYLE_RECT|BOX_STYLE_FILL|BOX_STYLE_OUTL, m_pClassify->Get_Class_Count() - 1);
 		}
@@ -598,8 +594,7 @@ void CWKSP_Layer_Legend::_Draw_Continuum(wxDC &dc, int y, double zFactor)
 	//-----------------------------------------------------
 	else
 	{
-		int		dxFont, dyFont;
-		double	yToDC, dz;
+		int dxFont, dyFont; double yToDC, dz;
 
 		dc.SetPen(dc.GetTextForeground());
 
