@@ -51,6 +51,7 @@
 #include <wx/filename.h>
 #include <wx/clipbrd.h>
 #include <wx/dataobj.h>
+#include <wx/fs_mem.h>
 
 #include <saga_gdi/sgdi_helper.h>
 
@@ -215,6 +216,35 @@ wxString CWKSP_Map::Get_Name(void)
 	return( m_Name );
 }
 
+//---------------------------------------------------------
+wxString CWKSP_Map::_Set_Description_Image(void)
+{
+	wxString s;
+
+	if( Get_Manager()->Get_Parameter("PREVIEW")->asBool() )
+	{
+		int nx, ny; double x2y = Get_Extent().Get_XRange() / Get_Extent().Get_YRange();
+
+		if( x2y > 1. ) { nx = Get_Manager()->Get_Parameter("PREVIEW_SIZE")->asInt(); ny = (int)(nx / x2y); }
+		else           { ny = Get_Manager()->Get_Parameter("PREVIEW_SIZE")->asInt(); nx = (int)(ny * x2y); }
+
+		wxBitmap Thumbnail;
+
+		if( _Get_Thumbnail(Thumbnail, nx, ny) )
+		{
+			wxMemoryFSHandler::RemoveFile("preview_map.png");
+
+			wxMemoryFSHandler::AddFile("preview_map.png", Thumbnail, wxBITMAP_TYPE_PNG);
+
+			s = "<img src=\"memory:preview_map.png\" border=\"5\">";
+
+			s = "<table border=\"1\"><th><tr>" + s + "</tr></th></table><hr>";
+		}
+	}
+
+	return( s );
+}
+
 //---------------------------------------------------------
 wxString CWKSP_Map::Get_Description(void)
 {
@@ -223,6 +253,8 @@ wxString CWKSP_Map::Get_Description(void)
 	//-----------------------------------------------------
 	s += wxString::Format("<h4>%s</h4>", _TL("Map"));
 
+	s += _Set_Description_Image();
+
 	s += "<table border=\"0\">";
 
 	DESC_ADD_STR(_TL("Name"             ), m_Name.c_str());
@@ -250,9 +282,7 @@ wxString CWKSP_Map::Get_Description(void)
 //---------------------------------------------------------
 wxMenu * CWKSP_Map::Get_Menu(void)
 {
-	wxMenu *pMenu;
-
-	pMenu = new wxMenu(_TL("Map"));
+	wxMenu *pMenu = new wxMenu(_TL("Map"));
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAPS_SHOW);
@@ -261,7 +291,7 @@ wxMenu * CWKSP_Map::Get_Menu(void)
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAPS_LAYOUT_SHOW);
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAPS_SCALEBAR);
-//	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAP_NORTH_ARROW);
+	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAP_NORTH_ARROW);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_GRATICULE_ADD);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_BASEMAP_ADD);
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAPS_SYNCHRONIZE);
@@ -285,60 +315,25 @@ bool CWKSP_Map::On_Command(int Cmd_ID)
 {
 	switch( Cmd_ID )
 	{
-	default:
-		return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
+	default: return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
 
-	case ID_CMD_WKSP_ITEM_RETURN:
-		View_Show(true);
-		break;
+	case ID_CMD_WKSP_ITEM_RETURN             : View_Show     (true); break;
+	case ID_CMD_MAPS_SHOW                    : View_Toggle       (); break;
+	case ID_CMD_MAPS_3D_SHOW                 : View_3D_Toggle    (); break;
+	case ID_CMD_MAPS_LAYOUT_SHOW             : View_Layout_Toggle(); break;
 
-	case ID_CMD_MAPS_SAVE_IMAGE:
-		SaveAs_Image();
-		break;
+	case ID_CMD_MAPS_PROJECTION              : Set_Projection(); break;
+	case ID_CMD_MAPS_SCALEBAR                : Set_ScaleBar   (!is_ScaleBar   ()); break;
+	case ID_CMD_MAP_NORTH_ARROW              : Set_North_Arrow(!is_North_Arrow()); break;
+	case ID_CMD_MAPS_SYNCHRONIZE             : Set_Synchronising(!m_Parameters("SYNC_MAPS")->asBool()); break;
 
-	case ID_CMD_MAPS_SAVE_IMAGE_ON_CHANGE:
-		SaveAs_Image_On_Change();
-		break;
+	case ID_CMD_MAPS_GRATICULE_ADD           : Add_Graticule(); break;
+	case ID_CMD_MAPS_BASEMAP_ADD             : Add_BaseMap  (); break;
 
-	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD:
-		SaveAs_Image_Clipboard(false);
-		break;
-
-	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND:
-		SaveAs_Image_Clipboard(true);
-		break;
-
-	case ID_CMD_MAPS_SCALEBAR:
-		Set_ScaleBar(!is_ScaleBar());
-		break;
-
-	case ID_CMD_MAPS_SYNCHRONIZE:
-		Set_Synchronising(!m_Parameters("SYNC_MAPS")->asBool());
-		break;
-
-	case ID_CMD_MAPS_GRATICULE_ADD:
-		Add_Graticule();
-		break;
-
-	case ID_CMD_MAPS_BASEMAP_ADD:
-		Add_BaseMap();
-		break;
-
-	case ID_CMD_MAPS_PROJECTION:
-		Set_Projection();
-		break;
-
-	case ID_CMD_MAPS_SHOW:
-		View_Toggle();
-		break;
-
-	case ID_CMD_MAPS_3D_SHOW:
-		View_3D_Toggle();
-		break;
-
-	case ID_CMD_MAPS_LAYOUT_SHOW:
-		View_Layout_Toggle();
-		break;
+	case ID_CMD_MAPS_SAVE_IMAGE              : SaveAs_Image()               ; break;
+	case ID_CMD_MAPS_SAVE_IMAGE_ON_CHANGE    : SaveAs_Image_On_Change()     ; break;
+	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD       : SaveAs_Image_Clipboard(false); break;
+	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND: SaveAs_Image_Clipboard( true); break;
 	}
 
 	return( true );
@@ -349,33 +344,19 @@ bool CWKSP_Map::On_Command_UI(wxUpdateUIEvent &event)
 {
 	switch( event.GetId() )
 	{
-	default:
-		return( CWKSP_Base_Manager::On_Command_UI(event) );
+	default: return( CWKSP_Base_Manager::On_Command_UI(event) );
 
-	case ID_CMD_MAPS_SHOW:
-		event.Check(m_pView != NULL);
-		break;
+	case ID_CMD_MAPS_SHOW                    : event.Check(m_pView    != NULL); break;
+	case ID_CMD_MAPS_3D_SHOW                 : event.Check(m_pView_3D != NULL); break;
+	case ID_CMD_MAPS_LAYOUT_SHOW             : event.Check(m_pLayout  != NULL); break;
 
-	case ID_CMD_MAPS_3D_SHOW:
-		event.Check(m_pView_3D != NULL);
-		break;
+	case ID_CMD_MAPS_SCALEBAR                : event.Check(is_ScaleBar   ()); break;
+	case ID_CMD_MAP_NORTH_ARROW              : event.Check(is_North_Arrow()); break;
 
-	case ID_CMD_MAPS_LAYOUT_SHOW:
-		event.Check(m_pLayout != NULL);
-		break;
+	case ID_CMD_MAPS_GRATICULE_ADD           :
+	case ID_CMD_MAPS_BASEMAP_ADD             : event.Enable(Get_Count() > 0 && m_Projection.is_Okay()); break;
 
-	case ID_CMD_MAPS_SAVE_IMAGE_ON_CHANGE:
-		event.Check(is_Image_Save_Mode());
-		break;
-
-	case ID_CMD_MAPS_SCALEBAR:
-		event.Check(is_ScaleBar());
-		break;
-
-	case ID_CMD_MAPS_GRATICULE_ADD:
-	case ID_CMD_MAPS_BASEMAP_ADD:
-		event.Enable(Get_Count() > 0 && m_Projection.is_Okay());
-		break;
+	case ID_CMD_MAPS_SAVE_IMAGE_ON_CHANGE    : event.Check(is_Image_Save_Mode()); break;
 	}
 
 	return( true );
@@ -434,10 +415,14 @@ void CWKSP_Map::On_Create_Parameters(void)
 	);
 
 	//-----------------------------------------------------
-	m_Parameters.Add_Bool("NODE_GENERAL",
-		"GCS_POSITION"  , _TL("Position as Geographic Coordinates"),
-		_TL("Display mouse position in status bar as geographic coordinates."),
-		false
+	m_Parameters.Add_Choice("NODE_GENERAL",
+		"GCS_POSITION"  , _TL("Display Coordinates"),
+		_TL("Show mouse position in status bar as map or geographic coordinates, the latter transformed to WGS84 and using either the sexagesimal DDD\u00B0MM'SS.S\" or the decimal degree format."),
+		CSG_String::Format("%s|%s|%s",
+			_TL("map coordinates"),
+			_TL("geographic coordinates (degree, minutes, seconds)"),
+			_TL("geographic coordinates (decimal degree)")
+		), 0
 	);
 
 	//-----------------------------------------------------
@@ -544,6 +529,12 @@ void CWKSP_Map::On_Create_Parameters(void)
 		Units, 1
 	);
 
+	m_Parameters.Add_Double("SCALE_SHOW",
+		"SCALE_RESCALE" , _TL("Rescaling"),
+		_TL("Rescaling factor used to convert original map coordinate units, e.g. from meters to feet."),
+		1., 0., true
+	);
+
 	m_Parameters.Add_Double("SCALE_SHOW",
 		"SCALE_WIDTH"   , _TL("Width"),
 		_TL("Width given as percentage of map size"),
@@ -623,6 +614,11 @@ int CWKSP_Map::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 		{
 			pParameter->Set_Children_Enabled(pParameter->asBool());
 		}
+
+		if(	pParameter->Cmp_Identifier("SCALE_UNIT") )
+		{
+			pParameters->Set_Enabled("SCALE_RESCALE", pParameter->asInt() != 1); // only applies if unit is not retrieved automatically!
+		}
 	}
 
 	return( CWKSP_Base_Manager::On_Parameter_Changed(pParameters, pParameter, Flags) );
@@ -807,7 +803,7 @@ bool CWKSP_Map::Serialize(CSG_MetaData &Root, const wxString &ProjectDir, bool b
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CWKSP_Map::Update(CWKSP_Layer *pLayer, bool bMapOnly)
+bool CWKSP_Map::Update_Map(CWKSP_Layer *pLayer, bool bMapOnly)
 {
 	if( !m_Projection.is_Okay() && pLayer->Get_Object()->Get_Projection().is_Okay() )
 	{
@@ -822,7 +818,7 @@ bool CWKSP_Map::Update(CWKSP_Layer *pLayer, bool bMapOnly)
 		{
 			CWKSP_Map_Layer *pMapLayer = (CWKSP_Map_Layer *)Get_Item(i);
 			
-			if( pMapLayer->Get_Layer()->Update(pLayer) )
+			if( pMapLayer->Get_Layer() == pLayer )
 			{
 				bRefresh = true;
 
@@ -841,10 +837,7 @@ bool CWKSP_Map::Update(CWKSP_Layer *pLayer, bool bMapOnly)
 
 	if( bRefresh )
 	{
-		if( m_pView )
-		{
-			View_Refresh(bMapOnly);
-		}
+		View_Refresh(bMapOnly);
 
 		_Img_Save_On_Change();
 
@@ -1288,6 +1281,8 @@ void CWKSP_Map::Set_Synchronising(bool bOn)
 	if( m_Parameters("SYNC_MAPS")->asBool() != bOn )
 	{
 		m_Parameters("SYNC_MAPS")->Set_Value(bOn ? 1 : 0);
+
+		g_pActive->Update_Item(this, false);
 	}
 
 	if( bOn && m_Sync_bLock < 1 )
@@ -1324,6 +1319,8 @@ void CWKSP_Map::Set_North_Arrow(bool bOn)
 		{
 			m_pView->Do_Update();
 		}
+
+		g_pActive->Update_Item(this, false);
 	}
 }
 
@@ -1341,9 +1338,10 @@ void CWKSP_Map::Set_ScaleBar(bool bOn)
 
 		if( m_pView )
 		{
-			m_pView->Do_Update();
-			m_pView->Ruler_Refresh();
+			m_pView->Do_Update(); m_pView->Ruler_Refresh();
 		}
+
+		g_pActive->Update_Item(this, false);
 	}
 }
 
@@ -1397,10 +1395,9 @@ void CWKSP_Map::Set_Projection(void)
 
 	if(	pTool )
 	{
-		CSG_Parameters P(*pTool->Get_Parameters());
+		CSG_Parameters P(*pTool->Get_Parameters()); P.Set_Name(_TL("Map CRS"));
 
-		P.Set_Parameter("CRS_WKT" , m_Projection.Get_WKT2());
-		P.Set_Parameter("CRS_PROJ", m_Projection.Get_PROJ());
+		P.Set_Parameter("CRS_STRING", m_Projection.Get_WKT());
 
 		P.Add_Bool("", "ONTHEFLY", _TL("On-The-Fly Projection"),
 			_TL("Turn on the on-the-fly projection for all layers in the map."),
@@ -1480,7 +1477,7 @@ void CWKSP_Map::View_Refresh(bool bMapOnly)
 		}
 	}
 
-	_Set_Thumbnail();
+	_Set_Thumbnail(m_Thumbnail);
 
 	if( g_pMap_Buttons ) { g_pMap_Buttons->Refresh(); }
 }
@@ -2123,28 +2120,37 @@ void CWKSP_Map::_Img_Save(wxString file, int type)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-const wxBitmap & CWKSP_Map::Get_Thumbnail(int dx, int dy)
+const wxBitmap & CWKSP_Map::Get_Thumbnail(int nx, int ny)
 {
-	if( dx > 0 && dy > 0 && (!m_Thumbnail.IsOk() || m_Thumbnail.GetWidth() != dx || m_Thumbnail.GetHeight() != dy) )
-	{
-		m_Thumbnail.Create(dx, dy);
-
-		_Set_Thumbnail();
-	}
+	_Get_Thumbnail(m_Thumbnail, nx, ny);
 
 	return( m_Thumbnail );
 }
 
 //---------------------------------------------------------
-bool CWKSP_Map::_Set_Thumbnail(void)
+bool CWKSP_Map::_Get_Thumbnail(wxBitmap &Thumbnail, int nx, int ny)
 {
-	if( m_Thumbnail.IsOk() && m_Thumbnail.GetWidth() > 0 && m_Thumbnail.GetHeight() > 0 )
+	if( nx > 0 && ny > 0 )
 	{
-		wxMemoryDC dc; wxRect r(0, 0, m_Thumbnail.GetWidth(), m_Thumbnail.GetHeight());
+		if( !Thumbnail.IsOk() || Thumbnail.GetWidth() != nx || Thumbnail.GetHeight() != ny )
+		{
+			Thumbnail.Create(nx, ny);
+		}
 
-		dc.SelectObject(m_Thumbnail);
-		dc.SetBackground(*wxWHITE_BRUSH);
-		dc.Clear();
+		return( _Set_Thumbnail(Thumbnail) );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Map::_Set_Thumbnail(wxBitmap &Thumbnail)
+{
+	if( Thumbnail.IsOk() && Thumbnail.GetWidth() > 0 && Thumbnail.GetHeight() > 0 )
+	{
+		wxMemoryDC dc; wxRect r(0, 0, Thumbnail.GetWidth(), Thumbnail.GetHeight());
+
+		dc.SelectObject(Thumbnail); dc.SetBackground(Get_Background()); dc.Clear();
 
 		Draw_Map(dc, Get_Extent(), 1., r, LAYER_DRAW_FLAG_NOEDITS|LAYER_DRAW_FLAG_NOLABELS|LAYER_DRAW_FLAG_THUMBNAIL);
 
@@ -2408,8 +2414,6 @@ bool CWKSP_Map::Draw_ScaleBar(CSG_Map_DC &dc)
 		return( true );
 	}
 
-	double Width = 0.01 * m_Parameters("SCALE_WIDTH")->asDouble();
-
 	wxRect r = !m_Parameters("SCALE_EXTENT")->asBool() ? wxRect(dc.rDC()) : wxRect(
 		(int) dc.xWorld2DC    (Get_Extent().Get_XMin  ()),
 		(int) dc.yWorld2DC    (Get_Extent().Get_YMax  ()),
@@ -2420,24 +2424,29 @@ bool CWKSP_Map::Draw_ScaleBar(CSG_Map_DC &dc)
 	r = wxRect(
 		(int)(0.5 + r.GetWidth () * 0.01 * m_Parameters("SCALE_OFFSET_X")->asDouble()) + r.GetX(), r.GetY() + r.GetHeight() -
 		(int)(0.5 + r.GetHeight() * 0.01 * m_Parameters("SCALE_OFFSET_Y")->asDouble()),
-		(int)(0.5 + r.GetWidth () * Width),
+		(int)(0.5 + r.GetWidth () * 0.01 * m_Parameters("SCALE_WIDTH"   )->asDouble()),
 		(int)(0.5 + r.GetHeight() * 0.01 * m_Parameters("SCALE_HEIGHT"  )->asDouble())
 	);
 
-	Width = dc.DC2World() * r.GetWidth();
+	double Length = dc.DC2World() * r.GetWidth();
+
+	if( m_Parameters("SCALE_UNIT")->asInt() != 1 && m_Parameters("SCALE_RESCALE")->asDouble() > 0. ) // don't rescale if unit is retrieved from coordinate system (automatically)!
+	{
+		Length *= m_Parameters("SCALE_RESCALE")->asDouble();
+	}
 
 	CSG_String Unit;
 
 	if( m_Parameters("SCALE_UNIT")->asInt() > 0 )
 	{
-		ESG_Projection_Unit _Unit = m_Parameters("SCALE_UNIT")->asInt() > 1
-			? (ESG_Projection_Unit)(m_Parameters("SCALE_UNIT")->asInt() - 2) : m_Projection.Get_Unit();
+		ESG_Projection_Unit _Unit = m_Parameters("SCALE_UNIT")->asInt() >= 2
+			? (ESG_Projection_Unit)(m_Parameters("SCALE_UNIT")->asInt()  - 2) : m_Projection.Get_Unit();
 
 		if( _Unit != ESG_Projection_Unit::Undefined )
 		{
-			if( Width > 10000. && _Unit == ESG_Projection_Unit::Meter )
+			if( Length > 10000. && _Unit == ESG_Projection_Unit::Meter )
 			{
-				Width /= 1000.; _Unit = ESG_Projection_Unit::Kilometer;
+				Length /= 1000.; _Unit = ESG_Projection_Unit::Kilometer;
 			}
 
 			Unit = CSG_Projections::Get_Unit_Name(_Unit, true);
@@ -2451,7 +2460,7 @@ bool CWKSP_Map::Draw_ScaleBar(CSG_Map_DC &dc)
 		Style |= SCALE_STYLE_BLACKWHITE;
 	}
 
-	Draw_Scale(dc.Get_DC(), r, 0., Width, SCALE_HORIZONTAL, SCALE_TICK_TOP, Style, Unit.c_str());
+	Draw_Scale(dc.Get_DC(), r, 0., Length, SCALE_HORIZONTAL, SCALE_TICK_TOP, Style, Unit.c_str());
 
 	return( true );
 }
