@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -65,9 +65,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -96,9 +96,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -148,7 +148,7 @@ public:
 	void						Set_CrossHair			(const TSG_Point &Point, const CSG_Projection &Projection);
 	void						Set_CrossHair_Off		(void);
 
-	bool						Update					(class CWKSP_Layer *pLayer, bool bMapOnly);
+	bool						Update_Map				(class CWKSP_Layer *pLayer, bool bMapOnly);
 	int							Get_Map_Layer_Index		(class CWKSP_Layer *pLayer);
 	class CWKSP_Map_Layer *		Get_Map_Layer			(class CWKSP_Layer *pLayer);
 	class CWKSP_Map_Layer *		Get_Map_Layer_Active	(bool bEditable = false);
@@ -190,14 +190,14 @@ public:
 	void						Draw_Map				(class CSG_Map_DC &dc, int Flags = 0);
 
 	void						Draw_Frame				(wxDC &dc, wxRect rMap, int Width);
-	void						Draw_Frame				(wxDC &dc, const CSG_Rect &rWorld, wxRect rMap, int Width, bool bScaleBar);
+	void						Draw_Frame				(wxDC &dc, const CSG_Rect &rWorld, wxRect rMap, int Width, bool bScaleBar, bool bUseDCFont = false);
 	bool						Draw_Legend				(wxDC &dc, double Zoom_Map, double Zoom, wxPoint Position, wxSize *pSize = NULL);
 
 	bool						Draw_North_Arrow		(class CSG_Map_DC &dc);
 	bool						Draw_ScaleBar			(class CSG_Map_DC &dc);
 	bool						Draw_Extent				(class CSG_Map_DC &dc);
 
-	const wxBitmap &			Get_Thumbnail			(int dx, int dy);
+	const wxBitmap &			Get_Thumbnail			(int nx, int ny);
 
 	bool						Get_Legend_Size			(wxSize &Size, double Zoom_Map = 1.0, double Zoom = 1.0);
 
@@ -246,15 +246,17 @@ private:
 	void						_Img_Save				(wxString file, int type);
 	void						_Img_Save_On_Change		(void);
 
-	bool						_Set_Thumbnail			(void);
+	wxString					_Set_Description_Image	(void);
+	bool						_Get_Thumbnail			(wxBitmap &Thumbnail, int nx, int ny);
+	bool						_Set_Thumbnail			(wxBitmap &Thumbnail);
 
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
