@@ -65,25 +65,25 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CWKSP_Map_Layer::CWKSP_Map_Layer(CWKSP_Layer *pLayer)
 {
-	m_pLayer        = pLayer;
+	m_pLayer          = pLayer;
 
-	m_bShow         = true;
-	m_bProject      = false;
-	m_bProject_Area = false;
-	m_bFitColors    = false;
+	m_bShow           = true;
+	m_bProject        = false;
+	m_bProject_Area   = false;
+	m_bStretch_Extent = false;
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -103,14 +103,15 @@ wxString CWKSP_Map_Layer::Get_Description(void)
 //---------------------------------------------------------
 wxMenu * CWKSP_Map_Layer::Get_Menu(void)
 {
-	wxMenu	*pMenu, *pMenu_Edit;
-
-	pMenu	= new wxMenu(m_pLayer->Get_Name());
+	wxMenu *pSubMenu, *pMenu = new wxMenu(m_pLayer->Get_Name());
 
 	//-----------------------------------------------------
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAPS_LAYER_SHOW);
 	pMenu->AppendSeparator();
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_ZOOM_LAYER_ACTIVE);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAP_PAN_LAYER_ACTIVE);
+	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_MOVE_TOP);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_MOVE_UP);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_MAPS_MOVE_DOWN);
@@ -119,10 +120,9 @@ wxMenu * CWKSP_Map_Layer::Get_Menu(void)
 	//-----------------------------------------------------
 	switch( m_pLayer->Get_Type() )
 	{
-	default:
-		break;
+	default: break;
 
-	case WKSP_ITEM_Grid:
+	case WKSP_ITEM_Grid :
 	case WKSP_ITEM_Grids:
 		pMenu->AppendSeparator();
 		CMD_Menu_Add_Item(pMenu, true, ID_CMD_MAPS_GRID_FITCOLORS);
@@ -130,7 +130,7 @@ wxMenu * CWKSP_Map_Layer::Get_Menu(void)
 	}
 
 	//-----------------------------------------------------
-	CSG_Projection	prj_Layer, prj_Map;
+	CSG_Projection prj_Layer, prj_Map;
 
 	if( _Projected_Get_Projections(prj_Layer, prj_Map) )
 	{
@@ -143,10 +143,10 @@ wxMenu * CWKSP_Map_Layer::Get_Menu(void)
 	}
 
 	//-----------------------------------------------------
-	if( (pMenu_Edit = m_pLayer->Edit_Get_Menu()) != NULL )
+	if( (pSubMenu = m_pLayer->Edit_Get_Menu()) != NULL )
 	{
 		pMenu->AppendSeparator();
-		pMenu->Append(ID_CMD_WKSP_FIRST, _TL("Edit"), pMenu_Edit);
+		pMenu->Append(ID_CMD_WKSP_FIRST, _TL("Edit"), pSubMenu);
 	}
 
 	//-----------------------------------------------------
@@ -155,7 +155,7 @@ wxMenu * CWKSP_Map_Layer::Get_Menu(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -163,62 +163,36 @@ bool CWKSP_Map_Layer::On_Command(int Cmd_ID)
 {
 	switch( Cmd_ID )
 	{
-	default:
-		return( CWKSP_Base_Item::On_Command(Cmd_ID) );
+	default: return( m_pLayer->On_Command(Cmd_ID) );
 
-	case ID_CMD_SHAPES_EDIT_SHAPE    :
-	case ID_CMD_SHAPES_EDIT_ADD_SHAPE:
-	case ID_CMD_SHAPES_EDIT_DEL_SHAPE:
-	case ID_CMD_SHAPES_EDIT_ADD_PART :
-	case ID_CMD_SHAPES_EDIT_DEL_PART :
-	case ID_CMD_SHAPES_EDIT_DEL_POINT:
-    case ID_CMD_SHAPES_EDIT_SEL_COPY :
-	case ID_CMD_DATA_SELECTION_CLEAR :
-	case ID_CMD_DATA_SELECTION_INVERT:
-		return( m_pLayer->On_Command(Cmd_ID) );
-
-	case ID_CMD_WKSP_ITEM_RETURN:
-	case ID_CMD_MAPS_LAYER_SHOW:
+	//-----------------------------------------------------
+	case ID_CMD_WKSP_ITEM_RETURN     :
+	case ID_CMD_MAPS_LAYER_SHOW      :
 		m_bShow	= !m_bShow;
 		((wxTreeCtrl *)Get_Control())->SetItemText(GetId(), Get_Name());
 		((CWKSP_Map *)Get_Manager())->View_Refresh(true);
 		break;
 
-	case ID_CMD_MAPS_MOVE_TOP:
-		if( Get_Manager()->Move_Top(this) )
-			((CWKSP_Map *)Get_Manager())->View_Refresh(false);
-		break;
+	case ID_CMD_MAPS_MOVE_TOP        : if( Get_Manager()->Move_Top   (this) ) { ((CWKSP_Map *)Get_Manager())->View_Refresh(false); } break;
+	case ID_CMD_MAPS_MOVE_BOTTOM     : if( Get_Manager()->Move_Bottom(this) ) { ((CWKSP_Map *)Get_Manager())->View_Refresh(false); } break;
+	case ID_CMD_MAPS_MOVE_UP         : if( Get_Manager()->Move_Up    (this) ) { ((CWKSP_Map *)Get_Manager())->View_Refresh(false); } break;
+	case ID_CMD_MAPS_MOVE_DOWN       : if( Get_Manager()->Move_Down  (this) ) { ((CWKSP_Map *)Get_Manager())->View_Refresh(false); } break;
 
-	case ID_CMD_MAPS_MOVE_BOTTOM:
-		if( Get_Manager()->Move_Bottom(this) )
-			((CWKSP_Map *)Get_Manager())->View_Refresh(false);
-		break;
-
-	case ID_CMD_MAPS_MOVE_UP:
-		if( Get_Manager()->Move_Up(this) )
-			((CWKSP_Map *)Get_Manager())->View_Refresh(false);
-		break;
-
-	case ID_CMD_MAPS_MOVE_DOWN:
-		if( Get_Manager()->Move_Down(this) )
-			((CWKSP_Map *)Get_Manager())->View_Refresh(false);
-		break;
-
-	case ID_CMD_MAPS_GRID_FITCOLORS:
-		if( (m_bFitColors = !m_bFitColors) == true )
+	case ID_CMD_MAPS_GRID_FITCOLORS  :
+		if( (m_bStretch_Extent = !m_bStretch_Extent) == true )
 		{
 			Fit_Colors(((CWKSP_Map *)Get_Manager())->Get_Extent());
 		}
 		break;
 
-	case ID_CMD_MAPS_PROJECT:
-		m_bProject	= !m_bProject; ((CWKSP_Map *)Get_Manager())->View_Refresh(false);
+	case ID_CMD_MAPS_PROJECT         :
+		m_bProject = !m_bProject; ((CWKSP_Map *)Get_Manager())->View_Refresh(false);
 		break;
 
-	case ID_CMD_MAPS_PROJECT_AREA:
+	case ID_CMD_MAPS_PROJECT_AREA    :
 		if( m_bProject )
 		{
-			m_bProject_Area	= !m_bProject_Area; ((CWKSP_Map *)Get_Manager())->View_Refresh(false);
+			m_bProject_Area = !m_bProject_Area; ((CWKSP_Map *)Get_Manager())->View_Refresh(false);
 		}
 		break;
 	}
@@ -231,45 +205,19 @@ bool CWKSP_Map_Layer::On_Command_UI(wxUpdateUIEvent &event)
 {
 	switch( event.GetId() )
 	{
-	default:
-		return( CWKSP_Base_Item::On_Command_UI(event) );
+	default: return( m_pLayer->On_Command_UI(event) );
 
-	case ID_CMD_SHAPES_EDIT_SHAPE    :
-	case ID_CMD_SHAPES_EDIT_ADD_SHAPE:
-	case ID_CMD_SHAPES_EDIT_DEL_SHAPE:
-	case ID_CMD_SHAPES_EDIT_ADD_PART :
-	case ID_CMD_SHAPES_EDIT_DEL_PART :
-	case ID_CMD_SHAPES_EDIT_DEL_POINT:
-    case ID_CMD_SHAPES_EDIT_SEL_COPY :
-	case ID_CMD_DATA_SELECTION_CLEAR :
-	case ID_CMD_DATA_SELECTION_INVERT:
-		return( m_pLayer->On_Command_UI(event) );
+	//-----------------------------------------------------
+	case ID_CMD_MAPS_LAYER_SHOW    : event.Check(m_bShow          ); break;
+	case ID_CMD_MAPS_GRID_FITCOLORS: event.Check(m_bStretch_Extent); break;
+	case ID_CMD_MAPS_PROJECT       : event.Check(m_bProject       ); break;
+	case ID_CMD_MAPS_PROJECT_AREA  : event.Check(m_bProject_Area  ); break;
 
-	case ID_CMD_MAPS_LAYER_SHOW:
-		event.Check(m_bShow);
-		break;
+	case ID_CMD_MAPS_MOVE_TOP      :
+	case ID_CMD_MAPS_MOVE_UP       : event.Enable(Get_Index() > 0                             ); break;
 
-	case ID_CMD_MAPS_MOVE_TOP:
-	case ID_CMD_MAPS_MOVE_UP:
-		event.Enable(Get_Index() > 0);
-		break;
-
-	case ID_CMD_MAPS_MOVE_DOWN:
-	case ID_CMD_MAPS_MOVE_BOTTOM:
-		event.Enable(Get_Index() < Get_Manager()->Get_Count() - 1);
-		break;
-
-	case ID_CMD_MAPS_GRID_FITCOLORS:
-		event.Check(m_bFitColors);
-		break;
-
-	case ID_CMD_MAPS_PROJECT:
-		event.Check(m_bProject);
-		break;
-
-	case ID_CMD_MAPS_PROJECT_AREA:
-		event.Check(m_bProject_Area);
-		break;
+	case ID_CMD_MAPS_MOVE_DOWN     :
+	case ID_CMD_MAPS_MOVE_BOTTOM   : event.Enable(Get_Index() < Get_Manager()->Get_Count() - 1); break;
 	}
 
 	return( true );
@@ -277,7 +225,7 @@ bool CWKSP_Map_Layer::On_Command_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -285,10 +233,10 @@ bool CWKSP_Map_Layer::Load_Settings(CSG_MetaData *pEntry)
 {
 	if( pEntry )
 	{
-		m_bShow         = !(*pEntry)("SHOW"        ) || (*pEntry)["SHOW"        ].Get_Content().CmpNoCase("true") == 0;
-		m_bProject      =  (*pEntry)("PROJECT"     ) && (*pEntry)["PROJECT"     ].Get_Content().CmpNoCase("true") == 0;
-		m_bProject_Area =  (*pEntry)("PROJECT_AREA") && (*pEntry)["PROJECT_AREA"].Get_Content().CmpNoCase("true") == 0;
-		m_bFitColors    =  (*pEntry)("FITCOLORS"   ) && (*pEntry)["FITCOLORS"   ].Get_Content().CmpNoCase("true") == 0;
+		m_bShow           = !(*pEntry)("SHOW"        ) || (*pEntry)["SHOW"        ].Get_Content().CmpNoCase("true") == 0;
+		m_bProject        =  (*pEntry)("PROJECT"     ) && (*pEntry)["PROJECT"     ].Get_Content().CmpNoCase("true") == 0;
+		m_bProject_Area   =  (*pEntry)("PROJECT_AREA") && (*pEntry)["PROJECT_AREA"].Get_Content().CmpNoCase("true") == 0;
+		m_bStretch_Extent =  (*pEntry)("FITCOLORS"   ) && (*pEntry)["FITCOLORS"   ].Get_Content().CmpNoCase("true") == 0;
 
 		if( !m_bShow )
 		{
@@ -306,10 +254,10 @@ bool CWKSP_Map_Layer::Save_Settings(CSG_MetaData *pEntry)
 {
 	if( pEntry )
 	{
-		pEntry->Add_Child("SHOW"        , m_bShow         ? "true" : "false");
-		pEntry->Add_Child("PROJECT"     , m_bProject      ? "true" : "false");
-		pEntry->Add_Child("PROJECT_AREA", m_bProject_Area ? "true" : "false");
-		pEntry->Add_Child("FITCOLORS"   , m_bFitColors    ? "true" : "false");
+		pEntry->Add_Child("SHOW"        , m_bShow           ? "true" : "false");
+		pEntry->Add_Child("PROJECT"     , m_bProject        ? "true" : "false");
+		pEntry->Add_Child("PROJECT_AREA", m_bProject_Area   ? "true" : "false");
+		pEntry->Add_Child("FITCOLORS"   , m_bStretch_Extent ? "true" : "false");
 
 		return( true );
 	}
@@ -319,7 +267,7 @@ bool CWKSP_Map_Layer::Save_Settings(CSG_MetaData *pEntry)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -338,49 +286,22 @@ void CWKSP_Map_Layer::Parameters_Changed(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CWKSP_Map_Layer::Fit_Colors(const CSG_Rect &rWorld)
 {
-	if( m_bFitColors )
+	if( m_bStretch_Extent )
 	{
-		CSG_Rect	_rWorld(rWorld);	CSG_Projection	prj_Layer, prj_Map;
+		CSG_Rect _rWorld(rWorld); CSG_Projection prj_Layer, prj_Map;
 
 		if( m_bProject && _Projected_Get_Projections(prj_Layer, prj_Map) )
 		{
 			SG_Get_Projected(prj_Map, prj_Layer, _rWorld);
 		}
 
-		switch( m_pLayer->Get_Type() )
-		{
-		default:
-			return( false );
-
-		case WKSP_ITEM_Grids:
-			((CWKSP_Grids *)m_pLayer)->Fit_Colors(_rWorld);
-			break;
-
-		case WKSP_ITEM_Grid :
-			((CWKSP_Grid  *)m_pLayer)->Fit_Colors(_rWorld);
-
-			if( m_pLayer->Get_Parameter("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
-			{
-				#define	FIT_OVERLAY_GRID_COLORS(band, extent)	{\
-					CWKSP_Grid	*pGrid	= (CWKSP_Grid *)g_pData->Get(m_pLayer->Get_Parameter(band)->asGrid());\
-					if( pGrid && m_pLayer->Get_Parameter(band)->is_Enabled() )\
-					{	pGrid->Fit_Colors(extent);	}\
-				}
-
-				FIT_OVERLAY_GRID_COLORS("OVERLAY_R", rWorld);
-				FIT_OVERLAY_GRID_COLORS("OVERLAY_G", rWorld);
-				FIT_OVERLAY_GRID_COLORS("OVERLAY_B", rWorld);
-			}
-			break;
-		}
-
-		return( true );
+		return( m_pLayer->Set_Stretch_Extent(_rWorld) );
 	}
 
 	return( false );
@@ -388,13 +309,13 @@ bool CWKSP_Map_Layer::Fit_Colors(const CSG_Rect &rWorld)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CWKSP_Map_Layer::is_Projecting(void)
 {
-	CSG_Projection	prj_Layer, prj_Map;
+	CSG_Projection prj_Layer, prj_Map;
 
 	return( m_bProject && _Projected_Get_Projections(prj_Layer, prj_Map) );
 }
@@ -402,8 +323,8 @@ bool CWKSP_Map_Layer::is_Projecting(void)
 //---------------------------------------------------------
 bool CWKSP_Map_Layer::_Projected_Get_Projections(CSG_Projection &prj_Layer, CSG_Projection &prj_Map)
 {
-	prj_Layer	= m_pLayer    ->Get_Object () ->Get_Projection();
-	prj_Map		= ((CWKSP_Map *)Get_Manager())->Get_Projection();
+	prj_Layer = (m_pLayer   ->Get_Object ())->Get_Projection();
+	prj_Map   = ((CWKSP_Map *)Get_Manager())->Get_Projection();
 
 	return( prj_Layer.is_Okay() && prj_Map.is_Okay() && prj_Layer.is_Equal(prj_Map) == false );
 }
@@ -411,7 +332,7 @@ bool CWKSP_Map_Layer::_Projected_Get_Projections(CSG_Projection &prj_Layer, CSG_
 //---------------------------------------------------------
 bool CWKSP_Map_Layer::_Set_Extent_Points(const CSG_Rect &Extent, CSG_Shapes &Points, int Resolution)
 {
-	double	d	= (Extent.Get_XRange() + Extent.Get_YRange()) / (double)Resolution;
+	double d = (Extent.Get_XRange() + Extent.Get_YRange()) / (double)Resolution;
 
 	for(double y=Extent.Get_YMin(); y<Extent.Get_YMax(); y+=d)
 	{
@@ -436,7 +357,7 @@ bool CWKSP_Map_Layer::_Set_Extent_Points(const CSG_Rect &Extent, CSG_Shapes &Poi
 //---------------------------------------------------------
 CSG_Rect CWKSP_Map_Layer::Get_Extent(void)
 {
-	CSG_Projection	prj_Layer, prj_Map;
+	CSG_Projection prj_Layer, prj_Map;
 
 	if( !m_bProject || !_Projected_Get_Projections(prj_Layer, prj_Map) )
 	{
@@ -444,7 +365,7 @@ CSG_Rect CWKSP_Map_Layer::Get_Extent(void)
 	}
 
 	//-----------------------------------------------------
-	CSG_Rect	rLayer	= m_pLayer->Get_Extent();
+	CSG_Rect rLayer = m_pLayer->Get_Extent();
 
 	if( rLayer.Get_XRange() == 0. || rLayer.Get_YRange() == 0. )
 	{
@@ -463,7 +384,7 @@ CSG_Rect CWKSP_Map_Layer::Get_Extent(void)
 	}
 
 	//-----------------------------------------------------
-	CSG_Shapes	Extent(SHAPE_TYPE_Point);
+	CSG_Shapes Extent(SHAPE_TYPE_Point);
 
 	Extent.Get_Projection().Create(prj_Layer);
 
@@ -474,7 +395,7 @@ CSG_Rect CWKSP_Map_Layer::Get_Extent(void)
 	return( Extent.Get_Extent() );
 
 	//-----------------------------------------------------
-	//CSG_Rect	rLayer(m_pLayer->Get_Extent());
+	//CSG_Rect rLayer(m_pLayer->Get_Extent());
 
 	//SG_Get_Projected(prj_Layer, prj_Map, rLayer.m_rect);
 
@@ -484,7 +405,7 @@ CSG_Rect CWKSP_Map_Layer::Get_Extent(void)
 //---------------------------------------------------------
 CSG_Rect CWKSP_Map_Layer::_Projected_Get_Layer_Extent(const CSG_Rect &rMap)
 {
-	CSG_Projection	prj_Layer, prj_Map;
+	CSG_Projection prj_Layer, prj_Map;
 
 	if( !m_bProject || !_Projected_Get_Projections(prj_Layer, prj_Map) )
 	{
@@ -492,7 +413,7 @@ CSG_Rect CWKSP_Map_Layer::_Projected_Get_Layer_Extent(const CSG_Rect &rMap)
 	}
 
 	//-----------------------------------------------------
-	CSG_Shapes	Extent(SHAPE_TYPE_Point);
+	CSG_Shapes Extent(SHAPE_TYPE_Point);
 
 	Extent.Get_Projection().Create(prj_Map);
 
@@ -500,7 +421,7 @@ CSG_Rect CWKSP_Map_Layer::_Projected_Get_Layer_Extent(const CSG_Rect &rMap)
 
 	SG_Get_Projected(&Extent, NULL, prj_Layer);
 
-	TSG_Rect	rLayer	= Extent.Get_Extent();
+	TSG_Rect rLayer = Extent.Get_Extent();
 
 	if( std::isinf(rLayer.xMin) ) rLayer.xMin = m_pLayer->Get_Extent().Get_XMin();
 	if( std::isinf(rLayer.xMax) ) rLayer.xMax = m_pLayer->Get_Extent().Get_XMax();
@@ -513,7 +434,7 @@ CSG_Rect CWKSP_Map_Layer::_Projected_Get_Layer_Extent(const CSG_Rect &rMap)
 //---------------------------------------------------------
 bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes *pShapes, CSG_Shapes &Clipped)
 {
-	CSG_Projection	prj_Layer, prj_Map;
+	CSG_Projection prj_Layer, prj_Map;
 
 	if( !m_bProject || !_Projected_Get_Projections(prj_Layer, prj_Map) )
 	{
@@ -521,7 +442,7 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes
 	}
 
 	//-----------------------------------------------------
-	CSG_Shapes	Shapes, Extent(SHAPE_TYPE_Point);	Extent.Get_Projection().Create(prj_Map);
+	CSG_Shapes Shapes, Extent(SHAPE_TYPE_Point); Extent.Get_Projection().Create(prj_Map);
 
 	_Set_Extent_Points(rMap, Extent);
 
@@ -533,11 +454,11 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes
 	if( std::isfinite(Extent.Get_Extent().Get_XMin()) && std::isfinite(Extent.Get_Extent().Get_XMax())
 	&&  std::isfinite(Extent.Get_Extent().Get_YMin()) && std::isfinite(Extent.Get_Extent().Get_YMax()) )
 	{
-		CSG_Shapes	Clip(SHAPE_TYPE_Polygon);	CSG_Shape	*pClip	= Clip.Add_Shape();
+		CSG_Shapes Clip(SHAPE_TYPE_Polygon); CSG_Shape *pClip = Clip.Add_Shape();
 
 		for(sLong i=0; i<Extent.Get_Count(); i++)
 		{
-			TSG_Point	p	= Extent.Get_Shape(i)->Get_Point();
+			TSG_Point p = Extent.Get_Shape(i)->Get_Point();
 
 			if( std::isinf(p.x) ) p.x = std::signbit(p.x) ? Extent.Get_Extent().Get_XMin() : Extent.Get_Extent().Get_XMax();
 			if( std::isinf(p.y) ) p.y = std::signbit(p.y) ? Extent.Get_Extent().Get_YMin() : Extent.Get_Extent().Get_YMax();
@@ -549,7 +470,7 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes
 		}
 
 		//-------------------------------------------------
-		if( ((CSG_Shape_Polygon *)pClip)->Get_Area() > 0.0 )
+		if( ((CSG_Shape_Polygon *)pClip)->Get_Area() > 0. )
 		{
 			Shapes.Create(pShapes->Get_Type(), SG_T(""), pShapes);	Shapes.Get_Projection().Create(prj_Layer);
 
@@ -561,7 +482,7 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes
 				}
 			}
 
-			pShapes	= &Shapes;	//	SG_UI_DataObject_Add(SG_Create_Shapes(Clip), 0);
+			pShapes = &Shapes; // SG_UI_DataObject_Add(SG_Create_Shapes(Clip), 0);
 		}
 	}
 
@@ -569,8 +490,8 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes
 	SG_Get_Projected(pShapes, pShapes == &Shapes ? NULL : &Shapes, prj_Map);
 
 	//-----------------------------------------------------
-	CSG_Shapes	Clip(SHAPE_TYPE_Polygon);	Clip.Get_Projection().Create(prj_Map);
-	CSG_Shape	*pClip	= Clip.Add_Shape();
+	CSG_Shapes  Clip(SHAPE_TYPE_Polygon); Clip.Get_Projection().Create(prj_Map);
+	CSG_Shape *pClip = Clip.Add_Shape();
 	pClip->Add_Point(rMap.Get_XMin(), rMap.Get_YMin());
 	pClip->Add_Point(rMap.Get_XMin(), rMap.Get_YMax());
 	pClip->Add_Point(rMap.Get_XMax(), rMap.Get_YMax());
@@ -578,9 +499,9 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes
 
 	SG_UI_ProgressAndMsg_Lock(true);
 
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("shapes_polygons", 11);	// Polygon Clipping
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("shapes_polygons", 11);	// Polygon Clipping
 
-	bool	bResult	= pTool && pTool->Set_Manager(NULL)
+	bool bResult = pTool && pTool->Set_Manager(NULL)
 	&&  pTool->Set_Parameter("CLIP"    , &Clip)
 	&&  pTool->Set_Parameter("S_INPUT" , &Shapes)
 	&&  pTool->Set_Parameter("S_OUTPUT", &Clipped)
@@ -606,7 +527,7 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Draw(CSG_Map_DC &dc_Map, int Flags, CSG_
 	}
 	else
 	{
-		CSG_Rect rMap(dc_Map.rWorld());	rMap.Inflate(dc_Map.DC2World(), false);	// inflate by one pixel
+		CSG_Rect rMap(dc_Map.rWorld()); rMap.Inflate(dc_Map.DC2World(), false); // inflate by one pixel
 
 		_Projected_Shapes_Clipped(rMap, pShapes, Shapes);
 	}
@@ -621,7 +542,7 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Draw(CSG_Map_DC &dc_Map, int Flags, CSG_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -797,9 +718,9 @@ bool CWKSP_Map_Layer::Draw(CSG_Map_DC &dc_Map, int Flags)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
