@@ -50,6 +50,8 @@
 //---------------------------------------------------------
 #include <saga_api/saga_api.h>
 
+#include <wx/fs_mem.h>
+
 #include "res_commands.h"
 #include "res_controls.h"
 #include "res_dialogs.h"
@@ -69,9 +71,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -79,22 +81,28 @@ CWKSP_Map_Manager *g_pMaps = NULL;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CWKSP_Map_Manager::CWKSP_Map_Manager(void)
 {
+	wxMemoryFSHandler::AddFile("preview_map.png", "dummy");
+
 	g_pMaps = this; m_Numbering = 0; m_Parameters.Set_Name(_TL("Maps"));
 
 	//-----------------------------------------------------
-	m_Parameters.Add_Bool (""          , "THUMBNAILS"        , _TL("Thumbnails"     ), _TL(""), true);
-	m_Parameters.Add_Int  ("THUMBNAILS", "THUMBNAIL_SIZE"    , _TL("Size"           ), _TL(""), 75, 10, true);
-	m_Parameters.Add_Color("THUMBNAILS", "THUMBNAIL_SELCOLOR", _TL("Selection Color"), _TL(""), Get_Color_asInt(SYS_Get_Color(wxSYS_COLOUR_BTNSHADOW)));
+	m_Parameters.Add_Bool (""          , "THUMBNAILS"        , _TL("Thumbnails"         ), _TL(""), true);
+	m_Parameters.Add_Int  ("THUMBNAILS", "THUMBNAIL_SIZE"    , _TL("Size"               ), _TL(""), 75, 10, true);
+	m_Parameters.Add_Color("THUMBNAILS", "THUMBNAIL_SELCOLOR", _TL("Selection Color"    ), _TL(""), Get_Color_asInt(SYS_Get_Color(wxSYS_COLOUR_BTNSHADOW)));
 
-	m_Parameters.Add_Int  (""          , "NUMBERING"         , _TL("Map Numeration" ),
+	m_Parameters.Add_Node (""          , "NODE_DESC"         , _TL("Description"        ), _TL(""));
+	m_Parameters.Add_Bool ("NODE_DESC" , "PREVIEW"           , _TL("Preview"            ), _TL("Show a preview in description."), false);
+	m_Parameters.Add_Int  ("PREVIEW"   , "PREVIEW_SIZE"      , _TL("Size"               ), _TL(""), 200, 10, true);
+
+	m_Parameters.Add_Int  (""          , "NUMBERING"         , _TL("Map Numeration"     ),
 		_TL("Minimum width of map numbering. If set to 0 no numbering is applied at all. Negative values will prepend zeros. Having many maps numbering helps in unambiguos map identification."),
 		2
 	);
@@ -128,8 +136,8 @@ CWKSP_Map_Manager::CWKSP_Map_Manager(void)
 	//-----------------------------------------------------
 	m_Parameters.Add_Node  ("NODE_DEFAULTS", "NODE_NEW_MAPS", _TL("New Maps"), _TL(""));
 
-	m_Parameters.Add_Choice("NODE_NEW_MAPS", "NAMING"       , _TL("Naming"             ), _TL(""), CSG_String::Format("\'%s\'|%s", _TL("Map"), _TL("first added layer name")));
-	m_Parameters.Add_Int   ("NAMING"       , "NAMING_LENGTH", _TL("Maximum Characters" ), _TL(""), 256, 5, true);
+	m_Parameters.Add_Choice("NODE_NEW_MAPS", "NAMING"       , _TL("Naming"             ), _TL(""), CSG_String::Format("\'%s\'|%s", _TL("Map"), _TL("first added layer name")), 1);
+	m_Parameters.Add_Int   ("NAMING"       , "NAMING_LENGTH", _TL("Maximum Characters" ), _TL(""), 64, 5, true);
 	m_Parameters.Add_Choice("NODE_NEW_MAPS", "BG_COLOR"     , _TL("Background Color"   ), _TL(""), CSG_String::Format("%s|%s", _TL("system"), _TL("user defined")));
 	m_Parameters.Add_Color ("BG_COLOR"     , "BG_USER"      , _TL("User Defined"       ), _TL(""), SG_COLOR_WHITE);
 	m_Parameters.Add_Bool  ("NODE_NEW_MAPS", "GOTO_NEWLAYER", _TL("Zoom to added layer"), _TL(""), false);
@@ -174,7 +182,7 @@ CWKSP_Map_Manager::~CWKSP_Map_Manager(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -241,7 +249,7 @@ wxString CWKSP_Map_Manager::Get_Description(void)
 	USAGE_ADD(_TL(""             ), _TL("Left"  ), _TL("Clicked shape as new selection"));
 	USAGE_ADD(_TL("Control"      ), _TL("Left"  ), _TL("Add/remove clicked shape to current selection"));
 	USAGE_ADD(_TL(""             ), _TL("Right" ), _TL("Context menu"));
-	USAGE_ADD(_TL("Return"       ), _TL(""      ), _TL("Enter/leave shape edit mode"));
+	USAGE_ADD(_TL("Space"        ), _TL(""      ), _TL("Enter/leave shape edit mode"));
 	USAGE_ADD(_TL("Delete"       ), _TL(""      ), _TL("Delete selection"));
 	USAGE_STOP;
 
@@ -276,7 +284,7 @@ wxMenu * CWKSP_Map_Manager::Get_Menu(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -296,7 +304,7 @@ bool CWKSP_Map_Manager::On_Command(int Cmd_ID)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -322,7 +330,7 @@ void CWKSP_Map_Manager::Parameters_Changed(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -355,6 +363,11 @@ int CWKSP_Map_Manager::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Par
 		{
 			pParameter->Set_Children_Enabled(pParameter->asBool());
 		}
+
+		if(	pParameter->Cmp_Identifier("PREVIEW") )
+		{
+			pParameter->Set_Children_Enabled(pParameter->asBool());
+		}
 	}
 
 	//-----------------------------------------------------
@@ -363,7 +376,7 @@ int CWKSP_Map_Manager::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Par
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -455,13 +468,13 @@ bool CWKSP_Map_Manager::Del(CWKSP_Layer *pLayer)
 }
 
 //---------------------------------------------------------
-bool CWKSP_Map_Manager::Update(CWKSP_Layer *pLayer, bool bMapsOnly)
+bool CWKSP_Map_Manager::Update_Maps(CWKSP_Layer *pLayer, bool bMapsOnly)
 {
 	int n = 0;
 
 	for(int i=0; i<Get_Count(); i++)
 	{
-		if( Get_Map(i)->Update(pLayer, bMapsOnly) )
+		if( Get_Map(i)->Update_Map(pLayer, bMapsOnly) )
 		{
 			n++;
 		}
@@ -472,7 +485,7 @@ bool CWKSP_Map_Manager::Update(CWKSP_Layer *pLayer, bool bMapsOnly)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -502,7 +515,7 @@ wxString CWKSP_Map_Manager::Get_Numbering(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -573,9 +586,9 @@ bool CWKSP_Map_Manager::Toggle_CrossHair(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
