@@ -65,9 +65,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -82,9 +82,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -144,9 +144,9 @@ wxMenu * CWKSP_Shapes::Edit_Get_Menu(void)
 //---------------------------------------------------------
 TSG_Rect CWKSP_Shapes::Edit_Get_Extent(void)
 {
-	if( m_Edit_pShape )
+	if( m_Edit.pShape )
 	{
-		return( m_Edit_pShape->Get_Extent() );
+		return( m_Edit.pShape->Get_Extent() );
 	}
 
 	if( Get_Shapes()->Get_Selection_Count() > 0 )
@@ -159,9 +159,9 @@ TSG_Rect CWKSP_Shapes::Edit_Get_Extent(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -169,32 +169,40 @@ bool CWKSP_Shapes::Edit_On_Key_Down(int KeyCode)
 {
 	switch( KeyCode )
 	{
-	default:
-		return( false );
+	default: break;
 
 	case WXK_DELETE:
-		if( m_Edit_pShape )
+		if( m_Edit.pShape )
+		{
 			return( _Edit_Point_Del() );
+		}
 		else
+		{
 			return( _Edit_Shape_Del() );
+		}
 
-	case WXK_RETURN:
-	case WXK_SPACE:
-		if( !m_Edit_pShape )
+	case WXK_SPACE :
+		if( !m_Edit.pShape )
+		{
 			return( _Edit_Shape_Start() );
+		}
 		else
+		{
 			return( _Edit_Shape_Stop(true) );
+		}
 
 	case WXK_ESCAPE:
 		return( _Edit_Shape_Stop(false) );
 	}
+
+	return( false );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -208,12 +216,12 @@ bool CWKSP_Shapes::Edit_On_Mouse_Down(const CSG_Point &Point, double ClientToWor
 	}
 
 	//-----------------------------------------------------
-	switch( m_Edit_Mode )
+	switch( m_Edit.Mode )
 	{
 	case EDIT_SHAPE_MODE_Split:
-		if( m_Edit_Shapes.Get_Count() > 1 )
+		if( m_Edit.Shapes.Get_Count() > 1 )
 		{
-			m_Edit_Shapes.Get_Shape(1)->Add_Point(Point);
+			m_Edit.Shapes.Get_Shape(1)->Add_Point(Point);
 
 			Update_Views(false);
 
@@ -222,34 +230,32 @@ bool CWKSP_Shapes::Edit_On_Mouse_Down(const CSG_Point &Point, double ClientToWor
 		break;
 
 	case EDIT_SHAPE_MODE_Move:
-		if( m_Edit_Shapes.Get_Count() > 1 && m_Edit_Shapes.Get_Shape(1)->Get_Point_Count() == 0 )
+		if( m_Edit.Shapes.Get_Count() > 1 && m_Edit.Shapes.Get_Shape(1)->Get_Point_Count() == 0 )
 		{
-			m_Edit_Shapes.Get_Shape(1)->Add_Point(Point);
+			m_Edit.Shapes.Get_Shape(1)->Add_Point(Point);
 
 			return( true );
 		}
 		break;
 
 	case EDIT_SHAPE_MODE_Normal: default:
-		if( m_Edit_pShape )
+		if( m_Edit.pShape )
 		{
-			if( m_Edit_iPart >= 0 && m_Edit_iPoint < 0 )
+			if( m_Edit.Part >= 0 && m_Edit.Point < 0 )
 			{
 				// NOP
 			}
 			else
 			{
-				int		iPart, iPoint;
+				int iPart, iPoint;
 
 				switch( Edit_Shape_HitTest(Point, EDIT_TICKMARK_SIZE * ClientToWorld, iPart, iPoint) )
 				{
-				//-----------------------------------------
-				case 0:	default:
-				case 1:
-					if( m_Edit_iPart != iPart || m_Edit_iPoint != iPoint )
+				default:
+					if( m_Edit.Part != iPart || m_Edit.Point != iPoint )
 					{
-						m_Edit_iPart	= iPart;
-						m_Edit_iPoint	= iPoint;
+						m_Edit.Part  = iPart;
+						m_Edit.Point = iPoint;
 
 						Update_Views(false);
 					}
@@ -257,11 +263,11 @@ bool CWKSP_Shapes::Edit_On_Mouse_Down(const CSG_Point &Point, double ClientToWor
 					return( true );
 
 				//-----------------------------------------
-				case 2:
-					m_Edit_pShape->Ins_Point(Point, iPoint, iPart);
+				case  2:
+					m_Edit.pShape->Ins_Point(Point, iPoint, iPart);
 
-					m_Edit_iPart	= iPart;
-					m_Edit_iPoint	= iPoint;
+					m_Edit.Part  = iPart;
+					m_Edit.Point = iPoint;
 
 					Update_Views(false);
 
@@ -282,15 +288,15 @@ bool CWKSP_Shapes::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld
 	//-----------------------------------------------------
 	if( Key & TOOL_INTERACTIVE_KEY_RIGHT )
 	{
-		switch( m_Edit_Mode )
+		switch( m_Edit.Mode )
 		{
 		case EDIT_SHAPE_MODE_Split:
 			return( _Edit_Split() );
 
 		case EDIT_SHAPE_MODE_Normal:
-			if( m_Edit_pShape && m_Edit_iPart >= 0 && m_Edit_iPoint < 0 )
+			if( m_Edit.pShape && m_Edit.Part >= 0 && m_Edit.Point < 0 )
 			{
-				m_Edit_iPart	= -1;
+				m_Edit.Part = -1;
 
 				Update_Views(false);
 
@@ -301,20 +307,20 @@ bool CWKSP_Shapes::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld
 	}
 
 	//-----------------------------------------------------
-	else if( m_Edit_pShape )
+	else if( m_Edit.pShape )
 	{
-		if( m_Edit_Mode == EDIT_SHAPE_MODE_Move )
+		if( m_Edit.Mode == EDIT_SHAPE_MODE_Move )
 		{
-			if( m_Edit_Shapes.Get_Count() > 1 && m_Edit_Shapes.Get_Shape(1)->Get_Point_Count() > 0 )
+			if( m_Edit.Shapes.Get_Count() > 1 && m_Edit.Shapes.Get_Shape(1)->Get_Point_Count() > 0 )
 			{
-				m_Edit_Shapes.Get_Shape(1)->Add_Point(Point);
+				m_Edit.Shapes.Get_Shape(1)->Add_Point(Point);
 
 				return( _Edit_Move(false) );
 			}
 		}
-		else if( m_Edit_iPart >= 0 )
+		else if( m_Edit.Part >= 0 )
 		{
-			if( m_Edit_iPoint >= 0 )
+			if( m_Edit.Point >= 0 )
 			{
 				if( Point != m_Edit_Mouse_Down )
 				{
@@ -322,7 +328,7 @@ bool CWKSP_Shapes::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld
 
 					_Edit_Snap_Point(Snapped, ClientToWorld);
 
-					m_Edit_pShape->Set_Point(Snapped, m_Edit_iPoint, m_Edit_iPart);
+					m_Edit.pShape->Set_Point(Snapped, m_Edit.Point, m_Edit.Part);
 
 					Update_Views(false);
 
@@ -335,7 +341,7 @@ bool CWKSP_Shapes::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld
 
 				_Edit_Snap_Point(Snapped, ClientToWorld);
 
-				m_Edit_pShape->Add_Point(Snapped, m_Edit_iPart);
+				m_Edit.pShape->Add_Point(Snapped, m_Edit.Part);
 
 				Update_Views(false);
 
@@ -345,25 +351,42 @@ bool CWKSP_Shapes::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld
 	}
 
 	//-----------------------------------------------------
-	else if( m_Edit_Mode == EDIT_SHAPE_MODE_Normal )
+	else if( m_Edit.Mode == EDIT_SHAPE_MODE_Normal )
 	{
 		g_pActive->Update_Attributes(true);
 
-		CSG_Rect	rWorld(m_Edit_Mouse_Down, Point);
+		CSG_Rect rWorld(m_Edit_Mouse_Down, Point);
 
-		if( rWorld.Get_XRange() == 0.0 && rWorld.Get_YRange() == 0.0 )
+		if( rWorld.Get_XRange() == 0. && rWorld.Get_YRange() == 0. )
 		{
-			rWorld.Inflate(2.0 * ClientToWorld, false);
+			rWorld.Inflate(2. * ClientToWorld, false);
 		}
 
-		int		Count	= Get_Shapes()->Get_Selection_Count();
+		if( (Key & TOOL_INTERACTIVE_KEY_CTRL) == 0 ) // new selection
+		{
+			Get_Shapes()->Select(rWorld, false);
 
-		Get_Shapes()->Select(rWorld, (Key & TOOL_INTERACTIVE_KEY_CTRL) != 0);
+			Edit_Set_Index(0);
+		}
+		else // modify existing selection (add or remove)
+		{
+			sLong Count = Get_Shapes()->Get_Selection_Count();
 
-		Edit_Set_Index((Key & TOOL_INTERACTIVE_KEY_CTRL) == 0 ? 0 :
-			Count < Get_Shapes()->Get_Selection_Count() || m_Edit_Index >= Get_Shapes()->Get_Selection_Count()
-			? Get_Shapes()->Get_Selection_Count() - 1 : m_Edit_Index
-		);
+			Get_Shapes()->Select(rWorld, true);
+
+			if( Get_Shapes()->Get_Selection_Count() < 1 ) // no selection
+			{
+				Edit_Set_Index(0);
+			}
+			else if( Count < Get_Shapes()->Get_Selection_Count() || m_Edit.Index >= Get_Shapes()->Get_Selection_Count() )
+			{
+				Edit_Set_Index(Get_Shapes()->Get_Selection_Count() - 1);
+			}
+			else
+			{
+				Edit_Set_Index(m_Edit.Index);
+			}
+		}
 
 		if( m_pTable->Get_View() )
 		{
@@ -381,11 +404,11 @@ bool CWKSP_Shapes::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld
 //---------------------------------------------------------
 bool CWKSP_Shapes::Edit_On_Mouse_Move(wxWindow *pMap, const CSG_Rect &rWorld, const wxPoint &Point, const wxPoint &Last, int Key)
 {
-	switch( m_Edit_Mode )
+	switch( m_Edit.Mode )
 	{
 	case EDIT_SHAPE_MODE_Split:
 	case EDIT_SHAPE_MODE_Move : {
-		CSG_Shape *pShape = m_Edit_Shapes.Get_Shape(1);
+		CSG_Shape *pShape = m_Edit.Shapes.Get_Shape(1);
 
 		if( pShape && pShape->Get_Point_Count() > 0 && Point != Last )
 		{
@@ -396,9 +419,9 @@ bool CWKSP_Shapes::Edit_On_Mouse_Move(wxWindow *pMap, const CSG_Rect &rWorld, co
 
 	//-----------------------------------------------------
 	case EDIT_SHAPE_MODE_Normal: default:
-		if( m_Edit_pShape )
+		if( m_Edit.pShape )
 		{
-			if( m_Edit_iPart >= 0 && (m_Edit_iPoint < 0 || Key & TOOL_INTERACTIVE_KEY_LEFT) && Point != Last )
+			if( m_Edit.Part >= 0 && (m_Edit.Point < 0 || Key & TOOL_INTERACTIVE_KEY_LEFT) && Point != Last )
 			{
 				pMap->Refresh(false);
 
@@ -429,11 +452,11 @@ bool CWKSP_Shapes::Edit_On_Mouse_Move(wxWindow *pMap, const CSG_Rect &rWorld, co
 //---------------------------------------------------------
 bool CWKSP_Shapes::Edit_On_Mouse_Move_Draw(wxDC &dc, const CSG_Rect &rWorld, const wxPoint &Point)
 {
-	switch( m_Edit_Mode )
+	switch( m_Edit.Mode )
 	{
 	case EDIT_SHAPE_MODE_Split:
 	case EDIT_SHAPE_MODE_Move : {
-		CSG_Shape *pShape = m_Edit_Shapes.Get_Shape(1);
+		CSG_Shape *pShape = m_Edit.Shapes.Get_Shape(1);
 
 		if( pShape && pShape->Get_Point_Count() > 0 )
 		{
@@ -444,7 +467,7 @@ bool CWKSP_Shapes::Edit_On_Mouse_Move_Draw(wxDC &dc, const CSG_Rect &rWorld, con
 
 	//-----------------------------------------------------
 	case EDIT_SHAPE_MODE_Normal: {
-		if( m_Edit_pShape && m_Edit_iPart >= 0 )
+		if( m_Edit.pShape && m_Edit.Part >= 0 )
 		{
 			Edit_Shape_Draw_Move(dc, rWorld, Point);
 		}
@@ -457,14 +480,14 @@ bool CWKSP_Shapes::Edit_On_Mouse_Move_Draw(wxDC &dc, const CSG_Rect &rWorld, con
 //---------------------------------------------------------
 bool CWKSP_Shapes::Edit_Do_Mouse_Move_Draw(bool bMouseDown)
 {
-	return( m_Edit_Mode == EDIT_SHAPE_MODE_Split || m_Edit_Mode == EDIT_SHAPE_MODE_Move );
+	return( m_Edit.Mode == EDIT_SHAPE_MODE_Split || m_Edit.Mode == EDIT_SHAPE_MODE_Move );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -472,22 +495,22 @@ bool CWKSP_Shapes::Edit_Set_Index(int Index)
 {
 	m_Edit_Attributes.Del_Records();
 
-	if( Index > Get_Shapes()->Get_Selection_Count() )
+	if( Index >= Get_Shapes()->Get_Selection_Count() )
 	{
-		Index	= Get_Shapes()->Get_Selection_Count();
+		Index = Get_Shapes()->Get_Selection_Count() - 1;
 	}
 
-	CSG_Table_Record	*pSelection	= Get_Shapes()->Get_Selection(Index);
+	CSG_Table_Record *pSelection = Get_Shapes()->Get_Selection(Index);
 
 	if( pSelection )
 	{
-		int	Decimals;	GET_TABLE_NUM_PREC(Decimals);
+		int	Decimals; GET_TABLE_NUM_PREC(Decimals);
 
-		m_Edit_Index	= Index;
+		m_Edit.Index = Index;
 
 		for(int i=0; i<Get_Shapes()->Get_Field_Count(); i++)
 		{
-			CSG_Table_Record	*pRecord	= m_Edit_Attributes.Add_Record();
+			CSG_Table_Record *pRecord = m_Edit_Attributes.Add_Record();
 
 			pRecord->Set_Value(0, pSelection->Get_Table()->Get_Field_Name(i));
 			pRecord->Set_Value(1, pSelection->asString(i, Decimals));
@@ -495,20 +518,26 @@ bool CWKSP_Shapes::Edit_Set_Index(int Index)
 	}
 	else
 	{
-		m_Edit_Index	= 0;
+		m_Edit.Index = 0;
 	}
 
 	return( true );
 }
 
+//---------------------------------------------------------
+int CWKSP_Shapes::Edit_Get_Index(void)
+{
+	return( m_Edit.Index );
+}
+
 //---------------------------------------------------------
 bool CWKSP_Shapes::Edit_Set_Attributes(void)
 {
-	CSG_Table_Record	*pSelection	= Get_Shapes()->Get_Selection(m_Edit_Index);
+	CSG_Table_Record *pSelection = Get_Shapes()->Get_Selection(m_Edit.Index);
 
 	if( pSelection )
 	{
-		int	Decimals;	GET_TABLE_NUM_PREC(Decimals);
+		int	Decimals; GET_TABLE_NUM_PREC(Decimals);
 
 		for(int i=0; i<m_Edit_Attributes.Get_Count(); i++)
 		{
@@ -528,9 +557,9 @@ bool CWKSP_Shapes::Edit_Set_Attributes(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -542,7 +571,7 @@ bool CWKSP_Shapes::_Edit_Merge(void)
 	}
 
 	//-----------------------------------------------------
-	CSG_Shape *pMerged = Get_Shapes()->Get_Selection(0);
+	CSG_Shape *pMerged = (CSG_Shape *)Get_Shapes()->Get_Selection(0);
 
 	if( pMerged->asPolygon() )
 	{
@@ -557,7 +586,7 @@ bool CWKSP_Shapes::_Edit_Merge(void)
 
 	for(sLong i=1; i<Get_Shapes()->Get_Selection_Count(); i++)
 	{
-		CSG_Shape *pShape = Get_Shapes()->Get_Selection(i);
+		CSG_Shape *pShape = (CSG_Shape *)Get_Shapes()->Get_Selection(i);
 
 		for(int iPart=0, jPart=pMerged->Get_Part_Count(); iPart<pShape->Get_Part_Count(); iPart++, jPart++)
 		{
@@ -587,34 +616,34 @@ bool CWKSP_Shapes::_Edit_Split(void)
 	if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon
 	||  Get_Shapes()->Get_Type() == SHAPE_TYPE_Line )
 	{
-		switch( m_Edit_Mode )
+		switch( m_Edit.Mode )
 		{
 		default:
 			break;
 
 		//-------------------------------------------------
 		case EDIT_SHAPE_MODE_Normal:
-			m_Edit_Mode	= EDIT_SHAPE_MODE_Split;
+			m_Edit.Mode	= EDIT_SHAPE_MODE_Split;
 
-			if( m_Edit_Shapes.Get_Count() == 0 )
+			if( m_Edit.Shapes.Get_Count() == 0 )
 			{
-				m_Edit_Shapes.Add_Shape(Get_Shapes()->Get_Selection());
+				m_Edit.Shapes.Add_Shape(Get_Shapes()->Get_Selection());
 			}
 
-			if( m_Edit_Shapes.Get_Count() > 1 )
+			if( m_Edit.Shapes.Get_Count() > 1 )
 			{
-				m_Edit_Shapes.Get_Shape(1)->Del_Parts();
+				m_Edit.Shapes.Get_Shape(1)->Del_Parts();
 			}
 			else
 			{
-				m_Edit_Shapes.Add_Shape();
+				m_Edit.Shapes.Add_Shape();
 			}
 
 			return( true );
 
 		//-------------------------------------------------
 		case EDIT_SHAPE_MODE_Split:
-			m_Edit_Mode	= EDIT_SHAPE_MODE_Normal;
+			m_Edit.Mode	= EDIT_SHAPE_MODE_Normal;
 
 			CSG_Tool	*pTool	= Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon
 			?	SG_Get_Tool_Library_Manager().Create_Tool("shapes_polygons", 8)  // Polygon-Line Intersection
@@ -628,26 +657,26 @@ bool CWKSP_Shapes::_Edit_Split(void)
 
 				Line.Add_Shape();
 
-				for(int i=0; i<m_Edit_Shapes.Get_Shape(1)->Get_Point_Count(); i++)
+				for(int i=0; i<m_Edit.Shapes.Get_Shape(1)->Get_Point_Count(); i++)
 				{
-					Line.Get_Shape(0)->Add_Point(m_Edit_Shapes.Get_Shape(1)->Get_Point(i));
+					Line.Get_Shape(0)->Add_Point(m_Edit.Shapes.Get_Shape(1)->Get_Point(i));
 				}
 
-				m_Edit_Shapes.Del_Shape(1);
+				m_Edit.Shapes.Del_Shape(1);
 
 				//-----------------------------------------
 				bool	bResult;
 
 				if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon )
 				{
-					bResult	= pTool->Get_Parameters()->Set_Parameter("POLYGONS" , &m_Edit_Shapes)
+					bResult	= pTool->Get_Parameters()->Set_Parameter("POLYGONS" , &m_Edit.Shapes)
 						&&    pTool->Get_Parameters()->Set_Parameter("LINES"    , &Line)
 						&&    pTool->Get_Parameters()->Set_Parameter("INTERSECT", &Split)
 						&&    pTool->Execute();
 				}
 				else //	if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Line )
 				{
-					bResult	= pTool->Get_Parameters()->Set_Parameter("LINES"    , &m_Edit_Shapes)
+					bResult	= pTool->Get_Parameters()->Set_Parameter("LINES"    , &m_Edit.Shapes)
 						&&    pTool->Get_Parameters()->Set_Parameter("SPLIT"    , &Line)
 						&&    pTool->Get_Parameters()->Set_Parameter("INTERSECT", &Split)
 						&&    pTool->Execute();
@@ -656,39 +685,39 @@ bool CWKSP_Shapes::_Edit_Split(void)
 				//-----------------------------------------
 				if( bResult )
 				{
-					if( m_Edit_pShape )
+					if( m_Edit.pShape )
 					{
-						m_Edit_pShape->Assign(Split.Get_Shape(0), false);
+						m_Edit.pShape->Assign(Split.Get_Shape(0), false);
 
 						for(sLong iSplit=1; iSplit<Split.Get_Count(); iSplit++)
 						{
-							CSG_Shape	*pSplit	= Split.Get_Shape(iSplit);
+							CSG_Shape *pSplit = Split.Get_Shape(iSplit);
 
 							for(int iPart=0; iPart<pSplit->Get_Part_Count(); iPart++)
 							{
-								for(int iPoint=0, jPart=m_Edit_pShape->Get_Part_Count(); iPoint<pSplit->Get_Point_Count(iPart); iPoint++)
+								for(int iPoint=0, jPart=m_Edit.pShape->Get_Part_Count(); iPoint<pSplit->Get_Point_Count(iPart); iPoint++)
 								{
-									m_Edit_pShape->Add_Point(pSplit->Get_Point(iPoint, iPart), jPart);
+									m_Edit.pShape->Add_Point(pSplit->Get_Point(iPoint, iPart), jPart);
 								}
 							}
 						}
 					}
-					else if( Get_Shapes()->Get_Selection_Count() == 1 ) // if( !m_Edit_pShape )
+					else if( Get_Shapes()->Get_Selection_Count() == 1 ) // if( !m_Edit.pShape )
 					{
-						CSG_Shape	*pSelection	= Get_Shapes()->Get_Selection();
+						CSG_Shape *pSelection = (CSG_Shape *)Get_Shapes()->Get_Selection();
 						
 						pSelection->Assign(Split.Get_Shape(0), false);
 
 						for(sLong iSplit=1; iSplit<Split.Get_Count(); iSplit++)
 						{
-							CSG_Shape	*pSplit	= Get_Shapes()->Add_Shape(Split.Get_Shape(iSplit));
+							CSG_Shape *pSplit = Get_Shapes()->Add_Shape(Split.Get_Shape(iSplit));
 
 							pSplit->Assign( pSelection, SHAPE_COPY_ATTR );
 
 							Get_Shapes()->Select(pSplit, true);
 						}
 
-						m_Edit_Shapes.Del_Shapes();
+						m_Edit.Shapes.Del_Shapes();
 					}
 				}
 
@@ -707,35 +736,35 @@ bool CWKSP_Shapes::_Edit_Split(void)
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Move(bool bToggle)
 {
-	if( m_Edit_pShape )
+	if( m_Edit.pShape )
 	{
 		if( bToggle )
 		{
-			switch( m_Edit_Mode )
+			switch( m_Edit.Mode )
 			{
 			default:
 				break;
 
 			//---------------------------------------------
 			case EDIT_SHAPE_MODE_Normal:
-				m_Edit_Mode	= EDIT_SHAPE_MODE_Move;
+				m_Edit.Mode	= EDIT_SHAPE_MODE_Move;
 
-				if( m_Edit_Shapes.Get_Count() > 1 )
+				if( m_Edit.Shapes.Get_Count() > 1 )
 				{
-					m_Edit_Shapes.Get_Shape(1)->Del_Parts();
+					m_Edit.Shapes.Get_Shape(1)->Del_Parts();
 				}
 				else
 				{
-					m_Edit_Shapes.Add_Shape();
+					m_Edit.Shapes.Add_Shape();
 				}
 
 				return( true );
 
 			//---------------------------------------------
 			case EDIT_SHAPE_MODE_Move:
-				m_Edit_Mode	= EDIT_SHAPE_MODE_Normal;
+				m_Edit.Mode	= EDIT_SHAPE_MODE_Normal;
 
-				m_Edit_Shapes.Del_Shape(1);
+				m_Edit.Shapes.Del_Shape(1);
 
 				return( true );
 			}
@@ -744,20 +773,20 @@ bool CWKSP_Shapes::_Edit_Move(bool bToggle)
 		//-------------------------------------------------
 		else // if( !bToggle )
 		{
-			if( m_Edit_Shapes.Get_Count() > 1 && m_Edit_Shapes.Get_Shape(1)->Get_Point_Count() > 1 )
+			if( m_Edit.Shapes.Get_Count() > 1 && m_Edit.Shapes.Get_Shape(1)->Get_Point_Count() > 1 )
 			{
-				CSG_Point	Move	= CSG_Point(m_Edit_Shapes.Get_Shape(1)->Get_Point(1))
-									- CSG_Point(m_Edit_Shapes.Get_Shape(1)->Get_Point());
+				CSG_Point Move = CSG_Point(m_Edit.Shapes.Get_Shape(1)->Get_Point(1))
+				               - CSG_Point(m_Edit.Shapes.Get_Shape(1)->Get_Point());
 
-				m_Edit_Shapes.Get_Shape(1)->Del_Parts();
+				m_Edit.Shapes.Get_Shape(1)->Del_Parts();
 
 				if( SG_Get_Length(Move.x, Move.y) > 0.0 )
 				{
-					for(int iPart=0; iPart<m_Edit_pShape->Get_Part_Count(); iPart++)
+					for(int iPart=0; iPart<m_Edit.pShape->Get_Part_Count(); iPart++)
 					{
-						for(int iPoint=0; iPoint<m_Edit_pShape->Get_Point_Count(iPart); iPoint++)
+						for(int iPoint=0; iPoint<m_Edit.pShape->Get_Point_Count(iPart); iPoint++)
 						{
-							m_Edit_pShape->Set_Point(Move + m_Edit_pShape->Get_Point(iPoint, iPart), iPoint, iPart);
+							m_Edit.pShape->Set_Point(Move + m_Edit.pShape->Get_Point(iPoint, iPart), iPoint, iPart);
 						}
 					}
 
@@ -772,7 +801,6 @@ bool CWKSP_Shapes::_Edit_Move(bool bToggle)
 	return( false );
 }
 
-
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Selection_Copy(void)
 {
@@ -781,7 +809,7 @@ bool CWKSP_Shapes::_Edit_Selection_Copy(void)
         return( false );
     }
 
-    CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("shapes_tools", 6);  // Copy Selection to New Shapes Layer
+    CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("shapes_tools", 6);  // Copy Selection to New Shapes Layer
 
     if(	pTool )
     {
@@ -801,7 +829,7 @@ bool CWKSP_Shapes::_Edit_Selection_Copy(void)
         }
         else
         {
-            delete( pCopy );
+            delete(pCopy);
         }
 
         return( bResult );
@@ -810,29 +838,30 @@ bool CWKSP_Shapes::_Edit_Selection_Copy(void)
     return( false );
 }
 
+
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Shape(void)
 {
-	return( m_Edit_pShape ? _Edit_Shape_Stop() : _Edit_Shape_Start() );
+	return( m_Edit.pShape ? _Edit_Shape_Stop() : _Edit_Shape_Start() );
 }
 
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Shape_Start(void)
 {
-	if( m_Edit_pShape == NULL && Get_Shapes()->Get_Selection(m_Edit_Index) != NULL )
+	if( m_Edit.pShape == NULL && Get_Shapes()->Get_Selection(m_Edit.Index) != NULL )
 	{
-		m_Edit_Mode		= EDIT_SHAPE_MODE_Normal;
+		m_Edit.Mode   = EDIT_SHAPE_MODE_Normal;
 
-		m_Edit_pShape	= m_Edit_Shapes.Add_Shape(Get_Shapes()->Get_Selection(m_Edit_Index), SHAPE_COPY_GEOM);
+		m_Edit.pShape = m_Edit.Shapes.Add_Shape(Get_Shapes()->Get_Selection(m_Edit.Index), SHAPE_COPY_GEOM);
 
-		m_Edit_iPart	= -1;
-		m_Edit_iPoint	= -1;
+		m_Edit.Part   = -1;
+		m_Edit.Point  = -1;
 
 		Update_Views(false);
 
@@ -850,30 +879,30 @@ bool CWKSP_Shapes::_Edit_Shape_Stop(void)
 
 bool CWKSP_Shapes::_Edit_Shape_Stop(bool bSave)
 {
-	if( m_Edit_pShape != NULL )
+	if( m_Edit.pShape != NULL )
 	{
 		if( bSave )
 		{
-			CSG_Shape	*pShape	= Get_Shapes()->Get_Selection(m_Edit_Index);
+			CSG_Shape *pShape = (CSG_Shape *)Get_Shapes()->Get_Selection(m_Edit.Index);
 
 			if( pShape == NULL )
 			{
 				Get_Shapes()->Select(pShape = Get_Shapes()->Add_Shape());
 
-				m_Edit_Index	= 0;
+				m_Edit.Index = 0;
 			}
 
 			if( pShape != NULL )
 			{
-				pShape->Assign(m_Edit_pShape, false);
+				pShape->Assign(m_Edit.pShape, false);
 			}
 		}
 
-		m_Edit_Shapes.Del_Shapes();
-		m_Edit_pShape	= NULL;
-		m_Edit_Mode		= EDIT_SHAPE_MODE_Normal;
+		m_Edit.Shapes.Del_Shapes();
+		m_Edit.pShape = NULL;
+		m_Edit.Mode   = EDIT_SHAPE_MODE_Normal;
 
-		Edit_Set_Index(m_Edit_Index);
+		Edit_Set_Index(m_Edit.Index);
 
 		Update_Views();
 
@@ -886,14 +915,14 @@ bool CWKSP_Shapes::_Edit_Shape_Stop(bool bSave)
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Shape_Add(void)
 {
-	if( !m_Edit_pShape )
+	if( !m_Edit.pShape )
 	{
 		if( Get_Shapes()->Get_Selection_Count() > 0 )
 		{
 			Get_Shapes()->Select();	// deselect
 		}
 
-		m_Edit_pShape	= m_Edit_Shapes.Add_Shape();
+		m_Edit.pShape = m_Edit.Shapes.Add_Shape();
 
 		return( _Edit_Part_Add() );
 	}
@@ -904,10 +933,10 @@ bool CWKSP_Shapes::_Edit_Shape_Add(void)
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Part_Add(void)
 {
-	if( m_Edit_pShape )
+	if( m_Edit.pShape )
 	{
-		m_Edit_iPart	= m_Edit_pShape->Get_Part_Count();
-		m_Edit_iPoint	= -1;
+		m_Edit.Part  = m_Edit.pShape->Get_Part_Count();
+		m_Edit.Point = -1;
 
 		Update_Views(false);
 
@@ -920,29 +949,24 @@ bool CWKSP_Shapes::_Edit_Part_Add(void)
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Shape_Del(void)
 {
-	if( DLG_Message_Confirm(_TL("Delete selected shape(s)."), _TL("Edit Shapes")) )
+	if( Get_Shapes()->Get_Selection_Count() > 0 && DLG_Message_Confirm(_TL("Delete selection?"), _TL("Edit Shapes")) )
 	{
-		if( Get_Shapes()->Get_Selection_Count() > 0 )
+		if( m_Edit.pShape )
 		{
-			if( m_Edit_pShape )
-			{
-				_Edit_Shape_Stop(false);
+			_Edit_Shape_Stop(false);
 
-				Get_Shapes()->Del_Shape(Get_Shapes()->Get_Selection(m_Edit_Index));
-			}
-			else
-			{
-				Get_Shapes()->Del_Selection();
-			}
-
-			Edit_Set_Index(0);
-
-			Update_Views();
-
-			return( true );
+			Get_Shapes()->Del_Shape((CSG_Shape *)Get_Shapes()->Get_Selection(m_Edit.Index));
+		}
+		else
+		{
+			Get_Shapes()->Del_Selection();
 		}
 
-		return( _Edit_Shape_Stop(false) );
+		Edit_Set_Index(0);
+
+		Update_Views();
+
+		return( true );
 	}
 
 	return( false );
@@ -951,14 +975,14 @@ bool CWKSP_Shapes::_Edit_Shape_Del(void)
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Part_Del(void)
 {
-	if( m_Edit_pShape && m_Edit_iPart >= 0 )
+	if( m_Edit.pShape && m_Edit.Part >= 0 )
 	{
-		if( m_Edit_pShape->Get_Part_Count() > 1 )
+		if( m_Edit.pShape->Get_Part_Count() > 1 )
 		{
-			m_Edit_pShape->Del_Part(m_Edit_iPart);
+			m_Edit.pShape->Del_Part(m_Edit.Part);
 
-			m_Edit_iPart	= -1;
-			m_Edit_iPoint	= -1;
+			m_Edit.Part  = -1;
+			m_Edit.Point = -1;
 
 			Update_Views(false);
 
@@ -976,22 +1000,22 @@ bool CWKSP_Shapes::_Edit_Part_Del(void)
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Point_Del(void)
 {
-	if( m_Edit_pShape && m_Edit_iPart >= 0 && m_Edit_iPoint >= 0 )
+	if( m_Edit.pShape && m_Edit.Part >= 0 && m_Edit.Point >= 0 )
 	{
-		if( m_Edit_pShape->Get_Point_Count(m_Edit_iPart) > 1 )
+		if( m_Edit.pShape->Get_Point_Count(m_Edit.Part) > 1 )
 		{
-			m_Edit_pShape->Del_Point(m_Edit_iPoint, m_Edit_iPart);
+			m_Edit.pShape->Del_Point(m_Edit.Point, m_Edit.Part);
 
-			if( m_Edit_iPoint >= m_Edit_pShape->Get_Point_Count(m_Edit_iPart) )
+			if( m_Edit.Point >= m_Edit.pShape->Get_Point_Count(m_Edit.Part) )
 			{
-				m_Edit_iPoint	= m_Edit_pShape->Get_Point_Count(m_Edit_iPart) - 1;
+				m_Edit.Point = m_Edit.pShape->Get_Point_Count(m_Edit.Part) - 1;
 			}
 
-			if( m_Edit_pShape->Get_Point_Count(m_Edit_iPart) <= 1 )
+			if( m_Edit.pShape->Get_Point_Count(m_Edit.Part) <= 1 )
 			{
 				if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Line || Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon )
 				{
-					m_Edit_iPoint	= -1;
+					m_Edit.Point = -1;
 				}
 			}
 
@@ -1010,9 +1034,9 @@ bool CWKSP_Shapes::_Edit_Point_Del(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1025,7 +1049,7 @@ void CWKSP_Shapes::_Edit_Shape_Draw_Point(wxDC &dc, int x, int y, bool bSelected
 {
 	dc.SetBrush(*wxTRANSPARENT_BRUSH);
 
-	dc.SetPen  (wxPen(m_Edit_Color));
+	dc.SetPen  (wxPen(m_Edit.Color));
 
 	dc.DrawCircle(x, y, 2);
 
@@ -1043,9 +1067,9 @@ void CWKSP_Shapes::_Edit_Shape_Draw_Point(wxDC &dc, int x, int y, bool bSelected
 			x + EDIT_TICKMARK_SIZE + 1, y + EDIT_TICKMARK_SIZE + 1
 		);
 	}
-	else if( m_Edit_bGleam )
+	else if( m_Edit.bGleam )
 	{
-		dc.SetPen(wxColour(255 - m_Edit_Color.Red(), 255 - m_Edit_Color.Green(), 255 - m_Edit_Color.Blue()));
+		dc.SetPen(wxColour(255 - m_Edit.Color.Red(), 255 - m_Edit.Color.Green(), 255 - m_Edit.Color.Blue()));
 
 		Draw_Edge(dc, EDGE_STYLE_SIMPLE,
 			x - EDIT_TICKMARK_SIZE + 1, y - EDIT_TICKMARK_SIZE + 1,
@@ -1076,19 +1100,19 @@ void CWKSP_Shapes::Edit_Shape_Draw_Move(wxDC &dc, const CSG_Rect &rWorld, const
 //---------------------------------------------------------
 void CWKSP_Shapes::Edit_Shape_Draw(CSG_Map_DC &dc_Map)
 {
-	if( m_Edit_pShape )
+	if( m_Edit.pShape )
 	{
-		for(int iPart=0; iPart<m_Edit_pShape->Get_Part_Count(); iPart++)
+		for(int iPart=0; iPart<m_Edit.pShape->Get_Part_Count(); iPart++)
 		{
-			for(int iPoint=0; iPoint<m_Edit_pShape->Get_Point_Count(iPart); iPoint++)
+			for(int iPoint=0; iPoint<m_Edit.pShape->Get_Point_Count(iPart); iPoint++)
 			{
-				_Edit_Shape_Draw_Point(dc_Map.Get_DC(), dc_Map.World2DC(m_Edit_pShape->Get_Point(iPoint, iPart)), false);
+				_Edit_Shape_Draw_Point(dc_Map.Get_DC(), dc_Map.World2DC(m_Edit.pShape->Get_Point(iPoint, iPart)), false);
 			}
 		}
 
-		if( m_Edit_iPart >= 0 && m_Edit_iPoint >= 0 )
+		if( m_Edit.Part >= 0 && m_Edit.Point >= 0 )
 		{
-			_Edit_Shape_Draw_Point(dc_Map.Get_DC(), dc_Map.World2DC(m_Edit_pShape->Get_Point(m_Edit_iPoint, m_Edit_iPart)), true);
+			_Edit_Shape_Draw_Point(dc_Map.Get_DC(), dc_Map.World2DC(m_Edit.pShape->Get_Point(m_Edit.Point, m_Edit.Part)), true);
 		}
 
 		if( m_Parameters("EDIT_SNAP_LIST")->asShapesList()->Get_Item_Count() > 0 )
@@ -1112,15 +1136,15 @@ void CWKSP_Shapes::Edit_Shape_Draw(CSG_Map_DC &dc_Map)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CWKSP_Shapes::_Edit_Snap_Point(CSG_Point &Point, double ClientToWorld)
 {
-	if( m_Edit_pShape )
+	if( m_Edit.pShape )
 	{
 		CSG_Parameter_Shapes_List *pList = m_Parameters("EDIT_SNAP_LIST")->asShapesList();
 
@@ -1159,84 +1183,78 @@ void CWKSP_Shapes::_Edit_Snap_Point(CSG_Point &Point, double ClientToWorld)
 //---------------------------------------------------------
 void CWKSP_Shapes::_Edit_Snap_Point(const CSG_Point &Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shapes *pShapes, bool bLine)
 {
-	CSG_Shape	*pSelected	= pShapes->Get_Selection(m_Edit_Index);
-
-	if( pShapes->Select(CSG_Rect(Point.x - snap_Dist, Point.y - snap_Dist, Point.x + snap_Dist, Point.y + snap_Dist)) )
+	if( m_Edit.pShape && pShapes )
 	{
-		for(sLong i=0; i<pShapes->Get_Selection_Count(); i++)
+		CSG_Rect Extent(Point.x - snap_Dist, Point.y - snap_Dist, Point.x + snap_Dist, Point.y + snap_Dist);
+
+		for(sLong i=0; i<pShapes->Get_Count(); i++)
 		{
-			if( pShapes != Get_Shapes() || pSelected != pShapes->Get_Selection(i) )
+			CSG_Shape *pShape = pShapes->Get_Shape(i);
+
+			if( pShape->Intersects(Extent) )
 			{
-				if( bLine )
+				if( pShapes != Get_Shapes() || m_Edit.pShape != pShape )
 				{
-					Edit_Snap_Point_ToLine(Point, snap_Point, snap_Dist, pShapes->Get_Selection(i));
-				}
-				else
-				{
-					_Edit_Snap_Point      (Point, snap_Point, snap_Dist, pShapes->Get_Selection(i));
+					if( bLine )
+					{
+						Edit_Snap_Point_ToLine(Point, snap_Point, snap_Dist, pShape);
+					}
+					else
+					{
+						_Edit_Snap_Point      (Point, snap_Point, snap_Dist, pShape);
+					}
 				}
 			}
 		}
 	}
-
-	pShapes->Select(pSelected);
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes::_Edit_Snap_Point(const CSG_Point &pos_Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shape *pShape)
+void CWKSP_Shapes::_Edit_Snap_Point(const CSG_Point &Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shape *pShape)
 {
-	int			iPart, iPoint;
-	double		d, dx, dy;
-	TSG_Point	Point;
+	bool bResult = false;
 
-	for(iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
+	for(int iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
 	{
-		for(iPoint=0; iPoint<pShape->Get_Point_Count(iPart); iPoint++)
+		for(int iPoint=0; iPoint<pShape->Get_Point_Count(iPart); iPoint++)
 		{
-			Point	= pShape->Get_Point(iPoint, iPart);
-			dx		= pos_Point.x - Point.x;
-			dy		= pos_Point.y - Point.y;
-			d		= sqrt(dx*dx + dy*dy);
+			CSG_Point p = pShape->Get_Point(iPoint, iPart); double d = Point.Get_Distance(p);
 
-			if( d < snap_Dist )
+			if( bResult ? (d < snap_Dist) : (d <= snap_Dist) )
 			{
-				snap_Dist	= d;
-				snap_Point	= Point;
+				snap_Dist = d; snap_Point = Point;
 			}
 		}
 	}
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes::Edit_Snap_Point_ToLine(CSG_Point pos_Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shape *pShape)
+void CWKSP_Shapes::Edit_Snap_Point_ToLine(const CSG_Point &Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shape *pShape)
 {}
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int CWKSP_Shapes::Edit_Shape_HitTest(CSG_Point pos_Point, double max_Dist, int &pos_iPart, int &pos_iPoint)
+int CWKSP_Shapes::Edit_Shape_HitTest(const CSG_Point &Point, double max_Dist, int &pos_iPart, int &pos_iPoint)
 {
-	int Result = 0; pos_iPoint = -1; pos_iPart  = -1;
+	int Result = 0; pos_iPoint = -1; pos_iPart = -1;
 
-	if( m_Edit_pShape )
+	if( m_Edit.pShape )
 	{
-		for(int iPart=0; iPart<m_Edit_pShape->Get_Part_Count(); iPart++)
+		for(int iPart=0; iPart<m_Edit.pShape->Get_Part_Count(); iPart++)
 		{
-			for(int iPoint=0; iPoint<m_Edit_pShape->Get_Point_Count(iPart); iPoint++)
+			for(int iPoint=0; iPoint<m_Edit.pShape->Get_Point_Count(iPart); iPoint++)
 			{
-				double d = SG_Get_Distance(pos_Point, m_Edit_pShape->Get_Point(iPoint, iPart));
+				double d = Point.Get_Distance(m_Edit.pShape->Get_Point(iPoint, iPart));
 
 				if( max_Dist < 0. || d < max_Dist )
 				{
-					max_Dist   = d;
-					pos_iPart  = iPart;
-					pos_iPoint = iPoint;
-					Result     = 1;
+					Result = 1; max_Dist = d; pos_iPart = iPart; pos_iPoint = iPoint;
 				}
 			}
 		}
@@ -1247,9 +1265,9 @@ int CWKSP_Shapes::Edit_Shape_HitTest(CSG_Point pos_Point, double max_Dist, int &
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
