@@ -63,9 +63,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -75,9 +75,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -91,7 +91,7 @@ CWKSP_Shapes_Point::CWKSP_Shapes_Point(CSG_Shapes *pShapes)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -99,248 +99,121 @@ void CWKSP_Shapes_Point::On_Create_Parameters(void)
 {
 	CWKSP_Shapes::On_Create_Parameters();
 
-	BrushList_Add("NODE_DISPLAY",
-		"DISPLAY_BRUSH"		, _TL("Fill Style"),
-		_TL("")
+	//-----------------------------------------------------
+	// Display...
+
+	BrushList_Add          ("NODE_DISPLAY", "DISPLAY_BRUSH", _TL("Fill Style"), _TL(""));
+
+	m_Parameters.Add_Bool  ("NODE_DISPLAY", "OUTLINE"      , _TL("Outline"   ), _TL(""), true)->Set_Collapsed();
+	m_Parameters.Add_Color ("OUTLINE"     , "OUTLINE_COLOR", _TL("Color"     ), _TL(""), SG_GET_RGB(0, 0, 0));
+	m_Parameters.Add_Int   ("OUTLINE"     , "OUTLINE_SIZE" , _TL("Size"      ), _TL(""), 1, 1, true);
+
+	m_Parameters.Add_Choice("NODE_DISPLAY", "DISPLAY_SYMBOL_TYPE", _TL("Symbol Type"), _TL(""), CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s",
+		_TL("circle"),
+		_TL("square"),
+		_TL("rhombus"),
+		_TL("triangle (up)"),
+		_TL("triangle (down)"),
+		_TL("circle with square"),
+		_TL("circle with rhombus"),
+		_TL("circle with triangle (up)"),
+		_TL("circle with triangle (down)"),
+		_TL("circle in square"),
+		_TL("circle in rhombus"),
+		_TL("circle in triangle (up)"),
+		_TL("circle in triangle (down)"),
+		_TL("image"),
+		_TL("arrow"),
+		_TL("beachball plot")), 0
 	);
 
-	m_Parameters.Add_Bool("NODE_DISPLAY",
-		"OUTLINE"			, _TL("Outline"),
-		_TL(""),
-		true
+	m_Parameters.Add_FilePath("DISPLAY_SYMBOL_TYPE", "DISPLAY_SYMBOL_IMAGE", _TL("Image Symbol File"), _TL(""), CSG_String::Format(
+		"%s|*.bmp;*.ico;*.gif;*.jpg;*.jif;*.jpeg;*.pcx;*.png;*.pnm;*.tif;*.tiff;*.xpm|"
+		"%s (*.png)|*.png|"
+		"%s (*.jpg)|*.jpg;*.jif;*.jpeg|"
+		"%s (*.tif)|*.tif;*.tiff|"
+		"%s (*.gif)|*.gif|"
+		"%s (*.bmp)|*.bmp|"
+		"%s (*.pcx)|*.pcx|"
+		"%s (*.xpm)|*.xpm|"
+		"%s|*.*",
+		_TL("Recognized File Types"      ),
+		_TL("Portable Network Graphics"  ),
+		_TL("JPEG - JFIF Compliant"      ),
+		_TL("Tagged Image File Format"   ),
+		_TL("Graphics Interchange Format"),
+		_TL("Windows or OS/2 Bitmap"     ),
+		_TL("Zsoft Paintbrush"           ),
+		_TL("X11 Pixel Map"              ),
+		_TL("All Files"                  ))
 	);
 
-	m_Parameters.Add_Color("OUTLINE",
-		"OUTLINE_COLOR"		, _TL("Color"),
-		_TL(""),
-		SG_GET_RGB(0, 0, 0)
-	);
-
-	m_Parameters.Add_Int("OUTLINE",
-		"OUTLINE_SIZE"		, _TL("Size"),
-		_TL(""),
-		1, 1, true
-	);
-
-	m_Parameters.Add_Choice("NODE_DISPLAY",
-		"DISPLAY_SYMBOL_TYPE"	, _TL("Symbol Type"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s",
-			_TL("circle"),
-			_TL("square"),
-			_TL("rhombus"),
-			_TL("triangle (up)"),
-			_TL("triangle (down)"),
-			_TL("circle with square"),
-			_TL("circle with rhombus"),
-			_TL("circle with triangle (up)"),
-			_TL("circle with triangle (down)"),
-			_TL("circle in square"),
-			_TL("circle in rhombus"),
-			_TL("circle in triangle (up)"),
-			_TL("circle in triangle (down)"),
-			_TL("image"),
-			_TL("arrow"),
-			_TL("beachball plot")
-		), 0
-	);
-
-	m_Parameters.Add_FilePath("DISPLAY_SYMBOL_TYPE",
-		"DISPLAY_SYMBOL_IMAGE"	, _TL("Image Symbol File"),
-		_TL(""),
-		CSG_String::Format(
-			"%s|*.bmp;*.ico;*.gif;*.jpg;*.jif;*.jpeg;*.pcx;*.png;*.pnm;*.tif;*.tiff;*.xpm|"
-			"%s (*.png)|*.png|"
-			"%s (*.jpg)|*.jpg;*.jif;*.jpeg|"
-			"%s (*.tif)|*.tif;*.tiff|"
-			"%s (*.gif)|*.gif|"
-			"%s (*.bmp)|*.bmp|"
-			"%s (*.pcx)|*.pcx|"
-			"%s (*.xpm)|*.xpm|"
-			"%s|*.*",
-			_TL("Recognized File Types"      ),
-			_TL("Portable Network Graphics"  ),
-			_TL("JPEG - JFIF Compliant"      ),
-			_TL("Tagged Image File Format"   ),
-			_TL("Graphics Interchange Format"),
-			_TL("Windows or OS/2 Bitmap"     ),
-			_TL("Zsoft Paintbrush"           ),
-			_TL("X11 Pixel Map"              ),
-			_TL("All Files"                  )
-		)
-	);
-
-	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "ARROW_DIRECTION"  , _TL("Direction"  ), _TL(""), _TL("<default>"));
+	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "ARROW_DIRECTION"  , _TL("Direction"  ), _TL(""), CSG_String::Format("<%s>", _TL("not set")));
 	m_Parameters.Add_Int   ("ARROW_DIRECTION"    , "ARROW_OFFSET"     , _TL("Offset"     ), _TL(""), 0.);
 	m_Parameters.Add_Choice("ARROW_DIRECTION"    , "ARROW_ORIENTATION", _TL("Orientation"), _TL(""), CSG_String::Format("%s|%s", _TL("clockwise"), _TL("counterclockwise")));
 	m_Parameters.Add_Choice("ARROW_DIRECTION"    , "ARROW_UNIT"       , _TL("Unit"       ), _TL(""), CSG_String::Format("%s|%s", _TL("degree"), _TL("radians")));
 	m_Parameters.Add_Choice("ARROW_DIRECTION"    , "ARROW_STYLE"      , _TL("Style"      ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("simple"), _TL("center"), _TL("circle")));
 	m_Parameters.Add_Int   ("ARROW_DIRECTION"    , "ARROW_WIDTH"      , _TL("Line Width" ), _TL(""), 2, 1, true);
 
-	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_STRIKE" , _TL("Strike"     ), _TL(""), _TL("<default>"));
-	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_DIP"    , _TL("Dip"        ), _TL(""), _TL("<default>"));
-	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_RAKE"   , _TL("Rake"       ), _TL(""), _TL("<default>"));
-
+	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_STRIKE" , _TL("Strike"     ), _TL(""), CSG_String::Format("<%s>", _TL("not set")));
+	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_DIP"    , _TL("Dip"        ), _TL(""), CSG_String::Format("<%s>", _TL("not set")));
+	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_RAKE"   , _TL("Rake"       ), _TL(""), CSG_String::Format("<%s>", _TL("not set")));
 
 	//-----------------------------------------------------
 	// Images...
 
-	m_Parameters.Add_Choice("NODE_DISPLAY",
-		"IMAGE_FIELD"			, _TL("Image Field"),
+	m_Parameters.Add_Choice("NODE_DISPLAY", "IMAGE_FIELD", _TL("Image Field"),
 		_TL("Field that provides file paths (either absolute or relative to this data set) to images to be displayed besides the points."),
-		_TL("<default>")
-	);
-
-	m_Parameters.Add_Choice("IMAGE_FIELD",
-		"IMAGE_ALIGN_X"			, _TL("Horizontal Align"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s",
-			_TL("left"),
-			_TL("center"),
-			_TL("right")
-		), 0
-	);
-
-	m_Parameters.Add_Choice("IMAGE_FIELD",
-		"IMAGE_ALIGN_Y"			, _TL("Vertical Align"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s",
-			_TL("top"),
-			_TL("center"),
-			_TL("bottom")
-		), 0
-	);
-
-	m_Parameters.Add_Double("IMAGE_FIELD",
-		"IMAGE_OFFSET"			, _TL("Offset"),
-		_TL("Offset distance to symbol relative to symbol's size."),
-		1., 0., true
-	);
-
-	m_Parameters.Add_Double("IMAGE_FIELD",
-		"IMAGE_SCALE"			, _TL("Size Scaling"),
-		_TL("Scales image size relative to symbol's size."),
-		10., 0.1, true
-	);
-
-	m_Parameters.Add_Choice("IMAGE_FIELD",
-		"IMAGE_FIT"				, _TL("Fit Size to..."),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s",
-			_TL("overall"),
-			_TL("width"),
-			_TL("height")
-		), 0
-	);
-
-
-	//-----------------------------------------------------
-	// Label...
-
-	m_Parameters.Add_Choice("LABEL_ATTRIB",
-		"LABEL_ANGLE_ATTRIB", _TL("Rotation by Attribute"),
-		_TL(""),
-		_TL("<default>")
-	);
-
-	m_Parameters.Add_Double("LABEL_ANGLE_ATTRIB",
-		"LABEL_ANGLE"		, _TL("Default Rotation"),
-		_TL("rotation clockwise in degree"),
-		0.0, -360.0, true, 360.0, true
-	);
-
-	m_Parameters.Add_Choice("LABEL_ATTRIB",
-		"LABEL_ALIGN_X"		, _TL("Horizontal Align"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s",
-			_TL("left"),
-			_TL("center"),
-			_TL("right")
-		), 1
-	);
-
-	m_Parameters.Add_Choice("LABEL_ATTRIB",
-		"LABEL_ALIGN_Y"		, _TL("Vertical Align"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s",
-			_TL("top"),
-			_TL("center"),
-			_TL("bottom")
-		), 0
-	);
-
-	m_Parameters.Add_Double("LABEL_ATTRIB",
-		"LABEL_OFFSET"		, _TL("Offset"),
-		_TL("Offset distance to symbol (either screen or map units)."),
-		0., 0., true
+		CSG_String::Format("<%s>", _TL("not set"))
 	);
 
+	m_Parameters.Add_Choice("IMAGE_FIELD", "IMAGE_ALIGN_X", _TL("Horizontal Align"), _TL(""), CSG_String::Format("%s|%s|%s", _TL("left"), _TL("center"), _TL("right" )), 0);
+	m_Parameters.Add_Choice("IMAGE_FIELD", "IMAGE_ALIGN_Y", _TL("Vertical Align"  ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("top" ), _TL("center"), _TL("bottom")), 0);
+	m_Parameters.Add_Double("IMAGE_FIELD", "IMAGE_OFFSET" , _TL("Offset"          ), _TL("Offset distance to symbol relative to symbol's size."), 1., 0., true);
+	m_Parameters.Add_Double("IMAGE_FIELD", "IMAGE_SCALE"  , _TL("Size Scaling"    ), _TL("Scales image size relative to symbol's size."), 10., 0.1, true);
+	m_Parameters.Add_Choice("IMAGE_FIELD", "IMAGE_FIT"    , _TL("Fit Size to..."  ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("overall"), _TL("width"), _TL("height")), 0);
 
 	//-----------------------------------------------------
 	// Size...
 
-	m_Parameters.Add_Choice("NODE_SIZE",
-		"SIZE_TYPE"			, _TL("Size relates to..."),
-		_TL(""),
-		CSG_String::Format("%s|%s",
-			_TL("Screen"),
-			_TL("Map Units")
-		), 0
-	);
+	m_Parameters.Add_Choice("NODE_SIZE" , "SIZE_FIELD"  , _TL("Field"             ), _TL(""), CSG_String::Format("<%s>", _TL("not set")));
+	m_Parameters.Add_Choice("SIZE_FIELD", "SIZE_SCALE"  , _TL("Field Values"      ), _TL(""), CSG_String::Format("%s|%s", _TL("take as size"), _TL("scale to size range")), 1);
+	m_Parameters.Add_Range ("SIZE_FIELD", "SIZE_RANGE"  , _TL("Size Range"        ), _TL(""), 2., 10., 0., true);
+	m_Parameters.Add_Double("NODE_SIZE" , "SIZE_DEFAULT", _TL("Size"              ), _TL(""), 5., 0., true);
+	m_Parameters.Add_Choice("NODE_SIZE" , "SIZE_TYPE"   , _TL("Size relates to..."), _TL(""), CSG_String::Format("%s|%s", _TL("Screen"), _TL("Map Units")), 0);
 
-	m_Parameters.Add_Choice("NODE_SIZE",
-		"SIZE_ATTRIB"		, _TL("Attribute"),
-		_TL(""),
-		_TL("<default>")
-	);
-
-	m_Parameters.Add_Choice("SIZE_ATTRIB",
-		"SIZE_SCALE"		, _TL("Attribute Values"),
-		_TL(""),
-		CSG_String::Format("%s|%s",
-			_TL("take as size"),
-			_TL("scale to size range")
-		), 1
-	);
-
-	m_Parameters.Add_Range("SIZE_ATTRIB",
-		"SIZE_RANGE"		, _TL("Size Range"),
-		_TL(""),
-		2., 10., 0., true
-	);
-
-	m_Parameters.Add_Double("SIZE_ATTRIB",
-		"SIZE_DEFAULT"		, _TL("Default Size"),
-		_TL(""),
-		5., 0., true
-	);
+	//-----------------------------------------------------
+	// Label...
 
+	m_Parameters.Add_Choice("LABEL_FIELD"      , "LABEL_ANGLE_FIELD", _TL("Rotation Value"  ), _TL(""), CSG_String::Format("<%s>", _TL("not set")));
+	m_Parameters.Add_Double("LABEL_ANGLE_FIELD", "LABEL_ANGLE"      , _TL("Default Rotation"), _TL("rotation clockwise in degree"), 0., -360., true, 360., true);
+	m_Parameters.Add_Node  ("LABEL_FIELD"      , "LABEL_PLACEMENT"  , _TL("Placement"       ), _TL(""));
+	m_Parameters.Add_Choice("LABEL_PLACEMENT"  , "LABEL_PLACEMENT_X", _TL("Horizontal"      ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("left" ), _TL("center"), _TL("right")), 1);
+	m_Parameters.Add_Double("LABEL_PLACEMENT_X", "LABEL_OFFSET_X"   , _TL("Offset"          ), _TL("Offset distance to symbol (either screen or map units)."), 0., 0., true);
+	m_Parameters.Add_Choice("LABEL_PLACEMENT"  , "LABEL_PLACEMENT_Y", _TL("Vertical"        ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("above"), _TL("center"), _TL("below")), 2);
+	m_Parameters.Add_Double("LABEL_PLACEMENT_Y", "LABEL_OFFSET_Y"   , _TL("Offset"          ), _TL("Offset distance to symbol (either screen or map units)."), 0., 0., true);
 
 	//-----------------------------------------------------
 	// Edit...
 
-	m_Parameters.Add_Color("NODE_SELECTION",
-		"SEL_COLOR_FILL"	, _TL("Fill Color"),
-		_TL(""),
-		SG_GET_RGB(255, 255, 0)
-	);
+	m_Parameters.Add_Color("NODE_SELECTION", "SEL_COLOR_FILL", _TL("Fill Color"), _TL(""), SG_GET_RGB(255, 255, 0));
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CWKSP_Shapes_Point::On_DataObject_Changed(void)
 {
-	AttributeList_Set(m_Parameters("IMAGE_FIELD"       ),  true);
-	AttributeList_Set(m_Parameters("SIZE_ATTRIB"       ),  true);
-	AttributeList_Set(m_Parameters("LABEL_ANGLE_ATTRIB"),  true);
-	AttributeList_Set(m_Parameters("ARROW_DIRECTION"   ), false);
-	AttributeList_Set(m_Parameters("BEACHBALL_STRIKE"  ), false);
-	AttributeList_Set(m_Parameters("BEACHBALL_DIP"     ), false);
-	AttributeList_Set(m_Parameters("BEACHBALL_RAKE"    ), false);
+	Set_Fields_Choice(m_Parameters("IMAGE_FIELD"      ), false,  true);
+	Set_Fields_Choice(m_Parameters("SIZE_FIELD"       ),  true,  true);
+	Set_Fields_Choice(m_Parameters("LABEL_ANGLE_FIELD"),  true,  true);
+	Set_Fields_Choice(m_Parameters("ARROW_DIRECTION"  ),  true, false);
+	Set_Fields_Choice(m_Parameters("BEACHBALL_STRIKE" ),  true, false);
+	Set_Fields_Choice(m_Parameters("BEACHBALL_DIP"    ),  true, false);
+	Set_Fields_Choice(m_Parameters("BEACHBALL_RAKE"   ),  true, false);
 
 	CWKSP_Shapes::On_DataObject_Changed();
 }
@@ -369,7 +242,7 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 
 	//-----------------------------------------------------
 	case SYMBOL_TYPE_Arrow:
-		m_Arrow.Field       = m_Parameters("ARROW_DIRECTION"  )->asInt   ();
+		m_Arrow.Field       = Get_Fields_Choice(m_Parameters("ARROW_DIRECTION"));
 		m_Arrow.Offset      = m_Parameters("ARROW_OFFSET"     )->asDouble();
 		m_Arrow.Orientation = m_Parameters("ARROW_ORIENTATION")->asInt   ();
 		m_Arrow.Unit        = m_Parameters("ARROW_UNIT"       )->asInt   ();
@@ -379,9 +252,9 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 
 	//-----------------------------------------------------
 	case SYMBOL_TYPE_Beachball:
-		m_Beachball.Strike  = m_Parameters("BEACHBALL_STRIKE" )->asInt   ();
-		m_Beachball.Dip     = m_Parameters("BEACHBALL_DIP"    )->asInt   ();
-		m_Beachball.Rake    = m_Parameters("BEACHBALL_RAKE"   )->asInt   ();
+		m_Beachball.Strike  = Get_Fields_Choice(m_Parameters("BEACHBALL_STRIKE"));
+		m_Beachball.Dip     = Get_Fields_Choice(m_Parameters("BEACHBALL_DIP"   ));
+		m_Beachball.Rake    = Get_Fields_Choice(m_Parameters("BEACHBALL_RAKE"  ));
 		break;
 	}
 
@@ -417,7 +290,7 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 	m_Size.Unit   = m_Parameters("SIZE_TYPE" )->asInt(); // screen pixels, map units
 	m_Size.Adjust = m_Parameters("SIZE_SCALE")->asInt(); // adjust to size range
 
-	if( (m_Size.Field = m_Parameters("SIZE_ATTRIB")->asInt()) < Get_Shapes()->Get_Field_Count()
+	if( (m_Size.Field = Get_Fields_Choice(m_Parameters("SIZE_FIELD"))) >= 0
 	&&  (m_Size.Scale = Get_Shapes()->Get_Maximum(m_Size.Field) - Get_Shapes()->Get_Minimum(m_Size.Field)) > 0. )
 	{
 		m_Size.Offset  =  m_Parameters("SIZE_RANGE.MIN")->asDouble();
@@ -433,26 +306,22 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 	}
 
 	//-----------------------------------------------------
-	switch( m_Parameters("LABEL_ALIGN_X")->asInt() )
+	switch( m_Parameters("LABEL_PLACEMENT_X")->asInt() )
 	{
-	default: m_Label.Align  = TEXTALIGN_LEFT   ; break;
-	case  1: m_Label.Align  = TEXTALIGN_XCENTER; break;
-	case  2: m_Label.Align  = TEXTALIGN_RIGHT  ; break;
+	default: m_Label_Point.Align  = TEXTALIGN_LEFT   ; break;
+	case  1: m_Label_Point.Align  = TEXTALIGN_XCENTER; break;
+	case  0: m_Label_Point.Align  = TEXTALIGN_RIGHT  ; break;
 	}
 
-	switch( m_Parameters("LABEL_ALIGN_Y")->asInt() )
+	switch( m_Parameters("LABEL_PLACEMENT_Y")->asInt() )
 	{
-	default: m_Label.Align |= TEXTALIGN_TOP    ; break;
-	case  1: m_Label.Align |= TEXTALIGN_YCENTER; break;
-	case  2: m_Label.Align |= TEXTALIGN_BOTTOM ; break;
+	default: m_Label_Point.Align |= TEXTALIGN_TOP    ; break;
+	case  1: m_Label_Point.Align |= TEXTALIGN_YCENTER; break;
+	case  0: m_Label_Point.Align |= TEXTALIGN_BOTTOM ; break;
 	}
 
-	m_Label.Angle = m_Parameters("LABEL_ANGLE")->asDouble();
-
-	if( (m_Label.Angle_Field = m_Parameters("LABEL_ANGLE_ATTRIB")->asInt()) >= Get_Shapes()->Get_Field_Count() )
-	{
-		m_Label.Angle_Field = -1;
-	}
+	m_Label_Point.Angle       = m_Parameters("LABEL_ANGLE")->asDouble();
+	m_Label_Point.Angle_Field = Get_Fields_Choice(m_Parameters("LABEL_ANGLE_FIELD"));
 
 	//-----------------------------------------------------
 	m_bOutline = m_Parameters("OUTLINE")->asBool();
@@ -462,7 +331,7 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -473,16 +342,7 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 	{
 		if(	pParameter->Cmp_Identifier("COLORS_FONT") )
 		{
-			Set_Metrics(
-				(*pParameters)("METRIC_ATTRIB")->asInt(),
-				(*pParameters)("METRIC_NORMAL")->asInt(),
-				(*pParameters)("METRIC_NORFMT")->asInt()
-			);
-
-			(*pParameters)("METRIC_ZRANGE")->asRange()->Set_Range(
-				m_Metrics.Get_Minimum(),
-				m_Metrics.Get_Maximum()
-			);
+			return( CWKSP_Shapes::On_Parameter_Changed(pParameters, (*pParameters)("METRIC_FIELD"), Flags) );
 		}
 	}
 
@@ -500,30 +360,37 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 			pParameters->Set_Enabled("BEACHBALL_RAKE"      , Value == SYMBOL_TYPE_Beachball);
 		}
 
-		if(	pParameter->Cmp_Identifier("LABEL_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("LABEL_FIELD") )
 		{
 			bool Value = pParameter->asInt() < Get_Shapes()->Get_Field_Count();
 
-			pParameters->Set_Enabled("LABEL_ANGLE_ATTRIB"  , Value);
+			pParameters->Set_Enabled("LABEL_ANGLE_FIELD"   , Value);
 			pParameters->Set_Enabled("LABEL_ANGLE"         , Value);
-			pParameters->Set_Enabled("LABEL_ALIGN_X"       , Value);
-			pParameters->Set_Enabled("LABEL_ALIGN_Y"       , Value);
+			pParameters->Set_Enabled("LABEL_PLACEMENT"     , Value);
 		}
 
-		if(	pParameter->Cmp_Identifier("LABEL_ANGLE_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("LABEL_PLACEMENT_X") )
 		{
-			bool Value = pParameter->asInt() >= Get_Shapes()->Get_Field_Count();
-
-			pParameters->Set_Enabled("LABEL_ANGLE"         , Value);
+			pParameters->Set_Enabled("LABEL_OFFSET_X"      , pParameter->asInt() != 1);
 		}
 
-		if(	pParameter->Cmp_Identifier("SIZE_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("LABEL_PLACEMENT_Y") )
 		{
-			bool Value = pParameter->asInt() < Get_Shapes()->Get_Field_Count();
+			pParameters->Set_Enabled("LABEL_OFFSET_Y"      , pParameter->asInt() != 1);
+		}
 
-			pParameters->Set_Enabled("SIZE_SCALE"          , Value ==  true);
-			pParameters->Set_Enabled("SIZE_RANGE"          , Value ==  true);
-			pParameters->Set_Enabled("SIZE_DEFAULT"        , Value == false);
+		if(	pParameter->Cmp_Identifier("LABEL_ANGLE_FIELD") )
+		{
+			pParameters->Set_Enabled("LABEL_ANGLE"         , Get_Fields_Choice(pParameter) < 0);
+		}
+
+		if(	pParameter->Cmp_Identifier("SIZE_FIELD") )
+		{
+			int Value = Get_Fields_Choice(pParameter);
+
+			pParameters->Set_Enabled("SIZE_SCALE"          , Value >= 0);
+			pParameters->Set_Enabled("SIZE_RANGE"          , Value >= 0);
+			pParameters->Set_Enabled("SIZE_DEFAULT"        , Value <  0);
 		}
 
 		if( pParameter->Cmp_Identifier("SIZT_SCALE") )
@@ -542,7 +409,7 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -568,7 +435,7 @@ bool CWKSP_Shapes_Point::Get_Style_Size(int &minSize, int &maxSize, double &Mini
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -592,18 +459,18 @@ inline void CWKSP_Shapes_Point::Draw_Initialize(CSG_Map_DC &dc_Map, int Flags)
 }
 
 //---------------------------------------------------------
-inline bool CWKSP_Shapes_Point::Draw_Initialize(CSG_Map_DC &dc_Map, int &Size, CSG_Shape *pShape, int Selection)
+inline bool CWKSP_Shapes_Point::Draw_Initialize(CSG_Map_DC &dc_Map, int &Size, CSG_Shape *pShape, int Flags)
 {
-	if( m_Brush.IsTransparent() && !m_bOutline && !Selection )
+	if( m_Brush.IsTransparent() && !m_bOutline && (Flags & LAYER_DRAW_FLAG_SELECTION) == 0 )
 	{
 		return( false ); // nothing to draw !
 	}
 
 	//-----------------------------------------------------
-	if( Selection )
+	if( (Flags & LAYER_DRAW_FLAG_SELECTION) != 0 )
 	{
 		dc_Map.SetBrush(wxBrush(m_Sel_Color_Fill, m_Brush.GetStyle()));
-		dc_Map.SetPen(wxPen(m_Sel_Color, Selection == 1 ? 2 : 0, wxPENSTYLE_SOLID));
+		dc_Map.SetPen(wxPen(m_Sel_Color, (Flags & LAYER_DRAW_FLAG_HIGHLIGHT) != 0 ? 2 : 0, wxPENSTYLE_SOLID));
 	}
 	else
 	{
@@ -638,15 +505,13 @@ inline bool CWKSP_Shapes_Point::Draw_Initialize(CSG_Map_DC &dc_Map, int &Size, C
 	}
 
 	//-----------------------------------------------------
-	m_Label.Offset = m_Parameters("LABEL_OFFSET")->asDouble();
+	m_Label_Point.Offset.x = m_Parameters("LABEL_OFFSET_X")->asDouble();
+	m_Label_Point.Offset.y = m_Parameters("LABEL_OFFSET_Y")->asDouble();
 
-	if( m_Label.Offset > 0. )
+	switch( m_Parameters("LABEL_FIELD_SIZE_TYPE")->asInt() )
 	{
-		switch( m_Parameters("LABEL_ATTRIB_SIZE_TYPE")->asInt() )
-		{
-		default: m_Label.Offset *= dc_Map.Scale   (); break;
-		case  1: m_Label.Offset *= dc_Map.World2DC(); break;
-		}
+	default: m_Label_Point.Offset *= dc_Map.Scale   (); break;
+	case  1: m_Label_Point.Offset *= dc_Map.World2DC(); break;
 	}
 
 	//-----------------------------------------------------
@@ -667,7 +532,7 @@ inline bool CWKSP_Shapes_Point::Draw_Initialize(CSG_Map_DC &dc_Map, int &Size, C
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes_Point::Draw_Shape(CSG_Map_DC &dc_Map, CSG_Shape *pShape, int Selection)
+void CWKSP_Shapes_Point::Draw_Shape(CSG_Map_DC &dc_Map, CSG_Shape *pShape, int Flags)
 {
 	if( m_Size.Field >= 0 && pShape->is_NoData(m_Size.Field) )
 	{
@@ -677,7 +542,7 @@ void CWKSP_Shapes_Point::Draw_Shape(CSG_Map_DC &dc_Map, CSG_Shape *pShape, int S
 	//-----------------------------------------------------
 	int Size;
 
-	if( !Draw_Initialize(dc_Map, Size, pShape, Selection) )
+	if( !Draw_Initialize(dc_Map, Size, pShape, Flags) )
 	{
 		return;
 	}
@@ -702,7 +567,7 @@ void CWKSP_Shapes_Point::Draw_Shape(CSG_Map_DC &dc_Map, CSG_Shape *pShape, int S
 			{
 				wxRect r(p.x - sx, p.y - sy, 2 * sx, 2 * sy);
 
-				if( Selection )
+				if( (Flags & LAYER_DRAW_FLAG_SELECTION) != 0 )
 				{
 					r.Inflate(1); dc_Map.DrawRectangle(r);
 				}
@@ -736,13 +601,13 @@ void CWKSP_Shapes_Point::Draw_Shape(CSG_Map_DC &dc_Map, CSG_Shape *pShape, int S
 	}
 
 	//---------------------------------------------
-	if( m_Image.Field >= 0 )
+	if( (Flags & LAYER_DRAW_FLAG_THUMBNAIL) == 0 && m_Image.Field >= 0 )
 	{
 		_Image_Draw(dc_Map, p.x, p.y, Size, pShape->asString(m_Image.Field));
 	}
 
 	//---------------------------------------------
-	if( Selection )
+	if( (Flags & LAYER_DRAW_FLAG_SELECTION) != 0 )
 	{
 		dc_Map.SetBrush(m_Brush);
 		dc_Map.SetPen  (m_Pen  );
@@ -754,23 +619,26 @@ void CWKSP_Shapes_Point::Draw_Label(CSG_Map_DC &dc_Map, CSG_Shape *pShape, const
 {
 	TSG_Point_Int p(dc_Map.World2DC(pShape->Get_Point()));
 
-	if( m_Label.Offset > 0. )
+	if( m_Label_Point.Offset.x > 0. )
 	{
-		if( (m_Label.Align & TEXTALIGN_LEFT  ) != 0 ) p.x += m_Label.Offset; else
-		if( (m_Label.Align & TEXTALIGN_RIGHT ) != 0 ) p.x -= m_Label.Offset;
-
-		if( (m_Label.Align & TEXTALIGN_TOP   ) != 0 ) p.y += m_Label.Offset; else
-		if( (m_Label.Align & TEXTALIGN_BOTTOM) != 0 ) p.y -= m_Label.Offset;
+		if( (m_Label_Point.Align & TEXTALIGN_LEFT  ) != 0 ) p.x += m_Label_Point.Offset.x; else
+		if( (m_Label_Point.Align & TEXTALIGN_RIGHT ) != 0 ) p.x -= m_Label_Point.Offset.x;
 	}
 
-	double Angle = m_Label.Angle_Field < 0 ? m_Label.Angle : pShape->asDouble(m_Label.Angle_Field);
+	if( m_Label_Point.Offset.y > 0. )
+	{
+		if( (m_Label_Point.Align & TEXTALIGN_TOP   ) != 0 ) p.y += m_Label_Point.Offset.y; else
+		if( (m_Label_Point.Align & TEXTALIGN_BOTTOM) != 0 ) p.y -= m_Label_Point.Offset.y;
+	}
 
-	dc_Map.DrawText(m_Label.Align, p.x, p.y, Angle, Label, m_Label_Eff, m_Label_Eff_Color, m_Label_Eff_Size);
+	double Angle = m_Label_Point.Angle_Field < 0 ? m_Label_Point.Angle : pShape->asDouble(m_Label_Point.Angle_Field);
+
+	dc_Map.DrawText(m_Label_Point.Align, p.x, p.y, Angle, Label, m_Label.Effect, m_Label.Effect_Color, m_Label.Effect_Size);
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -858,7 +726,7 @@ void CWKSP_Shapes_Point::Draw_Symbol(CSG_Map_DC &dc, int x, int y, int Size)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -918,7 +786,7 @@ void CWKSP_Shapes_Point::_Image_Draw(CSG_Map_DC &dc_Map, int x, int y, int size,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -973,7 +841,7 @@ void CWKSP_Shapes_Point::_Arrow_Draw(CSG_Map_DC &dc_Map, int x, int y, int size,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1118,9 +986,9 @@ void CWKSP_Shapes_Point::_Beachball_Get_Scaled(CSG_Shape *pShape, double x, doub
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
