@@ -64,9 +64,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -77,13 +77,20 @@ CWKSP_Shapes_Type::CWKSP_Shapes_Type(TSG_Shape_Type Type)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 wxString CWKSP_Shapes_Type::Get_Name(void)
 {
-	return( SG_Get_ShapeType_Name(m_Shape_Type).c_str() );
+	switch( m_Shape_Type )
+	{
+	case SHAPE_TYPE_Point  : return( _TL("Points"         ) );
+	case SHAPE_TYPE_Points : return( _TL("Multiple Points") );
+	case SHAPE_TYPE_Line   : return( _TL("Lines"          ) );
+	case SHAPE_TYPE_Polygon: return( _TL("Polygons"       ) );
+	default                : return( _TL("Features"       ) );
+	}
 }
 
 //---------------------------------------------------------
@@ -115,7 +122,7 @@ wxMenu * CWKSP_Shapes_Type::Get_Menu(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -154,9 +161,9 @@ CWKSP_Shapes * CWKSP_Shapes_Type::Add_Data(CSG_Shapes *pObject)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
