@@ -64,9 +64,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -74,9 +74,9 @@ CWKSP_Tool *g_pTool = NULL;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -108,7 +108,7 @@ CWKSP_Tool::~CWKSP_Tool(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -188,7 +188,7 @@ CSG_Parameters * CWKSP_Tool::Get_Parameters(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -234,7 +234,7 @@ bool CWKSP_Tool::On_Command(int Cmd_ID)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -245,7 +245,7 @@ void CWKSP_Tool::Set_Menu_ID(int Menu_ID)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -262,7 +262,7 @@ bool CWKSP_Tool::is_Executing(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -278,7 +278,7 @@ bool CWKSP_Tool::Set_Projection(const CSG_Projection &Projection)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -320,20 +320,18 @@ bool CWKSP_Tool::Execute(bool bDialog)
 
 	if( m_pTool->On_Before_Execution() )
 	{
-		#ifndef __WXMAC__
-		g_pTools->Set_Recently_Used(this);
-		#endif
-
 		if( !bDialog || DLG_Parameters(m_pTool->Get_Parameters(), "", m_pTool->Get_Summary(false).c_str()) )
 		{
+			#ifndef __WXMAC__
+			g_pTools->Add_Recent(this);
+			#endif
+
 			MSG_General_Add_Line(); MSG_Execution_Add_Line(); STATUSBAR_Set_Text(m_pTool->Get_Name().w_str());
 
 			bResult	= m_pTool->Execute(true);
 
 			SG_UI_ProgressAndMsg_Reset();
 
-			g_pActive->Get_Parameters()->Update_Parameters(m_pTool->Get_Parameters(), false);
-
 			if( g_pTools && g_pTools->Do_Beep() )
 			{
 				Do_Beep();
@@ -341,6 +339,12 @@ bool CWKSP_Tool::Execute(bool bDialog)
 		}
 
 		m_pTool->On_After_Execution();
+
+		g_pActive->Get_Parameters()->Update_Parameters(m_pTool->Get_Parameters(), false);
+
+		#ifdef __WXMAC__
+		g_pTools->Add_Recent(this);
+		#endif
 	}
 
 	if( !bResult || !m_pTool->is_Interactive() )
@@ -384,9 +388,9 @@ bool CWKSP_Tool::Finish(bool bDialog, bool bCloseGUI)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -414,7 +418,7 @@ void CWKSP_Tool::Save_to_Script(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -584,9 +588,9 @@ void CWKSP_Tool::Save_to_Clipboard(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
