@@ -139,6 +139,32 @@ CWKSP_Tool_Manager::CWKSP_Tool_Manager(void)
 	//-----------------------------------------------------
 	m_Parameters.Add_Node("", "NODE_TOOLS", _TL("Tools"), _TL(""));
 
+	m_Parameters.Add_Choice("NODE_TOOLS",
+		"RECENT_LIST"    , _TL("Recent Tools"),
+		_TL("Choose how to list recently used tools in geoprocessing menu."),
+		CSG_String::Format("%s|%s|%s",
+			_TL("append to top-level menu"),
+			_TL("list in sub menu"),
+			_TL("do not list")
+		), 1
+	);
+
+	m_Parameters.Add_Bool("RECENT_LIST",
+		"RECENT_RESTORE" , _TL("Restore"),
+		_TL("Save list of recently used tools to configuration and restore it on next program start."),
+		true
+	);
+
+	#ifdef __WXMAC__
+	m_Parameters["RECENT_LIST"].Set_Value(2); // here default is not to list!
+	#endif
+
+	m_Parameters.Add_Bool("NODE_TOOLS",
+		"MANAGEMENT_MENU", _TL("Management Menu"),
+		_TL(""),
+		false
+	);
+
 	m_Parameters.Add_Bool("NODE_TOOLS",
 		"BEEP"           , _TL("Beep when finished"),
 		_TL(""),
@@ -305,12 +331,17 @@ bool CWKSP_Tool_Manager::Initialise(void)
 	}
 
 	//-----------------------------------------------------
-	if( SG_Get_Tool_Library_Manager().Get_Count() == 0 )
+	bool bResult = SG_Get_Tool_Library_Manager().Get_Count() > 0 ? _Update(false) : _Reload();
+
+	if( bResult )
 	{
-		return( _Reload() );
+		if( m_Parameters("RECENT_RESTORE")->asBool() )
+		{
+			m_pMenu_Tools->Load_Recent();
+		}
 	}
 
-	return( _Update(false) );
+	return( bResult );
 }
 
 //---------------------------------------------------------
@@ -367,6 +398,8 @@ bool CWKSP_Tool_Manager::Finalise(void)
 		}
 	}
 
+	m_pMenu_Tools->Save_Recent();
+
 	return( true );
 }
 
@@ -499,17 +532,22 @@ bool CWKSP_Tool_Manager::On_Command(int Cmd_ID)
 	{
 	default: return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
 
-	case ID_CMD_TOOL_OPEN  :
-		Open();
-		break;
+	case ID_CMD_TOOL_OPEN     : Open(); break;
+	case ID_CMD_TOOL_CLOSE_ALL: g_pTool_Ctrl->Del_Item(this, false); break;
+	case ID_CMD_TOOL_RELOAD   : _Reload(); break;
 
-	case ID_CMD_TOOL_RELOAD:
-		_Reload();
-		break;
-
-	case ID_CMD_TOOL_SEARCH:
+	//-----------------------------------------------------
+	case ID_CMD_TOOL_RUN      :
+		if( g_pTool != NULL )
 		{
-			CWKSP_Base_Item	*pItem	= g_pTool_Ctrl->Search_Item(_TL("Run Tool"), WKSP_ITEM_Tool);
+			g_pTool->Execute(true);
+
+			break;
+		}
+
+	case ID_CMD_TOOL_SEARCH   :
+		{
+			CWKSP_Base_Item	*pItem	= g_pTool_Ctrl->Search_Item(_TL("Find and Run Tool"), WKSP_ITEM_Tool);
 
 			if( pItem && pItem->GetId().IsOk() && pItem->Get_Type() == WKSP_ITEM_Tool )
 			{
@@ -518,6 +556,7 @@ bool CWKSP_Tool_Manager::On_Command(int Cmd_ID)
 		}
 		break;
 
+	//-----------------------------------------------------
 	case ID_CMD_TOOL_SAVE_DOCS:
 		{
 			wxString Path;
@@ -561,11 +600,16 @@ bool CWKSP_Tool_Manager::On_Command_UI(wxUpdateUIEvent &event)
 	else switch( event.GetId() )
 	{
 	case ID_CMD_WKSP_ITEM_CLOSE:
+	case ID_CMD_TOOL_CLOSE_ALL :
 	case ID_CMD_TOOL_SEARCH    :
 	case ID_CMD_TOOL_SAVE_DOCS :
 		event.Enable(Get_Count() > 0 && g_pTool == NULL);
 		break;
 
+	case ID_CMD_TOOL_RUN       :
+		event.Enable(Get_Count() > 0); event.Check(g_pTool != NULL);
+		break;
+
 	default: return( CWKSP_Base_Manager::On_Command_UI(event) );
 	}
 
@@ -610,6 +654,47 @@ CWKSP_Tool_Library * CWKSP_Tool_Manager::Get_Library(CSG_Tool_Library *pLibrary)
 	return( NULL );
 }
 
+//---------------------------------------------------------
+CWKSP_Tool_Library * CWKSP_Tool_Manager::Get_Library(const wxString &Library, bool bChain)
+{
+	for(int i=0; i<Get_Count(); i++)
+	{
+		CWKSP_Tool_Group *pGroup = Get_Group(i);
+
+		for(int j=0; j<pGroup->Get_Count(); j++)
+		{
+			CSG_Tool_Library *pLibrary = pGroup->Get_Library(j)->Get_Library();
+
+			if( Library == pLibrary->Get_Library_Name().c_str() && pLibrary->Get_Type() == (bChain ? ESG_Library_Type::Chain : ESG_Library_Type::Library) )
+			{
+				return( pGroup->Get_Library(j) );
+			}
+		}
+	}
+
+	return( NULL );
+}
+
+//---------------------------------------------------------
+CWKSP_Tool * CWKSP_Tool_Manager::Get_Tool(const wxString &Library, const wxString &Tool)
+{
+	CWKSP_Tool_Library *pLibrary = Get_Library(Library, false);
+
+	CWKSP_Tool *pTool = pLibrary ? pLibrary->Get_Tool(Tool) : NULL;
+
+	if( !pTool && (pLibrary = Get_Library(Library, true)) )
+	{
+		pTool = pLibrary->Get_Tool(Tool);
+	}
+
+	return( pTool );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 bool CWKSP_Tool_Manager::_Reload(void)
 {
@@ -699,9 +784,9 @@ wxMenu * CWKSP_Tool_Manager::Get_Menu_Tools(void)
 }
 
 //---------------------------------------------------------
-void CWKSP_Tool_Manager::Set_Recently_Used(CWKSP_Tool *pTool)
+void CWKSP_Tool_Manager::Add_Recent(CWKSP_Tool *pTool)
 {
-	m_pMenu_Tools->Set_Recent(pTool);
+	m_pMenu_Tools->Add_Recent(pTool);
 }
 
 
