@@ -93,15 +93,9 @@ CGrid_Levels_Interpolation::CGrid_Levels_Interpolation(void)
 		_TL("")
 	)->asTable()->Add_Field(_TL("Height"), SG_DATATYPE_Double);
 
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"H_METHOD"		, _TL("Horizontal Interpolation Method"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_Choice("",
@@ -181,24 +175,18 @@ int CGrid_Levels_Interpolation::On_Parameters_Enable(CSG_Parameters *pParameters
 //---------------------------------------------------------
 bool CGrid_Levels_Interpolation::Initialize(const CSG_Rect &Extent)
 {
-	m_pVariables		= Parameters("VARIABLE"     )->asGridList();
-	m_pXGrids			= Parameters("X_GRIDS"      )->asGridList();
-	m_pXTable			= Parameters("X_TABLE"      )->asTable();
+	m_pVariables     = Parameters("VARIABLE"     )->asGridList();
+	m_pXGrids        = Parameters("X_GRIDS"      )->asGridList();
+	m_pXTable        = Parameters("X_TABLE"      )->asTable();
 
-	m_xSource			= Parameters("X_SOURCE"     )->asInt();
-	m_vMethod			= Parameters("V_METHOD"     )->asInt();
+	m_xSource        = Parameters("X_SOURCE"     )->asInt();
+	m_vMethod        = Parameters("V_METHOD"     )->asInt();
 
-	m_Linear_bSorted	= Parameters("LINEAR_SORTED")->asBool();
-	m_Spline_bAll		= Parameters("SPLINE_ALL"   )->asBool() == false;
-	m_Trend_Order		= Parameters("TREND_ORDER"  )->asInt();
+	m_Linear_bSorted = Parameters("LINEAR_SORTED")->asBool();
+	m_Spline_bAll    = Parameters("SPLINE_ALL"   )->asBool() == false;
+	m_Trend_Order    = Parameters("TREND_ORDER"  )->asInt();
 
-	switch( Parameters("H_METHOD")->asInt() )
-	{
-	default:	m_hMethod	= GRID_RESAMPLING_NearestNeighbour;	break;
-	case  1:	m_hMethod	= GRID_RESAMPLING_Bilinear        ;	break;
-	case  2:	m_hMethod	= GRID_RESAMPLING_BicubicSpline   ;	break;
-	case  3:	m_hMethod	= GRID_RESAMPLING_BSpline         ;	break;
-	}
+	m_hMethod        = Parameters("H_METHOD"     )->asGrid_Resampling();
 
 	//-----------------------------------------------------
 	if( m_pVariables->Get_Grid_Count() != (m_xSource == 0 ? m_pXTable->Get_Count() : m_pXGrids->Get_Grid_Count()) )
@@ -258,7 +246,7 @@ bool CGrid_Levels_Interpolation::Initialize(const CSG_Rect &Extent)
 	{
 		CSG_Grid	Surface(Get_System());
 
-		Surface.Assign(Parameters("SURFACE")->asGrid(), GRID_RESAMPLING_Mean_Cells);
+		Surface.Assign(Parameters("SURFACE")->asGrid(), CSG_Grid_Resampling::Mean_Cells);
 
 		m_Trend_Order	= 1;	// linear
 
