@@ -58,7 +58,7 @@
 //---------------------------------------------------------
 CShapes_Load::CShapes_Load(void)
 {
-	Set_Name		(_TL("Import Shapes from PostGIS"));
+	Set_Name		(_TL("Import Shapes"));
 
 	Set_Author		("O.Conrad (c) 2013");
 
@@ -143,7 +143,7 @@ bool CShapes_Load::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	CSG_Shapes *pShapes = Parameters("SHAPES")->asShapes();
+	CSG_Shapes *pShapes = Parameters("SHAPES")->asShapes(); pShapes->Destroy();
 
 	if( !Get_Connection()->Shapes_Load(pShapes, DB_Table) )
 	{
@@ -165,7 +165,7 @@ bool CShapes_Load::On_Execute(void)
 //---------------------------------------------------------
 CShapes_Save::CShapes_Save(void)
 {
-	Set_Name		(_TL("Export Shapes to PostGIS"));
+	Set_Name		(_TL("Export Shapes"));
 
 	Set_Author		("O.Conrad (c) 2013");
 
@@ -215,7 +215,7 @@ int CShapes_Save::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 		{
 			pParameters->Set_Parameter("NAME", CSG_PG_Connection::Make_Table_Name(pParameter->asShapes()->Get_Name()));
 
-			Set_SRID(pParameters, pParameter->asShapes()->Get_Projection().Get_EPSG());
+			Set_SRID(pParameters, pParameter->asShapes()->Get_Projection());
 		}
 		else
 		{
@@ -494,7 +494,131 @@ bool CShapes_SRID_Update::On_Execute(void)
 //---------------------------------------------------------
 CShapes_Join::CShapes_Join(void)
 {
-	Set_Name		(_TL("Import Shapes with Joined Data from PostGIS (GUI)"));
+	Set_Name		(_TL("Import Shapes with Joined Data"));
+
+	Set_Author		("O.Conrad (c) 2024");
+
+	Set_Description	(_TW(
+		"Imports shapes with joined data from a PostGIS database."
+	));
+
+	Parameters.Add_Shapes(""          , "SHAPES"    , _TL("Shapes"        ), _TL(""), PARAMETER_OUTPUT);
+
+	Parameters.Add_Choice(""          , "GEO_TABLE" , _TL("Geometry Table"), _TL(""), "");
+	Parameters.Add_Choice("GEO_TABLE" , "GEO_KEY"   , _TL("Key"           ), _TL(""), "");
+
+	Parameters.Add_Choice(""          , "JOIN_TABLE", _TL("Join Table"    ), _TL(""), "");
+	Parameters.Add_Choice("JOIN_TABLE", "JOIN_KEY"  , _TL("Key"           ), _TL(""), "");
+
+	Parameters.Add_String(""          , "FIELDS"    , _TL("Fields"        ), _TL(""), "");
+	Parameters.Add_String(""          , "WHERE"     , _TL("Where"         ), _TL(""), "");
+	Parameters.Add_String(""          , "GROUP"     , _TL("Group by"      ), _TL(""), "");
+	Parameters.Add_String(""          , "HAVING"    , _TL("Having"        ), _TL(""), "");
+	Parameters.Add_String(""          , "ORDER"     , _TL("Order by"      ), _TL(""), "");
+	Parameters.Add_Bool  (""          , "DISTINCT"  , _TL("Distinct"      ), _TL("")    );
+}
+
+//---------------------------------------------------------
+void CShapes_Join::On_Connection_Changed(CSG_Parameters *pParameters)
+{
+	CSG_String s; CSG_Table t;
+
+	if( Get_Connection()->Table_Load(t, "geometry_columns") )
+	{
+		for(sLong i=0; i<t.Get_Count(); i++)
+		{
+			s += t[i].asString("f_table_name") + CSG_String("|");
+		}
+	}
+
+	#define SET_ITEMS(id, items) { CSG_Parameter *p = (*pParameters)(id); p->asChoice()->Set_Items(items); p->Set_Value(0);\
+		On_Parameter_Changed(pParameters, p);\
+	}
+
+	SET_ITEMS("GEO_TABLE", s); SET_ITEMS("JOIN_TABLE", Get_Connection()->Get_Tables());
+}
+
+//---------------------------------------------------------
+int CShapes_Join::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier( "GEO_TABLE")
+	||  pParameter->Cmp_Identifier("JOIN_TABLE") )
+	{
+		CSG_String Names, Geometry;
+
+		CSG_Table Description = Get_Connection()->Get_Field_Desc(pParameter->asString());
+
+		Get_Connection()->Shapes_Geometry_Info(pParameter->asString(), &Geometry, NULL);
+
+		for(sLong i=0; i<Description.Get_Count(); i++)
+		{
+			if( Geometry.Cmp(Description[i].asString(0)) )
+			{
+				Names += Description[i].asString(0) + CSG_String("|");
+			}
+		}
+
+		pParameter->Get_Child(0)->asChoice()->Set_Items(Names);
+	}
+
+	return( CSG_PG_Tool::On_Parameter_Changed(pParameters, pParameter) );
+}
+
+//---------------------------------------------------------
+bool CShapes_Join::On_Execute(void)
+{
+	CSG_String  geoTable = Parameters( "GEO_TABLE")->asString();
+	CSG_String joinTable = Parameters("JOIN_TABLE")->asString();
+
+	if( !geoTable.Cmp(joinTable) )
+	{
+		Error_Set(_TL("Geometry and join table must not be identical."));
+
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	CSG_String Join; Join.Printf("\"%s\".\"%s\"=\"%s\".\"%s\"",
+		 geoTable.c_str(), Parameters( "GEO_KEY")->asString(),
+		joinTable.c_str(), Parameters("JOIN_KEY")->asString()
+	);
+
+	bool     Distinct = Parameters("DISTINCT")->asBool  ();
+	CSG_String Fields = Parameters("FIELDS"  )->asString();
+	CSG_String  Where = Parameters("WHERE"   )->asString();
+	CSG_String  Group = Parameters("GROUP"   )->asString();
+	CSG_String Having = Parameters("HAVING"  )->asString();
+	CSG_String  Order = Parameters("ORDER"   )->asString();
+
+	if( !Where.is_Empty() )
+	{
+		Where = " AND (" + Where + ")";
+	}
+
+	//-----------------------------------------------------
+	CSG_Shapes *pShapes = Parameters("SHAPES")->asShapes(); pShapes->Destroy();
+
+	if( !Get_Connection()->Shapes_Load(pShapes, geoTable + "." + joinTable, geoTable, "\"" + joinTable + "\"", Fields, Join + Where, Group, Having, Order, Distinct, true) )
+	{
+		Error_Set(_TL("unable to load vector data from PostGIS database") + CSG_String(":\n") + geoTable + "." + joinTable);
+
+		return( false );
+	}
+
+	return( true );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CShapes_Join_GUI::CShapes_Join_GUI(void)
+{
+	Set_Name		(_TL("Import Shapes with Joined Data (GUI)"));
 
 	Set_Author		("O.Conrad (c) 2017");
 
@@ -515,7 +639,7 @@ CShapes_Join::CShapes_Join(void)
 }
 
 //---------------------------------------------------------
-void CShapes_Join::On_Connection_Changed(CSG_Parameters *pParameters)
+void CShapes_Join_GUI::On_Connection_Changed(CSG_Parameters *pParameters)
 {
 	CSG_String s; CSG_Table t;
 
@@ -527,25 +651,26 @@ void CShapes_Join::On_Connection_Changed(CSG_Parameters *pParameters)
 		}
 	}
 
-	pParameters->Get_Parameter("GEO_TABLE")->asChoice()->Set_Items(s);
+	#define SET_ITEMS(id, items) { CSG_Parameter *p = (*pParameters)(id); p->asChoice()->Set_Items(items); p->Set_Value(0);\
+		On_Parameter_Changed(pParameters, p);\
+	}
 
-	CSG_Parameter *pParameter = pParameters->Get_Parameter("JOIN_TABLE");
-	pParameter->asChoice()->Set_Items(Get_Connection()->Get_Tables());
-	pParameter->Set_Value(pParameter->asString());
-	On_Parameter_Changed(pParameters, pParameter);
+	SET_ITEMS("GEO_TABLE", s); SET_ITEMS("JOIN_TABLE", Get_Connection()->Get_Tables());
 }
 
 //---------------------------------------------------------
-int CShapes_Join::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+int CShapes_Join_GUI::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( pParameter->Cmp_Identifier( "GEO_TABLE")
-	||  pParameter->Cmp_Identifier("JOIN_TABLE") )
+	if( pParameters->Cmp_Identifier("FIELDS") == false )
 	{
-		Update_Fields(pParameters,  true);
-		Update_Fields(pParameters, false);
+		if( pParameter->Cmp_Identifier( "GEO_TABLE")
+		||  pParameter->Cmp_Identifier("JOIN_TABLE") )
+		{
+			Update_Fields(pParameters, pParameter);
+		}
 	}
 
-	if( pParameters->Cmp_Identifier("FIELDS") && !pParameter->Get_Parent() )
+	if( pParameters->Cmp_Identifier("FIELDS") == true && !pParameter->Get_Parent() )
 	{
 		for(int i=0; i<pParameter->Get_Children_Count(); i++)
 		{
@@ -557,38 +682,51 @@ int CShapes_Join::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 }
 
 //---------------------------------------------------------
-void CShapes_Join::Update_Fields(CSG_Parameters *pParameters, bool bGeoTable)
+void CShapes_Join_GUI::Update_Fields(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	CSG_Parameters	&Fields	= *pParameters->Get_Parameter("FIELDS")->asParameters();
+	CSG_Parameters &Field_Check = *(*pParameters)("FIELDS")->asParameters();
 
-	if( bGeoTable )
+	CSG_Parameter *pField_All = Field_Check(pParameter->Get_Identifier());
+
+	if( pField_All == NULL )
 	{
-		Fields.Del_Parameters();
+		pField_All = Field_Check.Add_Bool("", pParameter->Get_Identifier(), pParameter->asString(), "", false);
 	}
-
-	CSG_String	FieldList, geoField, Table(pParameters->Get_Parameter(bGeoTable ? "GEO_TABLE" : "JOIN_TABLE")->asString());
-	CSG_Table	t	= Get_Connection()->Get_Field_Desc(Table);
-	CSG_Parameter	*pNode	= Fields.Add_Bool("", Table, Table, "");
-
-	Get_Connection()->Shapes_Geometry_Info(Table, &geoField, NULL);
-
-	for(sLong i=0; i<t.Get_Count(); i++)
+	else
 	{
-		if( geoField.Cmp(t[i].asString(0)) )
+		pField_All->Set_Name(pParameter->asString()); pField_All->Set_Value(false); // select all
+
+		while( pField_All->Get_Children_Count() )
 		{
-			FieldList	+= t[i].asString(0) + CSG_String("|");
-			Fields.Add_Bool(pNode, CSG_String::Format("%s.%s", Table.c_str(), t[i].asString(0)), t[i].asString(0), "");
+			Field_Check.Del_Parameter(pField_All->Get_Child(0)->Get_Identifier());
 		}
 	}
 
-	pParameters->Get_Parameter(bGeoTable ? "GEO_KEY" : "JOIN_KEY")->asChoice()->Set_Items(FieldList);
+	CSG_String Field_Names, Geometry;
+
+	Get_Connection()->Shapes_Geometry_Info(pParameter->asString(), &Geometry, NULL);
+
+	CSG_Table Description = Get_Connection()->Get_Field_Desc(pParameter->asString());
+
+	for(sLong i=0; i<Description.Get_Count(); i++)
+	{
+		if( Geometry.Cmp(Description[i].asString(0)) )
+		{
+			Field_Names += Description[i].asString(0) + CSG_String("|");
+			Field_Check.Add_Bool(pParameter->Get_Identifier(), CSG_String::Format("%s.%s",
+				pParameter->Get_Name(), Description[i].asString(0)), Description[i].asString(0), ""
+			);
+		}
+	}
+
+	pParameter->Get_Child(0)->asChoice()->Set_Items(Field_Names);
 }
 
 //---------------------------------------------------------
-bool CShapes_Join::On_Execute(void)
+bool CShapes_Join_GUI::On_Execute(void)
 {
-	CSG_String	geoTable	= Parameters("GEO_TABLE" )->asString();
-	CSG_String	joinTable	= Parameters("JOIN_TABLE")->asString();
+	CSG_String  geoTable = Parameters( "GEO_TABLE")->asString();
+	CSG_String joinTable = Parameters("JOIN_TABLE")->asString();
 
 	if( !geoTable.Cmp(joinTable) )
 	{
@@ -598,22 +736,20 @@ bool CShapes_Join::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	CSG_String	Join, Where	= Parameters("WHERE")->asString();
+	CSG_String Join, Where = Parameters("WHERE")->asString();
 
 	Join.Printf("\"%s\".\"%s\"=\"%s\".\"%s\"",
-		 geoTable.c_str(), Parameters( "GEO_KEY")->asString(),
+		geoTable.c_str(), Parameters( "GEO_KEY")->asString(),
 		joinTable.c_str(), Parameters("JOIN_KEY")->asString()
 	);
 
 	if( !Where.is_Empty() )
 	{
-		Join	+= " AND (" + Where + ")";
+		Join += " AND (" + Where + ")";
 	}
 
 	//-----------------------------------------------------
-	CSG_String Fields;
-
-	CSG_Parameters &P = *Parameters("FIELDS")->asParameters();
+	CSG_String Fields; CSG_Parameters &P = *Parameters("FIELDS")->asParameters();
 
 	for(int i=0; i<P.Get_Count(); i++)
 	{
@@ -621,24 +757,17 @@ bool CShapes_Join::On_Execute(void)
 		{
 			if( !Fields.is_Empty() )
 			{
-				Fields	+= ",";
+				Fields += ",";
 			}
 
-			CSG_String	ID	= P[i].Get_Identifier();
-
-			if( ID.Find('.') < 0 )	// table
-			{
-				Fields	+= "\"" + ID + "\"";
-			}
-			else					// field
-			{
-				Fields	+= "\"" + ID.BeforeFirst('.') + "\".\"" + ID.AfterFirst('.') + "\"";
-			}
+			Fields += CSG_String::Format("\"%s\".\"%s\"", P[i].Get_Parent()->Get_Name(), P[i].Get_Name());
 		}
 	}
 
 	//-----------------------------------------------------
-	if( !Get_Connection()->Shapes_Load(Parameters("SHAPES")->asShapes(), geoTable + "." + joinTable, geoTable, "\"" + joinTable + "\"", Fields, Join) )
+	CSG_Shapes *pShapes = Parameters("SHAPES")->asShapes(); pShapes->Destroy();
+
+	if( !Get_Connection()->Shapes_Load(pShapes, geoTable + "." + joinTable, geoTable, "\"" + joinTable + "\"", Fields, Join) )
 	{
 		Error_Set(_TL("unable to load vector data from PostGIS database") + CSG_String(":\n") + geoTable + "." + joinTable);
 
