@@ -68,38 +68,45 @@ CExercise_05::CExercise_05(void)
 		"Simple neighbourhood analysis for grid cells."
 	));
 
+	Add_Reference("Conrad, O.", "2007",
+		"SAGA - Entwurf, Funktionsumfang und Anwendung eines Systems für Automatisierte Geowissenschaftliche Analysen",
+		"ediss.uni-goettingen.de.",
+		SG_T("https://ediss.uni-goettingen.de/handle/11858/00-1735-0000-0006-B26C-6"), SG_T("online")
+	);
+
+	Add_Reference("O. Conrad, B. Bechtel, M. Bock, H. Dietrich, E. Fischer, L. Gerlitz, J. Wehberg, V. Wichmann, and J. Böhner", "2015",
+		"System for Automated Geoscientific Analyses (SAGA) v. 2.1.4",
+		"Geoscientific Model Development, 8, 1991-2007.",
+		SG_T("https://doi.org/10.5194/gmd-8-1991-2015"), SG_T("doi:10.5194/gmd-8-1991-2015")
+	);
+
 	Add_Reference("Zevenbergen, L.W. & Thorne, C.R.", "1987",
 		"Quantitative analysis of land surface topography",
 		"Earth Surface Processes and Landforms, 12: 47-56."
 	);
 
-	Add_Reference("Conrad, O.", "2007",
-		"SAGA - Entwurf, Funktionsumfang und Anwendung eines Systems für Automatisierte Geowissenschaftliche Analysen",
-		"ediss.uni-goettingen.de.", SG_T("http://hdl.handle.net/11858/00-1735-0000-0006-B26C-6"), SG_T("Online")
-	);
-
 
 	//-----------------------------------------------------
 	Parameters.Add_Grid(
-		"", "ELEVATION"	, _TL("Input grid"),
+		"", "ELEVATION", _TL("Input grid"),
 		_TL("This must be your input data of type grid."),
 		PARAMETER_INPUT
 	);
 
 	Parameters.Add_Grid(
-		"", "SLOPE"		, _TL("Slope"),
+		"", "SLOPE"    , _TL("Slope"),
 		_TL("This will contain your output data of type grid."),
 		PARAMETER_OUTPUT
 	);
 
 	Parameters.Add_Grid(
-		"", "ASPECT"		, _TL("Aspect"),
+		"", "ASPECT"   , _TL("Aspect"),
 		_TL("This will contain your output data of type grid."),
 		PARAMETER_OUTPUT
 	);
 
 	Parameters.Add_Choice(
-		"", "METHOD"		, _TL("Method"),
+		"", "METHOD"   , _TL("Method"),
 		_TL("Choose a method"),
 		CSG_String::Format("%s|%s|%s",
 			_TL("Steepest gradient (first version)"),
@@ -117,45 +124,42 @@ CExercise_05::CExercise_05(void)
 //---------------------------------------------------------
 bool CExercise_05::On_Execute(void)
 {
-	bool	bResult;
-	int		Method;
-
 	//-----------------------------------------------------
 	// Get parameter settings...
 
-	m_pDTM		= Parameters("ELEVATION")->asGrid();
+	m_pDTM    = Parameters("ELEVATION")->asGrid();
+	m_pSlope  = Parameters("SLOPE"    )->asGrid();
+	m_pAspect = Parameters("ASPECT"   )->asGrid();
 
-	m_pSlope	= Parameters("SLOPE"    )->asGrid();
-	m_pAspect	= Parameters("ASPECT"   )->asGrid();
-
-	Method		= Parameters("METHOD")->asInt();
-
-	m_pSlope	->Set_Unit(_TL("radians"));
-	m_pAspect	->Set_Unit(_TL("radians"));
+	m_pSlope ->Set_Unit(_TL("radians"));
+	m_pAspect->Set_Unit(_TL("radians"));
 
 
 	//-----------------------------------------------------
 	// Execute calculation...
 
-	switch( Method )
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
-	case 0:
-		bResult	= Method_01();
-		break;
+		for(int x=0; x<Get_NX(); x++)
+		{
+			if( m_pDTM->is_NoData(x, y) )
+			{
+				m_pSlope ->Set_NoData(x, y);
+				m_pAspect->Set_NoData(x, y);
 
-	case 1:
-		bResult	= Method_02();
-		break;
+				continue;
+			}
 
-	default:
-		bResult	= false;
+			switch( Parameters("METHOD")->asInt() )
+			{
+			case  0: Method_01(x, y); break;
+			case  1: Method_02(x, y); break;
+			default: Method_03(x, y); break;
+			}
+		}
 	}
 
-
-	//-----------------------------------------------------
-	// Return 'true' if everything went okay...
-
-	return( bResult );
+	return( true );
 }
 
 
@@ -164,188 +168,113 @@ bool CExercise_05::On_Execute(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CExercise_05::Method_01(void)
+bool CExercise_05::Method_01(int x, int y)
 {
-	int		x, y, i, ix, iy, iMax;
-	double	z, dz, dzMax,
-			dx[2]	= { Get_Cellsize(), sqrt(2.0) * Get_Cellsize()	};
+	const double dx[2] = { Get_Cellsize(), sqrt(2.) * Get_Cellsize() };
 
-	//-----------------------------------------------------
-	for(y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
+	int iMax = -1; double dzMax = 0., z = m_pDTM->asDouble(x, y);
+
+	for(int i=0; i<8; i++)
 	{
-		for(x=0; x<Get_NX(); x++)
+		int ix = Get_xTo(i, x), iy = Get_yTo(i, y);
+
+		if( is_InGrid(ix, iy) && !m_pDTM->is_NoData(ix, iy) )
 		{
-			if( m_pDTM->is_NoData(x, y) )
+			double dz = (z - m_pDTM->asDouble(ix, iy)) / dx[i % 2];
+
+			if( dzMax < dz )
 			{
-				m_pSlope	->Set_NoData(x, y);
-				m_pAspect	->Set_NoData(x, y);
-			}
-			else
-			{
-				z		= m_pDTM->asDouble(x, y);
-				iMax	= -1;
-
-				for(i=0; i<8; i++)
-				{
-					ix		= Get_xTo(i, x);
-					iy		= Get_yTo(i, y);
-
-					if( is_InGrid(ix, iy) && !m_pDTM->is_NoData(ix, iy) )
-					{
-						dz	= (z - m_pDTM->asDouble(ix, iy)) / dx[i % 2];
-
-						if( dz > 0.0 && (iMax < 0 || (iMax >= 0 && dzMax < dz)) )
-						{
-							iMax	= i;
-							dzMax	= dz;
-						}
-					}
-				}
-
-				if( iMax < 0 )
-				{
-					m_pSlope	->Set_NoData(x, y);
-					m_pAspect	->Set_NoData(x, y);
-				}
-				else
-				{
-					m_pSlope	->Set_Value(x, y, atan(dzMax));
-					m_pAspect	->Set_Value(x, y, M_PI_045 * iMax);
-				}
+				dzMax = dz; iMax = i;						
 			}
 		}
 	}
 
-	//-----------------------------------------------------
+	if( iMax < 0 )
+	{
+		m_pSlope ->Set_Value(x, y, 0.);
+		m_pAspect->Set_NoData(x, y);
+	}
+	else
+	{
+		m_pSlope ->Set_Value(x, y, atan(dzMax));
+		m_pAspect->Set_Value(x, y, M_PI_045 * iMax);
+	}
+
 	return( true );
 }
 
 //---------------------------------------------------------
-bool CExercise_05::Method_02(void)
+bool CExercise_05::Method_02(int x, int y)
 {
-	int		x, y, i, ix, iy, iMax;
-	double	z, dz, dzMax;
+	int iMax = -1; double dzMax = 0., z = m_pDTM->asDouble(x, y);
 
-	//-----------------------------------------------------
-	for(y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
+	for(int i=0; i<8; i++)
 	{
-		for(x=0; x<Get_NX(); x++)
+		int ix = Get_xTo(i, x), iy = Get_yTo(i, y);
+
+		if( is_InGrid(ix, iy) && !m_pDTM->is_NoData(ix, iy) )
 		{
-			if( m_pDTM->is_NoData(x, y) )
+			double dz = (z - m_pDTM->asDouble(ix, iy)) / Get_Length(i);
+
+			if( dzMax < dz )
 			{
-				m_pSlope	->Set_NoData(x, y);
-				m_pAspect	->Set_NoData(x, y);
-			}
-			else
-			{
-				z		= m_pDTM->asDouble(x, y);
-				iMax	= -1;
-
-				for(i=0; i<8; i++)
-				{
-					ix		= Get_xTo(i, x);
-					iy		= Get_yTo(i, y);
-
-					if( is_InGrid(ix, iy) && !m_pDTM->is_NoData(ix, iy) )
-					{
-						dz	= (z - m_pDTM->asDouble(ix, iy)) / Get_Length(i);
-
-						if( dz > 0.0 && (iMax < 0 || (iMax >= 0 && dzMax < dz)) )
-						{
-							iMax	= i;
-							dzMax	= dz;
-						}
-					}
-				}
-
-				if( iMax < 0 )
-				{
-					m_pSlope	->Set_NoData(x, y);
-					m_pAspect	->Set_NoData(x, y);
-				}
-				else
-				{
-					m_pSlope	->Set_Value(x, y, atan(dzMax));
-					m_pAspect	->Set_Value(x, y, M_PI_045 * iMax);
-				}
+				dzMax = dz; iMax = i;
 			}
 		}
 	}
 
-	//-----------------------------------------------------
+	if( iMax < 0 )
+	{
+		m_pSlope ->Set_Value(x, y, 0.);
+		m_pAspect->Set_NoData(x, y);
+	}
+	else
+	{
+		m_pSlope ->Set_Value(x, y, atan(dzMax));
+		m_pAspect->Set_Value(x, y, M_PI_045 * iMax);
+	}
+
 	return( true );
 }
 
 //---------------------------------------------------------
-bool CExercise_05::Method_03(void)
+bool CExercise_05::Method_03(int x, int y)
 {
-	static int	x_To[]	= { 0, 1, 0, -1 },
-				y_To[]	= { 1, 0, -1, 0 };
+	static int x_To[] = { 0, 1, 0, -1 };
+	static int y_To[] = { 1, 0, -1, 0 };
 
-	int		x, y, i, ix, iy;
-	double	z, dz[4], G, H, dx2;
+	double dz[4], z = m_pDTM->asDouble(x, y);
 
-	//-----------------------------------------------------
-	dx2		= 2.0 * Get_Cellsize();
-
-	//-----------------------------------------------------
-	for(y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
+	for(int i=0; i<4; i++)
 	{
-		for(x=0; x<Get_NX(); x++)
-		{
-			if( m_pDTM->is_NoData(x, y) )
-			{
-				m_pSlope	->Set_NoData(x, y);
-				m_pAspect	->Set_NoData(x, y);
-			}
+		int ix = x + x_To[i], iy = y + y_To[i];
 
-			//---------------------------------------------
-			else
-			{
-				z		= m_pDTM->asDouble(x, y);
+		dz[i] = m_pDTM->is_InGrid(ix, iy) ? m_pDTM->asDouble(ix, iy) - z : 0.;
+	}
 
-				for(i=0; i<4; i++)
-				{
-					ix		= x + x_To[i];
-					iy		= y + y_To[i];
+	//-----------------------------------------
+	double G = (dz[0] - dz[2]) / (2. * Get_Cellsize());
+	double H = (dz[1] - dz[3]) / (2. * Get_Cellsize());
 
-					if( m_pDTM->is_NoData(ix, iy) )
-					{
-						dz[i]	= 0.0;
-					}
-					else
-					{
-						dz[i]	= m_pDTM->asDouble(ix, iy) - z;
-					}
-				}
+	m_pSlope->Set_Value(x, y, atan(sqrt(G*G + H*H)));
 
-				//-----------------------------------------
-				G		= (dz[0] - dz[2]) / dx2;
-				H		= (dz[1] - dz[3]) / dx2;
-
-				m_pSlope		->Set_Value(x, y, atan(sqrt(G*G + H*H)));
-
-				if( G != 0.0 )
-				{
-					m_pAspect	->Set_Value(x, y, M_PI_180 + atan2(H, G));
-				}
-				else if( H > 0.0 )
-				{
-					m_pAspect	->Set_Value(x, y, M_PI_270);
-				}
-				else if( H < 0.0 )
-				{
-					m_pAspect	->Set_Value(x, y, M_PI_090);
-				}
-				else
-				{
-					m_pAspect	->Set_NoData(x, y);
-				}
-			}
-		}
+	if( G != 0. )
+	{
+		m_pAspect->Set_Value(x, y, M_PI_180 + atan2(H, G));
+	}
+	else if( H > 0. )
+	{
+		m_pAspect->Set_Value(x, y, M_PI_270);
+	}
+	else if( H < 0. )
+	{
+		m_pAspect->Set_Value(x, y, M_PI_090);
+	}
+	else
+	{
+		m_pAspect->Set_NoData(x, y);
 	}
 
-	//-----------------------------------------------------
 	return( true );
 }
 
