@@ -70,7 +70,14 @@ CExercise_07::CExercise_07(void)
 
 	Add_Reference("Conrad, O.", "2007",
 		"SAGA - Entwurf, Funktionsumfang und Anwendung eines Systems für Automatisierte Geowissenschaftliche Analysen",
-		"ediss.uni-goettingen.de.", SG_T("http://hdl.handle.net/11858/00-1735-0000-0006-B26C-6"), SG_T("Online")
+		"ediss.uni-goettingen.de.",
+		SG_T("https://ediss.uni-goettingen.de/handle/11858/00-1735-0000-0006-B26C-6"), SG_T("online")
+	);
+
+	Add_Reference("O. Conrad, B. Bechtel, M. Bock, H. Dietrich, E. Fischer, L. Gerlitz, J. Wehberg, V. Wichmann, and J. Böhner", "2015",
+		"System for Automated Geoscientific Analyses (SAGA) v. 2.1.4",
+		"Geoscientific Model Development, 8, 1991-2007.",
+		SG_T("https://doi.org/10.5194/gmd-8-1991-2015"), SG_T("doi:10.5194/gmd-8-1991-2015")
 	);
 
 
@@ -158,7 +165,7 @@ bool CExercise_07::On_Execute(void)
 
 	m_pArea			->Assign(0.0);
 	m_pArea			->Set_Unit(SG_T("m\xc2\xb2"));
-	DataObject_Set_Colors(m_pArea, 100, SG_COLORS_WHITE_BLUE);
+	DataObject_Set_Colors(m_pArea, 0, SG_COLORS_WHITE_BLUE);
 
 	pLength			->Assign(0.0);
 	pLength			->Set_Unit(SG_T("m"));
