@@ -65,7 +65,7 @@ CSG_String Get_Info(int i)
 		return( "SAGA Development" );
 
 	case TLB_INFO_Author:
-		return( "O. Conrad (c) 2010" );
+		return( "O. Conrad, J. Spitzmueller, V. Wichmann (c) 2010-2025" );
 
 	case TLB_INFO_Description:
 		return( _TL("Tools and helpers for the SAGA development.") );
@@ -92,6 +92,7 @@ CSG_String Get_Info(int i)
 #include "pysaga_tools.h"
 #include "tool_description.h"
 #include "pretty_printer_tool.h"
+#include "color_ramps_from_csv.h"
 
 
 //---------------------------------------------------------
@@ -112,8 +113,9 @@ CSG_Tool *		Create_Tool(int i)
 	case  9: return( new CPySAGA_Tools );
 	case 10: return( new CTool_Description );
 	case 11: return( new CPrettyPrinter );
+	case 12: return( new CColor_Ramps_From_CSV );
 
-	case 12: return( NULL );
+	case 13: return( NULL );
 	default: return( TLB_INTERFACE_SKIP_TOOL );
 	}
 }
