@@ -182,10 +182,10 @@ bool CQGIS_ToolBox::On_Execute(void)
 					CSG_String s[2];
 					
 					s[0] = pTool->Get_Name();
-					s[0].Replace("'", "''");
+					s[0].Replace("'", "\\'");
 
 					s[1] = pTool->Get_Name();
-					s[1].Replace("'", "''");
+					s[1].Replace("'", "\\'");
 					s[1].Replace("Grid"  , "Raster"  );
 					s[1].Replace("Shapes", "Features");
 
@@ -205,10 +205,10 @@ bool CQGIS_ToolBox::On_Execute(void)
 							? pLibrary->Get_Category()
 							: pLibrary->Get_Category() + " - " + pLibrary->Get_Name();
 
-						s[1].Replace("'", "''");
+						s[1].Replace("'", "\\'");
 						s[1].Replace("Gridding", "Rasterizing");
 						s[1].Replace("Grid"    , "Raster"     );
-						s[1].Replace("Shapes"  , "Features"   );
+						s[1].Replace("Shapes"  , "Vector"     );
 
 						if( !Groups.is_Empty() )
 						{
@@ -229,13 +229,19 @@ bool CQGIS_ToolBox::On_Execute(void)
 
 		if( Stream.Open(SG_File_Make_Path(Directory, "SagaNameDecorator", "py"), SG_FILE_W, false) )
 		{
-			Stream.Write("# -*- coding: utf-8 -*-\n\n");
+			Groups += ",\n'tta_tools': 'Travel Time Analysis'";
 
-			Stream.Write("groups = {\n"     + Groups     + "}\n\n");
-			Stream.Write("def decoratedGroupName(name):\n\treturn groups.get(name, name)\n\n");
+			Stream.Write("\"\"\"\nAlgorithm and group name formatting utilities\n\"\"\"\n\n");
 
-			Stream.Write("algorithms = {\n" + Algorithms + "}\n\n");
-			Stream.Write("def decoratedAlgorithmName(name):\n\treturn algorithms.get(name, name)\n\n");
+			Stream.Write("groups = {\n"     + Groups     + "}\n\n\n");
+			Stream.Write("def decoratedGroupName(name: str) -> str:\n");
+			Stream.Write("\t\"\"\"\n\tReturns a nice user-friendly group name instead of a raw SAGA group name\n\t\"\"\"\n");
+			Stream.Write("\treturn groups.get(name, name)\n\n\n");
+
+			Stream.Write("algorithms = {\n" + Algorithms + "}\n\n\n");
+			Stream.Write("def decoratedAlgorithmName(name: str) -> str:\n");
+			Stream.Write("\t\"\"\"\n\tReturns a nice user-friendly algorithm name instead of the raw SAGA name\n\t\"\"\"\n");
+			Stream.Write("\treturn algorithms.get(name, name)\n\n\n");
 		}
 
 		//-------------------------------------------------
@@ -268,9 +274,9 @@ bool CQGIS_ToolBox::On_Execute(void)
 				"    ~/.local/share/QGIS/QGIS3/profiles/default/python/plugins/processing_saga_nextgen\n"
 				"- replace the \"description\" folder with the generated one\n"
 				"- replace the \"SagaNameDecorator.py\" file in the \"processing\" subfolder\n"
-				"- edit the file \"processing/provider.py\" and set the\n"
+				"- edit the file \"processing/utils.py\", set the\n"
 				"  REQUIRED_VERSION = 'x.x.' to the version of your SAGA binaries, e.g.\n"
-				"  REQUIRED_VERSION = '9.2.'\n"
+				"  REQUIRED_VERSION = '9.9.'\n"
 				"- start QGIS and enjoy SAGA\n"
 			);
 		}
