@@ -1014,7 +1014,7 @@ void CProfile_Cross_Sections_PDF::DrawGuitar(TSG_Point *pProfile,
 	double fMinX, fMaxX;
 	double fDif;
 	CSG_String sValue;
-	CSG_String sField [] = {"Distancia","Dist. Parcial.", "Elevacion del terreno", "Elevacin de la calzada", " ", " "};
+	CSG_String sField [] = {"Distancia","Dist. Parcial.", "Elevacion del terreno", "Elevación de la calzada", " ", " "};
 	double fHeight;
 
 	fMinX = pProfile[0].x;
@@ -1236,8 +1236,8 @@ bool CProfile_Cross_Sections::On_Execute(void){
 	for (i = 1; i < iNumPoints +1; i++){
 		m_pSections->Add_Field(SG_Get_String(fInterval * i).c_str(), SG_DATATYPE_Double);
 	}//for
-	for(i=0; i<pLines->Get_Count() && Set_Progress(i, pLines->Get_Count()); i++){
-		pShape = pLines->Get_Shape(i);
+	for(sLong iShape=0; iShape<pLines->Get_Count() && Set_Progress(iShape, pLines->Get_Count()); iShape++){
+		pShape = pLines->Get_Shape(iShape);
 		for(j=0; j<pShape->Get_Part_Count(); j++){
 			for(k=0; k<pShape->Get_Point_Count(j)-1; k+=iStep){
 				Point = pShape->Get_Point(k,j);
@@ -1336,12 +1336,12 @@ void CProfile_Cross_Sections::AddLongitudinalProfiles(){
 	CSG_Shapes* pLines = Parameters("LINES")->asShapes();
 
 	pTable = m_pSections;
-	iSections = pTable->Get_Record_Count();
+	iSections = pTable->Get_Count();
 
 	m_pProfile = new TSG_Point[iSections];
 
-	for(i=0; i<pLines->Get_Count() && Set_Progress(i, pLines->Get_Count()); i++){
-		pShape = pLines->Get_Shape(i);
+	for(sLong iShape=0; iShape<pLines->Get_Count() && Set_Progress(iShape, pLines->Get_Count()); iShape++){
+		pShape = pLines->Get_Shape(iShape);
 		for(j=0; j<pShape->Get_Part_Count(); j++){
 			Point = pShape->Get_Point(0,j);
 			for(k=0; k<pShape->Get_Point_Count(j)-1; k+=iStep){
@@ -1431,9 +1431,9 @@ void CProfile_Cross_Sections::AddCrossSections(){
 	pRoadSection[1].y = 0;
 
 	pTable = m_pSections;
-	pCrossSections = new TSG_Point *[pTable->Get_Record_Count()];
+	pCrossSections = new TSG_Point *[pTable->Get_Count()];
 
-	for (i = 0; i < pTable->Get_Record_Count(); i++){
+	for (i = 0; i < pTable->Get_Count(); i++){
 		pCrossSections[i] = new TSG_Point [pTable->Get_Field_Count()];
 		for (j = 0; j < pTable->Get_Field_Count(); j++){
 			pCrossSections[i][j].x = -fInterval * iNumPoints + fInterval * j;
@@ -1443,10 +1443,10 @@ void CProfile_Cross_Sections::AddCrossSections(){
 
 	iRoadPoints = 2;
 
-	m_DocEngine.AddCrossSections(pCrossSections, m_pHeight, pRoadSection, pTable->Get_Record_Count(),
+	m_DocEngine.AddCrossSections(pCrossSections, m_pHeight, pRoadSection, pTable->Get_Count(),
 								pTable->Get_Field_Count(), iRoadPoints);
 	m_DocEngine.AddVolumesTable(m_pProfile, pCrossSections, m_pHeight, pRoadSection,
-								pTable->Get_Record_Count(),	pTable->Get_Field_Count(), iRoadPoints);
+								pTable->Get_Count(),	pTable->Get_Field_Count(), iRoadPoints);
 
 }//method
 
