@@ -72,15 +72,9 @@ bool _finite(double val)
 //---------------------------------------------------------
 CGrid_Calculator_Base::CGrid_Calculator_Base(void)
 {
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"RESAMPLING", _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 	
 	Parameters.Add_String("",
@@ -342,13 +336,7 @@ bool CGrid_Calculator_Base::Initialize(int nGrids, int nGrids_X)
 	//-----------------------------------------------------
 	m_bUseNoData = Parameters("USE_NODATA")->asBool();
 
-	switch( Parameters("RESAMPLING")->asInt() )
-	{
-	default: m_Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: m_Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: m_Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: m_Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+	m_Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 	//-----------------------------------------------------
 	return( true );
