@@ -80,7 +80,7 @@ protected:
 
 	CSG_Formula					m_Formula;
 
-	TSG_Grid_Resampling			m_Resampling;
+	CSG_Grid_Resampling			m_Resampling;
 
 
 	virtual int					On_Parameter_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
