@@ -130,7 +130,7 @@ int CKernel_Density::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Param
 	if( (pParameter->Cmp_Identifier("POINTS") || pParameter->Cmp_Identifier("RADIUS"))
 	&&  pParameters->Get_Parameter("POINTS")->asShapes() )
 	{
-		CSG_Rect	Extent(pParameters->Get_Parameter("POINTS")->asShapes()->Get_Extent());
+		CSG_Rect Extent(pParameters->Get_Parameter("POINTS")->asShapes()->Get_Extent());
 
 		Extent.Inflate(pParameters->Get_Parameter("RADIUS")->asDouble(), false);
 
@@ -158,19 +158,12 @@ int CKernel_Density::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Param
 //---------------------------------------------------------
 bool CKernel_Density::On_Execute(void)
 {
-	int			Population;
-	double		Radius;
-	CSG_Shapes	*pPoints;
-
-	//-----------------------------------------------------
-	pPoints		= Parameters("POINTS"    )->asShapes();
-	Population	= Parameters("POPULATION")->asInt();
-	Radius		= Parameters("RADIUS"    )->asDouble();
-	m_Kernel	= Parameters("KERNEL"    )->asInt();
+	CSG_Shapes *pPoints = Parameters("POINTS"    )->asShapes();
+	int      Population = Parameters("POPULATION")->asInt();
 
 	if( Population < 0 || Population >= pPoints->Get_Field_Count() || pPoints->Get_Field_Type(Population) == SG_DATATYPE_String )
 	{
-		Population	= -1;
+		Population = -1;
 	}
 
 	//-----------------------------------------------------
@@ -183,17 +176,18 @@ bool CKernel_Density::On_Execute(void)
 	m_pGrid->Set_NoData_Value(0.);
 	m_pGrid->Assign(0.);
 
-	DataObject_Set_Colors(m_pGrid, 11, SG_COLORS_BLACK_WHITE, true);
+	DataObject_Set_Colors(m_pGrid, 0, SG_COLORS_BLACK_WHITE, true);
 
-	m_dRadius	= Radius / m_pGrid->Get_Cellsize();
-	m_iRadius	= 1 + (int)m_dRadius;
+	m_Kernel  = Parameters("KERNEL")->asInt();
+	m_dRadius = Parameters("RADIUS")->asDouble() / m_pGrid->Get_Cellsize();
+	m_iRadius = 1 + (int)m_dRadius;
 
 	//-----------------------------------------------------
 	if( pPoints->Get_Selection_Count() > 0 )
 	{
 		for(sLong iPoint=0; iPoint<pPoints->Get_Selection_Count() && Set_Progress(iPoint, pPoints->Get_Selection_Count()); iPoint++)
 		{
-			CSG_Shape	*pPoint	= pPoints->Get_Selection(iPoint);
+			CSG_Shape *pPoint = (CSG_Shape *)pPoints->Get_Selection(iPoint);
 
 			Set_Kernel(pPoint->Get_Point(), Population < 0 ? 1. : pPoint->asDouble(Population));
 		}
@@ -214,15 +208,13 @@ bool CKernel_Density::On_Execute(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CKernel_Density::Set_Kernel(const TSG_Point &Point, double Population)
 {
-	double	x	= (Point.x - m_pGrid->Get_XMin()) / m_pGrid->Get_Cellsize();
-	double	y	= (Point.y - m_pGrid->Get_YMin()) / m_pGrid->Get_Cellsize();
+	double x = (Point.x - m_pGrid->Get_XMin()) / m_pGrid->Get_Cellsize();
+	double y = (Point.y - m_pGrid->Get_YMin()) / m_pGrid->Get_Cellsize();
 
 	for(int iy=(int)y-m_iRadius; iy<=y+m_iRadius; iy++)
 	{
@@ -242,14 +234,14 @@ void CKernel_Density::Set_Kernel(const TSG_Point &Point, double Population)
 //---------------------------------------------------------
 inline double CKernel_Density::Get_Kernel(double dx, double dy)
 {
-	double	d	= SG_Get_Length(dx, dy);
+	double d = SG_Get_Length(dx, dy);
 
 	if( d >= m_dRadius )
 	{
 		return( 0. );
 	}
 
-	d	/= m_dRadius;
+	d /= m_dRadius;
 
 	switch( m_Kernel )
 	{
@@ -258,11 +250,11 @@ inline double CKernel_Density::Get_Kernel(double dx, double dy)
 		return( (3. / (M_PI * m_dRadius*m_dRadius)) * SG_Get_Square(1. - d*d) );
 
 	case 1:	// gaussian kernel
-		d	*= 2.;
+		d *= 2.;
 		return( exp(-0.5 * d*d) );
 
 	case 2:	// exponential
-		d	*= 2.;
+		d *= 2.;
 		return( exp(-d) );
 
 	case 3:	// inverse distance
