@@ -154,7 +154,7 @@ bool CCropToData::On_Execute(void)
 		pCrop->Set_NoData_Value     (pGrid->Get_NoData_Value());
 		pCrop->Get_MetaData().Create(pGrid->Get_MetaData    ());
 
-		pCrop->Assign(pGrid, GRID_RESAMPLING_NearestNeighbour);
+		pCrop->Assign(pGrid, CSG_Grid_Resampling::NearestNeighbour);
 
 		pCropped->Add_Item(pCrop);
 	}
