@@ -277,7 +277,7 @@ bool CGrid_Clip_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Int
 
 						pClip->Set_NoData_Value_Range(pObject->Get_NoData_Value(), pObject->Get_NoData_Value(true));
 
-						((CSG_Grid  *)pClip)->Assign(pGrid, GRID_RESAMPLING_NearestNeighbour);
+						((CSG_Grid  *)pClip)->Assign(pGrid, CSG_Grid_Resampling::NearestNeighbour);
 					}
 					break;
 
@@ -292,7 +292,7 @@ bool CGrid_Clip_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Int
 
 						pClip->Set_NoData_Value_Range(pObject->Get_NoData_Value(), pObject->Get_NoData_Value(true));
 
-						((CSG_Grids *)pClip)->Assign(pGrids, GRID_RESAMPLING_NearestNeighbour);
+						((CSG_Grids *)pClip)->Assign(pGrids, CSG_Grid_Resampling::NearestNeighbour);
 					}
 					break;
 				}
@@ -549,7 +549,7 @@ bool CGrid_Clip::On_Execute(void)
 
 				pClip->Set_NoData_Value_Range(pObject->Get_NoData_Value(), pObject->Get_NoData_Value(true));
 
-				((CSG_Grid  *)pClip)->Assign(pGrid, GRID_RESAMPLING_NearestNeighbour);
+				((CSG_Grid  *)pClip)->Assign(pGrid, CSG_Grid_Resampling::NearestNeighbour);
 			}
 			break;
 
@@ -569,7 +569,7 @@ bool CGrid_Clip::On_Execute(void)
 
 				pClip->Set_NoData_Value_Range(pObject->Get_NoData_Value(), pObject->Get_NoData_Value(true));
 
-				((CSG_Grids *)pClip)->Assign(pGrids, GRID_RESAMPLING_NearestNeighbour);
+				((CSG_Grids *)pClip)->Assign(pGrids, CSG_Grid_Resampling::NearestNeighbour);
 			}
 			break;
 		}
