@@ -118,15 +118,9 @@ void CGrid_Merge::Add_Parameters(CSG_Parameters &Parameters)
 		SG_DATATYPES_Numeric|SG_DATATYPES_Bit, SG_DATATYPE_Undefined, _TL("same as first grid in list")
 	);
 
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"RESAMPLING", _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"           ),
-			_TL("Bilinear Interpolation"      ),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation"      )
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_Choice("",
@@ -362,13 +356,7 @@ bool CGrid_Merge::Initialize(void)
 	}
 	
 	//-----------------------------------------------------
-	switch( Parameters("RESAMPLING")->asInt() )
-	{
-	default: m_Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: m_Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: m_Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: m_Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+	m_Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 	//-----------------------------------------------------
 	TSG_Data_Type Type = Parameters("TYPE")->asDataType()->Get_Data_Type(m_pGrids->Get_Grid(0)->Get_Type());
@@ -810,7 +798,7 @@ void CGrid_Merge::Get_Match(CSG_Grid *pGrid)
 					{
 						double	z, px	= m_pMosaic->Get_XMin() + x * m_pMosaic->Get_Cellsize();
 
-						if( pGrid->Get_Value(px, py, z, GRID_RESAMPLING_NearestNeighbour) )
+						if( pGrid->Get_Value(px, py, z, CSG_Grid_Resampling::NearestNeighbour) )
 						{
 							Z[0].Add_Row(z);
 							Z[1].Add_Row(m_pMosaic->asDouble(x, y));
