@@ -96,7 +96,7 @@ private:
 
 	double						m_dBlend;
 
-	TSG_Grid_Resampling			m_Resampling;
+	CSG_Grid_Resampling			m_Resampling;
 
 	CSG_Vector					m_Match;
 
