@@ -263,7 +263,7 @@ bool CGrid_Tiling::On_Execute(void)
 	int					nx, ny;
 	double				dx, dy, dCell;
 	TSG_Rect			Extent;
-	TSG_Grid_Resampling	Resampling;
+	CSG_Grid_Resampling	Resampling;
 
 	switch( Parameters("METHOD")->asInt() )
 	{
@@ -277,7 +277,7 @@ bool CGrid_Tiling::On_Execute(void)
 		ny			= Parameters("NY")->asInt();
 		dx			= dCell * nx;
 		dy			= dCell * ny;
-		Resampling	= GRID_RESAMPLING_NearestNeighbour;
+		Resampling	= CSG_Grid_Resampling::NearestNeighbour;
 		break;
 
 	case  1:	// coordinates (offset, range, cell size, tile size)
@@ -290,7 +290,7 @@ bool CGrid_Tiling::On_Execute(void)
 		dy			= Parameters("DY"    )->asDouble();
 		nx			= (int)(dx / dCell);
 		ny			= (int)(dy / dCell);
-		Resampling	= GRID_RESAMPLING_Undefined;
+		Resampling	= CSG_Grid_Resampling::Undefined;
 		break;
 	}
 
