@@ -1,6 +1,3 @@
-/**********************************************************
- * Version $Id$
- *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -50,15 +47,6 @@
 //                                                       //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
 //---------------------------------------------------------
 #include "Grid_Value_Request.h"
 
@@ -82,37 +70,31 @@
 //---------------------------------------------------------
 CGrid_Value_Request::CGrid_Value_Request(void)
 {
-	//-----------------------------------------------------
-	// 1. Info...
+	Set_Name		(_TL("Grid Value Request"));
 
-	Set_Name(_TL("Grid Value Request"));
-
-	Set_Author		(SG_T("(c) 2003 by O.Conrad"));
+	Set_Author		("O.Conrad (c) 2003");
 
 	Set_Description	(_TW(
 		"The tool reads out grids values from one or more input grids and reports these in a table. "
 		"Besides the grid value(s), the x- and y-coordinates of the queried cell(s) are reported. The "
-		"reported grid coordinates (column, row) are those of the first input grid.\n")
-	);
-
+		"reported grid coordinates (column, row) are those of the first input grid.\n"
+	));
 
 	//-----------------------------------------------------
-	// 2. Standard in- and output...
-
-	m_pGrids	= Parameters.Add_Grid_List(
-		NULL	, "GRID_LIST"		, _TL("Grids to request"),
+	m_pGrids = Parameters.Add_Grid_List("",
+		"GRID_LIST"   , _TL("Grids to request"),
 		_TL(""),
 		PARAMETER_INPUT
 	)->asGridList();
 
-	Parameters.Add_Table(
-		NULL	, "VALUES"			, _TL("Values"),
+	Parameters.Add_Table("",
+		"VALUES"    , _TL("Values"),
 		_TL(""),
 		PARAMETER_OUTPUT
 	);
 
-	Parameters.Add_Choice(
-		NULL	, "METHOD"			, _TL("Method"),
+	Parameters.Add_Choice("",
+		"METHOD"    , _TL("Method"),
 		_TL(""),
 		CSG_String::Format(SG_T("%s|%s|"),
 			_TL("Single value"),
@@ -120,15 +102,9 @@ CGrid_Value_Request::CGrid_Value_Request(void)
 		), 0
 	);
 
-	Parameters.Add_Choice(
-		NULL	, "RESAMPLING"		, _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+	Parameters.Add_Grid_Resampling("",
+		"RESAMPLING", _TL("Resampling"),
+		_TL("")
 	);
 
 	Set_Drag_Mode(TOOL_INTERACTIVE_DRAG_NONE);
@@ -142,27 +118,19 @@ CGrid_Value_Request::CGrid_Value_Request(void)
 //---------------------------------------------------------
 bool CGrid_Value_Request::On_Execute(void)
 {
-	int		iGrid;
-
 	if( m_pGrids->Get_Grid_Count() > 0 )
 	{
-		m_Method	= Parameters("METHOD")->asInt();
+		m_Method = Parameters("METHOD")->asInt();
 
-		m_pTable	= Parameters("VALUES")->asTable();
+		m_pTable = Parameters("VALUES")->asTable();
 		m_pTable->Destroy();
 		m_pTable->Set_Name(_TL("Grid Values"));
 
-		switch( Parameters("RESAMPLING")->asInt() )
-		{
-		default:	m_Resampling	= GRID_RESAMPLING_NearestNeighbour;	break;
-		case  1:	m_Resampling	= GRID_RESAMPLING_Bilinear;			break;
-		case  2:	m_Resampling	= GRID_RESAMPLING_BicubicSpline;	break;
-		case  3:	m_Resampling	= GRID_RESAMPLING_BSpline;			break;
-		}
+		m_Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 		switch( m_Method )
 		{
-		case 0: default:
+		default:
 			m_pTable->Add_Field(_TL("NAME" ), SG_DATATYPE_String);
 			m_pTable->Add_Field(_TL("VALUE"), SG_DATATYPE_Double);
 
@@ -171,19 +139,19 @@ bool CGrid_Value_Request::On_Execute(void)
 			m_pTable->Add_Record()->Set_Value(FIELD_NAME, _TL("X Grid 1"));
 			m_pTable->Add_Record()->Set_Value(FIELD_NAME, _TL("Y Grid 1"));
 
-			for(iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
+			for(int iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
 			{
 				m_pTable->Add_Record()->Set_Value(FIELD_NAME, m_pGrids->Get_Grid(iGrid)->Get_Name());
 			}
 			break;
 
-		case 1:
+		case  1:
 			m_pTable->Add_Field(_TL("X World" ), SG_DATATYPE_Double);
 			m_pTable->Add_Field(_TL("Y World" ), SG_DATATYPE_Double);
 			m_pTable->Add_Field(_TL("X Grid 1"), SG_DATATYPE_Int);
 			m_pTable->Add_Field(_TL("Y Grid 1"), SG_DATATYPE_Int);
 
-			for(iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
+			for(int iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
 			{
 				m_pTable->Add_Field(m_pGrids->Get_Grid(iGrid)->Get_Name(), SG_DATATYPE_Double);
 			}
@@ -203,16 +171,12 @@ bool CGrid_Value_Request::On_Execute(void)
 //---------------------------------------------------------
 bool CGrid_Value_Request::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Interactive_Mode Mode)
 {
-	int					iGrid;
-	double				Value;
-	CSG_Table_Record	*pRecord;
-
 	if( m_pGrids->Get_Grid_Count() > 0 )
 	{
 		switch( m_Method )
 		{
 		//-------------------------------------------------
-		case 0:
+		default:
 			if( Mode == TOOL_INTERACTIVE_LDOWN || Mode == TOOL_INTERACTIVE_MOVE_LDOWN )
 			{
 				m_pTable->Get_Record(FIELD_X_WORLD)->Set_Value(FIELD_VALUE, ptWorld.x);
@@ -221,15 +185,17 @@ bool CGrid_Value_Request::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Intera
 				m_pTable->Get_Record(FIELD_X_GRID)->Set_Value(FIELD_VALUE, m_pGrids->Get_Grid(0)->Get_System().Get_xWorld_to_Grid(ptWorld.x));
 				m_pTable->Get_Record(FIELD_Y_GRID)->Set_Value(FIELD_VALUE, m_pGrids->Get_Grid(0)->Get_System().Get_yWorld_to_Grid(ptWorld.y));
 
-				for(iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
+				for(int iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
 				{
+					double Value;
+
 					if( m_pGrids->Get_Grid(iGrid)->Get_Value(ptWorld, Value, m_Resampling) )
 					{
 						m_pTable->Get_Record(iGrid + FIELD_GRIDS)->Set_Value(FIELD_VALUE, Value);
 					}
 					else
 					{
-						m_pTable->Get_Record(iGrid + FIELD_GRIDS)->Set_Value(FIELD_VALUE, 0.0);
+						m_pTable->Get_Record(iGrid + FIELD_GRIDS)->Set_Value(FIELD_VALUE, 0.);
 					}
 				}
 
@@ -240,10 +206,10 @@ bool CGrid_Value_Request::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Intera
 			break;
 
 		//-------------------------------------------------
-		case 1:
+		case  1:
 			if( Mode == TOOL_INTERACTIVE_LDOWN )
 			{
-				pRecord	= m_pTable->Add_Record();
+				CSG_Table_Record *pRecord = m_pTable->Add_Record();
 
 				pRecord->Set_Value(FIELD_X_WORLD, ptWorld.x);
 				pRecord->Set_Value(FIELD_Y_WORLD, ptWorld.y);
@@ -251,15 +217,17 @@ bool CGrid_Value_Request::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Intera
 				pRecord->Set_Value(FIELD_X_GRID, m_pGrids->Get_Grid(0)->Get_System().Get_xWorld_to_Grid(ptWorld.x));
 				pRecord->Set_Value(FIELD_Y_GRID, m_pGrids->Get_Grid(0)->Get_System().Get_yWorld_to_Grid(ptWorld.y));
 
-				for(iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
+				for(int iGrid=0; iGrid<m_pGrids->Get_Grid_Count(); iGrid++)
 				{
+					double Value;
+
 					if( m_pGrids->Get_Grid(iGrid)->Get_Value(ptWorld, Value, m_Resampling) )
 					{
 						pRecord->Set_Value(FIELD_GRIDS + iGrid, Value);
 					}
 					else
 					{
-						pRecord->Set_Value(FIELD_GRIDS + iGrid, 0.0);
+						pRecord->Set_Value(FIELD_GRIDS + iGrid, 0.);
 					}
 				}
 
