@@ -50,9 +50,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -61,7 +61,7 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -160,7 +160,7 @@ CGrids_Create::CGrids_Create(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -206,7 +206,7 @@ int CGrids_Create::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramet
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -248,7 +248,7 @@ TSG_Data_Type CGrids_Create::Get_Field_Type(int iField)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -395,12 +395,6 @@ bool CGrids_Create::On_Execute(void)
 	{
 		DataObject_Set_Parameters(pGrids, Parameters("COPY")->asGrids());
 	}
-	else
-	{
-		DataObject_Set_Parameter(pGrids, "BAND_R", 0);
-		DataObject_Set_Parameter(pGrids, "BAND_G", 1);
-		DataObject_Set_Parameter(pGrids, "BAND_B", 2);
-	}
 
 	pGrids->Set_Name(Parameters("NAME")->asString());
 
@@ -410,9 +404,9 @@ bool CGrids_Create::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -456,7 +450,7 @@ CGrids_Add_Grid::CGrids_Add_Grid(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -478,7 +472,7 @@ int CGrids_Add_Grid::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Param
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -528,9 +522,9 @@ bool CGrids_Add_Grid::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -566,7 +560,7 @@ CGrids_Extract::CGrids_Extract(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -595,7 +589,7 @@ int CGrids_Extract::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parame
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -639,9 +633,9 @@ bool CGrids_Extract::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -689,7 +683,7 @@ CGrids_Extract_Grid::CGrids_Extract_Grid(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -706,7 +700,7 @@ int CGrids_Extract_Grid::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_P
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -744,13 +738,13 @@ bool CGrids_Extract_Grid::On_Execute(void)
 		pGrid->Fmt_Name("%s [%.*f]", pGrids->Get_Name(), SG_Get_Significant_Decimals(Z), Z);
 	}
 
-	TSG_Grid_Resampling	Resampling;
+	CSG_Grid_Resampling	Resampling;
 
 	switch( Parameters("RESAMPLING")->asInt() )
 	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BSpline         ; break;
+	default: Resampling = CSG_Grid_Resampling::NearestNeighbour; break;
+	case  1: Resampling = CSG_Grid_Resampling::Bilinear        ; break;
+	case  2: Resampling = CSG_Grid_Resampling::Bicubic_2       ; break;
 	}
 
 	//-----------------------------------------------------
@@ -765,7 +759,7 @@ bool CGrids_Extract_Grid::On_Execute(void)
 		{
 			double	Value, px = Get_XMin() + x * Get_Cellsize();
 
-			if( (!pZ || !pZ->is_NoData(x, y)) && pGrids->Get_Value(px, py, !pZ ? Z : pZ->asDouble(x, y), Value, GRID_RESAMPLING_NearestNeighbour, Resampling) )
+			if( (!pZ || !pZ->is_NoData(x, y)) && pGrids->Get_Value(px, py, !pZ ? Z : pZ->asDouble(x, y), Value, CSG_Grid_Resampling::NearestNeighbour, Resampling) )
 			{
 				pGrid->Set_Value(x, y, Value);
 			}
@@ -782,9 +776,9 @@ bool CGrids_Extract_Grid::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -814,7 +808,7 @@ CGrids_Delete::CGrids_Delete(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -843,7 +837,7 @@ int CGrids_Delete::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramet
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -887,9 +881,9 @@ bool CGrids_Delete::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
