@@ -107,15 +107,9 @@ CSpectral_Profile::CSpectral_Profile(void)
 		false
 	);
 
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"RESAMPLING", _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_String("",
@@ -216,13 +210,7 @@ bool CSpectral_Profile::Initialize(void)
 	}
 
 	//-----------------------------------------------------
-	switch( Parameters("RESAMPLING")->asInt() )
-	{
-	default: m_Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: m_Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: m_Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: m_Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+	m_Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 	//-----------------------------------------------------
 	CSG_Vector Length(m_pBands->Get_Grid_Count());
@@ -378,7 +366,10 @@ CSpectral_Profile_Interactive::CSpectral_Profile_Interactive(void)
 	Set_Author		("O.Conrad (c) 2023");
 
 	Set_Description	(_TW(
-		"This is the interactive version of the 'Spectral Profile' tool.\n\n"
+		"This is the interactive version of the <i>'Spectral Profile'</i> tool.\n"
+		"Choosing single profile mode you can collect samples. Just activate "
+		"the <i>'Collect Samples'</i> output and press the right mouse button "
+		"after you have selected a profile position of interest (left mouse button).\n\n"
 		) + m_Profile.Get_Description()
 	);
 
