@@ -988,7 +988,7 @@ bool CDetect_CloudShadows::Get_Candidates(CSG_Grid &Candidates)
 //---------------------------------------------------------
 double CDetect_CloudShadows::Get_Correction(double dx, double dy, double dz, CSG_Grid *pDEM, int x, int y)
 {
-	TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline; // GRID_RESAMPLING_NearestNeighbour
+	CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2; // CSG_Grid_Resampling::NearestNeighbour
 
 	CSG_Point p0(Get_System().Get_Grid_to_World(x, y)); double z;
 
