@@ -56,13 +56,13 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-TSG_Grid_Resampling	Get_Resampling(int Resampling)
+CSG_Grid_Resampling	Get_Resampling(int Resampling)
 {
 	switch( Resampling )
 	{
-	case  0: return( GRID_RESAMPLING_NearestNeighbour );
-	case  1: return( GRID_RESAMPLING_Bilinear         );
-	default: return( GRID_RESAMPLING_BSpline          );
+	case  0: return( CSG_Grid_Resampling::NearestNeighbour );
+	case  1: return( CSG_Grid_Resampling::Bilinear         );
+	default: return( CSG_Grid_Resampling::Bicubic_2          );
 	}
 }
 
@@ -166,7 +166,7 @@ int CPanSharp_IHS::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramet
 //---------------------------------------------------------
 bool CPanSharp_IHS::On_Execute(void)
 {
-	TSG_Grid_Resampling	Resampling	= Get_Resampling(Parameters("RESAMPLING")->asInt());
+	CSG_Grid_Resampling	Resampling	= Get_Resampling(Parameters("RESAMPLING")->asInt());
 
 	//-----------------------------------------------------
 	CSG_Grid *pR, *pG, *pB, *pPan = Parameters("PAN")->asGrid();
@@ -406,7 +406,7 @@ int CPanSharp_Brovey::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Para
 //---------------------------------------------------------
 bool CPanSharp_Brovey::On_Execute(void)
 {
-	TSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
+	CSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
 
 	//-----------------------------------------------------
 	CSG_Grid *pR, *pG, *pB, *pPan = Parameters("PAN")->asGrid();
@@ -578,7 +578,7 @@ int CPanSharp_CN::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramete
 //---------------------------------------------------------
 bool CPanSharp_CN::On_Execute(void)
 {
-	TSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
+	CSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
 
 	//-----------------------------------------------------
 	CSG_Grid *pPan = Parameters("PAN")->asGrid();
@@ -864,7 +864,7 @@ bool CPanSharp_PCA::On_Execute(void)
 	//-----------------------------------------------------
 	// resample all other PCs to match the high resolution of the PAN band
 
-	TSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
+	CSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
 
 	for(int i=1; i<n; i++)
 	{
