@@ -201,15 +201,9 @@ CSentinel_2_Scene_Import::CSentinel_2_Scene_Import(void)
 		), 0
 	);
 
-	Parameters.Add_Choice("PROJECTION",
+	Parameters.Add_Grid_Resampling("PROJECTION",
 		"RESAMPLING"	, _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_Int("PROJECTION",
@@ -432,7 +426,7 @@ bool CSentinel_2_Scene_Import::On_Execute(void)
 			pBands[i]->Get_MetaData().Add_Child(Info_General)->Set_Name("SENTINEL-2");
 			pBands[i]->Get_MetaData().Add_Child(Info_Image  )->Set_Name("BANDS");
 			pBands[i]->Set_Description(Info_General.asText());
-			pBands[i]->Set_Z_Attribute (INFO_FIELD_WAVE);
+			pBands[i]->Set_Z_Attribute (INFO_FIELD_WAVE, true);
 			pBands[i]->Set_Z_Name_Field(INFO_FIELD_NAME);
 			pBands[i]->Set_Scaling(Scaling, Offset);
 
