@@ -630,7 +630,7 @@ bool CSpectral_Indices::Get_Result(int x, int y, double &Value)
 
 			Values[i] = pBand->asDouble(x, y);
 		}
-		else if( !pBand->Get_Value(Get_System().Get_Grid_to_World(x, y), Values[i], GRID_RESAMPLING_BSpline) )
+		else if( !pBand->Get_Value(Get_System().Get_Grid_to_World(x, y), Values[i], CSG_Grid_Resampling::Bicubic_2) )
 		{
 			return( false );
 		}
