@@ -1215,7 +1215,7 @@ bool CSG_GDAL_DataSet::Get_Transformation(CSG_Grid_System &System, bool bVerbose
 }
 
 //---------------------------------------------------------
-bool CSG_GDAL_DataSet::Get_Transformation(CSG_Grid **ppGrid, TSG_Grid_Resampling Interpolation, bool bVerbose)	const
+bool CSG_GDAL_DataSet::Get_Transformation(CSG_Grid **ppGrid, CSG_Grid_Resampling Interpolation, bool bVerbose)	const
 {
 	CSG_Grid_System	System;
 
@@ -1228,7 +1228,7 @@ bool CSG_GDAL_DataSet::Get_Transformation(CSG_Grid **ppGrid, TSG_Grid_Resampling
 }
 
 //---------------------------------------------------------
-bool CSG_GDAL_DataSet::Get_Transformation(CSG_Grid **ppGrid, TSG_Grid_Resampling Interpolation, const CSG_Grid_System &System, bool bVerbose)	const
+bool CSG_GDAL_DataSet::Get_Transformation(CSG_Grid **ppGrid, CSG_Grid_Resampling Interpolation, const CSG_Grid_System &System, bool bVerbose)	const
 {
 	if( !System.is_Valid() )
 	{
