@@ -52,29 +52,29 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define HDR_NROWS			SG_T("NROWS")
-#define HDR_NCOLS			SG_T("NCOLS")
-#define HDR_X_CORNER		SG_T("XLLCORNER")
-#define HDR_Y_CORNER		SG_T("YLLCORNER")
-#define HDR_X_CENTER		SG_T("XLLCENTER")
-#define HDR_Y_CENTER		SG_T("YLLCENTER")
-#define HDR_CELLSIZE		SG_T("CELLSIZE")
-#define HDR_NODATA			SG_T("NODATA_VALUE")
-#define HDR_BYTEORDER		SG_T("BYTE_ORDER")
-#define HDR_BYTEORDER_HI	SG_T("MSB_FIRST")
-#define HDR_BYTEORDER_LO	SG_T("LSB_FIRST")
+#define HDR_NROWS        SG_T("NROWS"       )
+#define HDR_NCOLS        SG_T("NCOLS"       )
+#define HDR_X_CORNER     SG_T("XLLCORNER"   )
+#define HDR_Y_CORNER     SG_T("YLLCORNER"   )
+#define HDR_X_CENTER     SG_T("XLLCENTER"   )
+#define HDR_Y_CENTER     SG_T("YLLCENTER"   )
+#define HDR_CELLSIZE     SG_T("CELLSIZE"    )
+#define HDR_NODATA       SG_T("NODATA_VALUE")
+#define HDR_BYTEORDER    SG_T("BYTE_ORDER"  )
+#define HDR_BYTEORDER_HI SG_T("MSB_FIRST"   )
+#define HDR_BYTEORDER_LO SG_T("LSB_FIRST"   )
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Import							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -90,12 +90,12 @@ CESRI_ArcInfo_Import::CESRI_ArcInfo_Import(void)
 
 	//-----------------------------------------------------
 	Parameters.Add_Grid_Output("",
-		"GRID"		, _TL("Grid"),
+		"GRID"      , _TL("Grid"),
 		_TL("")
 	);
 
 	Parameters.Add_FilePath("",
-		"FILE"		, _TL("File"),
+		"FILE"      , _TL("File"),
 		_TL(""),
 		CSG_String::Format("%s|*.asc;*.flt|%s|*.asc|%s|*.flt|%s|*.*",
 			_TL("ESRI Arc/Info Grids"),
@@ -111,7 +111,7 @@ CESRI_ArcInfo_Import::CESRI_ArcInfo_Import(void)
 	);
 
 	Parameters.Add_Choice("NODE_ASCII",
-		"GRID_TYPE"	, _TL("Target Grid Type"),
+		"GRID_TYPE" , _TL("Target Grid Type"),
 		_TL(""),
 		CSG_String::Format("%s|%s|%s|%s",
 			_TL("Integer (2 byte)"),
@@ -122,7 +122,7 @@ CESRI_ArcInfo_Import::CESRI_ArcInfo_Import(void)
 	);
 
 	Parameters.Add_Choice("NODE_ASCII",
-		"NODATA"	, _TL("No-Data Value"),
+		"NODATA"    , _TL("No-Data Value"),
 		_TL("Choose whether the input file's NoData value or a user specified NoData value is written"),
 		CSG_String::Format("%s|%s",
 			_TL("Input File's NoData Value"),
@@ -135,13 +135,39 @@ CESRI_ArcInfo_Import::CESRI_ArcInfo_Import(void)
 		_TL(""),
 		-99999.
 	);
+
+	m_CRS.Create(Parameters);
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+bool CESRI_ArcInfo_Import::On_Before_Execution(void)
+{
+	m_CRS.Activate_GUI(true);
+
+	return( CSG_Tool::On_Before_Execution() );
+}
+
+//---------------------------------------------------------
+bool CESRI_ArcInfo_Import::On_After_Execution(void)
+{
+	m_CRS.Deactivate_GUI();
+
+	return( CSG_Tool::On_After_Execution() );
+}
+
+//---------------------------------------------------------
+int CESRI_ArcInfo_Import::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	m_CRS.On_Parameter_Changed(pParameters, pParameter);
+
+	return( CSG_Tool::On_Parameter_Changed(pParameters, pParameter) );
+}
+
 //---------------------------------------------------------
 int CESRI_ArcInfo_Import::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
@@ -155,16 +181,16 @@ int CESRI_ArcInfo_Import::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CESRI_ArcInfo_Import::On_Execute(void)
 {
-	int		iNoData	= Parameters("NODATA"    )->asInt   ();
-	double	dNoData	= Parameters("NODATA_VAL")->asDouble();
+	int    iNoData = Parameters("NODATA"    )->asInt   ();
+	double dNoData = Parameters("NODATA_VAL")->asDouble();
 
-	TSG_Data_Type	Datatype;
+	TSG_Data_Type Datatype;
 
 	switch( Parameters("GRID_TYPE")->asInt() )
 	{
@@ -174,9 +200,7 @@ bool CESRI_ArcInfo_Import::On_Execute(void)
 	case  3: Datatype = SG_DATATYPE_Double; break;
 	}
 
-	CSG_Grid	*pGrid	= NULL;
-
-	CSG_File	Stream;
+	CSG_Grid *pGrid = NULL; CSG_File Stream;
 
 	//-----------------------------------------------------
 	// Binary...
@@ -185,7 +209,7 @@ bool CESRI_ArcInfo_Import::On_Execute(void)
 	{
 		if( Stream.Open(SG_File_Make_Path("", Parameters("FILE")->asString(), "flt"), SG_FILE_R, true) )
 		{
-			float	*Line	= (float *)SG_Malloc(pGrid->Get_NX() * sizeof(float));
+			float *Line = (float *)SG_Malloc(pGrid->Get_NX() * sizeof(float));
 
 			for(int iy=0, y=pGrid->Get_NY()-1; iy<pGrid->Get_NY() && !Stream.is_EOF() && Set_Progress(iy, pGrid->Get_NY()); iy++, y--)
 			{
@@ -210,11 +234,11 @@ bool CESRI_ArcInfo_Import::On_Execute(void)
 		{
 			for(int x=0; x<pGrid->Get_NX(); x++)
 			{
-				double	Value	= Read_Value(Stream);
+				double Value = Read_Value(Stream);
 
 				if( iNoData == 1 && Value == pGrid->Get_NoData_Value() )
 				{
-					Value	= dNoData;
+					Value = dNoData;
 				}
 
 				pGrid->Set_Value(x, y, Value);
@@ -232,7 +256,10 @@ bool CESRI_ArcInfo_Import::On_Execute(void)
 	{
 		pGrid->Set_Name(SG_File_Get_Name(Parameters("FILE")->asString(), false));
 
-		pGrid->Get_Projection().Load(SG_File_Make_Path("", Parameters("FILE")->asString(), "prj"));
+		if( !m_CRS.Get_CRS(pGrid->Get_Projection()) )
+		{
+			pGrid->Get_Projection().Load(SG_File_Make_Path("", Parameters("FILE")->asString(), "prj"));
+		}
 
 		return( true );
 	}
@@ -242,13 +269,13 @@ bool CESRI_ArcInfo_Import::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 double CESRI_ArcInfo_Import::Read_Value(CSG_File &Stream)
 {
-	CSG_String	s;	int	c;
+	CSG_String s; int c;
 
 	while( !Stream.is_EOF() && !SG_is_Character_Numeric(c = Stream.Read_Char()) );	// ignore leading white space...
 
@@ -258,10 +285,10 @@ double CESRI_ArcInfo_Import::Read_Value(CSG_File &Stream)
 		{
 			if( c == ',' )
 			{
-				c	= '.';
+				c = '.';
 			}
 
-			s	+= (char)c;
+			s += (char)c;
 		}
 		while( !Stream.is_EOF() && SG_is_Character_Numeric(c = Stream.Read_Char()) );
 	}
@@ -272,13 +299,13 @@ double CESRI_ArcInfo_Import::Read_Value(CSG_File &Stream)
 //---------------------------------------------------------
 CSG_String CESRI_ArcInfo_Import::Read_Header_Line(CSG_File &Stream)
 {
-	CSG_String	s;	int	c;
+	CSG_String s; int c;
 
 	while( !Stream.is_EOF() && (c = Stream.Read_Char()) != 0x0A )
 	{
 		if( c != 0x0D )
 		{
-			s	+= (char)c;
+			s += (char)c;
 		}
 	}
 
@@ -290,11 +317,11 @@ CSG_String CESRI_ArcInfo_Import::Read_Header_Line(CSG_File &Stream)
 //---------------------------------------------------------
 bool CESRI_ArcInfo_Import::Read_Header_Value(CSG_File &Stream, const CSG_String &sKey, int &Value)
 {
-	CSG_String	sLine(Read_Header_Line(Stream));
+	CSG_String sLine(Read_Header_Line(Stream));
 
 	if( sLine.Contains(sKey) )
 	{
-		CSG_String	sValue(sLine.c_str() + sKey.Length());
+		CSG_String sValue(sLine.c_str() + sKey.Length());
 
 		return( sValue.asInt(Value) );
 	}
@@ -305,11 +332,11 @@ bool CESRI_ArcInfo_Import::Read_Header_Value(CSG_File &Stream, const CSG_String
 //---------------------------------------------------------
 bool CESRI_ArcInfo_Import::Read_Header_Value(CSG_File &Stream, const CSG_String &sKey, double &Value)
 {
-	CSG_String	sLine(Read_Header_Line(Stream));
+	CSG_String sLine(Read_Header_Line(Stream));
 
 	if( sLine.Contains(sKey) )
 	{
-		CSG_String	sValue(sLine.c_str() + sKey.Length());
+		CSG_String sValue(sLine.c_str() + sKey.Length());
 
 		return( sValue.asDouble(Value) );
 	}
@@ -330,12 +357,12 @@ CSG_Grid * CESRI_ArcInfo_Import::Read_Header(CSG_File &Stream, TSG_Data_Type Dat
 	int NY; if( !Read_Header_Value(Stream, HDR_NROWS, NY) ) { return( NULL ); }
 
 	//-------------------------------------------------
-	double	xMin;	bool bCorner_X;
+	double xMin; bool bCorner_X;
 
 	if     ( Read_Header_Value(Stream, HDR_X_CORNER, xMin) ) { bCorner_X =  true; }
 	else if( Read_Header_Value(Stream, HDR_X_CENTER, xMin) ) { bCorner_X = false; } else { return( NULL ); }
 
-	double	yMin;	bool bCorner_Y;
+	double yMin; bool bCorner_Y;
 
 	if     ( Read_Header_Value(Stream, HDR_Y_CORNER, yMin) ) { bCorner_Y =  true; }
 	else if( Read_Header_Value(Stream, HDR_Y_CENTER, yMin) ) { bCorner_Y = false; } else { return( NULL ); }
@@ -347,7 +374,7 @@ CSG_Grid * CESRI_ArcInfo_Import::Read_Header(CSG_File &Stream, TSG_Data_Type Dat
 	if( bCorner_Y ) { yMin += Cellsize / 2.; }
 
 	//-------------------------------------------------
-	double	NoData; Read_Header_Value(Stream, HDR_NODATA, NoData = -9999.);
+	double NoData; Read_Header_Value(Stream, HDR_NODATA, NoData = -9999.);
 
 	//-------------------------------------------------
 	CSG_Grid *pGrid = Parameters("GRID")->asGrid();
@@ -366,9 +393,9 @@ CSG_Grid * CESRI_ArcInfo_Import::Read_Header(CSG_File &Stream, TSG_Data_Type Dat
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Export							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -445,7 +472,7 @@ CESRI_ArcInfo_Export::CESRI_ArcInfo_Export(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -465,7 +492,7 @@ int CESRI_ArcInfo_Export::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -545,7 +572,7 @@ bool CESRI_ArcInfo_Export::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -617,9 +644,9 @@ bool CESRI_ArcInfo_Export::Write_Header(CSG_File &Stream, CSG_Grid *pGrid, bool
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
