@@ -120,31 +120,16 @@ CImport_Clip_Resample::CImport_Clip_Resample(void)
 		100., 0., true
 	);
 
-	Parameters.Add_Choice("RESAMPLE",
+	Parameters.Add_Grid_Resampling("RESAMPLE",
 		"SCALE_UP"	, _TL("Upscaling Method"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation"),
-			_TL("Mean Value"),
-			_TL("Mean Value (cell area weighted)"),
-			_TL("Minimum Value"),
-			_TL("Maximum Value"),
-			_TL("Majority")
-		), 5
+		CSG_Grid_Resampling::All, CSG_Grid_Resampling::Mean_Cells
 	);
 
-	Parameters.Add_Choice("RESAMPLE",
+	Parameters.Add_Grid_Resampling("RESAMPLE",
 		"SCALE_DOWN", _TL("Downscaling Method"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		CSG_Grid_Resampling::Interpolations, CSG_Grid_Resampling::Bicubic_2
 	);
 }
 
@@ -266,7 +251,7 @@ bool CImport_Clip_Resample::Load_Grid(CSG_Grid *pImport)
 	}
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling	= GRID_RESAMPLING_Undefined;
+	CSG_Grid_Resampling	Resampling	= CSG_Grid_Resampling::Undefined;
 
 	if( Parameters("RESAMPLE")->asBool() )
 	{
@@ -276,28 +261,11 @@ bool CImport_Clip_Resample::Load_Grid(CSG_Grid *pImport)
 		{
 			if( Cellsize < System.Get_Cellsize() )	// Up-Scaling...
 			{
-				switch( Parameters("SCALE_UP")->asInt() )
-				{
-				default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-				case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-				case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-				case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-				case  4: Resampling = GRID_RESAMPLING_Mean_Nodes      ; break;
-				case  5: Resampling = GRID_RESAMPLING_Mean_Cells      ; break;
-				case  6: Resampling = GRID_RESAMPLING_Minimum         ; break;
-				case  7: Resampling = GRID_RESAMPLING_Maximum         ; break;
-				case  8: Resampling = GRID_RESAMPLING_Majority        ; break;
-				}
+				Resampling = Parameters("SCALE_UP"  )->asGrid_Resampling();
 			}
 			else // Get_Cellsize() >= System.Get_Cellsize()	// Down-Scaling...
 			{
-				switch( Parameters("SCALE_DOWN")->asInt() )
-				{
-				default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-				case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-				case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-				case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-				}
+				Resampling = Parameters("SCALE_DOWN")->asGrid_Resampling();
 			}
 
 			System.Assign(Cellsize, System.Get_Extent());
