@@ -88,6 +88,7 @@ CSG_String Get_Info(int i)
 #include "grid_import.h"
 #include "grid_to_kml.h"
 #include "export_gif_animation.h"
+#include "extract_exif_gps.h"
 
 
 //---------------------------------------------------------
@@ -102,8 +103,9 @@ CSG_Tool *		Create_Tool(int i)
 	case  2: return( new CGrid_to_KML );
 	case  3: return( new CGrid_from_KML );
 	case  4: return( new CExport_GIF_Animation );
+	case  5: return( new_CExtract_EXIF_GPS );
 
-	case  5: return( NULL );
+	case  6: return( NULL );
 	default: return( TLB_INTERFACE_SKIP_TOOL );
 	}
 }
