@@ -50,9 +50,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -88,30 +88,30 @@ CGeoCoding::CGeoCoding(void)
 
 	//-----------------------------------------------------
 	Parameters.Add_Shapes("",
-		"LOCATIONS"	, _TL("Locations"),
+		"LOCATIONS" , _TL("Locations"),
 		_TL(""),
 		PARAMETER_OUTPUT, SHAPE_TYPE_Point
 	);
 
 	Parameters.Add_Table("",
-		"ADDRESSES"	, _TL("Address List"),
+		"ADDRESSES" , _TL("Address List"),
 		_TL(""),
 		PARAMETER_INPUT_OPTIONAL
 	);
 
 	Parameters.Add_Table_Field("ADDRESSES",
-		"FIELD"		, _TL("Address Field"),
+		"FIELD"     , _TL("Address Field"),
 		_TL("")
 	);
 
 	Parameters.Add_String("ADDRESSES",
-		"ADDRESS"	, _TL("Single Address"),
+		"ADDRESS"   , _TL("Single Address"),
 		_TL(""),
 		"Bundesstrasse 55, Hamburg, Germany"
 	);
 
 	Parameters.Add_Choice("",
-		"PROVIDER"	, _TL("Service Provider"),
+		"PROVIDER"  , _TL("Service Provider"),
 		_TL(""),
 		CSG_String::Format("%s|%s|%s|%s|%s",
 			SG_T("Nominatim (OpenStreetMap)"),
@@ -123,24 +123,50 @@ CGeoCoding::CGeoCoding(void)
 	);
 
 	Parameters.Add_String("PROVIDER",
-		"API_KEY"	, _TL("API Key"),
+		"API_KEY"   , _TL("API Key"),
 		_TL(""),
 		"",
 		false, true
 	);
 
 	Parameters.Add_Bool("",
-		"METADATA"	, _TL("Store Metadata"),
+		"METADATA"  , _TL("Store Metadata"),
 		_TL(""),
 		false
 	);
+
+	m_CRS.Create(Parameters); Parameters.Set_Parameter("CRS_STRING", "epsg:4326"); m_CRS.On_Parameter_Changed(&Parameters, Parameters("CRS_STRING"));
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+bool CGeoCoding::On_Before_Execution(void)
+{
+	m_CRS.Activate_GUI();
+
+	return( CSG_Tool::On_Before_Execution() );
+}
+
+//---------------------------------------------------------
+bool CGeoCoding::On_After_Execution(void)
+{
+	m_CRS.Deactivate_GUI();
+
+	return( CSG_Tool::On_After_Execution() );
+}
+
+//---------------------------------------------------------
+int CGeoCoding::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	m_CRS.On_Parameter_Changed(pParameters, pParameter);
+
+	return( CSG_Tool::On_Parameter_Changed(pParameters, pParameter) );
+}
+
 //---------------------------------------------------------
 int CGeoCoding::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
@@ -156,50 +182,52 @@ int CGeoCoding::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter
 		pParameters->Set_Enabled("API_KEY", pParameter->asInt() >= 2 );
 	}
 
+	m_CRS.On_Parameters_Enable(pParameters, pParameter);
+
 	return( CSG_Tool::On_Parameters_Enable(pParameters, pParameter) );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CGeoCoding::On_Execute(void)
 {
-	int	Field	= Parameters("FIELD")->asInt();
+	int Field = Parameters("FIELD")->asInt();
 
-	CSG_Table	Table, *pTable	= Parameters("ADDRESSES")->asTable();
+	CSG_Table Table, *pTable = Parameters("ADDRESSES")->asTable();
 
 	if( !pTable )
 	{
-		Field	= 0;
-		pTable	= &Table;
-		pTable->Set_Name(_TL("Locations"));
+		Field  = 0;
+		pTable = &Table;
+		pTable->Set_Name(Parameters("ADDRESS")->asString());
 		pTable->Add_Field("ADDRESS", SG_DATATYPE_String);
 		pTable->Add_Record()->Set_Value(0, Parameters("ADDRESS")->asString());
 	}
 
 	//-----------------------------------------------------
-	CSG_Shapes	*pLocations	= Parameters("LOCATIONS")->asShapes();
+	CSG_Shapes *pLocations = Parameters("LOCATIONS")->asShapes();
 
 	pLocations->Create(SHAPE_TYPE_Point, pTable->Get_Name(), pTable);
 	pLocations->Get_Projection().Set_GCS_WGS84();
 
 	//-----------------------------------------------------
-	int	Provider	= Parameters("PROVIDER")->asInt();
+	int Provider = Parameters("PROVIDER")->asInt();
 
-	m_API_Key	= Parameters("API_KEY")->asString();
+	m_API_Key = Parameters("API_KEY")->asString();
 
-	CWebClient	Connection;
+	CWebClient Connection;
 
 	switch( Provider )
 	{
-	default: Connection.Create("https://nominatim.openstreetmap.org"); break;	// Nominatim
-	case  1: Connection.Create("https://www.datasciencetoolkit.org" ); break;	// The Data Science Toolkit
-	case  2: Connection.Create("https://maps.googleapis.com"        ); break;	// Google
-	case  3: Connection.Create("https://dev.virtualearth.net"       ); break;	// Bing
-	case  4: Connection.Create("https://www.mapquestapi.com"        ); break;	// MapQuest
+	default: Connection.Create("https://nominatim.openstreetmap.org"); break; // Nominatim
+	case  1: Connection.Create("https://www.datasciencetoolkit.org" ); break; // The Data Science Toolkit
+	case  2: Connection.Create("https://maps.googleapis.com"        ); break; // Google
+	case  3: Connection.Create("https://dev.virtualearth.net"       ); break; // Bing
+	case  4: Connection.Create("https://www.mapquestapi.com"        ); break; // MapQuest
 	}
 
 	if( !Connection.is_Connected() )
@@ -212,24 +240,20 @@ bool CGeoCoding::On_Execute(void)
 	//-----------------------------------------------------
 	for(sLong i=0; i<pTable->Get_Count() && Process_Get_Okay(); i++)
 	{
-		TSG_Point	Location;
-
-		CSG_String	Address(pTable->Get_Record(i)->asString(Field));
-
-		bool	bOkay;
+		bool bOkay; TSG_Point Location; CSG_String Address(pTable->Get_Record(i)->asString(Field));
 
 		switch( Provider )
 		{
-		default: bOkay = Request_Nominatim(Connection, Location, Address); break;	// Nominatim
-		case  1: bOkay = Request_DSTK     (Connection, Location, Address); break;	// The Data Science Toolkit
-		case  2: bOkay = Request_Google   (Connection, Location, Address); break;	// Google
-		case  3: bOkay = Request_Bing     (Connection, Location, Address); break;	// Bing
-		case  4: bOkay = Request_MapQuest (Connection, Location, Address); break;	// MapQuest
+		default: bOkay = Request_Nominatim(Connection, Location, Address); break; // Nominatim
+		case  1: bOkay = Request_DSTK     (Connection, Location, Address); break; // The Data Science Toolkit
+		case  2: bOkay = Request_Google   (Connection, Location, Address); break; // Google
+		case  3: bOkay = Request_Bing     (Connection, Location, Address); break; // Bing
+		case  4: bOkay = Request_MapQuest (Connection, Location, Address); break; // MapQuest
 		}
 
 		if( bOkay )
 		{
-			CSG_Shape	*pLocation	= pLocations->Add_Shape(pTable->Get_Record(i));
+			CSG_Shape *pLocation = pLocations->Add_Shape(pTable->Get_Record(i));
 
 			pLocation->Add_Point(Location);
 		}
@@ -242,13 +266,21 @@ bool CGeoCoding::On_Execute(void)
 
 	m_Answer.Destroy();
 
+	//-----------------------------------------------------
+	CSG_Projection Projection;
+	
+	if( m_CRS.Get_CRS(Projection) && Projection.is_Projection() )
+	{
+		SG_Get_Projected(pLocations, NULL, Projection);
+	}
+
 	//-----------------------------------------------------
 	return( pLocations->Get_Count() > 0 );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -290,7 +322,7 @@ void	Replace_Special_Chars(CSG_String &String)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -364,7 +396,7 @@ bool CGeoCoding::Request_Nominatim(CWebClient &Connection, TSG_Point &Location,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -442,7 +474,7 @@ bool CGeoCoding::Request_DSTK(CWebClient &Connection, TSG_Point &Location, CSG_S
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -519,7 +551,7 @@ bool CGeoCoding::Request_Google(CWebClient &Connection, TSG_Point &Location, CSG
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -591,7 +623,7 @@ bool CGeoCoding::Request_Bing(CWebClient &Connection, TSG_Point &Location, CSG_S
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -633,9 +665,9 @@ bool CGeoCoding::Request_MapQuest(CWebClient &Connection, TSG_Point &Location, C
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
