@@ -227,9 +227,11 @@ int CTiles_Provider::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Param
 
 		pParameters->Set_Enabled("CRS_PICKER", !Projection.is_Okay());
 
-		if( !Projection.is_Okay() )
+		if( !Projection.is_Okay() && (*pParameters)("CRS_PICKER") )
 		{
-			Projection.Create((*pParameters)("CRS_STRING")->asString());
+			CSG_Parameters &Picker = *(*pParameters)("CRS_PICKER")->asParameters();
+
+			Projection.Create(Picker["CRS_WKT"].asString(), Picker["CRS_PROJ"].asString());
 		}
 
 		pParameters->Set_Enabled("CELLSIZE", Projection.is_Projection());
