@@ -201,13 +201,13 @@ bool CPC_Drop_Attribute::On_After_Execution(void)
 	DataObject_Set_Parameter(pOutput, "DISPLAY_VALUE_AGGREGATE",  3);	// highest z
 	DataObject_Set_Parameter(pOutput, "METRIC_COLORS"          , 12);	// number of colors
 	DataObject_Set_Parameter(pOutput, "COLORS_TYPE"            ,  3);	// graduated color
-	DataObject_Set_Parameter(pOutput, "METRIC_ATTRIB"          ,  2);	// z attrib
+	DataObject_Set_Parameter(pOutput, "METRIC_FIELD"           ,  2);	// z attrib
 	DataObject_Set_Parameter(pOutput, "METRIC_ZRANGE",
 		pOutput->Get_Mean(2) - 2.0 * pOutput->Get_StdDev(2),
 		pOutput->Get_Mean(2) + 2.0 * pOutput->Get_StdDev(2)
 	);
 
-	DataObject_Set_Colors(pOutput, 11, SG_COLORS_RAINBOW);
+	DataObject_Set_Colors(pOutput, 0, SG_COLORS_RAINBOW);
 
 	if( pOutput == Parameters("INPUT")->asPointCloud() )
 	{
