@@ -305,15 +305,9 @@ CDirect_Georeferencing::CDirect_Georeferencing(void)
 		), 0
 	);
 
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"RESAMPLING", _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_Data_Type("",
@@ -464,15 +458,7 @@ bool CDirect_Georeferencing::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling;
-
-	switch( Parameters("RESAMPLING")->asInt() )
-	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+	CSG_Grid_Resampling Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 	bool bFlip = Parameters("ROW_ORDER")->asInt() == 1;
 
