@@ -83,24 +83,30 @@ CCRS_Definition::CCRS_Definition(void)
 	Add_Reference("https://proj.org", SG_T("PROJ Homepage"));
 
 	//-----------------------------------------------------
-	Parameters.Add_String("",
-		"DEFINITION", _TL("Definition"),
-		_TL(""),
-		"epsg:4326"
-	);
+	Parameters.Add_String("", "DEFINITION", _TL("Definition"), _TL(""), "");
+
+	if( has_GUI() || has_CMD() )
+	{
+		Parameters.Add_Choice("", "FORMAT", _TL("Format"), _TL(""), CSG_String::Format("PROJ|WKT-1|WKT-2|JSON|ESRI|%s", _TL("all")), 5);
+	}
+	else
+	{
+		Parameters.Add_Choice("", "FORMAT", _TL("Format"), _TL(""), CSG_String::Format("PROJ|WKT-1|WKT-2|JSON|ESRI|%s|PROJ + WKT-2", _TL("all")), 6);
+	}
 
 	Parameters.Add_Info_String("", "PROJ", _TL("PROJ" ), _TL(""), "", false);
 	Parameters.Add_Info_String("", "WKT1", _TL("WKT-1"), _TL(""), "",  true);
 	Parameters.Add_Info_String("", "WKT2", _TL("WKT-2"), _TL(""), "",  true);
 	Parameters.Add_Info_String("", "JSON", _TL("JSON" ), _TL(""), "",  true);
 	Parameters.Add_Info_String("", "ESRI", _TL("ESRI" ), _TL(""), "", false);
+	#ifdef _DEBUG
+	Parameters.Add_Info_String("", "XML" , _TL("XML"  ), _TL(""), "",  true);
+	#endif
 
 	Parameters.Add_Bool(""    , "MULTILINE" , _TL("Multiline" ), _TL("applies to JSON and WKT"), true);
 	Parameters.Add_Bool("WKT2", "SIMPLIFIED", _TL("Simplified"), _TL("applies to WKT-2"       ), true);
 
 	Parameters.Add_Table("", "FORMATS", _TL("Formats"), _TL(""), PARAMETER_OUTPUT_OPTIONAL)->Set_UseInGUI(false);
-
-	On_Parameter_Changed(&Parameters, Parameters("DEFINITION"));
 }
 
 
@@ -111,7 +117,7 @@ CCRS_Definition::CCRS_Definition(void)
 //---------------------------------------------------------
 int CCRS_Definition::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( pParameter->Cmp_Identifier("DEFINITION") || pParameter->Cmp_Identifier("MULTILINE") || pParameter->Cmp_Identifier("SIMPLIFIED") )
+	if( has_GUI() && pParameter->Cmp_Identifier("DEFINITION") || pParameter->Cmp_Identifier("FORMAT") || pParameter->Cmp_Identifier("MULTILINE") || pParameter->Cmp_Identifier("SIMPLIFIED") )
 	{
 		CSG_String Definition((*pParameters)["DEFINITION"].asString());
 		
@@ -120,18 +126,59 @@ int CCRS_Definition::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Param
 			Definition.Trim(); pParameter->Set_Value(Definition);
 		}
 
-		bool bMultiLine = (*pParameters)["MULTILINE"].asBool(), bSimplified = (*pParameters)["SIMPLIFIED"].asBool();
+		int       Format = (*pParameters)["FORMAT"    ].asInt ();
+		bool  bMultiLine = (*pParameters)["MULTILINE" ].asBool();
+		bool bSimplified = (*pParameters)["SIMPLIFIED"].asBool();
 
-		pParameters->Set_Parameter("PROJ", CSG_CRSProjector::Convert_CRS_To_PROJ(Definition));
-		pParameters->Set_Parameter("WKT1", CSG_CRSProjector::Convert_CRS_To_WKT1(Definition, bMultiLine));
-		pParameters->Set_Parameter("WKT2", CSG_CRSProjector::Convert_CRS_To_WKT2(Definition, bMultiLine, bSimplified));
-		pParameters->Set_Parameter("JSON", CSG_CRSProjector::Convert_CRS_To_JSON(Definition, bMultiLine));
-		pParameters->Set_Parameter("ESRI", CSG_CRSProjector::Convert_CRS_To_ESRI(Definition));
+		if( Format >= 5 || Format == 0 ) { pParameters->Set_Parameter("PROJ", CSG_CRSProjector::Convert_CRS_To_PROJ(Definition                         )); }
+		if( Format == 5 || Format == 1 ) { pParameters->Set_Parameter("WKT1", CSG_CRSProjector::Convert_CRS_To_WKT1(Definition, bMultiLine             )); }
+		if( Format >= 5 || Format == 2 ) { pParameters->Set_Parameter("WKT2", CSG_CRSProjector::Convert_CRS_To_WKT2(Definition, bMultiLine, bSimplified)); }
+		if( Format == 5 || Format == 3 ) { pParameters->Set_Parameter("JSON", CSG_CRSProjector::Convert_CRS_To_JSON(Definition, bMultiLine             )); }
+		if( Format == 5 || Format == 4 ) { pParameters->Set_Parameter("ESRI", CSG_CRSProjector::Convert_CRS_To_ESRI(Definition                         )); }
+		#ifdef _DEBUG
+		if( Format >= 5 || Format == 2 ) { pParameters->Set_Parameter("XML" , CSG_Projections::Convert_WKT2_to_XML((*pParameters)("WKT2")->asString()  )); }
+		#endif
 	}
 
 	return( CSG_Tool::On_Parameter_Changed(pParameters, pParameter) );
 }
 
+//---------------------------------------------------------
+int CCRS_Definition::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("FORMAT") )
+	{
+		int Format = pParameter->asInt();
+
+		pParameters->Set_Enabled("PROJ", Format >= 5 || Format == 0);
+		pParameters->Set_Enabled("WKT1", Format >= 5 || Format == 1);
+		pParameters->Set_Enabled("WKT2", Format >= 5 || Format == 2);
+		pParameters->Set_Enabled("JSON", Format >= 5 || Format == 3);
+		pParameters->Set_Enabled("ESRI", Format >= 5 || Format == 4);
+		#ifdef _DEBUG
+		pParameters->Set_Enabled("XML" , Format >= 5 || Format == 2);
+		#endif
+	}
+
+	return( CSG_Tool::On_Parameters_Enable(pParameters, pParameter) );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CCRS_Definition::On_Before_Execution(void)
+{
+	if( has_GUI() && !*Parameters("DEFINITION")->asString() )
+	{
+		Parameters.Set_Parameter("DEFINITION", "epsg:4326");
+	}
+
+	return( true );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -147,14 +194,36 @@ bool CCRS_Definition::On_Execute(void)
 		return( false );
 	}
 
-	bool bMultiLine = Parameters["MULTILINE"].asBool(), bSimplified = Parameters["SIMPLIFIED"].asBool();
+	int       Format = Parameters["FORMAT"    ].asInt ();
+	bool  bMultiLine = Parameters["MULTILINE" ].asBool();
+	bool bSimplified = Parameters["SIMPLIFIED"].asBool();
 
-	Set_Parameter("PROJ", CSG_CRSProjector::Convert_CRS_To_PROJ(Definition));
-	Set_Parameter("WKT1", CSG_CRSProjector::Convert_CRS_To_WKT1(Definition, bMultiLine));
-	Set_Parameter("WKT2", CSG_CRSProjector::Convert_CRS_To_WKT2(Definition, bMultiLine, bSimplified));
-	Set_Parameter("JSON", CSG_CRSProjector::Convert_CRS_To_JSON(Definition, bMultiLine));
-	Set_Parameter("ESRI", CSG_CRSProjector::Convert_CRS_To_ESRI(Definition));
+	//-----------------------------------------------------
+	CSG_String PROJ, WKT1, WKT2, JSON, ESRI;
 
+	switch( Format )
+	{
+	case  0: PROJ = CSG_CRSProjector::Convert_CRS_To_PROJ(Definition                         ); break;
+	case  1: WKT1 = CSG_CRSProjector::Convert_CRS_To_WKT1(Definition, bMultiLine             ); break;
+	case  2: WKT2 = CSG_CRSProjector::Convert_CRS_To_WKT2(Definition, bMultiLine, bSimplified); break;
+	case  3: JSON = CSG_CRSProjector::Convert_CRS_To_JSON(Definition, bMultiLine             ); break;
+	case  4: ESRI = CSG_CRSProjector::Convert_CRS_To_ESRI(Definition                         ); break;
+	case  5: CSG_CRSProjector::Convert_CRS_Format(Definition, &PROJ, &WKT1, &WKT2, &JSON, &ESRI, bMultiLine, bSimplified); break;
+	default: CSG_CRSProjector::Convert_CRS_Format(Definition, &PROJ,  NULL, &WKT2,  NULL,  NULL, bMultiLine, bSimplified); break;
+	}
+
+	Set_Parameter("PROJ", PROJ);
+	Set_Parameter("WKT1", WKT1);
+	Set_Parameter("WKT2", WKT2);
+	Set_Parameter("JSON", JSON);
+	Set_Parameter("ESRI", ESRI);
+
+	Set_Parameter("XML" , Format < 5 && Format != 2 ? CSG_String("") : CSG_Projections::Convert_WKT2_to_XML(WKT2));
+	#ifdef _DEBUG
+	Set_Parameter("XML" , Format < 5 && Format != 2 ? CSG_String("") : CSG_Projections::Convert_WKT2_to_XML(WKT2));
+	#endif
+
+	//-----------------------------------------------------
 	if( Parameters["FORMATS"].asTable() )
 	{
 		CSG_Table &Formats = *Parameters["FORMATS"].asTable(); Formats.Destroy(); Formats.Set_Name(_TL("CRS Definition"));
@@ -164,14 +233,24 @@ bool CCRS_Definition::On_Execute(void)
 
 		#define Add_Format(id) { CSG_Table_Record &r = *Formats.Add_Record(); r.Set_Value(0, Parameters[id].Get_Name()); r.Set_Value(1, Parameters[id].asString()); }
 
-		Add_Format("PROJ");
-		Add_Format("WKT1");
-		Add_Format("WKT2");
-		Add_Format("JSON");
-		Add_Format("ESRI");
+		if( Format >= 5 || Format == 0 ) { Add_Format("PROJ"); }
+		if( Format >= 5 || Format == 1 ) { Add_Format("WKT1"); }
+		if( Format >= 5 || Format == 2 ) { Add_Format("WKT2"); }
+		if( Format >= 5 || Format == 3 ) { Add_Format("JSON"); }
+		if( Format >= 5 || Format == 4 ) { Add_Format("ESRI"); }
 	}
 
-	return( SG_STR_LEN(Parameters["WKT2"].asString()) );
+	//-----------------------------------------------------
+	switch( Format )
+	{
+	case  0: Definition = Parameters["PROJ"].asString(); break;
+	case  1: Definition = Parameters["WKT1"].asString(); break;
+	default: Definition = Parameters["WKT2"].asString(); break;
+	case  3: Definition = Parameters["JSON"].asString(); break;
+	case  4: Definition = Parameters["ESRI"].asString(); break;
+	}
+
+	return( Definition.is_Empty() == false );
 }
 
 
