@@ -45,15 +45,6 @@
 //                                                       //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
 //---------------------------------------------------------
 #include "crs_distance.h"
 
@@ -81,14 +72,12 @@ CCRS_Distance_Calculator::~CCRS_Distance_Calculator(void)
 //---------------------------------------------------------
 bool CCRS_Distance_Calculator::Create(const CSG_Projection &Projection, double Epsilon)
 {
-	if( !m_ProjToGCS.Set_Source(Projection)
-	||  !m_ProjToGCS.Set_Target(CSG_Projection::Get_GCS_WGS84())
-	||  !m_Projector.Set_Target(Projection) )
+	if( !m_ProjToGCS.Set_Transformation(Projection, CSG_Projection::Get_GCS_WGS84()) || !m_Projector.Set_Target(Projection) )
 	{
 		return( false );
 	}
 
-	m_Epsilon	= Epsilon;
+	m_Epsilon = Epsilon;
 
 	return( true );
 }
@@ -101,21 +90,44 @@ bool CCRS_Distance_Calculator::Create(const CSG_Projection &Projection, double E
 //---------------------------------------------------------
 double CCRS_Distance_Calculator::Get_Orthodrome(const TSG_Point &A, const TSG_Point &B, CSG_Shape *pLine)
 {
-	static const TSG_Point	P0	= { 0.0, 0.0 };
+	const char *PROJ = "+proj=aeqd +R=6371000 +lon_0=%f +lat_0=%f";
+	const char *WKT2 =
+		"PROJCRS[\"<custom>\","
+		"    BASEGEODCRS[\"<custom>\","
+		"        DATUM[\"<custom>\","
+		"            ELLIPSOID[\"<custom>\",6371000,0]],"
+		"        UNIT[\"degree\",0.0174532925199433,"
+		"            ID[\"EPSG\",9122]]],"
+		"    CONVERSION[\"<custom>\","
+		"        METHOD[\"Azimuthal Equidistant\","
+		"            ID[\"EPSG\",1125]],"
+		"        PARAMETER[\"Latitude of natural origin\",%f,"
+		"            ID[\"EPSG\",8801]],"
+		"        PARAMETER[\"Longitude of natural origin\",%f,"
+		"            ID[\"EPSG\",8802]],"
+		"        PARAMETER[\"False easting\",0,"
+		"            ID[\"EPSG\",8806]],"
+		"        PARAMETER[\"False northing\",0,"
+		"            ID[\"EPSG\",8807]]],"
+		"    CS[Cartesian,2],"
+		"        AXIS[\"(E)\",east],"
+		"        AXIS[\"(N)\",north],"
+		"        UNIT[\"metre\",1,"
+		"            ID[\"EPSG\",9001]]]";
 
-	TSG_Point	P	= A;
+	static const TSG_Point P0 = { 0., 0. };
+
+	TSG_Point P = A;
 
 	if( m_ProjToGCS.Get_Projection(P) )
 	{
-		m_Projector.Set_Source(CSG_Projection(
-			CSG_String::Format("+proj=aeqd +R=6371000 +lon_0=%f +lat_0=%f", P.x, P.y))
-		);
+		CSG_Projection Projection(CSG_String::Format(WKT2, P.x, P.y), CSG_String::Format(PROJ, P.x, P.y)); // fast construction!
 
 		m_Projector.Set_Inverse();
 
-		if( m_Projector.Get_Projection(P = B) )
+		if( m_Projector.Set_Source(Projection, true) && m_Projector.Get_Projection(P = B) )
 		{
-			m_Projector.Set_Inverse(false);
+			m_Projector.Set_Forward();
 
 			Add_Segment(P0, P, pLine);
 
@@ -129,7 +141,7 @@ double CCRS_Distance_Calculator::Get_Orthodrome(const TSG_Point &A, const TSG_Po
 //---------------------------------------------------------
 double CCRS_Distance_Calculator::Get_Loxodrome(const TSG_Point &A, const TSG_Point &B, CSG_Shape *pLine)
 {
-	TSG_Point	AA, BB;
+	TSG_Point AA, BB;
 
 	m_Projector.Set_Source(CSG_Projection("+proj=merc +datum=WGS84"));
 
@@ -138,9 +150,9 @@ double CCRS_Distance_Calculator::Get_Loxodrome(const TSG_Point &A, const TSG_Poi
 	if( m_Projector.Get_Projection(AA = A)
 	&&  m_Projector.Get_Projection(BB = B) )
 	{
-		double	Length	= 0.0;
+		double Length = 0.;
 
-		m_Projector.Set_Inverse(false);
+		m_Projector.Set_Forward();
 
 		Add_Segment(AA, BB, pLine, &Length);
 
@@ -171,10 +183,10 @@ void CCRS_Distance_Calculator::Add_Segment(const TSG_Point &A, const TSG_Point &
 {
 	if( SG_Get_Distance(A, B) >= m_Epsilon )
 	{
-		TSG_Point	C, CC;
+		TSG_Point C, CC;
 
-		C.x	= CC.x = A.x + 0.5 * (B.x - A.x);
-		C.y	= CC.y = A.y + 0.5 * (B.y - A.y);
+		C.x = CC.x = A.x + 0.5 * (B.x - A.x);
+		C.y = CC.y = A.y + 0.5 * (B.y - A.y);
 
 		if( m_Projector.Get_Projection(CC) )
 		{
@@ -187,11 +199,11 @@ void CCRS_Distance_Calculator::Add_Segment(const TSG_Point &A, const TSG_Point &
 	}
 	else if( Length != NULL )
 	{
-		TSG_Point	AA, BB;
+		TSG_Point AA, BB;
 
 		if( m_Projector.Get_Projection(AA = A) && m_Projector.Get_Projection(BB = B) )
 		{
-			*Length	+= Get_Distance(AA, BB);
+			*Length += Get_Distance(AA, BB);
 		}
 	}
 }
@@ -206,7 +218,6 @@ void CCRS_Distance_Calculator::Add_Segment(const TSG_Point &A, const TSG_Point &
 //---------------------------------------------------------
 CCRS_Distance_Lines::CCRS_Distance_Lines(void)
 {
-	//-----------------------------------------------------
 	Set_Name		(_TL("Geographic Distances"));
 
 	Set_Author		("O. Conrad (c) 2015");
@@ -220,28 +231,28 @@ CCRS_Distance_Lines::CCRS_Distance_Lines(void)
 	Set_Description	(Get_Description() + "\n" + CSG_CRSProjector::Get_Description());
 
 	//-----------------------------------------------------
-	Parameters.Add_Shapes(
-		NULL	, "PLANAR"		, _TL("Segments"),
+	Parameters.Add_Shapes("",
+		"PLANAR"    , _TL("Segments"),
 		_TL(""),
 		PARAMETER_INPUT, SHAPE_TYPE_Line
 	);
 
-	Parameters.Add_Shapes(
-		NULL	, "ORTHODROME"	, _TL("Great Elliptic"),
+	Parameters.Add_Shapes("",
+		"ORTHODROME", _TL("Great Elliptic"),
 		_TL(""),
 		PARAMETER_OUTPUT, SHAPE_TYPE_Line
 	);
 
-	Parameters.Add_Shapes(
-		NULL	, "LOXODROME"	, _TL("Loxodrome"),
+	Parameters.Add_Shapes("",
+		"LOXODROME" , _TL("Loxodrome"),
 		_TL(""),
 		PARAMETER_OUTPUT, SHAPE_TYPE_Line
 	);
 
-	Parameters.Add_Value(
-		NULL	, "EPSILON"	, _TL("Epsilon"),
+	Parameters.Add_Double("",
+		"EPSILON"   , _TL("Epsilon"),
 		_TL("defines the maximum resolution [km] for the re-projected distance segments"),
-		PARAMETER_TYPE_Double, 100.0, 1.0, true
+		100., 1., true
 	);
 }
 
@@ -253,15 +264,14 @@ CCRS_Distance_Lines::CCRS_Distance_Lines(void)
 //---------------------------------------------------------
 bool CCRS_Distance_Lines::On_Execute(void)
 {
-	//-----------------------------------------------------
-	CSG_Shapes	*pPlanars		= Parameters("PLANAR"    )->asShapes();
-	CSG_Shapes	*pOrthodromes	= Parameters("ORTHODROME")->asShapes();
-	CSG_Shapes	*pLoxodromes	= Parameters("LOXODROME" )->asShapes();
+	CSG_Shapes *pPlanars     = Parameters("PLANAR"    )->asShapes();
+	CSG_Shapes *pOrthodromes = Parameters("ORTHODROME")->asShapes();
+	CSG_Shapes *pLoxodromes  = Parameters("LOXODROME" )->asShapes();
 
 	//-----------------------------------------------------
-	CCRS_Distance_Calculator	Distance;
+	CCRS_Distance_Calculator Distance;
 
-	if( !Distance.Create(pPlanars->Get_Projection(), Parameters("EPSILON")->asDouble() * 1000.0) )
+	if( !Distance.Create(pPlanars->Get_Projection(), Parameters("EPSILON")->asDouble() * 1000.) )
 	{
 		Error_Set(_TL("projection initialization failed"));
 
@@ -280,16 +290,16 @@ bool CCRS_Distance_Lines::On_Execute(void)
 	//-----------------------------------------------------
 	for(sLong iShape=0; iShape<pPlanars->Get_Count() && Set_Progress(iShape, pPlanars->Get_Count()); iShape++)
 	{
-		CSG_Shape_Line	*pProj	= (CSG_Shape_Line *)pPlanars->Get_Shape(iShape);
+		CSG_Shape_Line *pProj = (CSG_Shape_Line *)pPlanars->Get_Shape(iShape);
 
 		for(int iPart=0; iPart<pProj->Get_Part_Count(); iPart++)
 		{
 			if( pProj->Get_Point_Count(iPart) > 1 )
 			{
-				TSG_Point	A, B	= pProj->Get_Point(0, iPart);
+				TSG_Point A, B = pProj->Get_Point(0, iPart);
 
-				CSG_Shape_Line	*pOrthodrome = (CSG_Shape_Line *)pOrthodromes->Add_Shape(pProj, SHAPE_COPY_ATTR);
-				CSG_Shape_Line	*pLoxodrome  = (CSG_Shape_Line *)pLoxodromes->Add_Shape(pProj, SHAPE_COPY_ATTR);
+				CSG_Shape_Line *pOrthodrome = (CSG_Shape_Line *)pOrthodromes->Add_Shape(pProj, SHAPE_COPY_ATTR);
+				CSG_Shape_Line *pLoxodrome  = (CSG_Shape_Line *)pLoxodromes->Add_Shape(pProj, SHAPE_COPY_ATTR);
 
 				pOrthodrome->Set_Value(pPlanars->Get_Field_Count() + 0, pProj->Get_Length(iPart));
 				pLoxodrome ->Set_Value(pPlanars->Get_Field_Count() + 0, pProj->Get_Length(iPart));
@@ -297,15 +307,15 @@ bool CCRS_Distance_Lines::On_Execute(void)
 				pOrthodrome->Add_Point(B);
 				pLoxodrome ->Add_Point(B);
 
-				double	dOrthodrome	= 0.0;
-				double	dLoxodrome	= 0.0;
+				double dOrthodrome = 0.;
+				double dLoxodrome  = 0.;
 
 				for(int iPoint=1; iPoint<pProj->Get_Point_Count(iPart); iPoint++)
 				{
-					A	= B;	B	= pProj->Get_Point(iPoint, iPart);
+					A = B; B = pProj->Get_Point(iPoint, iPart);
 
-					dOrthodrome	+= Distance.Get_Orthodrome(A, B, pOrthodrome);
-					dLoxodrome	+= Distance.Get_Loxodrome (A, B, pLoxodrome );
+					dOrthodrome += Distance.Get_Orthodrome(A, B, pOrthodrome);
+					dLoxodrome  += Distance.Get_Loxodrome (A, B, pLoxodrome );
 
 					pOrthodrome->Add_Point(B);
 					pLoxodrome ->Add_Point(B);
@@ -341,26 +351,24 @@ CCRS_Distance_Points::CCRS_Distance_Points(void)
 		"of the input lines. "
 	));
 
-	Parameters.Add_Shapes(
-		NULL	, "DISTANCES"	, _TL("Geographic Distances"),
+	Parameters.Add_Shapes("",
+		"DISTANCES", _TL("Geographic Distances"),
 		_TL(""),
 		PARAMETER_OUTPUT, SHAPE_TYPE_Line
 	);
 
-	CSG_Parameter	*pNode;
+	Parameters.Add_Node  ("", "FROM", _TL("From"), _TL(""));
+	Parameters.Add_Double("FROM", "COORD_X1", _TL("X"), _TL(""),  10.0);
+	Parameters.Add_Double("FROM", "COORD_Y1", _TL("Y"), _TL(""),  53.5);
 
-	pNode	= Parameters.Add_Node(NULL, "NODE_A", _TL("From"), _TL(""));
-	Parameters.Add_Value(pNode, "COORD_X1", _TL("X"), _TL(""), PARAMETER_TYPE_Double,  10.0);
-	Parameters.Add_Value(pNode, "COORD_Y1", _TL("Y"), _TL(""), PARAMETER_TYPE_Double,  53.5);
+	Parameters.Add_Node  ("", "TO"  , _TL("To"  ), _TL(""));
+	Parameters.Add_Double("TO"  , "COORD_X2", _TL("X"), _TL(""), 116.5);
+	Parameters.Add_Double("TO"  , "COORD_Y2", _TL("Y"), _TL(""),   6.4);
 
-	pNode	= Parameters.Add_Node(NULL, "NODE_B", _TL("To"  ), _TL(""));
-	Parameters.Add_Value(pNode, "COORD_X2", _TL("X"), _TL(""), PARAMETER_TYPE_Double, 116.5);
-	Parameters.Add_Value(pNode, "COORD_Y2", _TL("Y"), _TL(""), PARAMETER_TYPE_Double,   6.4);
-
-	Parameters.Add_Value(
-		NULL	, "EPSILON"		, _TL("Epsilon"),
+	Parameters.Add_Double("",
+		"EPSILON", _TL("Epsilon"),
 		_TL("defines the maximum resolution [km] for the re-projected distance segments"),
-		PARAMETER_TYPE_Double, 100.0, 1.0, true
+		100., 1., true
 	);
 }
 
@@ -372,8 +380,7 @@ CCRS_Distance_Points::CCRS_Distance_Points(void)
 //---------------------------------------------------------
 bool CCRS_Distance_Points::On_Execute(void)
 {
-	//-----------------------------------------------------
-	CSG_Projection	Projection;
+	CSG_Projection Projection;
 
 	if( !Get_Projection(Projection) )
 	{
@@ -381,9 +388,9 @@ bool CCRS_Distance_Points::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	CCRS_Distance_Calculator	Distance;
+	CCRS_Distance_Calculator Distance;
 
-	if( !Distance.Create(Projection, Parameters("EPSILON")->asDouble() * 1000.0) )
+	if( !Distance.Create(Projection, Parameters("EPSILON")->asDouble() * 1000.) )
 	{
 		Error_Set(_TL("projection initialization failed"));
 
@@ -391,28 +398,30 @@ bool CCRS_Distance_Points::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	TSG_Point	A, B;
+	CSG_Point A(
+		Parameters("COORD_X1")->asDouble(),
+		Parameters("COORD_Y1")->asDouble()
+	);
 
-	A.x	= Parameters("COORD_X1")->asDouble();
-	A.y	= Parameters("COORD_Y1")->asDouble();
-
-	B.x	= Parameters("COORD_X2")->asDouble();
-	B.y	= Parameters("COORD_Y2")->asDouble();
+	CSG_Point B(
+		Parameters("COORD_X2")->asDouble(),
+		Parameters("COORD_Y2")->asDouble()
+	);
 
 	//-----------------------------------------------------
-	CSG_Shapes	*pDistances	= Parameters("DISTANCES")->asShapes();
+	CSG_Shapes *pDistances = Parameters("DISTANCES")->asShapes();
 
-	pDistances	->Create(SHAPE_TYPE_Line, CSG_String::Format("%s", _TL("Geographic Distances")));
+	pDistances->Create(SHAPE_TYPE_Line, CSG_String::Format("%s", _TL("Geographic Distances")));
 
-	pDistances	->Add_Field("TYPE"  , SG_DATATYPE_String);
-	pDistances	->Add_Field("LENGTH", SG_DATATYPE_Double);
+	pDistances->Add_Field("TYPE"  , SG_DATATYPE_String);
+	pDistances->Add_Field("LENGTH", SG_DATATYPE_Double);
 
-	pDistances	->Get_Projection().Create(Projection);
+	pDistances->Get_Projection().Create(Projection);
 
 	//-----------------------------------------------------
-	CSG_Shape	*pPlanar     = pDistances->Add_Shape();	pPlanar    ->Set_Value(0, "Planar"    );
-	CSG_Shape	*pOrthodrome = pDistances->Add_Shape();	pOrthodrome->Set_Value(0, "Orthodrome");
-	CSG_Shape	*pLoxodrome  = pDistances->Add_Shape();	pLoxodrome ->Set_Value(0, "Loxodrome" );
+	CSG_Shape *pPlanar     = pDistances->Add_Shape(); pPlanar    ->Set_Value(0, "Planar"    );
+	CSG_Shape *pOrthodrome = pDistances->Add_Shape(); pOrthodrome->Set_Value(0, "Orthodrome");
+	CSG_Shape *pLoxodrome  = pDistances->Add_Shape(); pLoxodrome ->Set_Value(0, "Loxodrome" );
 
 	pPlanar    ->Add_Point(A);
 	pOrthodrome->Add_Point(A);
@@ -450,16 +459,16 @@ CCRS_Distance_Interactive::CCRS_Distance_Interactive(void)
 		"of the input lines. "
 	));
 
-	Parameters.Add_Shapes(
-		NULL	, "DISTANCES"	, _TL("Geographic Distances"),
+	Parameters.Add_Shapes("",
+		"DISTANCES", _TL("Geographic Distances"),
 		_TL(""),
 		PARAMETER_OUTPUT, SHAPE_TYPE_Line
 	);
 
-	Parameters.Add_Value(
-		NULL	, "EPSILON"		, _TL("Epsilon"),
+	Parameters.Add_Double("",
+		"EPSILON"  , _TL("Epsilon"),
 		_TL("defines the maximum resolution [km] for the re-projected distance segments"),
-		PARAMETER_TYPE_Double, 100.0, 1.0, true
+		100., 1., true
 	);
 
 	Set_Drag_Mode(TOOL_INTERACTIVE_DRAG_LINE);
@@ -468,7 +477,7 @@ CCRS_Distance_Interactive::CCRS_Distance_Interactive(void)
 //---------------------------------------------------------
 bool CCRS_Distance_Interactive::On_Execute(void)
 {
-	CCRS_Picker	CRS;
+	CCRS_Picker CRS;
 
 	if( !Dlg_Parameters(CRS.Get_Parameters(), CRS.Get_Name()) )
 	{
@@ -477,7 +486,9 @@ bool CCRS_Distance_Interactive::On_Execute(void)
 		return( false );
 	}
 
-	return( m_Projection.Create(CRS.Get_Parameters()->Get_Parameter("CRS_WKT")->asString()) );
+	CSG_Parameters &P = *CRS.Get_Parameters();
+
+	return( m_Projection.Create(P["CRS_WKT"].asString(), P["CRS_PROJ"].asString()) );
 }
 
 //---------------------------------------------------------
@@ -485,21 +496,22 @@ bool CCRS_Distance_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_
 {
 	if( Mode == TOOL_INTERACTIVE_LDOWN )
 	{
-		m_Down	= ptWorld;
+		m_Down = ptWorld;
 	}
 	else if( Mode == TOOL_INTERACTIVE_LUP )
 	{
 		if( m_Down != ptWorld )
 		{
-			CCRS_Distance_Points	Distance;
+			CCRS_Distance_Points Distance;
 
-			Distance.Set_Parameter("DISTANCES" , Parameters("DISTANCES")->asShapes());
-			Distance.Set_Parameter("EPSILON"   , Parameters("EPSILON"  )->asDouble());
-			Distance.Set_Parameter("CRS_STRING", m_Projection.Get_WKT());
-			Distance.Set_Parameter("COORD_X1"  , m_Down .x);
-			Distance.Set_Parameter("COORD_Y1"  , m_Down .y);
-			Distance.Set_Parameter("COORD_X2"  , ptWorld.x);
-			Distance.Set_Parameter("COORD_Y2"  , ptWorld.y);
+			Distance.Set_Parameter("DISTANCES", Parameters("DISTANCES")->asShapes());
+			Distance.Set_Parameter("EPSILON"  , Parameters("EPSILON"  )->asDouble());
+			Distance.Set_Parameter("CRS_WKT"  , m_Projection.Get_WKT ());
+			Distance.Set_Parameter("CRS_PROJ" , m_Projection.Get_PROJ());
+			Distance.Set_Parameter("COORD_X1" , m_Down .x);
+			Distance.Set_Parameter("COORD_Y1" , m_Down .y);
+			Distance.Set_Parameter("COORD_X2" , ptWorld.x);
+			Distance.Set_Parameter("COORD_Y2" , ptWorld.y);
 
 			Distance.Execute();
 
