@@ -102,15 +102,9 @@ CCRS_Transform_Grid::CCRS_Transform_Grid(bool bList)
 		_TL("")
 	);
 
-	Parameters.Add_Choice("TARGET_NODE",
+	Parameters.Add_Grid_Resampling("TARGET_NODE",
 		"RESAMPLING"	, _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_Bool("TARGET_NODE",
@@ -227,13 +221,7 @@ bool CCRS_Transform_Grid::On_Execute_Transformation(void)
 	}
 
 	//-----------------------------------------------------
-	switch( Parameters("RESAMPLING")->asInt() )
-	{
-	default: m_Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: m_Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: m_Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: m_Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+	m_Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 	m_bByteWise = Parameters("BYTEWISE")->asBool();
 
@@ -289,7 +277,7 @@ bool CCRS_Transform_Grid::On_Execute_Transformation(void)
 		{
 			TSG_Data_Type Type = Parameters("DATA_TYPE")->asDataType()->Get_Data_Type();
 			
-			if( m_Resampling == GRID_RESAMPLING_NearestNeighbour || m_bByteWise || Type == SG_DATATYPE_Undefined )
+			if( m_Resampling == CSG_Grid_Resampling::NearestNeighbour || m_bByteWise || Type == SG_DATATYPE_Undefined )
 			{
 				Type = pGrid->Get_Type();
 			}
@@ -452,7 +440,7 @@ bool CCRS_Transform_Grid::Transform(const CSG_Array_Pointer &Grids, CSG_Paramete
 
 	TSG_Data_Type Type = Parameters("DATA_TYPE")->asDataType()->Get_Data_Type();
 
-	if( m_Resampling == GRID_RESAMPLING_NearestNeighbour || m_bByteWise )
+	if( m_Resampling == CSG_Grid_Resampling::NearestNeighbour || m_bByteWise )
 	{
 		Type = SG_DATATYPE_Undefined;
 	}
