@@ -128,7 +128,7 @@ CCRS_Transform_Shapes::CCRS_Transform_Shapes(bool bList)
 
 	Parameters.Add_Bool("",
 		"COPY"			, _TL("Copy"),
-		_TL("If set the projected data will be created as a copy of the orignal, if not vertices will be projected in place thus reducing memory requirements."),
+		_TL("If set the projected data will be created as a copy of the original, if not vertices will be projected in place thus reducing memory requirements."),
 		true
 	);
 }
@@ -237,12 +237,7 @@ bool CCRS_Transform_Shapes::On_Execute_Transformation(void)
 //---------------------------------------------------------
 bool CCRS_Transform_Shapes::Transform(CSG_Shapes *pShapes)
 {
-	if( !pShapes || !pShapes->is_Valid() )
-	{
-		return( false );
-	}
-
-	if( !m_Projector.Set_Source(pShapes->Get_Projection()) )
+	if( !pShapes || !pShapes->is_Valid() || !m_Projector.Set_Source(pShapes->Get_Projection(), true) )
 	{
 		return( false );
 	}
@@ -254,7 +249,7 @@ bool CCRS_Transform_Shapes::Transform(CSG_Shapes *pShapes)
 	CSG_Array _Okay(sizeof(bool), pShapes->Get_Count()); bool *bOkay = (bool *)_Okay.Get_Array();
 
 	//-----------------------------------------------------
-	if( !Parameters("PARALLEL") || !Parameters("PARALLEL")->asBool() || SG_OMP_Get_Max_Num_Threads() < 2 )
+	if( !Parameters("PARALLEL") || !Parameters("PARALLEL")->asBool() || SG_OMP_Get_Max_Num_Threads() < 2 || pShapes->Get_Count() < 1000 * SG_OMP_Get_Max_Num_Threads() )
 	{
 		for(sLong i=0; i<pShapes->Get_Count() && Set_Progress(i, pShapes->Get_Count()); i++)
 		{
