@@ -283,7 +283,7 @@ bool CGrid_To_Contour::On_Execute(void)
 			return( false );
 		}
 
-		Patched.Assign(m_pGrid, GRID_RESAMPLING_NearestNeighbour);
+		Patched.Assign(m_pGrid, CSG_Grid_Resampling::NearestNeighbour);
 
 		#pragma omp parallel for
 		for(int y=0; y<Patched.Get_NY(); y++) for(int x=0; x<Patched.Get_NX(); x++)
@@ -325,7 +325,7 @@ bool CGrid_To_Contour::On_Execute(void)
 			return( false );
 		}
 
-		Scaled.Assign(m_pGrid, GRID_RESAMPLING_BSpline);
+		Scaled.Assign(m_pGrid, CSG_Grid_Resampling::Bicubic_2);
 
 		m_pGrid	= &Scaled; Patched.Destroy();
 	}
@@ -389,6 +389,8 @@ bool CGrid_To_Contour::On_Execute(void)
 
 		if( Parameters("POLY_OMP")->asBool() )
 		{
+			m_pGrid->Update(true); // ensur statistics is up-to-date before entering parallelization! otherwise requesting e.g. grid's maximum value will likely be incorrect!
+
 			pPolygons->Set_Count(pContours->Get_Count() + 1);
 
 			#pragma omp parallel for
