@@ -182,7 +182,7 @@ bool CGrid_To_Gradient::On_Execute(void)
 	double sMin   = Parameters("SIZE.MIN")->asDouble() * Step * Get_Cellsize() / 100.;
 	double sRange = Parameters("SIZE.MAX")->asDouble() * Step * Get_Cellsize() / 100. - sMin;
 
-	TSG_Grid_Resampling Interpolation = Parameters("AGGR")->asInt() == 0 ? GRID_RESAMPLING_NearestNeighbour : GRID_RESAMPLING_Mean_Cells;
+	CSG_Grid_Resampling Interpolation = Parameters("AGGR")->asInt() == 0 ? CSG_Grid_Resampling::NearestNeighbour : CSG_Grid_Resampling::Mean_Cells;
 
 	//-----------------------------------------------------
 	if( Step > Get_NX() || Step > Get_NY() )
