@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -88,21 +88,15 @@ CGrid_Values_AddTo_Points::CGrid_Values_AddTo_Points(void)
 		PARAMETER_OUTPUT_OPTIONAL, SHAPE_TYPE_Point
 	);
 
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"RESAMPLING", _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -136,14 +130,14 @@ bool CGrid_Values_AddTo_Points::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling;
+	CSG_Grid_Resampling	Resampling;
 
 	switch( Parameters("RESAMPLING")->asInt() )
 	{
-	default: Resampling	= GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling	= GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling	= GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling	= GRID_RESAMPLING_BSpline         ; break;
+	default: Resampling	= CSG_Grid_Resampling::NearestNeighbour; break;
+	case  1: Resampling	= CSG_Grid_Resampling::Bilinear        ; break;
+	case  2: Resampling	= CSG_Grid_Resampling::Bicubic_1   ; break;
+	case  3: Resampling	= CSG_Grid_Resampling::Bicubic_2         ; break;
 	}
 
 	//-----------------------------------------------------
@@ -177,9 +171,9 @@ bool CGrid_Values_AddTo_Points::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
