@@ -83,19 +83,25 @@ CConvex_Hull::CConvex_Hull(void)
 
 	//-----------------------------------------------------
 	Parameters.Add_Shapes("",
-		"SHAPES"	, _TL("Points"),
+		"SHAPES"    , _TL("Points"),
 		_TL(""),
 		PARAMETER_INPUT
 	);
 
+	Parameters.Add_Table_Field("SHAPES",
+		"FIELD"     , _TL("Object Identifier"),
+		_TL(""),
+		true
+	);
+
 	Parameters.Add_Shapes("",
-		"HULLS"		, _TL("Convex Hull"),
+		"HULLS"     , _TL("Convex Hull"),
 		_TL(""),
 		PARAMETER_OUTPUT, SHAPE_TYPE_Polygon
 	);
 
 	Parameters.Add_Shapes("",
-		"BOXES"		, _TL("Minimum Bounding Box"),
+		"BOXES"     , _TL("Minimum Bounding Box"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL, SHAPE_TYPE_Polygon
 	);
@@ -125,8 +131,9 @@ CConvex_Hull::CConvex_Hull(void)
 //---------------------------------------------------------
 int CConvex_Hull::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	CSG_Shapes	*pShapes	= (*pParameters)("SHAPES")->asShapes();
+	CSG_Shapes *pShapes = (*pParameters)("SHAPES")->asShapes();
 
+	pParameters->Set_Enabled("FIELD"     , pShapes && pShapes->Get_Type() == SHAPE_TYPE_Point);
 	pParameters->Set_Enabled("POLYPOINTS", pShapes && pShapes->Get_Type() != SHAPE_TYPE_Point);
 	pParameters->Set_Enabled("POLYGONCVX", pShapes && pShapes->Get_Type() == SHAPE_TYPE_Polygon && (*pParameters)("POLYPOINTS")->asInt() == 1);
 
@@ -141,10 +148,9 @@ int CConvex_Hull::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramete
 //---------------------------------------------------------
 bool CConvex_Hull::On_Execute(void)
 {
-	//-----------------------------------------------------
-	CSG_Shapes	*pShapes = Parameters("SHAPES")->asShapes();
-	CSG_Shapes	*pHulls  = Parameters("HULLS" )->asShapes();
-	CSG_Shapes	*pBoxes  = Parameters("BOXES" )->asShapes();
+	CSG_Shapes *pShapes = Parameters("SHAPES")->asShapes();
+	CSG_Shapes *pHulls  = Parameters("HULLS" )->asShapes();
+	CSG_Shapes *pBoxes  = Parameters("BOXES" )->asShapes();
 
 	//-----------------------------------------------------
 	pHulls->Create(SHAPE_TYPE_Polygon, CSG_String::Format("%s [%s]", pShapes->Get_Name(), _TL("Convex Hull")));
@@ -153,26 +159,20 @@ bool CConvex_Hull::On_Execute(void)
 	pHulls->Add_Field(_TL("PERIMETER"), SG_DATATYPE_Double);	// 2
 
 	//-----------------------------------------------------
-	int	nOkay	= 0;
+	int nOkay = 0;
 
 	//-----------------------------------------------------
-	if( pShapes->Get_Type() == SHAPE_TYPE_Point )
+	if( pShapes->Get_Type() != SHAPE_TYPE_Point )
 	{
-		nOkay	= Get_Chain_Hull(pShapes, pHulls) ? 1 : 0;
-	}
+		CSG_Shapes Points(SHAPE_TYPE_Point);
 
-	//-----------------------------------------------------
-	else
-	{
-		CSG_Shapes	Points(SHAPE_TYPE_Point);
+		int Construction = Parameters("POLYPOINTS")->asInt();
 
-		int	Construction	= Parameters("POLYPOINTS")->asInt();
-
-		bool	bConvexity	= pShapes->Get_Type() == SHAPE_TYPE_Polygon && Construction == 1 && Parameters("POLYGONCVX")->asBool();
+		bool bConvexity = pShapes->Get_Type() == SHAPE_TYPE_Polygon && Construction == 1 && Parameters("POLYGONCVX")->asBool();
 
 		if( bConvexity )
 		{
-			pHulls->Add_Field(_TL("CONVEXITY"), SG_DATATYPE_Double);	// 3
+			pHulls->Add_Field(_TL("CONVEXITY"), SG_DATATYPE_Double); // 3
 		}
 
 		if( Construction != 0 )
@@ -185,7 +185,7 @@ bool CConvex_Hull::On_Execute(void)
 
 		for(sLong iShape=0; iShape<pShapes->Get_Count() && Set_Progress(iShape, pShapes->Get_Count()); iShape++)
 		{
-			CSG_Shape	*pShape	= pShapes->Get_Shape(iShape);
+			CSG_Shape *pShape = pShapes->Get_Shape(iShape);
 
 			for(int iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
 			{
@@ -196,22 +196,84 @@ bool CConvex_Hull::On_Execute(void)
 
 				if( Construction == 2 )	// one hull per shape part
 				{
-					if( Get_Chain_Hull(&Points, pHulls, pShape) )	nOkay++;	Points.Del_Records();
+					if( Get_Chain_Hull(&Points, pHulls, pShape) )
+					{
+						nOkay++;
+					}
+
+					Points.Del_Records();
 				}
 			}
 
 			if( Construction == 1 )	// one hull per shape
 			{
-				if( Get_Chain_Hull(&Points, pHulls, pShape, bConvexity) )	nOkay++;	Points.Del_Records();
+				if( Get_Chain_Hull(&Points, pHulls, pShape, bConvexity) )
+				{
+					nOkay++;
+				}
+
+				Points.Del_Records();
 			}
 		}
 
 		if( Construction == 0 )	// one hull for all shapes
 		{
-			if( Get_Chain_Hull(&Points, pHulls) )	nOkay++;	Points.Del_Records();
+			if( Get_Chain_Hull(&Points, pHulls) )
+			{
+				nOkay++;
+			}
 		}
 	}
 
+	//-----------------------------------------------------
+	else if( Parameters("FIELD")->asInt() >= 0 ) // if( pShapes->Get_Type() == SHAPE_TYPE_Point )
+	{
+		CSG_Shapes Points(SHAPE_TYPE_Point);
+
+		int Field = Parameters("FIELD")->asInt();
+
+		pHulls->Add_Field(pShapes->Get_Field_Name(Field), pShapes->Get_Field_Type(Field)); // field index := 3
+
+		CSG_String ID; CSG_Index Index; pShapes->Set_Index(Index, Field);
+
+		for(sLong iShape=0; iShape<pShapes->Get_Count() && Set_Progress(iShape, pShapes->Get_Count()); iShape++)
+		{
+			CSG_Shape *pShape = pShapes->Get_Shape(Index[iShape]);
+
+			if( iShape == 0 )
+			{
+				ID = pShape->asString(Field);
+			}
+			else if( ID.Cmp(pShape->asString(Field)) ) // new object
+			{
+				CSG_Shape *pHull = Get_Chain_Hull(&Points, pHulls); Points.Del_Records();
+
+				if( pHull )
+				{
+					nOkay++; pHull->Set_Value(3, ID);
+				}
+
+				ID = pShape->asString(Field);
+			}
+
+			Points.Add_Shape()->Add_Point(pShape->Get_Point());
+		}
+
+		CSG_Shape *pHull = Get_Chain_Hull(&Points, pHulls);
+
+		if( pHull )
+		{
+			nOkay++; pHull->Set_Value(3, ID);
+		}
+	}
+
+	//-----------------------------------------------------
+	else
+	{
+		nOkay = Get_Chain_Hull(pShapes, pHulls) ? 1 : 0;
+	}
+
+	//-----------------------------------------------------
 	if( nOkay <= 0 )
 	{
 		return( false );
@@ -243,54 +305,48 @@ bool CConvex_Hull::On_Execute(void)
 //---------------------------------------------------------
 bool CConvex_Hull::Get_Bounding_Box(CSG_Shape *pHull, CSG_Shape *pBox)
 {
-	int			i, iBox;
-	double		a, aBox, d, dBox, dSin, dCos;
-	TSG_Rect	r, rBox;
-	TSG_Point	A, B;
+	double aBox = 0., dBox = 0.; CSG_Rect rBox;
 
-	B	= pHull->Get_Point(pHull->Get_Point_Count() - 1);
+	TSG_Point B = pHull->Get_Point(pHull->Get_Point_Count() - 1);
 
-	for(i=0; i<pHull->Get_Point_Count(); i++)
+	for(int i=0; i<pHull->Get_Point_Count(); i++)
 	{
-		A		= B;
-		B		= pHull->Get_Point(i);
-		d		= SG_Get_Angle_Of_Direction(A, B);
-		dSin	= sin(-d);
-		dCos	= cos(-d);
+		TSG_Point A = B; B = pHull->Get_Point(i); CSG_Rect r;
+
+		double d = SG_Get_Angle_Of_Direction(A, B); double dSin = sin(-d), dCos = cos(-d);
 
 		for(int j=0; j<pHull->Get_Point_Count(); j++)
 		{
-			TSG_Point	q, p	= pHull->Get_Point(j);
+			TSG_Point q, p = pHull->Get_Point(j);
 
-			q.x	= p.x * dCos - p.y * dSin;
-			q.y	= p.x * dSin + p.y * dCos;
+			q.x = p.x * dCos - p.y * dSin;
+			q.y = p.x * dSin + p.y * dCos;
 
 			if( j == 0 )
 			{
-				r.xMin	= r.xMax	= q.x;
-				r.yMin	= r.yMax	= q.y;
+				r.xMin = r.xMax = q.x;
+				r.yMin = r.yMax = q.y;
 			}
 			else
 			{
-				if( r.xMin > q.x ) r.xMin = q.x; else if( r.xMax < q.x ) r.xMax = q.x;
-				if( r.yMin > q.y ) r.yMin = q.y; else if( r.yMax < q.y ) r.yMax = q.y;
+				if( r.xMin > q.x ) { r.xMin = q.x; } else if( r.xMax < q.x ) { r.xMax = q.x; }
+				if( r.yMin > q.y ) { r.yMin = q.y; } else if( r.yMax < q.y ) { r.yMax = q.y; }
 			}
 		}
 
-		a	= (r.xMax - r.xMin) * (r.yMax - r.yMin);
+		double a = (r.xMax - r.xMin) * (r.yMax - r.yMin);
 
 		if( i == 0 || a < aBox )
 		{
-			iBox	= i;
-			aBox	= a;
-			dBox	= d;
-			rBox	= r;
+			aBox = a;
+			dBox = d;
+			rBox = r;
 		}
 	}
 
 	//-----------------------------------------------------
-	dSin	= sin(dBox);
-	dCos	= cos(dBox);
+	double dSin = sin(dBox);
+	double dCos = cos(dBox);
 
 	pBox->Add_Point(rBox.xMin * dCos - rBox.yMin * dSin, rBox.xMin * dSin + rBox.yMin * dCos);
 	pBox->Add_Point(rBox.xMin * dCos - rBox.yMax * dSin, rBox.xMin * dSin + rBox.yMax * dCos);
@@ -314,48 +370,47 @@ bool CConvex_Hull::Get_Bounding_Box(CSG_Shape *pHull, CSG_Shape *pBox)
 class CIndex_Compare_Points : public CSG_Index::CSG_Index_Compare
 {
 public:
-	CSG_Shapes	*m_pPoints;
+	CSG_Shapes *m_pPoints;
 
 	CIndex_Compare_Points(CSG_Shapes *pPoints) : m_pPoints(pPoints) {}
 
-	virtual int			Compare		(const sLong _a, const sLong _b)
+	virtual int Compare(const sLong _a, const sLong _b)
 	{
-		TSG_Point	a	= m_pPoints->Get_Shape(_a)->Get_Point();
-		TSG_Point	b	= m_pPoints->Get_Shape(_b)->Get_Point();
+		TSG_Point a = m_pPoints->Get_Shape(_a)->Get_Point();
+		TSG_Point b = m_pPoints->Get_Shape(_b)->Get_Point();
 
-		if( a.x < b.x )	{	return( -1 );	}
-		if( a.x > b.x )	{	return(  1 );	}
+		if( a.x < b.x ) { return( -1 ); }
+		if( a.x > b.x ) { return(  1 ); }
 
-		if( a.y < b.y )	{	return( -1 );	}
-		if( a.y > b.y )	{	return(  1 );	}
+		if( a.y < b.y ) { return( -1 ); }
+		if( a.y > b.y ) { return(  1 ); }
 
 		return( 0 );
 	}
 };
 
 //---------------------------------------------------------
-bool CConvex_Hull::Get_Chain_Hull(CSG_Shapes *pPoints, CSG_Shapes *pHulls, CSG_Shape *pAttributes, bool bConvexity)
+CSG_Shape_Polygon * CConvex_Hull::Get_Chain_Hull(CSG_Shapes *pPoints, CSG_Shapes *pHulls, CSG_Shape *pAttributes, bool bConvexity)
 {
-	//-----------------------------------------------------
 	if( pPoints->Get_Count() < 3 )
 	{
 		Error_Set(_TL("less than three points"));
 
-		return( false );
+		return( NULL );
 	}
 
 	//-----------------------------------------------------
-	CSG_Points	Points;
+	CSG_Points Points;
 
 	CIndex_Compare_Points Compare(pPoints);
 
-	CSG_Index	Index(pPoints->Get_Count(), &Compare);
+	CSG_Index Index(pPoints->Get_Count(), &Compare);
 
 	if( !Index.is_Okay() )
 	{
 		Error_Set(_TL("index creation failed"));
 
-		return( false );
+		return( NULL );
 	}
 
 	for(int i=0; i<pPoints->Get_Count(); i++)
@@ -366,19 +421,19 @@ bool CConvex_Hull::Get_Chain_Hull(CSG_Shapes *pPoints, CSG_Shapes *pHulls, CSG_S
 	Index.Destroy();
 
 	//-----------------------------------------------------
-	CSG_Points	Hull;
+	CSG_Points Hull;
 
-	int	nHullPoints	= Get_Chain_Hull(Points, Hull);
+	int nHullPoints = Get_Chain_Hull(Points, Hull);
 
 	if( nHullPoints < 3 )
 	{
 		Error_Set(_TL("convex hull creation failed"));
 
-		return( false );
+		return( NULL );
 	}
 
 	//-----------------------------------------------------
-	CSG_Shape_Polygon	*pHull	= (CSG_Shape_Polygon *)pHulls->Add_Shape();
+	CSG_Shape_Polygon *pHull = (CSG_Shape_Polygon *)pHulls->Add_Shape();
 
 	for(int i=0; i<nHullPoints && Process_Get_Okay(); i++)
 	{
@@ -398,12 +453,12 @@ bool CConvex_Hull::Get_Chain_Hull(CSG_Shapes *pPoints, CSG_Shapes *pHulls, CSG_S
 
 		for(int i=bConvexity?4:3, n=0; i<pHulls->Get_Field_Count(); i++, n++)
 		{
-			*pHull->Get_Value(i)	= *pAttributes->Get_Value(n);
+			*pHull->Get_Value(i) = *pAttributes->Get_Value(n);
 		}
 	}
 
 	//-----------------------------------------------------
-	return( true );
+	return( pHull );
 }
 
 
@@ -457,7 +512,7 @@ int CConvex_Hull::Get_Chain_Hull(CSG_Points &P, CSG_Points &H)
 	//-----------------------------------------------------
     // the output array H[] will be used as the stack
 
-	n	= P.Get_Count();
+	n	= (int)P.Get_Count();
 
 	H.Set_Count(2 * n);
 
