@@ -176,7 +176,7 @@ bool CSnap_Points_to_Features::On_Execute(void)
 		{
 			for(sLong i=0, n=bDistance?pFeatures->Get_Selection_Count():pFeatures->Get_Count(); i<n && 0.<snap_Dist; i++)
 			{
-				CSG_Shape	*pFeature	= bDistance ? pFeatures->Get_Selection(i) : pFeatures->Get_Shape(i);
+				CSG_Shape *pFeature = bDistance ? (CSG_Shape *)pFeatures->Get_Selection(i) : pFeatures->Get_Shape(i);
 
 				switch( pFeatures->Get_Type() )
 				{
