@@ -141,11 +141,11 @@ int CPolygon_Clip::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramet
 //---------------------------------------------------------
 bool CPolygon_Clip::On_Execute(void)
 {
-	CSG_Shapes	Clip, *pClip	= Parameters("CLIP")->asShapes();
+	CSG_Shapes Clip, *pClip = Parameters("CLIP")->asShapes();
 
 	if( Parameters("DISSOLVE")->asBool() && Dissolve(pClip, &Clip) )
 	{
-		pClip	= &Clip;
+		pClip = &Clip;
 	}
 
 	//-----------------------------------------------------
@@ -160,14 +160,14 @@ bool CPolygon_Clip::On_Execute(void)
 	//-----------------------------------------------------
 	else									// multiple input mode
 	{
-		CSG_Parameter_Shapes_List	*pInput		= Parameters("M_INPUT" )->asShapesList();
-		CSG_Parameter_Shapes_List	*pOutput	= Parameters("M_OUTPUT")->asShapesList();
+		CSG_Parameter_Shapes_List  *pInput = Parameters("M_INPUT" )->asShapesList();
+		CSG_Parameter_Shapes_List *pOutput = Parameters("M_OUTPUT")->asShapesList();
 
 		pOutput->Del_Items();
 
 		for(int i=0; i<pInput->Get_Item_Count() && Process_Get_Okay(); i++)
 		{
-			CSG_Shapes	*pShapes	= SG_Create_Shapes();
+			CSG_Shapes *pShapes = SG_Create_Shapes();
 
 			if( Clip_Shapes(pClip, pInput->Get_Shapes(i), pShapes) )
 			{
@@ -190,10 +190,10 @@ bool CPolygon_Clip::Clip_Shapes(CSG_Shapes *pClip, CSG_Shapes *pInput, CSG_Shape
 
 	switch( pInput->Get_Type() )
 	{
-	case SHAPE_TYPE_Point  :	Clip_Points  (pClip, pInput, pOutput);	break;
-	case SHAPE_TYPE_Points :	Clip_Points  (pClip, pInput, pOutput);	break;
-	case SHAPE_TYPE_Line   :	Clip_Lines   (pClip, pInput, pOutput);	break;
-	case SHAPE_TYPE_Polygon:	Clip_Polygons(pClip, pInput, pOutput);	break;
+	case SHAPE_TYPE_Point  : Clip_Points  (pClip, pInput, pOutput);	break;
+	case SHAPE_TYPE_Points : Clip_Points  (pClip, pInput, pOutput);	break;
+	case SHAPE_TYPE_Line   : Clip_Lines   (pClip, pInput, pOutput);	break;
+	case SHAPE_TYPE_Polygon: Clip_Polygons(pClip, pInput, pOutput);	break;
 	}
 
 	return( pOutput->Get_Count() > 0 );
@@ -209,12 +209,12 @@ void CPolygon_Clip::Clip_Points(CSG_Shapes *pClips, CSG_Shapes *pInputs, CSG_Sha
 {
 	for(sLong iClip=0; iClip<pClips->Get_Count() && Set_Progress(iClip, pClips->Get_Count()); iClip++)
 	{
-		CSG_Shape_Polygon	*pClip	= (CSG_Shape_Polygon *)pClips->Get_Shape(iClip);
+		CSG_Shape_Polygon *pClip = (CSG_Shape_Polygon *)pClips->Get_Shape(iClip);
 
 		for(sLong iInput=0; iInput<pInputs->Get_Count(); iInput++)
 		{
-			CSG_Shape	*pInput		= pInputs->Get_Shape(iInput);
-			CSG_Shape	*pOutput	= NULL;
+			CSG_Shape  *pInput = pInputs->Get_Shape(iInput);
+			CSG_Shape *pOutput = NULL;
 
 			for(int iPoint=0; iPoint<pInput->Get_Point_Count(0); iPoint++)
 			{
@@ -222,7 +222,7 @@ void CPolygon_Clip::Clip_Points(CSG_Shapes *pClips, CSG_Shapes *pInputs, CSG_Sha
 				{
 					if( pOutput == NULL )
 					{
-						pOutput	= pOutputs->Add_Shape(pInput, SHAPE_COPY_ATTR);
+						pOutput = pOutputs->Add_Shape(pInput, SHAPE_COPY_ATTR);
 					}
 
 					pOutput->Add_Point(pInput->Get_Point(iPoint, 0));
@@ -242,30 +242,28 @@ void CPolygon_Clip::Clip_Lines(CSG_Shapes *pClips, CSG_Shapes *pInputs, CSG_Shap
 {
 	for(sLong iClip=0; iClip<pClips->Get_Count() && Set_Progress(iClip, pClips->Get_Count()); iClip++)
 	{
-		CSG_Shape_Polygon	*pClip	= (CSG_Shape_Polygon *)pClips->Get_Shape(iClip);
+		CSG_Shape_Polygon *pClip = (CSG_Shape_Polygon *)pClips->Get_Shape(iClip);
 
 		if( pInputs->Select(pClip->Get_Extent()) )
 		{
 			for(sLong iInput=0; iInput<pInputs->Get_Selection_Count(); iInput++)
 			{
-				CSG_Shape	*pNew_Line, *pLine	= pInputs->Get_Selection(iInput);
+				CSG_Shape *pNew_Line, *pLine = (CSG_Shape *)pInputs->Get_Selection(iInput);
 
 				for(int iPart=0, jPart=-1; iPart<pLine->Get_Part_Count(); iPart++)
 				{
-					TSG_Point	B, A	= pLine->Get_Point(0, iPart);
-					bool		bIn		= pClip->Contains(A);
+					TSG_Point B, A = pLine->Get_Point(0, iPart); bool bIn = pClip->Contains(A);
 
 					if( bIn )
 					{
-						pNew_Line	= pOutputs->Add_Shape(pLine, SHAPE_COPY_ATTR);
+						pNew_Line = pOutputs->Add_Shape(pLine, SHAPE_COPY_ATTR);
 
 						pNew_Line->Add_Point(A, ++jPart);
 					}
 
 					for(int iPoint=1; iPoint<pLine->Get_Point_Count(iPart); iPoint++)
 					{
-						B	= A;
-						A	= pLine->Get_Point(iPoint, iPart);
+						B = A; A = pLine->Get_Point(iPoint, iPart);
 
 						if( bIn )
 						{
@@ -277,14 +275,14 @@ void CPolygon_Clip::Clip_Lines(CSG_Shapes *pClips, CSG_Shapes *pInputs, CSG_Shap
 							{
 								pNew_Line->Add_Point(Get_Crossing(pClip, A, B), jPart);
 
-								bIn	= false;
+								bIn = false;
 							}
 						}
 						else if( pClip->Contains(A) )
 						{
 							if( jPart < 0 )
 							{
-								pNew_Line	= pOutputs->Add_Shape(pLine, SHAPE_COPY_ATTR);
+								pNew_Line = pOutputs->Add_Shape(pLine, SHAPE_COPY_ATTR);
 							}
 
 							pNew_Line->Add_Point(Get_Crossing(pClip, A, B), ++jPart);
@@ -302,18 +300,15 @@ void CPolygon_Clip::Clip_Lines(CSG_Shapes *pClips, CSG_Shapes *pInputs, CSG_Shap
 //---------------------------------------------------------
 TSG_Point CPolygon_Clip::Get_Crossing(CSG_Shape_Polygon *pPolygon, const TSG_Point &a, const TSG_Point &b)
 {
-	TSG_Point	c	= a;
+	TSG_Point c = a;
 
 	for(int iPart=0; iPart<pPolygon->Get_Part_Count(); iPart++)
 	{
-		TSG_Point	A, B;
-
-		B	= pPolygon->Get_Point(pPolygon->Get_Point_Count(iPart) - 1, iPart);
+		TSG_Point A, B = pPolygon->Get_Point(pPolygon->Get_Point_Count(iPart) - 1, iPart);
 
 		for(int iPoint=0; iPoint<pPolygon->Get_Point_Count(iPart); iPoint++)
 		{
-			A	= B;
-			B	= pPolygon->Get_Point(iPoint, iPart);
+			A = B; B = pPolygon->Get_Point(iPoint, iPart);
 
 			if( SG_Get_Crossing(c, A, B, a, b) )
 			{
