@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -63,9 +63,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -92,19 +92,20 @@ CShapes_Create_Empty::CShapes_Create_Empty(void)
 	));
 
 	//-----------------------------------------------------
-	Parameters.Add_Shapes_Output("",
-		"SHAPES"	, _TL("Shapes"),
-		_TL("")
+	Parameters.Add_Shapes("",
+		"SHAPES" , _TL("Shapes"),
+		_TL(""),
+		PARAMETER_OUTPUT
 	);
 
 	Parameters.Add_String("",
-		"NAME"		, _TL("Name"),
+		"NAME"   , _TL("Name"),
 		_TL(""),
 		_TL("New Shapes Layer")
 	);
 
 	Parameters.Add_Choice("",
-		"TYPE"		, _TL("Shape Type"),
+		"TYPE"   , _TL("Geometry Type"),
 		_TL(""),
 		CSG_String::Format("%s|%s|%s|%s",
 			_TL("Point"),
@@ -115,39 +116,42 @@ CShapes_Create_Empty::CShapes_Create_Empty(void)
 	);
 
 	Parameters.Add_Choice("",
-		"VERTEX"	, _TL("Vertex Type"),
+		"VERTEX" , _TL("Vertex Type"),
 		_TL(""),
 		CSG_String::Format("%s|%s|%s",
-			_TL("x, y"),
-			_TL("x, y, z"),
-			_TL("x, y, z, m")
+			SG_T("x, y"),
+			SG_T("x, y, z"),
+			SG_T("x, y, z, m")
 		)
 	);
 
+	//-----------------------------------------------------
+	m_CRS.Create(Parameters, "SHAPES");
+
 	//-----------------------------------------------------
 	Parameters.Add_Int("",
-		"NFIELDS"	, _TL("Number of Attributes"),
+		"NFIELDS", _TL("Number of Attributes"),
 		_TL(""),
 		2, 1, true
 	);
 
 	CSG_Parameters *pFields = Parameters.Add_Parameters("",
-		"FIELDS"	, _TL("Attributes"),
+		"FIELDS" , _TL("Attributes"),
 		_TL("")
 	)->asParameters();
 
 	Set_Field_Count(pFields, Parameters("NFIELDS")->asInt());
 
-	(*pFields)(GET_ID_NAME(0))->Set_Value("ID");
-	(*pFields)(GET_ID_TYPE(0))->Set_Value( 3  );
+	(*pFields)(GET_ID_NAME(0))->Set_Value("ID"  );
+	(*pFields)(GET_ID_TYPE(0))->Set_Value( 3    );
 
 	(*pFields)(GET_ID_NAME(1))->Set_Value("Name");
-	(*pFields)(GET_ID_TYPE(1))->Set_Value( 0  );
+	(*pFields)(GET_ID_TYPE(1))->Set_Value( 0    );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -180,12 +184,35 @@ void CShapes_Create_Empty::Set_Field_Count(CSG_Parameters *pFields, int nFields)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+bool CShapes_Create_Empty::On_Before_Execution(void)
+{
+	m_CRS.Activate_GUI();
+
+	if( has_GUI() )
+	{
+		Parameters.Set_Parameter("SHAPES", DATAOBJECT_CREATE);
+	}
+
+	return( CSG_Tool::On_Before_Execution() );
+}
+
+//---------------------------------------------------------
+bool CShapes_Create_Empty::On_After_Execution(void)
+{
+	m_CRS.Deactivate_GUI();
+
+	return( CSG_Tool::On_After_Execution() );
+}
+
 //---------------------------------------------------------
 int CShapes_Create_Empty::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
+	m_CRS.On_Parameter_Changed(pParameters, pParameter);
+
 	if( pParameter->Cmp_Identifier("NFIELDS") )
 	{
 		Set_Field_Count((*pParameters)("FIELDS")->asParameters(), pParameter->asInt());
@@ -196,7 +223,7 @@ int CShapes_Create_Empty::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -214,11 +241,6 @@ bool CShapes_Create_Empty::On_Execute(void)
 	//-----------------------------------------------------
 	CSG_Shapes *pShapes = Parameters("SHAPES")->asShapes();
 
-	if( !pShapes )
-	{
-		Parameters("SHAPES")->Set_Value(pShapes = SG_Create_Shapes());
-	}
-
 	switch( Parameters("TYPE")->asInt() )
 	{
 	default: pShapes->Create(SHAPE_TYPE_Point  , Parameters("NAME")->asString(), NULL, Vertex); break;
@@ -227,6 +249,8 @@ bool CShapes_Create_Empty::On_Execute(void)
 	case  3: pShapes->Create(SHAPE_TYPE_Polygon, Parameters("NAME")->asString(), NULL, Vertex); break;
 	}
 
+	m_CRS.Get_CRS(pShapes->Get_Projection(), true);
+
 	//-----------------------------------------------------
 	CSG_Parameters &Fields = *Parameters("FIELDS")->asParameters();
 
@@ -244,9 +268,9 @@ bool CShapes_Create_Empty::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -276,7 +300,7 @@ CShapes_Create_Copy::CShapes_Create_Copy(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -289,9 +313,9 @@ bool CShapes_Create_Copy::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
