@@ -44,10 +44,10 @@
 
 CSimulateVariableWind::CSimulateVariableWind(void){
 	
-	Set_Name		(_TL("Simulacin (Viento variable)"));
+	Set_Name		(_TL("Simulación (Viento variable)"));
 
 	Set_Description	(_TW(
-		"(c) 2004 by Victor Olaya. Simulacin con viento variable."
+		"(c) 2004 by Victor Olaya. Simulación con viento variable."
 	));
 
 	Parameters.Add_Grid(NULL, 
@@ -70,8 +70,8 @@ CSimulateVariableWind::CSimulateVariableWind(void){
 	
 	Parameters.Add_Grid_List(NULL, 
 							"WINDDIR", 
-							_TL("Direccin del viento"), 
-							_TL("Direccin del viento (grados desde el norte en sentido antihorario)"),
+							_TL("Dirección del viento"), 
+							_TL("Dirección del viento (grados desde el norte en sentido antihorario)"),
 							PARAMETER_INPUT);
 
 	Parameters.Add_Grid(NULL, 
@@ -94,13 +94,13 @@ CSimulateVariableWind::CSimulateVariableWind(void){
 
 	Parameters.Add_Grid(NULL, 
 						"MHERB", 
-						_TL("Humedad del combustible herbceo vivo"), 
+						_TL("Humedad del combustible herbáceo vivo"), 
 						_TL("Fraction (weight of water in sample / dry weight of sample)"), 
 						PARAMETER_INPUT);
 
 	Parameters.Add_Grid(NULL, 
 						"MWOOD", 
-						_TL("Humedad del combustible leoso vivo"), 
+						_TL("Humedad del combustible leñoso vivo"), 
 						_TL("Fraction (weight of water in sample / dry weight of sample)"), 
 						PARAMETER_INPUT);
 	
@@ -151,8 +151,8 @@ CSimulateVariableWind::CSimulateVariableWind(void){
 
 	Parameters.Add_Value(NULL, 
 						"DEFAULTWINDDIR", 
-						_TL("Direccin del viento"), 
-						_TL("Direccin del viento (grados desde el norte)"),
+						_TL("Dirección del viento"), 
+						_TL("Dirección del viento (grados desde el norte)"),
 						PARAMETER_TYPE_Double, 
 						0);
 
@@ -166,14 +166,14 @@ CSimulateVariableWind::CSimulateVariableWind(void){
 	Parameters.Add_Value(NULL, 
 						"COORDX", 
 						_TL("Coordenada X"), 
-						_TL("Coordenada X del punto de ignicin (slo si no se usa grid de puntos de ignicin)"), 
+						_TL("Coordenada X del punto de ignición (sólo si no se usa grid de puntos de ignición)"), 
 						PARAMETER_TYPE_Double, 
 						0);
 
 	Parameters.Add_Value(NULL, 
 						"COORDY", 
 						_TL("Coordenada Y"), 
-						_TL("Coordenada Y del punto de ignicin (slo si no se usa grid de puntos de ignicin)"), 
+						_TL("Coordenada Y del punto de ignición (sólo si no se usa grid de puntos de ignición)"), 
 						PARAMETER_TYPE_Double, 
 						0);
 
@@ -540,10 +540,10 @@ void CSimulateVariableWind::CreateReport(){
 	//	std::locale::global(spanish);
 		strftime(cDate, 80, "%#x", timeinfo);
 
-		sFile += "\t\t\t SIMULACIN realizada el ";
+		sFile += "\t\t\t SIMULACIÓN realizada el ";
 		sFile += cDate;
 		sFile += "\n\t\t ==============================================================================";
-		sFile += "\n\n\t Parmetros de entrada\n";
+		sFile += "\n\n\t Parámetros de entrada\n";
 		sFile += "\t --------------------------------\n\n";
 		sFile += "\t\t Modelos de combustible (por area) \n:  ";
 		for (i = 0; i < 12; i++){
@@ -560,33 +560,33 @@ void CSimulateVariableWind::CreateReport(){
 			sFile	+= SG_Get_String(i * m_fInterval, -1) + " min: " 
 					 + SG_Get_String(m_pMeanWindSpd[i]) + "Km/h\n";
 		}//for
-		sFile += "\t\t Direccin del vector viento, desde el norte geogrfico: \n";
+		sFile += "\t\t Dirección del vector viento, desde el norte geográfico: \n";
 		for(i = 0; i < m_iWindDirGrids; i++){
 			sFile += "\t\t\t * ";
 			sFile += SG_Get_String(i * m_fInterval, -1) + " min: " 
-					+ SG_Get_String(m_pMeanWindDir[i]) + "\n";
+					+ SG_Get_String(m_pMeanWindDir[i]) + "º\n";
 		}//for
 
 		sFile += "\t\t Pendiente del terreno media: ";	sFile += SG_Get_String(m_fSlope) + " %\n";       
-		sFile += "\t\t Orientacin del terreno: ";	sFile += SG_Get_String(m_fAspect) + "\n";
+		sFile += "\t\t Orientación del terreno: ";	sFile += SG_Get_String(m_fAspect) + "º\n";
 		sFile += "\t\t Foco de partida: X = ";	sFile += SG_Get_String(Parameters("COORDX")->asDouble()) + " / Y = "
 				+ SG_Get_String(Parameters("COORDY")->asDouble()) + "\n";
-		sFile += "\t\t Tiempo de simulacin: 3.0 h";
+		sFile += "\t\t Tiempo de simulación: 3.0 h";
 
-		sFile += "\n\n\t Resultado de la simulacin\n";
+		sFile += "\n\n\t Resultado de la simulación\n";
 		sFile += "\t --------------------------------\n\n";	
-		sFile += "\t\t Velocidad de propagacin: ";					sFile += SG_Get_String(m_fMeanSpeed) + " m/min\n";
+		sFile += "\t\t Velocidad de propagación: ";					sFile += SG_Get_String(m_fMeanSpeed) + " m/min\n";
 		sFile += "\t\t Calor por unidad de area: ";					sFile += SG_Get_String(m_fHeatPerUnitArea) + " kJ/m^2\n"; //revisar unidades!!
-		sFile += "\t\t Intensidad de la lnea de fuego: ";			sFile += SG_Get_String(m_fIntensity) + " kCal/m\n";
+		sFile += "\t\t Intensidad de la línea de fuego: ";			sFile += SG_Get_String(m_fIntensity) + " kCal/m\n";
 		sFile += "\t\t Longitud de la llama: ";						sFile += SG_Get_String(m_fFlameHeight) + " m\n";
-		sFile += "\t\t Intensidad de reaccin: ";					sFile += SG_Get_String(m_fReactionIntensity) + " kCal/m2\n";
+		sFile += "\t\t Intensidad de reacción: ";					sFile += SG_Get_String(m_fReactionIntensity) + " kCal/m2\n";
 		sFile += "\t\t Velocidad efectiva del viento: ";			sFile += SG_Get_String(m_fEffectiveWind / KMH2FTMIN) + " Km/h\n";
-		sFile += "\t\t Direccin de mxima propagacin, desde el norte geogrfico: ";	sFile += SG_Get_String(m_fMaxSpreadDir) + "\n";
+		sFile += "\t\t Dirección de máxima propagación, desde el norte geográfico: ";	sFile += SG_Get_String(m_fMaxSpreadDir) + "º\n";
 		sFile += "\t\t Area: ";										sFile += SG_Get_String(m_fArea / 10000) + " ha\n";
-		sFile += "\t\t Permetro: ";								sFile += SG_Get_String(m_fPerimeter) + "m\n";
-		//Razn Longitud/Ancho:                   1.9
-		sFile += "\t\t Distancia de propagacin hacia delante: ";	sFile += SG_Get_String(m_fFrontDistance) + " m\n";
-		sFile += "\t\t Distancia de propagacin hacia atrs: ";		sFile +=  SG_Get_String(m_fRearDistance) + " m\n";
+		sFile += "\t\t Perímetro: ";								sFile += SG_Get_String(m_fPerimeter) + "m\n";
+		//Razón Longitud/Ancho:                   1.9
+		sFile += "\t\t Distancia de propagación hacia delante: ";	sFile += SG_Get_String(m_fFrontDistance) + " m\n";
+		sFile += "\t\t Distancia de propagación hacia atrás: ";		sFile +=  SG_Get_String(m_fRearDistance) + " m\n";
 
 		CSG_File	file;
 
