@@ -985,7 +985,7 @@ CSoilWater_Glugla_Grid::CSoilWater_Glugla_Grid(void)
 
 	Parameters.Add_Grid_List("", "FC"     , _TL("Field Capacity"              ), _TL("[vol.%]"     ), PARAMETER_INPUT_OPTIONAL, false);
 	Parameters.Add_Grid_List("", "PWP"    , _TL("Permanent Wilting Point"     ), _TL("[vol.%]"     ), PARAMETER_INPUT_OPTIONAL, false);
-	Parameters.Add_Grid_List("", "ETMAX"  , _TL("Maxmimum Evapotranspiration" ), _TL("[vol.%/day]" ), PARAMETER_INPUT_OPTIONAL, false);
+	Parameters.Add_Grid_List("", "ETMAX"  , _TL("Maximum Evapotranspiration"  ), _TL("[vol.%/day]" ), PARAMETER_INPUT_OPTIONAL, false);
 //	Parameters.Add_Grid_List("", "ROOTING", _TL("Rooting"                     ), _TL("[% of total]"), PARAMETER_INPUT_OPTIONAL, false);
 
 	Parameters.Add_Grid_or_Const("",
@@ -1258,12 +1258,12 @@ bool CSoilWater_Glugla_Grid::On_Execute(void)
 		{
 			Model.Set_Water(i, Layers[i].asDouble("Water_0"));
 
-			DataObject_Set_Colors(pWater->Get_Grid((int)i), 11, SG_COLORS_COUNT + 9, true);
+			DataObject_Set_Colors(pWater->Get_Grid((int)i), 0, SG_COLORS_COUNT + 9, true);
 		}
 
-		DataObject_Set_Colors(pLitter      , 11, SG_COLORS_COUNT + 9, true);
-		DataObject_Set_Colors(pRecharge    , 11, SG_COLORS_COUNT + 9, true);
-		DataObject_Set_Colors(pRecharge_Sum, 11, SG_COLORS_COUNT + 9, true);
+		DataObject_Set_Colors(pLitter      , 0, SG_COLORS_COUNT + 9, true);
+		DataObject_Set_Colors(pRecharge    , 0, SG_COLORS_COUNT + 9, true);
+		DataObject_Set_Colors(pRecharge_Sum, 0, SG_COLORS_COUNT + 9, true);
 	}
 
 	//-----------------------------------------------------
