@@ -188,7 +188,7 @@ bool Cihacres_elev_cal::On_Execute()
 		//m_pTable->Set_Name("ihacres_elevBands_output");
 		//Parameters("TABLEout")->Set_Value(m_pTable);
 
-		delete[] m_p_elevbands; // smtliche Unter-Pointer noch lschen
+		delete[] m_p_elevbands; // sämtliche Unter-Pointer noch löschen
 		delete[] m_p_pcpField;
 		delete[] m_p_tmpField;
 		delete[] m_p_Q_obs_m3s;
@@ -1380,7 +1380,7 @@ bool Cihacres_elev_cal::_CreateDialog3()
 
 	s.Printf(SG_T("LDAY") , 1-2);
 	P.Add_String(pNode,s,_TL("Last Day"),_TL(""),
-				 m_p_InputTable->Get_Record(m_p_InputTable->Get_Record_Count()-1)->asString(m_dateField));
+				 m_p_InputTable->Get_Record(m_p_InputTable->Get_Count()-1)->asString(m_dateField));
 
 	if( SG_UI_Dlg_Parameters(&P, _TL("Choose Time Range")) )
 	{
