@@ -88,15 +88,10 @@ CGSGrid_Statistics::CGSGrid_Statistics(void)
 		PARAMETER_INPUT_OPTIONAL, false
 	);
 
-	Parameters.Add_Choice("WEIGHTS",
+	Parameters.Add_Grid_Resampling("WEIGHTS",
 		"RESAMPLING", _TL("Resampling"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 0
+		CSG_Grid_Resampling::Interpolations, CSG_Grid_Resampling::NearestNeighbour
 	);
 
 	Parameters.Add_Grid("", "MEAN"    , _TL("Arithmetic Mean"             ), _TL(""), PARAMETER_OUTPUT_OPTIONAL);
@@ -171,15 +166,7 @@ bool CGSGrid_Statistics::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling;
-
-	switch( Parameters("RESAMPLING")->asInt() )
-	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+	CSG_Grid_Resampling Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 	//-----------------------------------------------------
 	#define Get_Output(id) Parameters(id)->asGrid(); if( Parameters(id)->asGrid() ) bHasOutput = true;
