@@ -232,7 +232,7 @@ bool CGW_Multi_Regression_Grid::On_Execute(void)
 		if( m_dimModel.Get_Cellsize() > Get_Cellsize() )	// scaling
 		{
 			m_pPredictors[i] = SG_Create_Grid(m_dimModel);
-			m_pPredictors[i] ->Assign(pPredictors->Get_Grid(i), GRID_RESAMPLING_NearestNeighbour);	// GRID_RESAMPLING_Mean_Cells
+			m_pPredictors[i] ->Assign(pPredictors->Get_Grid(i), CSG_Grid_Resampling::NearestNeighbour);	// CSG_Grid_Resampling::Mean_Cells
 		}
 		else
 		{
@@ -320,7 +320,7 @@ bool CGW_Multi_Regression_Grid::Initialize(CSG_Shapes *pPoints, int iDependent,
 	//-----------------------------------------------------
 	int	iPredictor;
 	
-	TSG_Grid_Resampling Resampling = GRID_RESAMPLING_BSpline;
+	CSG_Grid_Resampling Resampling = CSG_Grid_Resampling::Bicubic_2;
 
 	m_Points.Create   (SHAPE_TYPE_Point);
 	m_Points.Set_Name (Parameters("DEPENDENT")->asString());
@@ -521,7 +521,7 @@ bool CGW_Multi_Regression_Grid::Set_Model(void)
 //---------------------------------------------------------
 bool CGW_Multi_Regression_Grid::Set_Model(double x, double y, double &Value)
 {
-	if( !m_pModel[m_nPredictors]->Get_Value(x, y, Value, GRID_RESAMPLING_BSpline) )
+	if( !m_pModel[m_nPredictors]->Get_Value(x, y, Value, CSG_Grid_Resampling::Bicubic_2) )
 	{
 		return( false );
 	}
@@ -530,8 +530,8 @@ bool CGW_Multi_Regression_Grid::Set_Model(double x, double y, double &Value)
 
 	for(int i=0; i<m_nPredictors; i++)
 	{
-		if( !m_pModel     [i]->Get_Value(x, y, Model    , GRID_RESAMPLING_BSpline)
-		||  !m_pPredictors[i]->Get_Value(x, y, Predictor, GRID_RESAMPLING_NearestNeighbour) )
+		if( !m_pModel     [i]->Get_Value(x, y, Model    , CSG_Grid_Resampling::Bicubic_2)
+		||  !m_pPredictors[i]->Get_Value(x, y, Predictor, CSG_Grid_Resampling::NearestNeighbour) )
 		{
 			return( false );
 		}
