@@ -131,15 +131,9 @@ CPoint_Multi_Grid_Regression::CPoint_Multi_Grid_Regression(void)
 		PARAMETER_OUTPUT_OPTIONAL
 	);
 
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"RESAMPLING"    , _TL("Resampling"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation")
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_Bool("",
@@ -348,15 +342,7 @@ bool CPoint_Multi_Grid_Regression::Get_Samples(CSG_Parameter_Grid_List *pGrids,
 	CSG_Vector Sample(1 + pGrids->Get_Grid_Count() + (bCoord_X ? 1 : 0) + (bCoord_Y ? 1 : 0));
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling;
-
-	switch( Parameters("RESAMPLING")->asInt() )
-	{
-	default: Resampling	= GRID_RESAMPLING_NearestNeighbour;	break;
-	case  1: Resampling	= GRID_RESAMPLING_Bilinear        ;	break;
-	case  2: Resampling	= GRID_RESAMPLING_BicubicSpline   ;	break;
-	case  3: Resampling	= GRID_RESAMPLING_BSpline         ;	break;
-	}
+	CSG_Grid_Resampling Resampling = Parameters("RESAMPLING")->asGrid_Resampling();
 
 	//-----------------------------------------------------
 	for(sLong i=0; i<pPoints->Get_Count() && Set_Progress(i, pPoints->Get_Count()); i++)
@@ -415,14 +401,14 @@ bool CPoint_Multi_Grid_Regression::Set_Regression(CSG_Parameter_Grid_List *pGrid
 	}
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling;
+	CSG_Grid_Resampling	Resampling;
 
 	switch( Parameters("RESAMPLING")->asInt() )
 	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
+	default: Resampling = CSG_Grid_Resampling::NearestNeighbour; break;
+	case  1: Resampling = CSG_Grid_Resampling::Bilinear        ; break;
+	case  2: Resampling = CSG_Grid_Resampling::Bicubic_1   ; break;
+	case  3: Resampling = CSG_Grid_Resampling::Bicubic_2         ; break;
 	}
 
 	//-----------------------------------------------------
@@ -513,14 +499,14 @@ bool CPoint_Multi_Grid_Regression::Set_Residuals(CSG_Shapes *pResiduals)
 	int         Attribute = Parameters("ATTRIBUTE" )->asInt   ();
 	CSG_Grid *pRegression = Parameters("REGRESSION")->asGrid  ();
 
-	TSG_Grid_Resampling	Resampling;
+	CSG_Grid_Resampling	Resampling;
 
 	switch( Parameters("RESAMPLING")->asInt() )
 	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
+	default: Resampling = CSG_Grid_Resampling::NearestNeighbour; break;
+	case  1: Resampling = CSG_Grid_Resampling::Bilinear        ; break;
+	case  2: Resampling = CSG_Grid_Resampling::Bicubic_1   ; break;
+	case  3: Resampling = CSG_Grid_Resampling::Bicubic_2         ; break;
 	}
 
 	//-----------------------------------------------------
