@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -73,7 +73,7 @@ CFlow_AreaUpslope::~CFlow_AreaUpslope(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -142,7 +142,7 @@ CSG_String CFlow_AreaUpslope::Get_Methods(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -235,7 +235,7 @@ bool CFlow_AreaUpslope::Get_Area(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -594,9 +594,9 @@ void CFlow_AreaUpslope::Set_MDInf(int x, int y)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -654,7 +654,7 @@ CFlow_AreaUpslope_Interactive::CFlow_AreaUpslope_Interactive(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -671,7 +671,7 @@ int CFlow_AreaUpslope_Interactive::On_Parameters_Enable(CSG_Parameters *pParamet
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -685,8 +685,9 @@ bool CFlow_AreaUpslope_Interactive::On_Execute(void)
 		Parameters("CONVERGE"   )->asDouble(),
 		Parameters("MFD_CONTOUR")->asBool  ()) )
 	{
-		DataObject_Set_Colors(Parameters("AREA")->asGrid(), 11, SG_COLORS_WHITE_BLUE);
-		DataObject_Update    (Parameters("AREA")->asGrid(), SG_UI_DATAOBJECT_SHOW_MAP);
+		DataObject_Set_Stretch_StdDev(Parameters("AREA")->asGrid(), -1, 2., true, 0, 1., SG_COLORS_WHITE_BLUE);
+		DataObject_Update            (Parameters("AREA")->asGrid(), SG_UI_DATAOBJECT_SHOW_MAP_ACTIVE);
+		Parameters("AREA")->asGrid()->Set_NoData_Value(0.);
 
 		return( true );
 	}
@@ -726,9 +727,9 @@ bool CFlow_AreaUpslope_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG_T
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -803,7 +804,7 @@ CFlow_AreaUpslope_Area::CFlow_AreaUpslope_Area(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -876,7 +877,7 @@ bool CFlow_AreaUpslope_Area::On_Execute(void)
 		{
 			m_Calculator.Get_Area();
 
-			DataObject_Set_Colors(Parameters("AREA")->asGrid(), 11, SG_COLORS_WHITE_BLUE);
+			DataObject_Set_Colors(Parameters("AREA")->asGrid(), 0, SG_COLORS_WHITE_BLUE);
 		}
 	}
 
@@ -888,9 +889,9 @@ bool CFlow_AreaUpslope_Area::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
