@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -178,7 +178,7 @@ CSAGA_Wetness_Index::CSAGA_Wetness_Index(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -190,10 +190,10 @@ bool CSAGA_Wetness_Index::On_Execute(void)
 	m_pAmod  = Parameters("AREA_MOD")->asGrid(); CSG_Grid Amod ; if( !m_pAmod  ) { m_pAmod  = &Amod ; Amod .Create(Get_System()); }
 	m_pTWI   = Parameters("TWI"     )->asGrid();
 
-	DataObject_Set_Colors(m_pArea , 11, SG_COLORS_WHITE_BLUE   );
-	DataObject_Set_Colors(m_pAmod , 11, SG_COLORS_WHITE_BLUE   );
-	DataObject_Set_Colors(m_pSlope, 11, SG_COLORS_GREEN_RED    );
-	DataObject_Set_Colors(m_pTWI  , 11, SG_COLORS_RED_GREY_BLUE);
+	DataObject_Set_Colors(m_pArea , 0, SG_COLORS_WHITE_BLUE       );
+	DataObject_Set_Colors(m_pAmod , 0, SG_COLORS_WHITE_BLUE       );
+	DataObject_Set_Colors(m_pSlope, 0, SG_COLORS_GREEN_YELLOW_RED );
+	DataObject_Set_Colors(m_pTWI  , 0, SG_COLORS_RED_GREY_BLUE    );
 
 	m_pSlope->Set_Unit(_TL("radians"));
 
@@ -217,7 +217,7 @@ bool CSAGA_Wetness_Index::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -238,7 +238,7 @@ double CSAGA_Wetness_Index::Get_Local_Maximum(CSG_Grid *pGrid, int x, int y)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -325,7 +325,7 @@ bool CSAGA_Wetness_Index::Get_Area(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -442,7 +442,7 @@ bool CSAGA_Wetness_Index::Get_Modified(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -500,9 +500,9 @@ bool CSAGA_Wetness_Index::Get_TWI(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -948,13 +948,13 @@ foreach p in SB do
 foreach p in SB do
 {SB[p] = ln(SB[p]);}
 showMatrix(SB);
-/**/
+*/
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
