@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -140,88 +140,63 @@ CTWI::CTWI(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CTWI::On_Execute(void)
 {
-	bool		bTopmodel, bConvert;
-	int			x, y;
-	double		Area, Slope, Kf, Mean_Kf, Mean_TWI;
-	CSG_Grid	*pArea, *pSlope, *pKf, *pTWI;
+	CSG_Grid *pSlope = Parameters("SLOPE" )->asGrid();
+	CSG_Grid *pArea  = Parameters("AREA"  )->asGrid();
+	CSG_Grid *pKf    = Parameters("TRANS" )->asGrid();
+	CSG_Grid *pTWI   = Parameters("TWI"   )->asGrid();
+
+	bool bConvert    = Parameters("CONV"  )->asInt() == 1;
+	bool bTopmodel   = Parameters("METHOD")->asInt() == 1;
+
+	DataObject_Set_Colors(pTWI, 0, SG_COLORS_RED_GREY_BLUE);
 
 	//-----------------------------------------------------
-	pSlope		= Parameters("SLOPE" )->asGrid();
-	pArea		= Parameters("AREA"  )->asGrid();
-	pKf			= Parameters("TRANS" )->asGrid();
-	pTWI		= Parameters("TWI"   )->asGrid();
-
-	bConvert	= Parameters("CONV"  )->asInt() == 1;
-	bTopmodel	= Parameters("METHOD")->asInt() == 1;
-
-	DataObject_Set_Colors(pTWI, 11, SG_COLORS_RED_GREY_BLUE);
-
-	//-----------------------------------------------------
-	Kf			= 1.;
+	double Mean_Kf = 0., Mean_TWI = 0.;
 
 	if( bTopmodel )
 	{
-		Mean_TWI	= 0.;
-		Mean_Kf		= 0.;
-		Area		= 0.;
+		sLong Area = 0;
 
-		for(y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
+		for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 		{
-			for(x=0; x<Get_NX(); x++)
+			for(int x=0; x<Get_NX(); x++)
 			{
 				if( !pArea->is_NoData(x, y) && !pSlope->is_NoData(x, y) )
 				{
-					if( pKf )
+					double Kf = pKf ? 0. : 1.;
+
+					if( pKf && !pKf->is_NoData(x, y) )
 					{
-						if( !pKf->is_NoData(x, y) )
-						{
-							Kf	= pKf->asDouble(x, y);
-
-							if( Kf	< M_FLT_EPSILON )
-								Kf	= M_FLT_EPSILON;
-
-							Kf	= log(Kf);
-						}
-						else
-						{
-							Kf	= 0.;
-						}
+						Kf = pKf->asDouble(x, y); if( Kf < M_FLT_EPSILON ) { Kf = M_FLT_EPSILON; }
+						Kf = log(Kf);
 					}
 
-					Slope	= tan(pSlope->asDouble(x, y));
+					double Slope = tan(pSlope->asDouble(x, y)); if( Slope < M_FLT_EPSILON ) { Slope = M_FLT_EPSILON; }
 
-					if( Slope	< M_FLT_EPSILON )
-						Slope	= M_FLT_EPSILON;
-
-					Area		++;
-					Mean_TWI	+= log((pArea->asDouble(x, y) / (bConvert ? Get_Cellsize() : 1.)) / Slope);
-					Mean_Kf		+= Kf;
+					Area++; Mean_Kf += Kf; Mean_TWI += log((pArea->asDouble(x, y) / (bConvert ? Get_Cellsize() : 1.)) / Slope);
 				}
 			}
 		}
 
-		if( Area > 0. )
-		{
-			Area		*= pArea->Get_Cellarea();
-			Mean_TWI	/= Area;
-			Mean_Kf		/= Area;
-		}
-		else
+		if( Area < 1 )
 		{
 			return( false );
 		}
+
+		Mean_Kf /= Area * pArea->Get_Cellarea(); Mean_TWI /= Area * pArea->Get_Cellarea();
 	}
 
 	//-----------------------------------------------------
-	for(y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
-		for(x=0; x<Get_NX(); x++)
+		#pragma omp parallel for
+		for(int x=0; x<Get_NX(); x++)
 		{
 			if( pArea->is_NoData(x, y) || pSlope->is_NoData(x, y) || (pKf && pKf->is_NoData(x, y)) )
 			{
@@ -229,23 +204,9 @@ bool CTWI::On_Execute(void)
 			}
 			else
 			{
-				Area	= pArea->asDouble(x, y);
-
-				if( bConvert )
-					Area	/= Get_Cellsize();
-
-				Slope	= tan(pSlope->asDouble(x, y));
-
-				if( Slope	< M_FLT_EPSILON )
-					Slope	= M_FLT_EPSILON;
-
-				if( pKf )
-				{
-					Kf	= pKf->asDouble(x, y);
-
-					if( Kf	< M_FLT_EPSILON )
-						Kf	= M_FLT_EPSILON;
-				}
+				double Area  =      pArea->asDouble(x, y)     ; if( bConvert ) { Area /= Get_Cellsize(); }
+				double Slope = tan(pSlope->asDouble(x, y))    ; if( Slope < M_FLT_EPSILON ) { Slope	= M_FLT_EPSILON; }
+				double Kf    =  pKf ? pKf->asDouble(x, y) : 1.; if( Kf    < M_FLT_EPSILON ) { Kf    = M_FLT_EPSILON; }
 
 				pTWI->Set_Value(x, y, bTopmodel
 					? (log(Area / (     Slope)) - Mean_TWI) - (log(Kf) - Mean_Kf)
@@ -260,9 +221,9 @@ bool CTWI::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -314,7 +275,7 @@ CStream_Power::CStream_Power(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -326,7 +287,7 @@ bool CStream_Power::On_Execute(void)
 
 	bool	bConvert	= Parameters("CONV" )->asInt() == 1;
 
-	DataObject_Set_Colors(pSPI, 11, SG_COLORS_RED_GREY_GREEN, true);
+	DataObject_Set_Colors(pSPI, 0, SG_COLORS_RED_GREY_GREEN, true);
 
 	//-----------------------------------------------------
 	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
@@ -350,9 +311,9 @@ bool CStream_Power::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -412,7 +373,7 @@ CCIT::CCIT(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -424,7 +385,7 @@ bool CCIT::On_Execute(void)
 
     bool	bConvert	= Parameters("CONV" )->asInt() == 1;
 
-    DataObject_Set_Colors(pCIT, 11, SG_COLORS_RED_GREY_GREEN, true);
+    DataObject_Set_Colors(pCIT, 0, SG_COLORS_RED_GREY_GREEN, true);
 
     //-----------------------------------------------------
     for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
@@ -448,9 +409,9 @@ bool CCIT::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -566,7 +527,7 @@ CLS_Factor::CLS_Factor(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -584,7 +545,7 @@ bool CLS_Factor::On_Execute(void)
 	m_Erosivity	= Parameters("EROSIVITY")->asInt();
 	m_Stability	= Parameters("STABILITY")->asInt();
 
-	DataObject_Set_Colors(pLS, 11, SG_COLORS_RED_GREY_GREEN, true);
+	DataObject_Set_Colors(pLS, 0, SG_COLORS_RED_GREY_GREEN, true);
 
 	//-----------------------------------------------------
 	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
@@ -689,9 +650,9 @@ inline double CLS_Factor::Get_LS(double Slope, double SCA, bool bFeet)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -736,7 +697,7 @@ CTCI_Low::CTCI_Low(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -747,7 +708,7 @@ bool CTCI_Low::On_Execute(void)
 	CSG_Grid	*pTWI		= Parameters("TWI"     )->asGrid();
 	CSG_Grid	*pTCI_Low	= Parameters("TCILOW"  )->asGrid();
 
-	DataObject_Set_Colors(pTCI_Low, 11, SG_COLORS_RED_GREY_BLUE, false);
+	DataObject_Set_Colors(pTCI_Low, 0, SG_COLORS_RED_GREY_BLUE, false);
 
 	double	dMax	= pDistance->Get_Max();
 	double	dRange	= pDistance->Get_Range();
@@ -780,9 +741,9 @@ bool CTCI_Low::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
