@@ -413,7 +413,7 @@ bool CSolarRadiation::On_Execute(void)
 		pFlat->Add(  *m_pDiffus);	// total irradiation for flat terrain...
 
 		pFlat->Set_Unit("");
-		DataObject_Set_Colors(pFlat, 11, SG_COLORS_RED_GREY_BLUE, true);
+		DataObject_Set_Colors(pFlat, 0, SG_COLORS_RED_GREY_BLUE, true);
 	}
 
 	//-----------------------------------------------------
@@ -487,7 +487,7 @@ bool CSolarRadiation::Finalize(void)
 		pRatio->Assign( m_pDirect);
 		pRatio->Divide(*m_pDiffus);
 
-		DataObject_Set_Colors(pRatio, 11, SG_COLORS_RED_GREY_BLUE, true);
+		DataObject_Set_Colors(pRatio, 0, SG_COLORS_RED_GREY_BLUE, true);
 	}
 
 	//-----------------------------------------------------
@@ -533,9 +533,9 @@ bool CSolarRadiation::Get_Insolation(void)
 	//-----------------------------------------------------
 	case 1:	// One Day
 
-		if( !!(m_pDuration = Parameters("GRD_DURATION")->asGrid()) ) { DataObject_Set_Colors(m_pDuration, 11, SG_COLORS_YELLOW_RED,  true); m_pDuration->Assign_NoData(); m_pDuration->Set_Unit(_TL("h")); }
-		if( !!(m_pSunrise  = Parameters("GRD_SUNRISE" )->asGrid()) ) { DataObject_Set_Colors(m_pSunrise , 11, SG_COLORS_YELLOW_RED, false); m_pSunrise ->Assign_NoData(); m_pSunrise ->Set_Unit(_TL("h")); }
-		if( !!(m_pSunset   = Parameters("GRD_SUNSET"  )->asGrid()) ) { DataObject_Set_Colors(m_pSunset  , 11, SG_COLORS_YELLOW_RED,  true); m_pSunset  ->Assign_NoData(); m_pSunset  ->Set_Unit(_TL("h")); }
+		if( !!(m_pDuration = Parameters("GRD_DURATION")->asGrid()) ) { DataObject_Set_Colors(m_pDuration, 0, SG_COLORS_YELLOW_RED,  true); m_pDuration->Assign_NoData(); m_pDuration->Set_Unit(_TL("h")); }
+		if( !!(m_pSunrise  = Parameters("GRD_SUNRISE" )->asGrid()) ) { DataObject_Set_Colors(m_pSunrise , 0, SG_COLORS_YELLOW_RED, false); m_pSunrise ->Assign_NoData(); m_pSunrise ->Set_Unit(_TL("h")); }
+		if( !!(m_pSunset   = Parameters("GRD_SUNSET"  )->asGrid()) ) { DataObject_Set_Colors(m_pSunset  , 0, SG_COLORS_YELLOW_RED,  true); m_pSunset  ->Assign_NoData(); m_pSunset  ->Set_Unit(_TL("h")); }
 
 		return( Get_Insolation(Date) );
 
@@ -1181,6 +1181,10 @@ void CSolarRadiation::Set_Shade(double x, double y, double z, double dx, double
 //---------------------------------------------------------
 void CSolarRadiation::Set_Shade_Bended(double x, double y, double z, int Shadowing)
 {
+	const double Radius = 6371000; // radius of earth [m]
+
+	double xStart = x, yStart = y;
+
 	for(int ix=(int)x, iy=(int)y; ; )
 	{
 		double dx, dy, dz;
@@ -1192,6 +1196,11 @@ void CSolarRadiation::Set_Shade_Bended(double x, double y, double z, int Shadowi
 
 		x += dx; y += dy; z -= dz;
 
+		//-------------------------------------------------
+		double d = SG_Get_Distance(xStart, yStart, x, y);
+
+		double zSphere = d < Radius ? Radius - sqrt(Radius*Radius - d*d) : Radius;
+
 		//-------------------------------------------------
 		bool bX = dx && fabs(dx) < 1., bY = dy && fabs(dy) < 1.;
 
@@ -1205,7 +1214,7 @@ void CSolarRadiation::Set_Shade_Bended(double x, double y, double z, int Shadowi
 
 		if( !m_pDEM->is_NoData(ix, iy) )
 		{
-			if( z < m_pDEM->asDouble(ix, iy) )
+			if( z < m_pDEM->asDouble(ix, iy) - zSphere )
 			{
 				return;
 			}
