@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -111,7 +111,7 @@ CConvergence_Radius::CConvergence_Radius(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -124,18 +124,18 @@ int CConvergence_Radius::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_P
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CConvergence_Radius::On_Execute(void)
 {
-	CSG_Grid	*pConvergence;
+	m_pDTM = Parameters("ELEVATION")->asGrid();
 
-	m_pDTM			= Parameters("ELEVATION"  )->asGrid();
-	pConvergence	= Parameters("CONVERGENCE")->asGrid();
-	m_bSlope		= Parameters("SLOPE"      )->asBool();
-	m_bDifference	= Parameters("DIFFERENCE" )->asInt() == 0;
+	CSG_Grid *pConvergence = Parameters("CONVERGENCE")->asGrid();
+
+	m_bSlope      = Parameters("SLOPE"      )->asBool();
+	m_bDifference = Parameters("DIFFERENCE" )->asInt() == 0;
 
 	//-----------------------------------------------------
 	m_Cells.Get_Weighting().Set_Parameters(Parameters);
@@ -146,19 +146,19 @@ bool CConvergence_Radius::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	DataObject_Set_Colors(pConvergence, 11, SG_COLORS_RED_GREY_BLUE, true);
+	DataObject_Set_Colors(pConvergence, 0, SG_COLORS_RED_GREY_BLUE, true);
 
 	//-----------------------------------------------------
 	m_Direction.Create(m_Cells.Get_Count());
 
 	for(int i=0; i<m_Cells.Get_Count(); i++)
 	{
-		int	y, x;	double	d, w;
+		int y, x; double d, w;
 
 		if( m_Cells.Get_Values(i, x, y, d, w, false) )
 		{
-			m_Direction[i]	= SG_Get_Angle_Of_Direction(0., 0., x, y);
-			m_Direction[i]	= y != 0 ? (M_PI_180 + atan2((double)x, (double)y)) : (x > 0 ? M_PI_270 : M_PI_090);
+			m_Direction[i] = SG_Get_Angle_Of_Direction(0., 0., x, y);
+			m_Direction[i] = y != 0 ? (M_PI_180 + atan2((double)x, (double)y)) : (x > 0 ? M_PI_270 : M_PI_090);
 		}
 	}
 
@@ -192,11 +192,11 @@ bool CConvergence_Radius::On_Execute(void)
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
 		{
-			double	d;
+			double Convergence;
 
-			if( Get_Convergence(x, y, d) )
+			if( Get_Convergence(x, y, Convergence) )
 			{
-				pConvergence->Set_Value(x, y, d);
+				pConvergence->Set_Value(x, y, Convergence);
 			}
 			else
 			{
@@ -216,7 +216,7 @@ bool CConvergence_Radius::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -227,37 +227,35 @@ bool CConvergence_Radius::Get_Convergence(int x, int y, double &Convergence)
 		return( false );
 	}
 
-	int		i, ix, iy;	double	id, iw, z	= m_pDTM->asDouble(x, y);
-
-	CSG_Simple_Statistics	s;
+	CSG_Simple_Statistics s;
 
 	//-----------------------------------------------------
-	for(i=0; i<m_Cells.Get_Count(); i++)
+	for(int i=0; i<m_Cells.Get_Count(); i++)
 	{
-		if( m_Cells.Get_Values(i, ix = x, iy = y, id, iw, true) && id > 0. && m_Aspect.is_InGrid(ix, iy) )
-		{
-			double	d, Direction	= m_bDifference ? m_Direction[i] : m_Aspect.asDouble(x, y);
+		int ix, iy; double Distance, Weight;
 
-			d		= fmod(m_Aspect.asDouble(ix, iy) - Direction, M_PI_360);
+		if( m_Cells.Get_Values(i, ix = x, iy = y, Distance, Weight, true) && Distance > 0. && m_Aspect.is_InGrid(ix, iy) )
+		{
+			double d = fmod(m_Aspect.asDouble(ix, iy) - (m_bDifference ? m_Direction[i] : m_Aspect.asDouble(x, y)), M_PI_360);
 
 			if( d < -M_PI_180 )
 			{
-				d	+= M_PI_360;
+				d += M_PI_360;
 			}
 			else if( d > M_PI_180 )
 			{
-				d	-= M_PI_360;
+				d -= M_PI_360;
 			}
 
-		//	s.Add_Value(m_bSlope ? fabs(d) * tan(m_Slope(ix, iy)) : fabs(d), iWeight);
-			s.Add_Value(fabs(d), m_bSlope ? iw * tan(m_Slope(ix, iy)) : iw);
+		//	s.Add_Value(m_bSlope ? fabs(d) * tan(m_Slope(ix, iy)) : fabs(d), Weight);
+			s.Add_Value(fabs(d), m_bSlope ? Weight * tan(m_Slope(ix, iy)) : Weight);
 		}
 	}
 
 	//-----------------------------------------------------
 	if( s.Get_Count() > 0 )
 	{
-		Convergence	= (s.Get_Mean() - M_PI_090) * 100. / M_PI_090;
+		Convergence = (s.Get_Mean() - M_PI_090) * 100. / M_PI_090;
 
 		return( true );
 	}
@@ -267,9 +265,9 @@ bool CConvergence_Radius::Get_Convergence(int x, int y, double &Convergence)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
