@@ -168,8 +168,8 @@ bool CMRVBF::On_Execute(void)
 	CSG_Grid	*pMRVBF	= Parameters("MRVBF")->asGrid();
 	CSG_Grid	*pMRRTF	= Parameters("MRRTF")->asGrid();
 
-	DataObject_Set_Colors(pMRVBF, 11, SG_COLORS_RED_GREY_BLUE, false);
-	DataObject_Set_Colors(pMRRTF, 11, SG_COLORS_WHITE_RED    , false);
+	DataObject_Set_Colors(pMRVBF, 0, SG_COLORS_RED_GREY_BLUE, false);
+	DataObject_Set_Colors(pMRRTF, 0, SG_COLORS_WHITE_RED    , false);
 
 	CSG_Grid	CF, VF, RF, DEM, Slopes, Percentiles;
 
@@ -333,7 +333,7 @@ bool CMRVBF::Get_Values(CSG_Grid *pDEM, CSG_Grid *pSlopes, CSG_Grid *pPercentile
 		int	ny	= 2 + (int)(pDEM->Get_YRange() / Resolution);
 
 		pDEM->Create(SG_DATATYPE_Float, nx, ny, Resolution, pDEM->Get_XMin(), pDEM->Get_YMin());
-		pDEM->Assign(&Smoothed, GRID_RESAMPLING_NearestNeighbour);
+		pDEM->Assign(&Smoothed, CSG_Grid_Resampling::NearestNeighbour);
 
 		Get_Percentiles(pDEM, pPercentiles, 6);
 
