@@ -163,7 +163,7 @@ bool CTC_Parameter_Base::Get_Parameter(CSG_Grid *pValues, CSG_Grid *pParameter)
 
 		CSG_Grid	Values(CSG_Grid_System(Cellsize, Get_XMin(), Get_YMin(), Get_XMax(), Get_YMax()), SG_DATATYPE_Float);
 
-		Values.Assign(pValues, GRID_RESAMPLING_Mean_Cells);
+		Values.Assign(pValues, CSG_Grid_Resampling::Mean_Cells);
 
 		for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 		{
@@ -270,7 +270,7 @@ bool CTC_Texture::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	DataObject_Set_Colors(Parameters("TEXTURE")->asGrid(), 5, SG_COLORS_RED_GREY_BLUE, true);
+	DataObject_Set_Colors(Parameters("TEXTURE")->asGrid(), 0, SG_COLORS_RED_GREY_BLUE, true);
 
 	return( Get_Parameter(&Noise, Parameters("TEXTURE")->asGrid()) );
 }
@@ -408,7 +408,7 @@ bool CTC_Convexity::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	DataObject_Set_Colors(Parameters("CONVEXITY")->asGrid(), 5, SG_COLORS_RED_GREY_BLUE, true);
+	DataObject_Set_Colors(Parameters("CONVEXITY")->asGrid(), 0, SG_COLORS_RED_GREY_BLUE, true);
 
 	return( Get_Parameter(&Laplace, Parameters("CONVEXITY")->asGrid()) );
 }
