@@ -50,9 +50,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -119,7 +119,7 @@ CTPI::CTPI(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -132,7 +132,7 @@ int CTPI::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pPara
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -141,7 +141,7 @@ bool CTPI::On_Execute(void)
 	m_pDEM	= Parameters("DEM")->asGrid();
 	m_pTPI	= Parameters("TPI")->asGrid();
 
-	DataObject_Set_Colors(m_pTPI, 11, SG_COLORS_RED_GREY_BLUE, true);
+	DataObject_Set_Colors(m_pTPI, 0, SG_COLORS_RED_GREY_BLUE, true);
 
 	//-----------------------------------------------------
 	double	r_inner	= Parameters("RADIUS")->asRange()->Get_Min() / Get_Cellsize();
@@ -178,7 +178,7 @@ bool CTPI::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -216,9 +216,9 @@ bool CTPI::Get_Statistics(int x, int y)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -285,7 +285,7 @@ CTPI_Classification::CTPI_Classification(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -306,7 +306,7 @@ enum
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -319,7 +319,7 @@ int CTPI_Classification::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_P
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -365,13 +365,11 @@ bool CTPI_Classification::On_Execute(void)
 		Name	+= _TL("High Ridges"       );	Desc	+= _TL("Mountain Tops, High Ridges"            );
 
 		//-------------------------------------------------
-		CSG_Table	*pTable	= pLUT->asTable();
-
 		pLUT->asTable()->Del_Records();
 
 		for(int i=0; i<LF_COUNT; i++)
 		{
-			CSG_Table_Record	*pRecord	= pLUT->asTable()->Add_Record();
+			CSG_Table_Record *pRecord = pLUT->asTable()->Add_Record();
 
 			pRecord->Set_Value(0, LF_Colors[i]);
 			pRecord->Set_Value(1, Name[i].c_str());
@@ -494,9 +492,9 @@ bool CTPI_Classification::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -580,7 +578,7 @@ CTPI_MultiScale::CTPI_MultiScale(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -629,7 +627,7 @@ int CTPI_MultiScale::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Param
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -713,9 +711,9 @@ bool CTPI_MultiScale::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
