@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -160,16 +160,16 @@ CWind_Effect::CWind_Effect(void)
 		false
 	);
 
-/*	Parameters.Add_Bool("",
-		"TRACE"		, _TL("Precise Tracing"),
-		_TL(""),
-		false
-	);/**/
+//	Parameters.Add_Bool("",
+//		"TRACE"		, _TL("Precise Tracing"),
+//		_TL(""),
+//		false
+//	);
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -200,7 +200,7 @@ int CWind_Effect::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramete
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -359,7 +359,7 @@ bool CWind_Effect::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -396,7 +396,7 @@ inline bool CWind_Effect::Get_Next(TSG_Point &Position, double Distance, bool bR
 
 			Distance	-= d;
 		}
-	/**/
+	*/
 
 		if( !m_DX.Get_Value(Position, dx) || !m_DY.Get_Value(Position, dy) )
 		{
@@ -436,7 +436,7 @@ inline bool CWind_Effect::Get_Z(const TSG_Point &Position, double Distance, doub
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -508,7 +508,7 @@ void CWind_Effect::Get_Lee(int x, int y, double &Sum_A, double &Sum_B)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -558,9 +558,9 @@ void CWind_Effect::Get_Lee_Old(int x, int y, double dx, double dy, double &Sum_A
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -635,7 +635,7 @@ CWind_Exposition::CWind_Exposition(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -652,7 +652,7 @@ int CWind_Exposition::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Para
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -727,9 +727,9 @@ bool CWind_Exposition::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
