@@ -57,9 +57,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -70,15 +70,14 @@ class CCell
 {
 public:
 
-	int		m_x, m_y, m_backLink;	double	m_Cost;
+	int m_x = 0, m_y = 0, m_backLink = 0; double m_Cost = 0.;
 
-	CCell(void)
-		: m_x(0), m_y(0), m_Cost(0.), m_backLink(0)
-	{}
+	CCell(void) {} virtual ~CCell(void) {}
 
 	CCell(int x, int y, double Cost, int backLink)
-		: m_x(x), m_y(y), m_Cost(Cost), m_backLink(backLink % 8)
-	{}
+	{
+		m_x = x; m_y = y; m_Cost = Cost; m_backLink = backLink % 8;
+	}
 
 	virtual int		Compare			(const CCell &Cell)
 	{
@@ -100,9 +99,9 @@ public:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -161,7 +160,7 @@ CBreach_Depressions::CBreach_Depressions(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -172,7 +171,7 @@ int CBreach_Depressions::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_P
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -460,7 +459,7 @@ bool CBreach_Depressions::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -489,9 +488,9 @@ bool CBreach_Depressions::is_Pit(CSG_Grid *pDEM, int x, int y)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -524,7 +523,7 @@ import whitebox.interfaces.WhiteboxPlugin;
 import whitebox.interfaces.WhiteboxPluginHost;
 import whitebox.utilities.FileUtilities;
 
-/**
+// **
 * This tool can be used to pre-process a digital elevation model (DEM) prior to being used for hydrological analysis.
 *
 * @author Dr. John Lindsay email: jlindsay@uoguelph.ca
@@ -534,7 +533,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 	private WhiteboxPluginHost myHost = null;
 	private String[] args;
 
-	/**
+	// **
 	* Used to retrieve the plugin tool's name. This is a short, unique name
 	* containing no spaces.
 	*
@@ -545,7 +544,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		return "BreachDepressions";
 	}
 
-	/**
+	// **
 	* Used to retrieve the plugin tool's descriptive name. This can be a longer
 	* name (containing spaces) and is used in the interface to list the tool.
 	*
@@ -556,7 +555,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		return "Breach Depressions";
 	}
 
-	/**
+	// **
 	* Used to retrieve a short description of what the plugin tool does.
 	*
 	* @return String containing the plugin's description.
@@ -566,7 +565,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		return "Remove all depressions in a DEM by breaching.";
 	}
 
-	/**
+	// **
 	* Used to identify which toolboxes this plugin tool should be listed in.
 	*
 	* @return Array of Strings.
@@ -577,7 +576,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		return ret;
 	}
 
-	/**
+	// **
 	* Sets the WhiteboxPluginHost to which the plugin tool is tied. This is the
 	* class that the plugin will send all feedback messages, progress updates,
 	* and return objects.
@@ -589,7 +588,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		myHost = host;
 	}
 
-	/**
+	// **
 	* Used to communicate feedback pop-up messages between a plugin tool and
 	* the main Whitebox user-interface.
 	*
@@ -603,7 +602,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		}
 	}
 
-	/**
+	// **
 	* Used to communicate a return object from a plugin tool to the main
 	* Whitebox user-interface.
 	*
@@ -617,7 +616,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 	private int previousProgress = 0;
 	private String previousProgressLabel = "";
 
-	/**
+	// **
 	* Used to communicate a progress update between a plugin tool and the main
 	* Whitebox user interface.
 	*
@@ -633,7 +632,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		previousProgressLabel = progressLabel;
 	}
 
-	/**
+	// **
 	* Used to communicate a progress update between a plugin tool and the main
 	* Whitebox user interface.
 	*
@@ -646,7 +645,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		previousProgress = progress;
 	}
 
-	/**
+	// **
 	* Sets the arguments (parameters) used by the plugin.
 	*
 	* @param args An array of string arguments.
@@ -657,7 +656,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 	}
 	private boolean cancelOp = false;
 
-	/**
+	// **
 	* Used to communicate a cancel operation from the Whitebox GUI.
 	*
 	* @param cancel Set to true if the plugin should be canceled.
@@ -673,7 +672,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 	}
 	private boolean amIActive = false;
 
-	/**
+	// **
 	* Used by the Whitebox GUI to tell if this plugin is still running.
 	*
 	* @return a boolean describing whether or not the plugin is actively being
@@ -684,7 +683,7 @@ public class BreachDepressions implements WhiteboxPlugin {
 		return amIActive;
 	}
 
-	/**
+	// **
 	* Used to execute this plugin tool.
 	*//*
 	@Override
@@ -1192,9 +1191,9 @@ public class BreachDepressions implements WhiteboxPlugin {
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
