@@ -104,15 +104,9 @@ CGrid_Cross_Profiles::CGrid_Cross_Profiles(void)
 		11, 3, true
 	);
 
-	Parameters.Add_Choice("",
+	Parameters.Add_Grid_Resampling("",
 		"INTERPOLATION"	, _TL("Interpolation"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"           ),
-			_TL("Bilinear Interpolation"      ),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation"      )
-		), 3
+		_TL("")
 	);
 
 	Parameters.Add_Choice("",
@@ -176,13 +170,7 @@ bool CGrid_Cross_Profiles::On_Execute(void)
 
 	m_pDEM	= Parameters("DEM")->asGrid();
 
-	switch( Parameters("INTERPOLATION")->asInt() )
-	{
-	default: m_Interpolation = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: m_Interpolation = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: m_Interpolation = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: m_Interpolation = GRID_RESAMPLING_BSpline         ; break;
-	}
+	m_Interpolation = Parameters("INTERPOLATION")->asGrid_Resampling();
 
 	//-----------------------------------------------------
 	m_pProfiles	= Parameters("PROFILES")->asShapes();
