@@ -295,9 +295,11 @@ bool CSHALSTAB::On_Execute(void)
 					pH->Set_Value(x, y, CR_NODATA);
 			}
 
-			else if ((pCmin || pCmax || pDmin || pDmax || pEmin || pEmax || pFmin || pFmax || pJmin || pJmax) &&
-				(pCmin && pCmax->is_NoData(x, y) || pDmin && pDmax->is_NoData(x, y) || pEmin && pEmax->is_NoData(x, y) ||
-				pFmin && pFmax->is_NoData(x, y) || pJmin && pJmax->is_NoData(x, y)))
+			else if( (pCmin && pCmax->is_NoData(x, y))
+			      || (pDmin && pDmax->is_NoData(x, y))
+			      || (pEmin && pEmax->is_NoData(x, y))
+			      || (pFmin && pFmax->is_NoData(x, y))
+			      || (pJmin && pJmax->is_NoData(x, y)) )
 			{
 				pG->Set_NoData(x, y);
 
