@@ -265,12 +265,11 @@ bool CSafetyfactor::On_Execute(void)
 					pH->Set_Value(x, y, FS_NODATA);
 			}
 
-			else if( (pBmin || pBmax || pCmin || pCmax || pDmin || pDmax || pEmin || pEmax || pFmin || pFmax)
-			&&	(  pBmin && pBmax->is_NoData(x, y)
-				|| pCmin && pCmax->is_NoData(x, y)
-				|| pDmin && pDmax->is_NoData(x, y)
-				|| pEmin && pEmax->is_NoData(x, y)
-				|| pFmin && pFmax->is_NoData(x, y) ))
+			else if( (pBmin && pBmin->is_NoData(x, y)) || (pBmax && pBmax->is_NoData(x, y))
+			      || (pCmin && pCmin->is_NoData(x, y)) || (pCmax && pCmax->is_NoData(x, y))
+			      || (pDmin && pDmin->is_NoData(x, y)) || (pDmax && pDmax->is_NoData(x, y))
+			      || (pEmin && pEmin->is_NoData(x, y)) || (pEmax && pEmax->is_NoData(x, y))
+			      || (pFmin && pFmin->is_NoData(x, y)) || (pFmax && pFmax->is_NoData(x, y)) )
 			{
 				pG->Set_NoData(x, y);
 
