@@ -633,15 +633,9 @@ C3D_Viewer_Globe_Grid::C3D_Viewer_Globe_Grid(void)
 		0.25, 0.001, true
 	);
 
-	Parameters.Add_Choice("RESAMPLING",
+	Parameters.Add_Grid_Resampling("RESAMPLING",
 		"INTERPOLATION", _TL("Interpolation"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
-			_TL("Nearest Neighbour"           ),
-			_TL("Bilinear Interpolation"      ),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation"      )
-		), 3
+		_TL("")
 	);
 }
 
@@ -689,15 +683,7 @@ bool C3D_Viewer_Globe_Grid::On_Execute(void)
 	//-----------------------------------------------------
 	if( Parameters("RESAMPLING")->asInt() == 1 )
 	{
-		TSG_Grid_Resampling Resampling;
-
-		switch( Parameters("INTERPOLATION")->asInt() )
-		{
-		default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-		case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-		case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-		case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-		}
+		CSG_Grid_Resampling Resampling = Parameters("INTERPOLATION")->asGrid_Resampling();
 
 		CSG_Grid_System System(Parameters("RESOLUTION")->asDouble(), Get_System().Get_Extent());
 
