@@ -76,6 +76,7 @@ public:
 
 protected:
 
+	virtual int					On_Parameter_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 	virtual int					On_Parameters_Enable	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 
 	virtual void				Update_Statistics		(void);
@@ -100,7 +101,9 @@ private:
 	CSG_Grid					m_Plane[3];
 
 	CSG_Grids					*m_pGrids;
-	
+
+
+	bool						Adjust_Color_Stretch	(CSG_Parameters &Parameters);
 
 	bool						Inc_ZScale				(double Scale);
 	bool						Set_ZLevel				(bool bIncrease);
@@ -153,17 +156,10 @@ C3D_Viewer_Grids_Panel::C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGr
 		m_pGrids->Get_Extent().Get_Diameter() / 10, true
 	);
 
-	m_Parameters.Add_Choice("RESOLUTION_XY",
+	m_Parameters.Add_Grid_Resampling("RESOLUTION_XY",
 		"RESAMPLING_XY"	, _TL("Resampling"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s",
-			_TL("Nearest Neighbour"),
-			_TL("Bilinear Interpolation"),
-			_TL("Bicubic Spline Interpolation"),
-			_TL("B-Spline Interpolation"),
-			_TL("Mean Value"),
-			_TL("Mean Value (cell area weighted)")
-		), 0
+		(CSG_Grid_Resampling)((int)CSG_Grid_Resampling::Interpolations|(int)CSG_Grid_Resampling::Means), CSG_Grid_Resampling::NearestNeighbour
 	);
 
 	m_Parameters.Add_Int("GENERAL",
@@ -177,8 +173,8 @@ C3D_Viewer_Grids_Panel::C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGr
 		_TL(""),
 		CSG_String::Format("%s|%s|%s",
 			_TL("Nearest Neighbour"),
-			_TL("Linear Interpolation"),
-			_TL("Spline Interpolation")
+			_TL("Linear"),
+			_TL("Cubic")
 		), 1
 	);
 
@@ -188,16 +184,21 @@ C3D_Viewer_Grids_Panel::C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGr
 		m_Colors.Set_Palette(SG_COLORS_RAINBOW);
 	}
 
-	m_Parameters.Add_Colors("GENERAL", "COLORS"       , _TL("Colors"           ), _TL(""), &m_Colors);
-	m_Parameters.Add_Bool  ("COLORS" , "COLORS_GRAD"  , _TL("Graduated"        ), _TL(""), true);
-	m_Parameters.Add_Range ("COLORS" , "COLORS_RANGE" , _TL("Histogram Stretch"), _TL(""),
-		m_pGrids->Get_Mean() - 2. * m_pGrids->Get_StdDev(),
-		m_pGrids->Get_Mean() + 2. * m_pGrids->Get_StdDev()
-	);
+	m_Parameters.Set_Callback(false);
+	m_Parameters.Add_Colors("GENERAL"       , "COLORS"        , _TL("Colors"            ), _TL(""), &m_Colors);
+	m_Parameters.Add_Bool  ("COLORS"        , "COLORS_GRAD"   , _TL("Graduated"         ), _TL(""), true);
+	m_Parameters.Add_Choice("COLORS"        , "COLORS_STRETCH", _TL("Adjustment"        ), _TL(""), CSG_String::Format("%s|%s|%s|%s", _TL("Linear"), _TL("Standard Deviation"), _TL("Percent Clip"), _TL("Manual")), 2);
+	m_Parameters.Add_Range ("COLORS_STRETCH", "COLORS_RANGE"  , _TL("Stretch Range"     ), _TL(""), m_pGrids->Get_Percentile(2.), m_pGrids->Get_Percentile(98.));
+	m_Parameters.Add_Range ("COLORS_STRETCH", "COLORS_LINEAR" , _TL("Linear"            ), _TL(""), 5., 95., 0., true, 100., true);
+	m_Parameters.Add_Double("COLORS_STRETCH", "COLORS_STDDEV" , _TL("Standard Deviation"), _TL(""), 2., 0.1, true);
+	m_Parameters.Add_Bool  ("COLORS_STDDEV" , "COLORS_INRANGE", _TL("Keep in Range"     ), _TL(""), false);
+	m_Parameters.Add_Range ("COLORS_STRETCH", "COLORS_PERCENT", _TL("Percent Clip"      ), _TL(""), 2., 98., 0., true, 100., true);
+	m_Parameters.Set_Callback(true);
 
-	m_Parameters.Add_Choice("GENERAL", "SHADING"      , _TL("Light Source"     ), _TL(""), CSG_String::Format("%s|%s", _TL("no"), _TL("yes")), 1);
-	m_Parameters.Add_Double("SHADING", "SHADE_DEC"    , _TL("Height"           ), _TL(""), 45., -90., true, 90., true);
-	m_Parameters.Add_Double("SHADING", "SHADE_AZI"    , _TL("Direction"        ), _TL(""), 45., -90., true, 90., true);
+	//-----------------------------------------------------
+	m_Parameters.Add_Choice("GENERAL"       , "SHADING"       , _TL("Light Source"      ), _TL(""), CSG_String::Format("%s|%s", _TL("no"), _TL("yes")), 1);
+	m_Parameters.Add_Double("SHADING"       , "SHADE_DEC"     , _TL("Height"            ), _TL(""), 45., -90., true, 90., true);
+	m_Parameters.Add_Double("SHADING"       , "SHADE_AZI"     , _TL("Direction"         ), _TL(""), 45., -90., true, 90., true);
 
 	//-----------------------------------------------------
 	m_Parameters("Z_SCALE")->Set_Value(0.2 * (m_pGrids->Get_XRange() + m_pGrids->Get_YRange()) / m_pGrids->Get_ZRange());
@@ -223,6 +224,21 @@ C3D_Viewer_Grids_Panel::C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGr
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+int C3D_Viewer_Grids_Panel::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("COLORS_STRETCH")
+	||  pParameter->Cmp_Identifier("COLORS_LINEAR" )
+	||  pParameter->Cmp_Identifier("COLORS_STDDEV" )
+	||  pParameter->Cmp_Identifier("COLORS_INRANGE")
+	||  pParameter->Cmp_Identifier("COLORS_PERCENT") )
+	{
+		Adjust_Color_Stretch(*pParameters);
+	}
+
+	return( CSG_3DView_Panel::On_Parameter_Changed(pParameters, pParameter) );
+}
+
 //---------------------------------------------------------
 int C3D_Viewer_Grids_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
@@ -231,10 +247,60 @@ int C3D_Viewer_Grids_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CS
 		pParameter->Set_Children_Enabled(pParameter->asInt() > 0);
 	}
 
+	if( pParameter->Cmp_Identifier("COLORS_STRETCH") )
+	{
+		pParameters->Set_Enabled("COLORS_LINEAR" , pParameter->asInt() == 0);
+		pParameters->Set_Enabled("COLORS_STDDEV" , pParameter->asInt() == 1);
+		pParameters->Set_Enabled("COLORS_PERCENT", pParameter->asInt() == 2);
+		pParameters->Set_Enabled("COLORS_RANGE"  , pParameter->asInt() == 3);
+	}
+
 	return( CSG_3DView_Panel::On_Parameters_Enable(pParameters, pParameter) );
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool C3D_Viewer_Grids_Panel::Adjust_Color_Stretch(CSG_Parameters &Parameters)
+{
+	double Minimum = 0., Maximum = 0.;
+
+	switch( Parameters["COLORS_STRETCH"].asInt() )
+	{
+	case  0: // linear
+		Minimum = m_pGrids->Get_Min() + m_pGrids->Get_Range() * Parameters["COLORS_LINEAR.MIN"].asDouble() / 100.;
+		Maximum = m_pGrids->Get_Min() + m_pGrids->Get_Range() * Parameters["COLORS_LINEAR.MAX"].asDouble() / 100.;
+		break;
+
+	case  1: // standard deviation
+		Minimum = m_pGrids->Get_Mean() - m_pGrids->Get_StdDev() * Parameters["COLORS_STDDEV"].asDouble(); if( Parameters["COLORS_INRANGE"].asBool() && Minimum < m_pGrids->Get_Min() ) { Minimum = m_pGrids->Get_Min(); }
+		Maximum = m_pGrids->Get_Mean() + m_pGrids->Get_StdDev() * Parameters["COLORS_STDDEV"].asDouble(); if( Parameters["COLORS_INRANGE"].asBool() && Maximum > m_pGrids->Get_Max() ) { Maximum = m_pGrids->Get_Max(); }
+		break;
+
+	case  2: // percent clip
+		Minimum = m_pGrids->Get_Percentile(Parameters["COLORS_PERCENT.MIN"].asDouble());
+		Maximum = m_pGrids->Get_Percentile(Parameters["COLORS_PERCENT.MAX"].asDouble());
+		break;
+
+	default: // manual
+		break;
+	}
+
+	if( Minimum < Maximum )
+	{
+		Parameters["COLORS_RANGE.MIN"].Set_Value(Minimum);
+		Parameters["COLORS_RANGE.MAX"].Set_Value(Maximum);
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -478,24 +544,16 @@ bool C3D_Viewer_Grids_Panel::Set_Plane(CSG_Grid &Plane, double Position, int Sid
 	int zLevels = m_Parameters("RESOLUTION_Z")->asInt();
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling zResampling, Resampling;
+	CSG_Grid_Resampling zResampling, Resampling;
 
 	switch( m_Parameters("RESAMPLING_Z")->asInt() )
 	{
-	default: zResampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: zResampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: zResampling = GRID_RESAMPLING_BSpline         ; break;
+	default: zResampling = CSG_Grid_Resampling::NearestNeighbour; break;
+	case  1: zResampling = CSG_Grid_Resampling::Bilinear        ; break;
+	case  2: zResampling = CSG_Grid_Resampling::Bicubic_2         ; break;
 	}
 
-	switch( m_Parameters("RESAMPLING_XY")->asInt() )
-	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-	case  4: Resampling = GRID_RESAMPLING_Mean_Nodes      ; break;
-	case  5: Resampling = GRID_RESAMPLING_Mean_Cells      ; break;
-	}
+	Resampling = m_Parameters("RESAMPLING_XY")->asGrid_Resampling();
 
 	switch( Side )
 	{
@@ -741,6 +799,7 @@ public:
 		Set_Histogram(false);
 	}
 
+	void					Update_Histogram	(void)	{	Set_Histogram(false);	}
 
 private:
 
@@ -807,6 +866,8 @@ private:
 					Minimum + (m_Mouse_Move.x * Range / GetClientSize().GetWidth())
 				);
 
+				m_pPanel->m_Parameters("COLORS_STRETCH")->Set_Value(3); // => manual
+
 				m_Mouse_Down = m_Mouse_Move = wxPoint(0, 0);
 
 				Set_Histogram();
@@ -831,6 +892,8 @@ private:
 		{
 			m_pPanel->m_Parameters("COLORS_RANGE")->asRange()->Set_Range(m_pGrids->Get_Min(), m_pGrids->Get_Max());
 
+			m_pPanel->m_Parameters("COLORS_STRETCH")->Set_Value(3); // => manual
+
 			Set_Histogram();
 		}
 	}
@@ -871,7 +934,7 @@ private:
 		double Minimum = m_pPanel->m_Parameters("COLORS_RANGE.MIN")->asDouble();
 		double Maximum = m_pPanel->m_Parameters("COLORS_RANGE.MAX")->asDouble();
 
-		m_Histogram.Create(m_nClasses, Minimum, Maximum, m_pGrids, m_pGrids->Get_Max_Samples());
+		m_Histogram.Create(m_nClasses, m_pGrids, Minimum, Maximum, m_pGrids->Get_Max_Samples());
 
 		if( bFullRefresh )
 		{
@@ -1216,7 +1279,7 @@ protected:
 		m_pShade[0]->Set_Value(m_pPanel->m_Parameters("SHADE_DEC")->asDouble());
 		m_pShade[1]->Set_Value(m_pPanel->m_Parameters("SHADE_AZI")->asDouble());
 
-		m_pHistogram->Refresh();
+		m_pHistogram->Update_Histogram();
 		m_pLegend   ->Refresh();
 
 	#ifndef HISTOGRAM_AS_PANEL
