@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -82,7 +82,7 @@ protected:
 	virtual bool				On_Before_Draw			(void);
 	virtual bool				On_Draw					(void);
 
-	virtual int					Get_Color				(double Value, double z);
+	virtual int					Get_Color				(double Value, double Dim);
 
 
 private:
@@ -109,7 +109,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -119,7 +119,7 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -197,7 +197,7 @@ C3D_Viewer_PointCloud_Panel::C3D_Viewer_PointCloud_Panel(wxWindow *pParent, CSG_
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -250,7 +250,7 @@ int C3D_Viewer_PointCloud_Panel::On_Parameters_Enable(CSG_Parameters *pParameter
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -387,7 +387,7 @@ void C3D_Viewer_PointCloud_Panel::Update_Parent(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -423,7 +423,7 @@ void C3D_Viewer_PointCloud_Panel::On_Key_Down(wxKeyEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -439,11 +439,11 @@ bool C3D_Viewer_PointCloud_Panel::On_Before_Draw(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int C3D_Viewer_PointCloud_Panel::Get_Color(double Value, double z)
+int C3D_Viewer_PointCloud_Panel::Get_Color(double Value, double Dim)
 {
 	int	Color = -1;
 
@@ -483,11 +483,11 @@ int C3D_Viewer_PointCloud_Panel::Get_Color(double Value, double z)
 	//-----------------------------------------------------
 	if( m_Color_Dim_Min < m_Color_Dim_Max )
 	{
-		double dim = 1. - (z - m_Color_Dim_Min) / (m_Color_Dim_Max - m_Color_Dim_Min);
+		Dim = 1. - (Dim - m_Color_Dim_Min) / (m_Color_Dim_Max - m_Color_Dim_Min);
 
-		if( dim < 1. )
+		if( Dim < 1. )
 		{
-			Color = Dim_Color(Color, dim < 0.1 ? 0.1 : dim);
+			Color = Dim_Color(Color, Dim < 0.1 ? 0.1 : Dim);
 		}
 	}
 
@@ -496,7 +496,7 @@ int C3D_Viewer_PointCloud_Panel::Get_Color(double Value, double z)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -577,9 +577,9 @@ bool C3D_Viewer_PointCloud_Panel::On_Draw(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -894,9 +894,9 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1100,9 +1100,9 @@ void C3D_Viewer_PointCloud_Dialog::On_Menu_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1131,7 +1131,7 @@ C3D_Viewer_PointCloud::C3D_Viewer_PointCloud(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1142,7 +1142,7 @@ int C3D_Viewer_PointCloud::On_Parameter_Changed(CSG_Parameters *pParameters, CSG
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1215,9 +1215,9 @@ bool C3D_Viewer_PointCloud::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
