@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -85,7 +85,7 @@ protected:
 	virtual bool				On_Before_Draw			(void);
 	virtual bool				On_Draw					(void);
 
-	virtual int					Get_Color				(double Value, double z);
+	virtual int					Get_Color				(double Value, double Dim);
 
 
 private:
@@ -118,7 +118,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -128,7 +128,7 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -200,7 +200,7 @@ bool C3D_Viewer_Scatterplot_Panel::On_Construction(int MaxBins)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -216,7 +216,7 @@ int C3D_Viewer_Scatterplot_Panel::On_Parameters_Enable(CSG_Parameters *pParamete
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -429,7 +429,7 @@ void C3D_Viewer_Scatterplot_Panel::Update_Parent(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -465,7 +465,7 @@ void C3D_Viewer_Scatterplot_Panel::On_Key_Down(wxKeyEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -481,11 +481,11 @@ bool C3D_Viewer_Scatterplot_Panel::On_Before_Draw(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int C3D_Viewer_Scatterplot_Panel::Get_Color(double Value, double z)
+int C3D_Viewer_Scatterplot_Panel::Get_Color(double Value, double Dim)
 {
 	int	Color;
 
@@ -503,11 +503,11 @@ int C3D_Viewer_Scatterplot_Panel::Get_Color(double Value, double z)
 	//-----------------------------------------------------
 	if( m_Color_Dim_Min < m_Color_Dim_Max )
 	{
-		double dim = 1. - (z - m_Color_Dim_Min) / (m_Color_Dim_Max - m_Color_Dim_Min);
+		Dim = 1. - (Dim - m_Color_Dim_Min) / (m_Color_Dim_Max - m_Color_Dim_Min);
 
-		if( dim < 1. )
+		if( Dim < 1. )
 		{
-			Color = Dim_Color(Color, dim < 0.1 ? 0.1 : dim);
+			Color = Dim_Color(Color, Dim < 0.1 ? 0.1 : Dim);
 		}
 	}
 
@@ -516,7 +516,7 @@ int C3D_Viewer_Scatterplot_Panel::Get_Color(double Value, double z)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -573,9 +573,9 @@ bool C3D_Viewer_Scatterplot_Panel::On_Draw(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -760,9 +760,9 @@ void C3D_Viewer_Scatterplot_Dialog::On_Menu_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -803,7 +803,7 @@ C3D_Viewer_Scatterplot::C3D_Viewer_Scatterplot(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -825,7 +825,7 @@ int C3D_Viewer_Scatterplot::On_Parameters_Enable(CSG_Parameters *pParameters, CS
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -859,9 +859,9 @@ bool C3D_Viewer_Scatterplot::On_Execute(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
