@@ -164,7 +164,7 @@ void C3D_Viewer_Shapes_Panel::Update_Statistics(void)
 
 		for(sLong i=0; i<m_pShapes->Get_Selection_Count(); i++)
 		{
-			CSG_Shape *pShape = m_pShapes->Get_Selection(i);
+			CSG_Shape *pShape = (CSG_Shape *)m_pShapes->Get_Selection(i);
 
 			for(int iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
 			{
@@ -255,7 +255,7 @@ bool C3D_Viewer_Shapes_Panel::On_Draw(void)
 	{
 		for(sLong iShape=0; iShape<m_pShapes->Get_Selection_Count(); iShape++)
 		{
-			Draw_Shape(m_pShapes->Get_Selection(iShape), Field);
+			Draw_Shape((CSG_Shape *)m_pShapes->Get_Selection(iShape), Field);
 		}
 	}
 	else
